
import numpy as np


class Lebedev(object):

    def __init__(
        self,
        order,
        xyzw,
        ):

        self.order = order
        self.xyzw = xyzw

    @property
    def N(self):
        return self.xyzw.shape[0]

    @property
    def xyz(self):
        return self.xyzw[:,:3]
    
    @property
    def x(self):
        return self.xyzw[:,0]

    @property
    def y(self):
        return self.xyzw[:,1]

    @property
    def z(self):
        return self.xyzw[:,2]

    @property
    def w(self):
        return self.xyzw[:,3]

    @property
    def phi(self):
        return np.arctan2(self.xyzw[:,1], self.xyzw[:,0])

    @property
    def theta(self):
        return np.arccos(self.xyzw[:,2])

    @property
    def r(self):
        return np.sqrt(self.x**2 + self.y**2 + self.z**2)

    @property
    def is_positive(self):
        return np.all(self.w >= 0.0)

    @staticmethod
    def valid_Ns():
        return [6, 14, 26, 38, 50, 74, 86, 110, 146, 170, 194, 230, 266, 302,
            350, 434, 590, 770, 974, 1202, 1454, 1730, 2030, 2354, 2702, 3074, 3470, 3890,
            4334, 4802, 5294, 5810 ]

    @staticmethod
    def valid_orders():
        return [3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,35,41,47,53,59,65,71,77, 
            83,89,95,101,107,113,119,125,131]

    @staticmethod
    def build(N):

        # Lookup table holding N -> build function pointers
        build_methods = {
            6 : Lebedev.build6,
            14 : Lebedev.build14,
            26 : Lebedev.build26,
            38 : Lebedev.build38,
            50 : Lebedev.build50,
            74 : Lebedev.build74,
            86 : Lebedev.build86,
            110 : Lebedev.build110,
            146 : Lebedev.build146,
            170 : Lebedev.build170,
            194 : Lebedev.build194,
            230 : Lebedev.build230,
            266 : Lebedev.build266,
            302 : Lebedev.build302,
            350 : Lebedev.build350,
            434 : Lebedev.build434,
            590 : Lebedev.build590,
            770 : Lebedev.build770,
            974 : Lebedev.build974,
            1202 : Lebedev.build1202,
            1454 : Lebedev.build1454,
            1730 : Lebedev.build1730,
            2030 : Lebedev.build2030,
            2354 : Lebedev.build2354,
            2702 : Lebedev.build2702,
            3074 : Lebedev.build3074,
            3470 : Lebedev.build3470,
            3890 : Lebedev.build3890,
            4334 : Lebedev.build4334,
            4802 : Lebedev.build4802,
            5294 : Lebedev.build5294,
            5810 : Lebedev.build5810,
        }
    
        if not N in build_methods:
            keys = list(sorted(build_methods.keys()))
            raise ValueError('build: Invalid N = %d: Valid N lies in %r' % (N, keys))
        else:
            return build_methods[N]()
       
    @staticmethod
    def build6():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.0943951023931962E+00],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.0943951023931962E+00],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   2.0943951023931962E+00],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   2.0943951023931962E+00],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   2.0943951023931962E+00],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   2.0943951023931962E+00],
        ])
  
        order = 3
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build14():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   8.3775804095727813E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   8.3775804095727813E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   8.3775804095727813E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   8.3775804095727813E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   8.3775804095727813E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   8.3775804095727813E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.4247779607693793E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.4247779607693793E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.4247779607693793E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4247779607693793E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.4247779607693793E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4247779607693793E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4247779607693793E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4247779607693793E-01],
        ])
  
        order = 5
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build26():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   5.9839860068377015E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   5.9839860068377015E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   5.9839860068377015E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   5.9839860068377015E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   5.9839860068377015E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   5.9839860068377015E-01],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   4.7871888054701611E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   4.7871888054701611E-01],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   4.7871888054701611E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   4.7871888054701611E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   4.7871888054701611E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   4.7871888054701611E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   4.7871888054701611E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   4.7871888054701611E-01],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   4.7871888054701611E-01],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   4.7871888054701611E-01],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   4.7871888054701611E-01],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   4.7871888054701611E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
        ])
  
        order = 7
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build38():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.1967972013675403E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.1967972013675403E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.1967972013675403E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.1967972013675403E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.1967972013675403E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.1967972013675403E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.0391905546154477E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.0391905546154477E-01],
            [   4.5970084338098310E-01,   8.8807383397711526E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [  -4.5970084338098310E-01,   8.8807383397711526E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [   4.5970084338098310E-01,  -8.8807383397711526E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [  -4.5970084338098310E-01,  -8.8807383397711526E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [   8.8807383397711526E-01,   4.5970084338098310E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [  -8.8807383397711526E-01,   4.5970084338098310E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [   8.8807383397711526E-01,  -4.5970084338098310E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [  -8.8807383397711526E-01,  -4.5970084338098310E-01,   0.0000000000000000E+00,   3.5903916041026207E-01],
            [   4.5970084338098310E-01,   0.0000000000000000E+00,   8.8807383397711526E-01,   3.5903916041026207E-01],
            [  -4.5970084338098310E-01,   0.0000000000000000E+00,   8.8807383397711526E-01,   3.5903916041026207E-01],
            [   4.5970084338098310E-01,   0.0000000000000000E+00,  -8.8807383397711526E-01,   3.5903916041026207E-01],
            [  -4.5970084338098310E-01,   0.0000000000000000E+00,  -8.8807383397711526E-01,   3.5903916041026207E-01],
            [   8.8807383397711526E-01,   0.0000000000000000E+00,   4.5970084338098310E-01,   3.5903916041026207E-01],
            [  -8.8807383397711526E-01,   0.0000000000000000E+00,   4.5970084338098310E-01,   3.5903916041026207E-01],
            [   8.8807383397711526E-01,   0.0000000000000000E+00,  -4.5970084338098310E-01,   3.5903916041026207E-01],
            [  -8.8807383397711526E-01,   0.0000000000000000E+00,  -4.5970084338098310E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,   4.5970084338098310E-01,   8.8807383397711526E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,  -4.5970084338098310E-01,   8.8807383397711526E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,   4.5970084338098310E-01,  -8.8807383397711526E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,  -4.5970084338098310E-01,  -8.8807383397711526E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,   8.8807383397711526E-01,   4.5970084338098310E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,  -8.8807383397711526E-01,   4.5970084338098310E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,   8.8807383397711526E-01,  -4.5970084338098310E-01,   3.5903916041026207E-01],
            [   0.0000000000000000E+00,  -8.8807383397711526E-01,  -4.5970084338098310E-01,   3.5903916041026207E-01],
        ])
  
        order = 9
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build50():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.5957296018233871E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.5957296018233871E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.5957296018233871E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.5957296018233871E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.5957296018233871E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.5957296018233871E-01],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   2.8368526254637988E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   2.8368526254637988E-01],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   2.8368526254637988E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   2.8368526254637988E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.8368526254637988E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.8368526254637988E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.8368526254637988E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.8368526254637988E-01],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.8368526254637988E-01],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.8368526254637988E-01],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.8368526254637988E-01],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.8368526254637988E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.6507188014663879E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.6507188014663879E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.6507188014663879E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6507188014663879E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.6507188014663879E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6507188014663879E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6507188014663879E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6507188014663879E-01],
            [   3.0151134457776357E-01,   3.0151134457776357E-01,   9.0453403373329089E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,   3.0151134457776357E-01,   9.0453403373329089E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,  -3.0151134457776357E-01,   9.0453403373329089E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,   3.0151134457776357E-01,  -9.0453403373329089E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,  -3.0151134457776357E-01,   9.0453403373329089E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,   3.0151134457776357E-01,  -9.0453403373329089E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,  -3.0151134457776357E-01,  -9.0453403373329089E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,  -3.0151134457776357E-01,  -9.0453403373329089E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,   9.0453403373329089E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,  -9.0453403373329089E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,   9.0453403373329089E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,  -9.0453403373329089E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,   9.0453403373329089E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,  -9.0453403373329089E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -3.0151134457776357E-01,  -9.0453403373329089E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [   3.0151134457776357E-01,   9.0453403373329089E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [   9.0453403373329089E-01,   3.0151134457776357E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -9.0453403373329089E-01,   3.0151134457776357E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [   9.0453403373329089E-01,  -3.0151134457776357E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [   9.0453403373329089E-01,   3.0151134457776357E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -9.0453403373329089E-01,  -3.0151134457776357E-01,   3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -9.0453403373329089E-01,   3.0151134457776357E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [   9.0453403373329089E-01,  -3.0151134457776357E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
            [  -9.0453403373329089E-01,  -3.0151134457776357E-01,  -3.0151134457776357E-01,   2.5350561089731127E-01],
        ])
  
        order = 11
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build74():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.4473923305995431E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.4473923305995431E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   6.4473923305995431E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   6.4473923305995431E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   6.4473923305995431E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   6.4473923305995431E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   2.0865289186971622E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   2.0865289186971622E-01],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   2.0865289186971622E-01],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   2.0865289186971622E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.0865289186971622E-01],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.0865289186971622E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.0865289186971622E-01],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.0865289186971622E-01],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.0865289186971622E-01],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.0865289186971622E-01],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.0865289186971622E-01],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.0865289186971622E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,  -3.7178913059528557E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,  -3.7178913059528557E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,  -3.7178913059528557E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,  -3.7178913059528557E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,  -3.7178913059528557E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -3.7178913059528557E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,  -3.7178913059528557E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -3.7178913059528557E-01],
            [   4.8038446141526142E-01,   4.8038446141526142E-01,   7.3379938570534275E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,   4.8038446141526142E-01,   7.3379938570534275E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,  -4.8038446141526142E-01,   7.3379938570534275E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,   4.8038446141526142E-01,  -7.3379938570534275E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,  -4.8038446141526142E-01,   7.3379938570534275E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,   4.8038446141526142E-01,  -7.3379938570534275E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,  -4.8038446141526142E-01,  -7.3379938570534275E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,  -4.8038446141526142E-01,  -7.3379938570534275E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,   7.3379938570534275E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,  -7.3379938570534275E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,   7.3379938570534275E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,  -7.3379938570534275E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,   7.3379938570534275E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,  -7.3379938570534275E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -4.8038446141526142E-01,  -7.3379938570534275E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [   4.8038446141526142E-01,   7.3379938570534275E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [   7.3379938570534275E-01,   4.8038446141526142E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -7.3379938570534275E-01,   4.8038446141526142E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [   7.3379938570534275E-01,  -4.8038446141526142E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [   7.3379938570534275E-01,   4.8038446141526142E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -7.3379938570534275E-01,  -4.8038446141526142E-01,   4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -7.3379938570534275E-01,   4.8038446141526142E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [   7.3379938570534275E-01,  -4.8038446141526142E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [  -7.3379938570534275E-01,  -4.8038446141526142E-01,  -4.8038446141526142E-01,   3.3396646771837279E-01],
            [   3.2077264898077640E-01,   9.4715622136258792E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [  -3.2077264898077640E-01,   9.4715622136258792E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [   3.2077264898077640E-01,  -9.4715622136258792E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [  -3.2077264898077640E-01,  -9.4715622136258792E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [   9.4715622136258792E-01,   3.2077264898077640E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [  -9.4715622136258792E-01,   3.2077264898077640E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [   9.4715622136258792E-01,  -3.2077264898077640E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [  -9.4715622136258792E-01,  -3.2077264898077640E-01,   0.0000000000000000E+00,   2.0762372406084659E-01],
            [   3.2077264898077640E-01,   0.0000000000000000E+00,   9.4715622136258792E-01,   2.0762372406084659E-01],
            [  -3.2077264898077640E-01,   0.0000000000000000E+00,   9.4715622136258792E-01,   2.0762372406084659E-01],
            [   3.2077264898077640E-01,   0.0000000000000000E+00,  -9.4715622136258792E-01,   2.0762372406084659E-01],
            [  -3.2077264898077640E-01,   0.0000000000000000E+00,  -9.4715622136258792E-01,   2.0762372406084659E-01],
            [   9.4715622136258792E-01,   0.0000000000000000E+00,   3.2077264898077640E-01,   2.0762372406084659E-01],
            [  -9.4715622136258792E-01,   0.0000000000000000E+00,   3.2077264898077640E-01,   2.0762372406084659E-01],
            [   9.4715622136258792E-01,   0.0000000000000000E+00,  -3.2077264898077640E-01,   2.0762372406084659E-01],
            [  -9.4715622136258792E-01,   0.0000000000000000E+00,  -3.2077264898077640E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,   3.2077264898077640E-01,   9.4715622136258792E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,  -3.2077264898077640E-01,   9.4715622136258792E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,   3.2077264898077640E-01,  -9.4715622136258792E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,  -3.2077264898077640E-01,  -9.4715622136258792E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,   9.4715622136258792E-01,   3.2077264898077640E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,  -9.4715622136258792E-01,   3.2077264898077640E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,   9.4715622136258792E-01,  -3.2077264898077640E-01,   2.0762372406084659E-01],
            [   0.0000000000000000E+00,  -9.4715622136258792E-01,  -3.2077264898077640E-01,   2.0762372406084659E-01],
        ])
  
        order = 13
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build86():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.4506632743848968E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.4506632743848968E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.4506632743848968E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.4506632743848968E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.4506632743848968E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.4506632743848968E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.5009158815708187E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.5009158815708187E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.5009158815708187E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.5009158815708187E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.5009158815708187E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.5009158815708187E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.5009158815708187E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.5009158815708187E-01],
            [   3.6960284645415020E-01,   3.6960284645415020E-01,   8.5251831170126757E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,   3.6960284645415020E-01,   8.5251831170126757E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,  -3.6960284645415020E-01,   8.5251831170126757E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,   3.6960284645415020E-01,  -8.5251831170126757E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,  -3.6960284645415020E-01,   8.5251831170126757E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,   3.6960284645415020E-01,  -8.5251831170126757E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,  -3.6960284645415020E-01,  -8.5251831170126757E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,  -3.6960284645415020E-01,  -8.5251831170126757E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,   8.5251831170126757E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,  -8.5251831170126757E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,   8.5251831170126757E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,  -8.5251831170126757E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,   8.5251831170126757E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,  -8.5251831170126757E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -3.6960284645415020E-01,  -8.5251831170126757E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [   3.6960284645415020E-01,   8.5251831170126757E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [   8.5251831170126757E-01,   3.6960284645415020E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -8.5251831170126757E-01,   3.6960284645415020E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [   8.5251831170126757E-01,  -3.6960284645415020E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [   8.5251831170126757E-01,   3.6960284645415020E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -8.5251831170126757E-01,  -3.6960284645415020E-01,   3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -8.5251831170126757E-01,   3.6960284645415020E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [   8.5251831170126757E-01,  -3.6960284645415020E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [  -8.5251831170126757E-01,  -3.6960284645415020E-01,  -3.6960284645415020E-01,   1.3961936079092707E-01],
            [   6.9435400660266644E-01,   6.9435400660266644E-01,   1.8906355288539498E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,   6.9435400660266644E-01,   1.8906355288539498E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,  -6.9435400660266644E-01,   1.8906355288539498E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,   6.9435400660266644E-01,  -1.8906355288539498E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,  -6.9435400660266644E-01,   1.8906355288539498E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,   6.9435400660266644E-01,  -1.8906355288539498E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,  -6.9435400660266644E-01,  -1.8906355288539498E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,  -6.9435400660266644E-01,  -1.8906355288539498E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,   1.8906355288539498E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,  -1.8906355288539498E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,   1.8906355288539498E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,  -1.8906355288539498E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,   1.8906355288539498E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,  -1.8906355288539498E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -6.9435400660266644E-01,  -1.8906355288539498E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [   6.9435400660266644E-01,   1.8906355288539498E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [   1.8906355288539498E-01,   6.9435400660266644E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -1.8906355288539498E-01,   6.9435400660266644E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [   1.8906355288539498E-01,  -6.9435400660266644E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [   1.8906355288539498E-01,   6.9435400660266644E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -1.8906355288539498E-01,  -6.9435400660266644E-01,   6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -1.8906355288539498E-01,   6.9435400660266644E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [   1.8906355288539498E-01,  -6.9435400660266644E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [  -1.8906355288539498E-01,  -6.9435400660266644E-01,  -6.9435400660266644E-01,   1.4924451686907020E-01],
            [   3.7424303909034118E-01,   9.2733065715117247E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [  -3.7424303909034118E-01,   9.2733065715117247E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [   3.7424303909034118E-01,  -9.2733065715117247E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [  -3.7424303909034118E-01,  -9.2733065715117247E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [   9.2733065715117247E-01,   3.7424303909034118E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [  -9.2733065715117247E-01,   3.7424303909034118E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [   9.2733065715117247E-01,  -3.7424303909034118E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [  -9.2733065715117247E-01,  -3.7424303909034118E-01,   0.0000000000000000E+00,   1.4843778669298521E-01],
            [   3.7424303909034118E-01,   0.0000000000000000E+00,   9.2733065715117247E-01,   1.4843778669298521E-01],
            [  -3.7424303909034118E-01,   0.0000000000000000E+00,   9.2733065715117247E-01,   1.4843778669298521E-01],
            [   3.7424303909034118E-01,   0.0000000000000000E+00,  -9.2733065715117247E-01,   1.4843778669298521E-01],
            [  -3.7424303909034118E-01,   0.0000000000000000E+00,  -9.2733065715117247E-01,   1.4843778669298521E-01],
            [   9.2733065715117247E-01,   0.0000000000000000E+00,   3.7424303909034118E-01,   1.4843778669298521E-01],
            [  -9.2733065715117247E-01,   0.0000000000000000E+00,   3.7424303909034118E-01,   1.4843778669298521E-01],
            [   9.2733065715117247E-01,   0.0000000000000000E+00,  -3.7424303909034118E-01,   1.4843778669298521E-01],
            [  -9.2733065715117247E-01,   0.0000000000000000E+00,  -3.7424303909034118E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,   3.7424303909034118E-01,   9.2733065715117247E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,  -3.7424303909034118E-01,   9.2733065715117247E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,   3.7424303909034118E-01,  -9.2733065715117247E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,  -3.7424303909034118E-01,  -9.2733065715117247E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,   9.2733065715117247E-01,   3.7424303909034118E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,  -9.2733065715117247E-01,   3.7424303909034118E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,   9.2733065715117247E-01,  -3.7424303909034118E-01,   1.4843778669298521E-01],
            [   0.0000000000000000E+00,  -9.2733065715117247E-01,  -3.7424303909034118E-01,   1.4843778669298521E-01],
        ])
  
        order = 15
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build110():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   4.8107465851396594E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   4.8107465851396594E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   4.8107465851396594E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   4.8107465851396594E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   4.8107465851396594E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   4.8107465851396594E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.2307173528167017E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.2307173528167017E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.2307173528167017E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.2307173528167017E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.2307173528167017E-01],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.2307173528167017E-01],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.2307173528167017E-01],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.2307173528167017E-01],
            [   1.8511563534473621E-01,   1.8511563534473621E-01,   9.6512403508659406E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,   1.8511563534473621E-01,   9.6512403508659406E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,  -1.8511563534473621E-01,   9.6512403508659406E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,   1.8511563534473621E-01,  -9.6512403508659406E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,  -1.8511563534473621E-01,   9.6512403508659406E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,   1.8511563534473621E-01,  -9.6512403508659406E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,  -1.8511563534473621E-01,  -9.6512403508659406E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,  -1.8511563534473621E-01,  -9.6512403508659406E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,   9.6512403508659406E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,  -9.6512403508659406E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,   9.6512403508659406E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,  -9.6512403508659406E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,   9.6512403508659406E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,  -9.6512403508659406E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -1.8511563534473621E-01,  -9.6512403508659406E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [   1.8511563534473621E-01,   9.6512403508659406E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [   9.6512403508659406E-01,   1.8511563534473621E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -9.6512403508659406E-01,   1.8511563534473621E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [   9.6512403508659406E-01,  -1.8511563534473621E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [   9.6512403508659406E-01,   1.8511563534473621E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -9.6512403508659406E-01,  -1.8511563534473621E-01,   1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -9.6512403508659406E-01,   1.8511563534473621E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [   9.6512403508659406E-01,  -1.8511563534473621E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [  -9.6512403508659406E-01,  -1.8511563534473621E-01,  -1.8511563534473621E-01,   1.0319173408833041E-01],
            [   6.9042104838229224E-01,   6.9042104838229224E-01,   2.1595729184584844E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,   6.9042104838229224E-01,   2.1595729184584844E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,  -6.9042104838229224E-01,   2.1595729184584844E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,   6.9042104838229224E-01,  -2.1595729184584844E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,  -6.9042104838229224E-01,   2.1595729184584844E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,   6.9042104838229224E-01,  -2.1595729184584844E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,  -6.9042104838229224E-01,  -2.1595729184584844E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,  -6.9042104838229224E-01,  -2.1595729184584844E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,   2.1595729184584844E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,  -2.1595729184584844E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,   2.1595729184584844E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,  -2.1595729184584844E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,   2.1595729184584844E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,  -2.1595729184584844E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -6.9042104838229224E-01,  -2.1595729184584844E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [   6.9042104838229224E-01,   2.1595729184584844E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [   2.1595729184584844E-01,   6.9042104838229224E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -2.1595729184584844E-01,   6.9042104838229224E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [   2.1595729184584844E-01,  -6.9042104838229224E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [   2.1595729184584844E-01,   6.9042104838229224E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -2.1595729184584844E-01,  -6.9042104838229224E-01,   6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -2.1595729184584844E-01,   6.9042104838229224E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [   2.1595729184584844E-01,  -6.9042104838229224E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [  -2.1595729184584844E-01,  -6.9042104838229224E-01,  -6.9042104838229224E-01,   1.2494509687251330E-01],
            [   3.9568947305594188E-01,   3.9568947305594188E-01,   8.2876998125259227E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,   3.9568947305594188E-01,   8.2876998125259227E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,  -3.9568947305594188E-01,   8.2876998125259227E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,   3.9568947305594188E-01,  -8.2876998125259227E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,  -3.9568947305594188E-01,   8.2876998125259227E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,   3.9568947305594188E-01,  -8.2876998125259227E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,  -3.9568947305594188E-01,  -8.2876998125259227E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,  -3.9568947305594188E-01,  -8.2876998125259227E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,   8.2876998125259227E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,  -8.2876998125259227E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,   8.2876998125259227E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,  -8.2876998125259227E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,   8.2876998125259227E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,  -8.2876998125259227E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -3.9568947305594188E-01,  -8.2876998125259227E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [   3.9568947305594188E-01,   8.2876998125259227E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [   8.2876998125259227E-01,   3.9568947305594188E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -8.2876998125259227E-01,   3.9568947305594188E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [   8.2876998125259227E-01,  -3.9568947305594188E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [   8.2876998125259227E-01,   3.9568947305594188E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -8.2876998125259227E-01,  -3.9568947305594188E-01,   3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -8.2876998125259227E-01,   3.9568947305594188E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [   8.2876998125259227E-01,  -3.9568947305594188E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [  -8.2876998125259227E-01,  -3.9568947305594188E-01,  -3.9568947305594188E-01,   1.2058024902852789E-01],
            [   4.7836902881215021E-01,   8.7815891060406615E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [  -4.7836902881215021E-01,   8.7815891060406615E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [   4.7836902881215021E-01,  -8.7815891060406615E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [  -4.7836902881215021E-01,  -8.7815891060406615E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [   8.7815891060406615E-01,   4.7836902881215021E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [  -8.7815891060406615E-01,   4.7836902881215021E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [   8.7815891060406615E-01,  -4.7836902881215021E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [  -8.7815891060406615E-01,  -4.7836902881215021E-01,   0.0000000000000000E+00,   1.2183091738552138E-01],
            [   4.7836902881215021E-01,   0.0000000000000000E+00,   8.7815891060406615E-01,   1.2183091738552138E-01],
            [  -4.7836902881215021E-01,   0.0000000000000000E+00,   8.7815891060406615E-01,   1.2183091738552138E-01],
            [   4.7836902881215021E-01,   0.0000000000000000E+00,  -8.7815891060406615E-01,   1.2183091738552138E-01],
            [  -4.7836902881215021E-01,   0.0000000000000000E+00,  -8.7815891060406615E-01,   1.2183091738552138E-01],
            [   8.7815891060406615E-01,   0.0000000000000000E+00,   4.7836902881215021E-01,   1.2183091738552138E-01],
            [  -8.7815891060406615E-01,   0.0000000000000000E+00,   4.7836902881215021E-01,   1.2183091738552138E-01],
            [   8.7815891060406615E-01,   0.0000000000000000E+00,  -4.7836902881215021E-01,   1.2183091738552138E-01],
            [  -8.7815891060406615E-01,   0.0000000000000000E+00,  -4.7836902881215021E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,   4.7836902881215021E-01,   8.7815891060406615E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,  -4.7836902881215021E-01,   8.7815891060406615E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,   4.7836902881215021E-01,  -8.7815891060406615E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,  -4.7836902881215021E-01,  -8.7815891060406615E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,   8.7815891060406615E-01,   4.7836902881215021E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,  -8.7815891060406615E-01,   4.7836902881215021E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,   8.7815891060406615E-01,  -4.7836902881215021E-01,   1.2183091738552138E-01],
            [   0.0000000000000000E+00,  -8.7815891060406615E-01,  -4.7836902881215021E-01,   1.2183091738552138E-01],
        ])
  
        order = 17
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build146():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   7.5351900131171382E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   7.5351900131171382E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   7.5351900131171382E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   7.5351900131171382E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   7.5351900131171382E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   7.5351900131171382E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   9.2651847003754312E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   9.2651847003754312E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   9.2651847003754312E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   9.2651847003754312E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   9.2651847003754312E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   9.2651847003754312E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   9.2651847003754312E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   9.2651847003754312E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   9.2651847003754312E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   9.2651847003754312E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   9.2651847003754312E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   9.2651847003754312E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.0610008336105136E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.0610008336105136E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.0610008336105136E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.0610008336105136E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.0610008336105136E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.0610008336105136E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.0610008336105136E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.0610008336105136E-02],
            [   6.7644104001142635E-01,   6.7644104001142635E-01,   2.9129888220952682E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,   6.7644104001142635E-01,   2.9129888220952682E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,  -6.7644104001142635E-01,   2.9129888220952682E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,   6.7644104001142635E-01,  -2.9129888220952682E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,  -6.7644104001142635E-01,   2.9129888220952682E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,   6.7644104001142635E-01,  -2.9129888220952682E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,  -6.7644104001142635E-01,  -2.9129888220952682E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,  -6.7644104001142635E-01,  -2.9129888220952682E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,   2.9129888220952682E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,  -2.9129888220952682E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,   2.9129888220952682E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,  -2.9129888220952682E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,   2.9129888220952682E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,  -2.9129888220952682E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -6.7644104001142635E-01,  -2.9129888220952682E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [   6.7644104001142635E-01,   2.9129888220952682E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [   2.9129888220952682E-01,   6.7644104001142635E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -2.9129888220952682E-01,   6.7644104001142635E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [   2.9129888220952682E-01,  -6.7644104001142635E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [   2.9129888220952682E-01,   6.7644104001142635E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -2.9129888220952682E-01,  -6.7644104001142635E-01,   6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -2.9129888220952682E-01,   6.7644104001142635E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [   2.9129888220952682E-01,  -6.7644104001142635E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [  -2.9129888220952682E-01,  -6.7644104001142635E-01,  -6.7644104001142635E-01,   8.9426760550045920E-02],
            [   4.1749612279654530E-01,   4.1749612279654530E-01,   8.0708981835958260E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,   4.1749612279654530E-01,   8.0708981835958260E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,  -4.1749612279654530E-01,   8.0708981835958260E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,   4.1749612279654530E-01,  -8.0708981835958260E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,  -4.1749612279654530E-01,   8.0708981835958260E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,   4.1749612279654530E-01,  -8.0708981835958260E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,  -4.1749612279654530E-01,  -8.0708981835958260E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,  -4.1749612279654530E-01,  -8.0708981835958260E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,   8.0708981835958260E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,  -8.0708981835958260E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,   8.0708981835958260E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,  -8.0708981835958260E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,   8.0708981835958260E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,  -8.0708981835958260E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -4.1749612279654530E-01,  -8.0708981835958260E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [   4.1749612279654530E-01,   8.0708981835958260E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [   8.0708981835958260E-01,   4.1749612279654530E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -8.0708981835958260E-01,   4.1749612279654530E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [   8.0708981835958260E-01,  -4.1749612279654530E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [   8.0708981835958260E-01,   4.1749612279654530E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -8.0708981835958260E-01,  -4.1749612279654530E-01,   4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -8.0708981835958260E-01,   4.1749612279654530E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [   8.0708981835958260E-01,  -4.1749612279654530E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [  -8.0708981835958260E-01,  -4.1749612279654530E-01,  -4.1749612279654530E-01,   8.4871124391214747E-02],
            [   1.5746766720390820E-01,   1.5746766720390820E-01,   9.7488864367717321E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,   1.5746766720390820E-01,   9.7488864367717321E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,  -1.5746766720390820E-01,   9.7488864367717321E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,   1.5746766720390820E-01,  -9.7488864367717321E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,  -1.5746766720390820E-01,   9.7488864367717321E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,   1.5746766720390820E-01,  -9.7488864367717321E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,  -1.5746766720390820E-01,  -9.7488864367717321E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,  -1.5746766720390820E-01,  -9.7488864367717321E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,   9.7488864367717321E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,  -9.7488864367717321E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,   9.7488864367717321E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,  -9.7488864367717321E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,   9.7488864367717321E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,  -9.7488864367717321E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -1.5746766720390820E-01,  -9.7488864367717321E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [   1.5746766720390820E-01,   9.7488864367717321E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [   9.7488864367717321E-01,   1.5746766720390820E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -9.7488864367717321E-01,   1.5746766720390820E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [   9.7488864367717321E-01,  -1.5746766720390820E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [   9.7488864367717321E-01,   1.5746766720390820E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -9.7488864367717321E-01,  -1.5746766720390820E-01,   1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -9.7488864367717321E-01,   1.5746766720390820E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [   9.7488864367717321E-01,  -1.5746766720390820E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [  -9.7488864367717321E-01,  -1.5746766720390820E-01,  -1.5746766720390820E-01,   9.5182644181910372E-02],
            [   1.4035538117131829E-01,   4.4933283232695570E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,   4.4933283232695570E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,  -4.4933283232695570E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,   4.4933283232695570E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,  -4.4933283232695570E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,  -4.4933283232695570E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,   4.4933283232695570E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,  -4.4933283232695570E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,   1.4035538117131829E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,   1.4035538117131829E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,  -1.4035538117131829E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,   1.4035538117131829E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,  -1.4035538117131829E-01,   8.8227001126032267E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,  -1.4035538117131829E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,   1.4035538117131829E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,  -1.4035538117131829E-01,  -8.8227001126032267E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,   1.4035538117131829E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,   1.4035538117131829E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,  -1.4035538117131829E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,   1.4035538117131829E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,  -1.4035538117131829E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,  -1.4035538117131829E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,   1.4035538117131829E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,  -1.4035538117131829E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,   4.4933283232695570E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,   4.4933283232695570E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,  -4.4933283232695570E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,   4.4933283232695570E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,  -4.4933283232695570E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   8.8227001126032267E-01,  -4.4933283232695570E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,   4.4933283232695570E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -8.8227001126032267E-01,  -4.4933283232695570E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,   8.8227001126032267E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,   8.8227001126032267E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,  -8.8227001126032267E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,   8.8227001126032267E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,  -8.8227001126032267E-01,   4.4933283232695570E-01,   8.7852594678968152E-02],
            [   1.4035538117131829E-01,  -8.8227001126032267E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,   8.8227001126032267E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [  -1.4035538117131829E-01,  -8.8227001126032267E-01,  -4.4933283232695570E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,   8.8227001126032267E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,   8.8227001126032267E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,  -8.8227001126032267E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,   8.8227001126032267E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,  -8.8227001126032267E-01,   1.4035538117131829E-01,   8.7852594678968152E-02],
            [   4.4933283232695570E-01,  -8.8227001126032267E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,   8.8227001126032267E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
            [  -4.4933283232695570E-01,  -8.8227001126032267E-01,  -1.4035538117131829E-01,   8.7852594678968152E-02],
        ])
  
        order = 19
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build170():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.9678550905400385E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.9678550905400385E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   6.9678550905400385E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   6.9678550905400385E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   6.9678550905400385E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   6.9678550905400385E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   7.6294617719352795E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   7.6294617719352795E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   7.6294617719352795E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   7.6294617719352795E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   7.6294617719352795E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.6294617719352795E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   7.6294617719352795E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.6294617719352795E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   7.6294617719352795E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   7.6294617719352795E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.6294617719352795E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.6294617719352795E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   8.0219623085526007E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   8.0219623085526007E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   8.0219623085526007E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   8.0219623085526007E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   8.0219623085526007E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   8.0219623085526007E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   8.0219623085526007E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   8.0219623085526007E-02],
            [   2.5512526211141340E-01,   2.5512526211141340E-01,   9.3264259031269059E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,   2.5512526211141340E-01,   9.3264259031269059E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,  -2.5512526211141340E-01,   9.3264259031269059E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,   2.5512526211141340E-01,  -9.3264259031269059E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,  -2.5512526211141340E-01,   9.3264259031269059E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,   2.5512526211141340E-01,  -9.3264259031269059E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,  -2.5512526211141340E-01,  -9.3264259031269059E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,  -2.5512526211141340E-01,  -9.3264259031269059E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,   9.3264259031269059E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,  -9.3264259031269059E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,   9.3264259031269059E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,  -9.3264259031269059E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,   9.3264259031269059E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,  -9.3264259031269059E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -2.5512526211141340E-01,  -9.3264259031269059E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [   2.5512526211141340E-01,   9.3264259031269059E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [   9.3264259031269059E-01,   2.5512526211141340E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -9.3264259031269059E-01,   2.5512526211141340E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [   9.3264259031269059E-01,  -2.5512526211141340E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [   9.3264259031269059E-01,   2.5512526211141340E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -9.3264259031269059E-01,  -2.5512526211141340E-01,   2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -9.3264259031269059E-01,   2.5512526211141340E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [   9.3264259031269059E-01,  -2.5512526211141340E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [  -9.3264259031269059E-01,  -2.5512526211141340E-01,  -2.5512526211141340E-01,   6.5136369465507910E-02],
            [   6.7436014603627659E-01,   6.7436014603627659E-01,   3.0079359513770149E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,   6.7436014603627659E-01,   3.0079359513770149E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,  -6.7436014603627659E-01,   3.0079359513770149E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,   6.7436014603627659E-01,  -3.0079359513770149E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,  -6.7436014603627659E-01,   3.0079359513770149E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,   6.7436014603627659E-01,  -3.0079359513770149E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,  -6.7436014603627659E-01,  -3.0079359513770149E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,  -6.7436014603627659E-01,  -3.0079359513770149E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,   3.0079359513770149E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,  -3.0079359513770149E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,   3.0079359513770149E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,  -3.0079359513770149E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,   3.0079359513770149E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,  -3.0079359513770149E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -6.7436014603627659E-01,  -3.0079359513770149E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [   6.7436014603627659E-01,   3.0079359513770149E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [   3.0079359513770149E-01,   6.7436014603627659E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -3.0079359513770149E-01,   6.7436014603627659E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [   3.0079359513770149E-01,  -6.7436014603627659E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [   3.0079359513770149E-01,   6.7436014603627659E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -3.0079359513770149E-01,  -6.7436014603627659E-01,   6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -3.0079359513770149E-01,   6.7436014603627659E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [   3.0079359513770149E-01,  -6.7436014603627659E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [  -3.0079359513770149E-01,  -6.7436014603627659E-01,  -6.7436014603627659E-01,   7.9393437452530538E-02],
            [   4.3189106967194102E-01,   4.3189106967194102E-01,   7.9179555939349211E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,   4.3189106967194102E-01,   7.9179555939349211E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,  -4.3189106967194102E-01,   7.9179555939349211E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,   4.3189106967194102E-01,  -7.9179555939349211E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,  -4.3189106967194102E-01,   7.9179555939349211E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,   4.3189106967194102E-01,  -7.9179555939349211E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,  -4.3189106967194102E-01,  -7.9179555939349211E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,  -4.3189106967194102E-01,  -7.9179555939349211E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,   7.9179555939349211E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,  -7.9179555939349211E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,   7.9179555939349211E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,  -7.9179555939349211E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,   7.9179555939349211E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,  -7.9179555939349211E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -4.3189106967194102E-01,  -7.9179555939349211E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [   4.3189106967194102E-01,   7.9179555939349211E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [   7.9179555939349211E-01,   4.3189106967194102E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -7.9179555939349211E-01,   4.3189106967194102E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [   7.9179555939349211E-01,  -4.3189106967194102E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [   7.9179555939349211E-01,   4.3189106967194102E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -7.9179555939349211E-01,  -4.3189106967194102E-01,   4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -7.9179555939349211E-01,   4.3189106967194102E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [   7.9179555939349211E-01,  -4.3189106967194102E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [  -7.9179555939349211E-01,  -4.3189106967194102E-01,  -4.3189106967194102E-01,   7.7932483730753635E-02],
            [   2.6139313603359882E-01,   9.6523242197644843E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [  -2.6139313603359882E-01,   9.6523242197644843E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [   2.6139313603359882E-01,  -9.6523242197644843E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [  -2.6139313603359882E-01,  -9.6523242197644843E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [   9.6523242197644843E-01,   2.6139313603359882E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [  -9.6523242197644843E-01,   2.6139313603359882E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [   9.6523242197644843E-01,  -2.6139313603359882E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [  -9.6523242197644843E-01,  -2.6139313603359882E-01,   0.0000000000000000E+00,   6.8827813685621686E-02],
            [   2.6139313603359882E-01,   0.0000000000000000E+00,   9.6523242197644843E-01,   6.8827813685621686E-02],
            [  -2.6139313603359882E-01,   0.0000000000000000E+00,   9.6523242197644843E-01,   6.8827813685621686E-02],
            [   2.6139313603359882E-01,   0.0000000000000000E+00,  -9.6523242197644843E-01,   6.8827813685621686E-02],
            [  -2.6139313603359882E-01,   0.0000000000000000E+00,  -9.6523242197644843E-01,   6.8827813685621686E-02],
            [   9.6523242197644843E-01,   0.0000000000000000E+00,   2.6139313603359882E-01,   6.8827813685621686E-02],
            [  -9.6523242197644843E-01,   0.0000000000000000E+00,   2.6139313603359882E-01,   6.8827813685621686E-02],
            [   9.6523242197644843E-01,   0.0000000000000000E+00,  -2.6139313603359882E-01,   6.8827813685621686E-02],
            [  -9.6523242197644843E-01,   0.0000000000000000E+00,  -2.6139313603359882E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,   2.6139313603359882E-01,   9.6523242197644843E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,  -2.6139313603359882E-01,   9.6523242197644843E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,   2.6139313603359882E-01,  -9.6523242197644843E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,  -2.6139313603359882E-01,  -9.6523242197644843E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,   9.6523242197644843E-01,   2.6139313603359882E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,  -9.6523242197644843E-01,   2.6139313603359882E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,   9.6523242197644843E-01,  -2.6139313603359882E-01,   6.8827813685621686E-02],
            [   0.0000000000000000E+00,  -9.6523242197644843E-01,  -2.6139313603359882E-01,   6.8827813685621686E-02],
            [   4.9904531617960368E-01,   1.4466307443251150E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,   1.4466307443251150E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,  -1.4466307443251150E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,   1.4466307443251150E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,  -1.4466307443251150E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,  -1.4466307443251150E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,   1.4466307443251150E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,  -1.4466307443251150E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,   4.9904531617960368E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,   4.9904531617960368E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,  -4.9904531617960368E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,   4.9904531617960368E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,  -4.9904531617960368E-01,   8.5441580468465883E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,  -4.9904531617960368E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,   4.9904531617960368E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,  -4.9904531617960368E-01,  -8.5441580468465883E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,   4.9904531617960368E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,   4.9904531617960368E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,  -4.9904531617960368E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,   4.9904531617960368E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,  -4.9904531617960368E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,  -4.9904531617960368E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,   4.9904531617960368E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,  -4.9904531617960368E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,   1.4466307443251150E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,   1.4466307443251150E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,  -1.4466307443251150E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,   1.4466307443251150E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,  -1.4466307443251150E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   8.5441580468465883E-01,  -1.4466307443251150E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,   1.4466307443251150E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -8.5441580468465883E-01,  -1.4466307443251150E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,   8.5441580468465883E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,   8.5441580468465883E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,  -8.5441580468465883E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,   8.5441580468465883E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,  -8.5441580468465883E-01,   1.4466307443251150E-01,   7.5000925158008297E-02],
            [   4.9904531617960368E-01,  -8.5441580468465883E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,   8.5441580468465883E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [  -4.9904531617960368E-01,  -8.5441580468465883E-01,  -1.4466307443251150E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,   8.5441580468465883E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,   8.5441580468465883E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,  -8.5441580468465883E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,   8.5441580468465883E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,  -8.5441580468465883E-01,   4.9904531617960368E-01,   7.5000925158008297E-02],
            [   1.4466307443251150E-01,  -8.5441580468465883E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,   8.5441580468465883E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
            [  -1.4466307443251150E-01,  -8.5441580468465883E-01,  -4.9904531617960368E-01,   7.5000925158008297E-02],
        ])
  
        order = 21
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build194():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.2397550621038466E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.2397550621038466E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   2.2397550621038466E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   2.2397550621038466E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   2.2397550621038466E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   2.2397550621038466E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   7.1840758934847357E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   7.1840758934847357E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   7.1840758934847357E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   7.1840758934847357E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   7.1840758934847357E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.1840758934847357E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   7.1840758934847357E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.1840758934847357E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   7.1840758934847357E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   7.1840758934847357E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.1840758934847357E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.1840758934847357E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   7.0037198601248490E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   7.0037198601248490E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   7.0037198601248490E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   7.0037198601248490E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   7.0037198601248490E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   7.0037198601248490E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   7.0037198601248490E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   7.0037198601248490E-02],
            [   6.7129734426952259E-01,   6.7129734426952259E-01,   3.1419699418258629E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,   6.7129734426952259E-01,   3.1419699418258629E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,  -6.7129734426952259E-01,   3.1419699418258629E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,   6.7129734426952259E-01,  -3.1419699418258629E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,  -6.7129734426952259E-01,   3.1419699418258629E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,   6.7129734426952259E-01,  -3.1419699418258629E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,  -6.7129734426952259E-01,  -3.1419699418258629E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,  -6.7129734426952259E-01,  -3.1419699418258629E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,   3.1419699418258629E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,  -3.1419699418258629E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,   3.1419699418258629E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,  -3.1419699418258629E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,   3.1419699418258629E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,  -3.1419699418258629E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -6.7129734426952259E-01,  -3.1419699418258629E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [   6.7129734426952259E-01,   3.1419699418258629E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [   3.1419699418258629E-01,   6.7129734426952259E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -3.1419699418258629E-01,   6.7129734426952259E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [   3.1419699418258629E-01,  -6.7129734426952259E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [   3.1419699418258629E-01,   6.7129734426952259E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -3.1419699418258629E-01,  -6.7129734426952259E-01,   6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -3.1419699418258629E-01,   6.7129734426952259E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [   3.1419699418258629E-01,  -6.7129734426952259E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [  -3.1419699418258629E-01,  -6.7129734426952259E-01,  -6.7129734426952259E-01,   7.0481054168070129E-02],
            [   2.8924656275754390E-01,   2.8924656275754390E-01,   9.1250909686747372E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,   2.8924656275754390E-01,   9.1250909686747372E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,  -2.8924656275754390E-01,   9.1250909686747372E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,   2.8924656275754390E-01,  -9.1250909686747372E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,  -2.8924656275754390E-01,   9.1250909686747372E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,   2.8924656275754390E-01,  -9.1250909686747372E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,  -2.8924656275754390E-01,  -9.1250909686747372E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,  -2.8924656275754390E-01,  -9.1250909686747372E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,   9.1250909686747372E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,  -9.1250909686747372E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,   9.1250909686747372E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,  -9.1250909686747372E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,   9.1250909686747372E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,  -9.1250909686747372E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -2.8924656275754390E-01,  -9.1250909686747372E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [   2.8924656275754390E-01,   9.1250909686747372E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [   9.1250909686747372E-01,   2.8924656275754390E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -9.1250909686747372E-01,   2.8924656275754390E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [   9.1250909686747372E-01,  -2.8924656275754390E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [   9.1250909686747372E-01,   2.8924656275754390E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -9.1250909686747372E-01,  -2.8924656275754390E-01,   2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -9.1250909686747372E-01,   2.8924656275754390E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [   9.1250909686747372E-01,  -2.8924656275754390E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [  -9.1250909686747372E-01,  -2.8924656275754390E-01,  -2.8924656275754390E-01,   6.4820326803510464E-02],
            [   4.4469331787174371E-01,   4.4469331787174371E-01,   7.7749321931476711E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,   4.4469331787174371E-01,   7.7749321931476711E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,  -4.4469331787174371E-01,   7.7749321931476711E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,   4.4469331787174371E-01,  -7.7749321931476711E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,  -4.4469331787174371E-01,   7.7749321931476711E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,   4.4469331787174371E-01,  -7.7749321931476711E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,  -4.4469331787174371E-01,  -7.7749321931476711E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,  -4.4469331787174371E-01,  -7.7749321931476711E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,   7.7749321931476711E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,  -7.7749321931476711E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,   7.7749321931476711E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,  -7.7749321931476711E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,   7.7749321931476711E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,  -7.7749321931476711E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -4.4469331787174371E-01,  -7.7749321931476711E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [   4.4469331787174371E-01,   7.7749321931476711E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [   7.7749321931476711E-01,   4.4469331787174371E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -7.7749321931476711E-01,   4.4469331787174371E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [   7.7749321931476711E-01,  -4.4469331787174371E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [   7.7749321931476711E-01,   4.4469331787174371E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -7.7749321931476711E-01,  -4.4469331787174371E-01,   4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -7.7749321931476711E-01,   4.4469331787174371E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [   7.7749321931476711E-01,  -4.4469331787174371E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [  -7.7749321931476711E-01,  -4.4469331787174371E-01,  -4.4469331787174371E-01,   6.9350927593711004E-02],
            [   1.2993354476500671E-01,   1.2993354476500671E-01,   9.8297230270725322E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,   1.2993354476500671E-01,   9.8297230270725322E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,  -1.2993354476500671E-01,   9.8297230270725322E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,   1.2993354476500671E-01,  -9.8297230270725322E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,  -1.2993354476500671E-01,   9.8297230270725322E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,   1.2993354476500671E-01,  -9.8297230270725322E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,  -1.2993354476500671E-01,  -9.8297230270725322E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,  -1.2993354476500671E-01,  -9.8297230270725322E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,   9.8297230270725322E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,  -9.8297230270725322E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,   9.8297230270725322E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,  -9.8297230270725322E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,   9.8297230270725322E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,  -9.8297230270725322E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -1.2993354476500671E-01,  -9.8297230270725322E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [   1.2993354476500671E-01,   9.8297230270725322E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [   9.8297230270725322E-01,   1.2993354476500671E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -9.8297230270725322E-01,   1.2993354476500671E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [   9.8297230270725322E-01,  -1.2993354476500671E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [   9.8297230270725322E-01,   1.2993354476500671E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -9.8297230270725322E-01,  -1.2993354476500671E-01,   1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -9.8297230270725322E-01,   1.2993354476500671E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [   9.8297230270725322E-01,  -1.2993354476500671E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [  -9.8297230270725322E-01,  -1.2993354476500671E-01,  -1.2993354476500671E-01,   5.1607282166513162E-02],
            [   3.4577021976112832E-01,   9.3831921813759156E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [  -3.4577021976112832E-01,   9.3831921813759156E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [   3.4577021976112832E-01,  -9.3831921813759156E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [  -3.4577021976112832E-01,  -9.3831921813759156E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [   9.3831921813759156E-01,   3.4577021976112832E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [  -9.3831921813759156E-01,   3.4577021976112832E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [   9.3831921813759156E-01,  -3.4577021976112832E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [  -9.3831921813759156E-01,  -3.4577021976112832E-01,   0.0000000000000000E+00,   6.3483369934641556E-02],
            [   3.4577021976112832E-01,   0.0000000000000000E+00,   9.3831921813759156E-01,   6.3483369934641556E-02],
            [  -3.4577021976112832E-01,   0.0000000000000000E+00,   9.3831921813759156E-01,   6.3483369934641556E-02],
            [   3.4577021976112832E-01,   0.0000000000000000E+00,  -9.3831921813759156E-01,   6.3483369934641556E-02],
            [  -3.4577021976112832E-01,   0.0000000000000000E+00,  -9.3831921813759156E-01,   6.3483369934641556E-02],
            [   9.3831921813759156E-01,   0.0000000000000000E+00,   3.4577021976112832E-01,   6.3483369934641556E-02],
            [  -9.3831921813759156E-01,   0.0000000000000000E+00,   3.4577021976112832E-01,   6.3483369934641556E-02],
            [   9.3831921813759156E-01,   0.0000000000000000E+00,  -3.4577021976112832E-01,   6.3483369934641556E-02],
            [  -9.3831921813759156E-01,   0.0000000000000000E+00,  -3.4577021976112832E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,   3.4577021976112832E-01,   9.3831921813759156E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,  -3.4577021976112832E-01,   9.3831921813759156E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,   3.4577021976112832E-01,  -9.3831921813759156E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,  -3.4577021976112832E-01,  -9.3831921813759156E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,   9.3831921813759156E-01,   3.4577021976112832E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,  -9.3831921813759156E-01,   3.4577021976112832E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,   9.3831921813759156E-01,  -3.4577021976112832E-01,   6.3483369934641556E-02],
            [   0.0000000000000000E+00,  -9.3831921813759156E-01,  -3.4577021976112832E-01,   6.3483369934641556E-02],
            [   1.5904171053835300E-01,   8.3603601548245887E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,   8.3603601548245887E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,  -8.3603601548245887E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,   8.3603601548245887E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,  -8.3603601548245887E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,  -8.3603601548245887E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,   8.3603601548245887E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,  -8.3603601548245887E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,   1.5904171053835300E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,   1.5904171053835300E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,  -1.5904171053835300E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,   1.5904171053835300E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,  -1.5904171053835300E-01,   5.2511857244364202E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,  -1.5904171053835300E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,   1.5904171053835300E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,  -1.5904171053835300E-01,  -5.2511857244364202E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,   1.5904171053835300E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,   1.5904171053835300E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,  -1.5904171053835300E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,   1.5904171053835300E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,  -1.5904171053835300E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,  -1.5904171053835300E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,   1.5904171053835300E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,  -1.5904171053835300E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,   8.3603601548245887E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,   8.3603601548245887E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,  -8.3603601548245887E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,   8.3603601548245887E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,  -8.3603601548245887E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   5.2511857244364202E-01,  -8.3603601548245887E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,   8.3603601548245887E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -5.2511857244364202E-01,  -8.3603601548245887E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,   5.2511857244364202E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,   5.2511857244364202E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,  -5.2511857244364202E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,   5.2511857244364202E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,  -5.2511857244364202E-01,   8.3603601548245887E-01,   6.9495157471043220E-02],
            [   1.5904171053835300E-01,  -5.2511857244364202E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,   5.2511857244364202E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [  -1.5904171053835300E-01,  -5.2511857244364202E-01,  -8.3603601548245887E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,   5.2511857244364202E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,   5.2511857244364202E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,  -5.2511857244364202E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,   5.2511857244364202E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,  -5.2511857244364202E-01,   1.5904171053835300E-01,   6.9495157471043220E-02],
            [   8.3603601548245887E-01,  -5.2511857244364202E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,   5.2511857244364202E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
            [  -8.3603601548245887E-01,  -5.2511857244364202E-01,  -1.5904171053835300E-01,   6.9495157471043220E-02],
        ])
  
        order = 23
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build230():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,  -6.9399540000948357E-01],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,  -6.9399540000948357E-01],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,  -6.9399540000948357E-01],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,  -6.9399540000948357E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,  -6.9399540000948357E-01],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,  -6.9399540000948357E-01],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.5923800052828487E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.5923800052828487E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.5923800052828487E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.5923800052828487E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.5923800052828487E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.5923800052828487E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.5923800052828487E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.5923800052828487E-02],
            [   4.4920446873976111E-01,   4.4920446873976111E-01,   7.7228925314836405E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,   4.4920446873976111E-01,   7.7228925314836405E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,  -4.4920446873976111E-01,   7.7228925314836405E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,   4.4920446873976111E-01,  -7.7228925314836405E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,  -4.4920446873976111E-01,   7.7228925314836405E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,   4.4920446873976111E-01,  -7.7228925314836405E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,  -4.4920446873976111E-01,  -7.7228925314836405E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,  -4.4920446873976111E-01,  -7.7228925314836405E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,   7.7228925314836405E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,  -7.7228925314836405E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,   7.7228925314836405E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,  -7.7228925314836405E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,   7.7228925314836405E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,  -7.7228925314836405E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -4.4920446873976111E-01,  -7.7228925314836405E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [   4.4920446873976111E-01,   7.7228925314836405E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [   7.7228925314836405E-01,   4.4920446873976111E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -7.7228925314836405E-01,   4.4920446873976111E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [   7.7228925314836405E-01,  -4.4920446873976111E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [   7.7228925314836405E-01,   4.4920446873976111E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -7.7228925314836405E-01,  -4.4920446873976111E-01,   4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -7.7228925314836405E-01,   4.4920446873976111E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [   7.7228925314836405E-01,  -4.4920446873976111E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [  -7.7228925314836405E-01,  -4.4920446873976111E-01,  -4.4920446873976111E-01,   5.6508971453371054E-02],
            [   2.5204194902102012E-01,   2.5204194902102012E-01,   9.3431777884581169E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,   2.5204194902102012E-01,   9.3431777884581169E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,  -2.5204194902102012E-01,   9.3431777884581169E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,   2.5204194902102012E-01,  -9.3431777884581169E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,  -2.5204194902102012E-01,   9.3431777884581169E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,   2.5204194902102012E-01,  -9.3431777884581169E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,  -2.5204194902102012E-01,  -9.3431777884581169E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,  -2.5204194902102012E-01,  -9.3431777884581169E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,   9.3431777884581169E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,  -9.3431777884581169E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,   9.3431777884581169E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,  -9.3431777884581169E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,   9.3431777884581169E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,  -9.3431777884581169E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -2.5204194902102012E-01,  -9.3431777884581169E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [   2.5204194902102012E-01,   9.3431777884581169E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [   9.3431777884581169E-01,   2.5204194902102012E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -9.3431777884581169E-01,   2.5204194902102012E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [   9.3431777884581169E-01,  -2.5204194902102012E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [   9.3431777884581169E-01,   2.5204194902102012E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -9.3431777884581169E-01,  -2.5204194902102012E-01,   2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -9.3431777884581169E-01,   2.5204194902102012E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [   9.3431777884581169E-01,  -2.5204194902102012E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [  -9.3431777884581169E-01,  -2.5204194902102012E-01,  -2.5204194902102012E-01,   6.3449533547486378E-02],
            [   6.9819066584472422E-01,   6.9819066584472422E-01,   1.5830220546347831E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,   6.9819066584472422E-01,   1.5830220546347831E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,  -6.9819066584472422E-01,   1.5830220546347831E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,   6.9819066584472422E-01,  -1.5830220546347831E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,  -6.9819066584472422E-01,   1.5830220546347831E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,   6.9819066584472422E-01,  -1.5830220546347831E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,  -6.9819066584472422E-01,  -1.5830220546347831E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,  -6.9819066584472422E-01,  -1.5830220546347831E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,   1.5830220546347831E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,  -1.5830220546347831E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,   1.5830220546347831E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,  -1.5830220546347831E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,   1.5830220546347831E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,  -1.5830220546347831E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -6.9819066584472422E-01,  -1.5830220546347831E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [   6.9819066584472422E-01,   1.5830220546347831E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [   1.5830220546347831E-01,   6.9819066584472422E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -1.5830220546347831E-01,   6.9819066584472422E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [   1.5830220546347831E-01,  -6.9819066584472422E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [   1.5830220546347831E-01,   6.9819066584472422E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -1.5830220546347831E-01,  -6.9819066584472422E-01,   6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -1.5830220546347831E-01,   6.9819066584472422E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [   1.5830220546347831E-01,  -6.9819066584472422E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [  -1.5830220546347831E-01,  -6.9819066584472422E-01,  -6.9819066584472422E-01,   4.9969016868749376E-02],
            [   6.5874052434609598E-01,   6.5874052434609598E-01,   3.6348568495672712E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,   6.5874052434609598E-01,   3.6348568495672712E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,  -6.5874052434609598E-01,   3.6348568495672712E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,   6.5874052434609598E-01,  -3.6348568495672712E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,  -6.5874052434609598E-01,   3.6348568495672712E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,   6.5874052434609598E-01,  -3.6348568495672712E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,  -6.5874052434609598E-01,  -3.6348568495672712E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,  -6.5874052434609598E-01,  -3.6348568495672712E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,   3.6348568495672712E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,  -3.6348568495672712E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,   3.6348568495672712E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,  -3.6348568495672712E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,   3.6348568495672712E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,  -3.6348568495672712E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -6.5874052434609598E-01,  -3.6348568495672712E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [   6.5874052434609598E-01,   3.6348568495672712E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [   3.6348568495672712E-01,   6.5874052434609598E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -3.6348568495672712E-01,   6.5874052434609598E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [   3.6348568495672712E-01,  -6.5874052434609598E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [   3.6348568495672712E-01,   6.5874052434609598E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -3.6348568495672712E-01,  -6.5874052434609598E-01,   6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -3.6348568495672712E-01,   6.5874052434609598E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [   3.6348568495672712E-01,  -6.5874052434609598E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [  -3.6348568495672712E-01,  -6.5874052434609598E-01,  -6.5874052434609598E-01,   5.5309631794969331E-02],
            [   4.0385440500976602E-02,   4.0385440500976602E-02,   9.9836768396772746E-01,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,   4.0385440500976602E-02,   9.9836768396772746E-01,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,  -4.0385440500976602E-02,   9.9836768396772746E-01,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,   4.0385440500976602E-02,  -9.9836768396772746E-01,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,  -4.0385440500976602E-02,   9.9836768396772746E-01,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,   4.0385440500976602E-02,  -9.9836768396772746E-01,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,  -4.0385440500976602E-02,  -9.9836768396772746E-01,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,  -4.0385440500976602E-02,  -9.9836768396772746E-01,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,   9.9836768396772746E-01,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,  -9.9836768396772746E-01,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,   9.9836768396772746E-01,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,  -9.9836768396772746E-01,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,   9.9836768396772746E-01,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,  -9.9836768396772746E-01,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -4.0385440500976602E-02,  -9.9836768396772746E-01,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [   4.0385440500976602E-02,   9.9836768396772746E-01,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [   9.9836768396772746E-01,   4.0385440500976602E-02,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -9.9836768396772746E-01,   4.0385440500976602E-02,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [   9.9836768396772746E-01,  -4.0385440500976602E-02,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [   9.9836768396772746E-01,   4.0385440500976602E-02,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -9.9836768396772746E-01,  -4.0385440500976602E-02,   4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -9.9836768396772746E-01,   4.0385440500976602E-02,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [   9.9836768396772746E-01,  -4.0385440500976602E-02,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [  -9.9836768396772746E-01,  -4.0385440500976602E-02,  -4.0385440500976602E-02,   2.1671263449840283E-01],
            [   5.8238423097155845E-01,   8.1291365317336528E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [  -5.8238423097155845E-01,   8.1291365317336528E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [   5.8238423097155845E-01,  -8.1291365317336528E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [  -5.8238423097155845E-01,  -8.1291365317336528E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [   8.1291365317336528E-01,   5.8238423097155845E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [  -8.1291365317336528E-01,   5.8238423097155845E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [   8.1291365317336528E-01,  -5.8238423097155845E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [  -8.1291365317336528E-01,  -5.8238423097155845E-01,   0.0000000000000000E+00,   5.3169358276410360E-02],
            [   5.8238423097155845E-01,   0.0000000000000000E+00,   8.1291365317336528E-01,   5.3169358276410360E-02],
            [  -5.8238423097155845E-01,   0.0000000000000000E+00,   8.1291365317336528E-01,   5.3169358276410360E-02],
            [   5.8238423097155845E-01,   0.0000000000000000E+00,  -8.1291365317336528E-01,   5.3169358276410360E-02],
            [  -5.8238423097155845E-01,   0.0000000000000000E+00,  -8.1291365317336528E-01,   5.3169358276410360E-02],
            [   8.1291365317336528E-01,   0.0000000000000000E+00,   5.8238423097155845E-01,   5.3169358276410360E-02],
            [  -8.1291365317336528E-01,   0.0000000000000000E+00,   5.8238423097155845E-01,   5.3169358276410360E-02],
            [   8.1291365317336528E-01,   0.0000000000000000E+00,  -5.8238423097155845E-01,   5.3169358276410360E-02],
            [  -8.1291365317336528E-01,   0.0000000000000000E+00,  -5.8238423097155845E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,   5.8238423097155845E-01,   8.1291365317336528E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,  -5.8238423097155845E-01,   8.1291365317336528E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,   5.8238423097155845E-01,  -8.1291365317336528E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,  -5.8238423097155845E-01,  -8.1291365317336528E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,   8.1291365317336528E-01,   5.8238423097155845E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,  -8.1291365317336528E-01,   5.8238423097155845E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,   8.1291365317336528E-01,  -5.8238423097155845E-01,   5.3169358276410360E-02],
            [   0.0000000000000000E+00,  -8.1291365317336528E-01,  -5.8238423097155845E-01,   5.3169358276410360E-02],
            [   3.5458773905186880E-01,   9.3502274588059298E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [  -3.5458773905186880E-01,   9.3502274588059298E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [   3.5458773905186880E-01,  -9.3502274588059298E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [  -3.5458773905186880E-01,  -9.3502274588059298E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [   9.3502274588059298E-01,   3.5458773905186880E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [  -9.3502274588059298E-01,   3.5458773905186880E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [   9.3502274588059298E-01,  -3.5458773905186880E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [  -9.3502274588059298E-01,  -3.5458773905186880E-01,   0.0000000000000000E+00,   6.5320872391164839E-02],
            [   3.5458773905186880E-01,   0.0000000000000000E+00,   9.3502274588059298E-01,   6.5320872391164839E-02],
            [  -3.5458773905186880E-01,   0.0000000000000000E+00,   9.3502274588059298E-01,   6.5320872391164839E-02],
            [   3.5458773905186880E-01,   0.0000000000000000E+00,  -9.3502274588059298E-01,   6.5320872391164839E-02],
            [  -3.5458773905186880E-01,   0.0000000000000000E+00,  -9.3502274588059298E-01,   6.5320872391164839E-02],
            [   9.3502274588059298E-01,   0.0000000000000000E+00,   3.5458773905186880E-01,   6.5320872391164839E-02],
            [  -9.3502274588059298E-01,   0.0000000000000000E+00,   3.5458773905186880E-01,   6.5320872391164839E-02],
            [   9.3502274588059298E-01,   0.0000000000000000E+00,  -3.5458773905186880E-01,   6.5320872391164839E-02],
            [  -9.3502274588059298E-01,   0.0000000000000000E+00,  -3.5458773905186880E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,   3.5458773905186880E-01,   9.3502274588059298E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,  -3.5458773905186880E-01,   9.3502274588059298E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,   3.5458773905186880E-01,  -9.3502274588059298E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,  -3.5458773905186880E-01,  -9.3502274588059298E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,   9.3502274588059298E-01,   3.5458773905186880E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,  -9.3502274588059298E-01,   3.5458773905186880E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,   9.3502274588059298E-01,  -3.5458773905186880E-01,   6.5320872391164839E-02],
            [   0.0000000000000000E+00,  -9.3502274588059298E-01,  -3.5458773905186880E-01,   6.5320872391164839E-02],
            [   2.2721818089981871E-01,   4.8646615358866468E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,   4.8646615358866468E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,  -4.8646615358866468E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,   4.8646615358866468E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,  -4.8646615358866468E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,  -4.8646615358866468E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,   4.8646615358866468E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,  -4.8646615358866468E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,   2.2721818089981871E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,   2.2721818089981871E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,  -2.2721818089981871E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,   2.2721818089981871E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,  -2.2721818089981871E-01,   8.4363652106889431E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,  -2.2721818089981871E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,   2.2721818089981871E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,  -2.2721818089981871E-01,  -8.4363652106889431E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,   2.2721818089981871E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,   2.2721818089981871E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,  -2.2721818089981871E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,   2.2721818089981871E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,  -2.2721818089981871E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,  -2.2721818089981871E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,   2.2721818089981871E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,  -2.2721818089981871E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,   4.8646615358866468E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,   4.8646615358866468E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,  -4.8646615358866468E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,   4.8646615358866468E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,  -4.8646615358866468E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   8.4363652106889431E-01,  -4.8646615358866468E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,   4.8646615358866468E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -8.4363652106889431E-01,  -4.8646615358866468E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,   8.4363652106889431E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,   8.4363652106889431E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,  -8.4363652106889431E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,   8.4363652106889431E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,  -8.4363652106889431E-01,   4.8646615358866468E-01,   5.9008170042919680E-02],
            [   2.2721818089981871E-01,  -8.4363652106889431E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,   8.4363652106889431E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [  -2.2721818089981871E-01,  -8.4363652106889431E-01,  -4.8646615358866468E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,   8.4363652106889431E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,   8.4363652106889431E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,  -8.4363652106889431E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,   8.4363652106889431E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,  -8.4363652106889431E-01,   2.2721818089981871E-01,   5.9008170042919680E-02],
            [   4.8646615358866468E-01,  -8.4363652106889431E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,   8.4363652106889431E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
            [  -4.8646615358866468E-01,  -8.4363652106889431E-01,  -2.2721818089981871E-01,   5.9008170042919680E-02],
        ])
  
        order = 25
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build266():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.6509309755693702E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.6509309755693702E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,  -1.6509309755693702E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,  -1.6509309755693702E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,  -1.6509309755693702E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,  -1.6509309755693702E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,  -3.1701543864744733E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,  -3.1701543864744733E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,  -3.1701543864744733E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,  -3.1701543864744733E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,  -3.1701543864744733E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,  -3.1701543864744733E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,  -3.1701543864744733E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.2613557585617844E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.2613557585617844E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.2613557585617844E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.2613557585617844E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.2613557585617844E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.2613557585617844E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.2613557585617844E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.2613557585617844E-02],
            [   7.0393733915854750E-01,   7.0393733915854750E-01,   9.4575076403713099E-02,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,   7.0393733915854750E-01,   9.4575076403713099E-02,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,  -7.0393733915854750E-01,   9.4575076403713099E-02,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,   7.0393733915854750E-01,  -9.4575076403713099E-02,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,  -7.0393733915854750E-01,   9.4575076403713099E-02,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,   7.0393733915854750E-01,  -9.4575076403713099E-02,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,  -7.0393733915854750E-01,  -9.4575076403713099E-02,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,  -7.0393733915854750E-01,  -9.4575076403713099E-02,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,   9.4575076403713099E-02,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,  -9.4575076403713099E-02,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,   9.4575076403713099E-02,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,  -9.4575076403713099E-02,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,   9.4575076403713099E-02,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,  -9.4575076403713099E-02,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -7.0393733915854750E-01,  -9.4575076403713099E-02,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [   7.0393733915854750E-01,   9.4575076403713099E-02,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [   9.4575076403713099E-02,   7.0393733915854750E-01,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -9.4575076403713099E-02,   7.0393733915854750E-01,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [   9.4575076403713099E-02,  -7.0393733915854750E-01,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [   9.4575076403713099E-02,   7.0393733915854750E-01,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -9.4575076403713099E-02,  -7.0393733915854750E-01,   7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -9.4575076403713099E-02,   7.0393733915854750E-01,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [   9.4575076403713099E-02,  -7.0393733915854750E-01,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [  -9.4575076403713099E-02,  -7.0393733915854750E-01,  -7.0393733915854750E-01,   6.6792370686745567E-02],
            [   1.0125262485724140E-01,   1.0125262485724140E-01,   9.8969480746290539E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,   1.0125262485724140E-01,   9.8969480746290539E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,  -1.0125262485724140E-01,   9.8969480746290539E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,   1.0125262485724140E-01,  -9.8969480746290539E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,  -1.0125262485724140E-01,   9.8969480746290539E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,   1.0125262485724140E-01,  -9.8969480746290539E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,  -1.0125262485724140E-01,  -9.8969480746290539E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,  -1.0125262485724140E-01,  -9.8969480746290539E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,   9.8969480746290539E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,  -9.8969480746290539E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,   9.8969480746290539E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,  -9.8969480746290539E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,   9.8969480746290539E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,  -9.8969480746290539E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -1.0125262485724140E-01,  -9.8969480746290539E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [   1.0125262485724140E-01,   9.8969480746290539E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [   9.8969480746290539E-01,   1.0125262485724140E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -9.8969480746290539E-01,   1.0125262485724140E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [   9.8969480746290539E-01,  -1.0125262485724140E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [   9.8969480746290539E-01,   1.0125262485724140E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -9.8969480746290539E-01,  -1.0125262485724140E-01,   1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -9.8969480746290539E-01,   1.0125262485724140E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [   9.8969480746290539E-01,  -1.0125262485724140E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [  -9.8969480746290539E-01,  -1.0125262485724140E-01,  -1.0125262485724140E-01,   5.0857891039543995E-02],
            [   4.6474487264205389E-01,   4.6474487264205389E-01,   7.5367393925081572E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,   4.6474487264205389E-01,   7.5367393925081572E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,  -4.6474487264205389E-01,   7.5367393925081572E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,   4.6474487264205389E-01,  -7.5367393925081572E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,  -4.6474487264205389E-01,   7.5367393925081572E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,   4.6474487264205389E-01,  -7.5367393925081572E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,  -4.6474487264205389E-01,  -7.5367393925081572E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,  -4.6474487264205389E-01,  -7.5367393925081572E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,   7.5367393925081572E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,  -7.5367393925081572E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,   7.5367393925081572E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,  -7.5367393925081572E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,   7.5367393925081572E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,  -7.5367393925081572E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -4.6474487264205389E-01,  -7.5367393925081572E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [   4.6474487264205389E-01,   7.5367393925081572E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [   7.5367393925081572E-01,   4.6474487264205389E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -7.5367393925081572E-01,   4.6474487264205389E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [   7.5367393925081572E-01,  -4.6474487264205389E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [   7.5367393925081572E-01,   4.6474487264205389E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -7.5367393925081572E-01,  -4.6474487264205389E-01,   4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -7.5367393925081572E-01,   4.6474487264205389E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [   7.5367393925081572E-01,  -4.6474487264205389E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [  -7.5367393925081572E-01,  -4.6474487264205389E-01,  -4.6474487264205389E-01,   5.1678977913145449E-02],
            [   3.2774206549716289E-01,   3.2774206549716289E-01,   8.8609834499749907E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,   3.2774206549716289E-01,   8.8609834499749907E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,  -3.2774206549716289E-01,   8.8609834499749907E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,   3.2774206549716289E-01,  -8.8609834499749907E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,  -3.2774206549716289E-01,   8.8609834499749907E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,   3.2774206549716289E-01,  -8.8609834499749907E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,  -3.2774206549716289E-01,  -8.8609834499749907E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,  -3.2774206549716289E-01,  -8.8609834499749907E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,   8.8609834499749907E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,  -8.8609834499749907E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,   8.8609834499749907E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,  -8.8609834499749907E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,   8.8609834499749907E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,  -8.8609834499749907E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -3.2774206549716289E-01,  -8.8609834499749907E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [   3.2774206549716289E-01,   8.8609834499749907E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [   8.8609834499749907E-01,   3.2774206549716289E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -8.8609834499749907E-01,   3.2774206549716289E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [   8.8609834499749907E-01,  -3.2774206549716289E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [   8.8609834499749907E-01,   3.2774206549716289E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -8.8609834499749907E-01,  -3.2774206549716289E-01,   3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -8.8609834499749907E-01,   3.2774206549716289E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [   8.8609834499749907E-01,  -3.2774206549716289E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [  -8.8609834499749907E-01,  -3.2774206549716289E-01,  -3.2774206549716289E-01,   4.5183452425762327E-02],
            [   6.6203386636999739E-01,   6.6203386636999739E-01,   3.5131512856463343E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,   6.6203386636999739E-01,   3.5131512856463343E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,  -6.6203386636999739E-01,   3.5131512856463343E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,   6.6203386636999739E-01,  -3.5131512856463343E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,  -6.6203386636999739E-01,   3.5131512856463343E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,   6.6203386636999739E-01,  -3.5131512856463343E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,  -6.6203386636999739E-01,  -3.5131512856463343E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,  -6.6203386636999739E-01,  -3.5131512856463343E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,   3.5131512856463343E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,  -3.5131512856463343E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,   3.5131512856463343E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,  -3.5131512856463343E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,   3.5131512856463343E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,  -3.5131512856463343E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -6.6203386636999739E-01,  -3.5131512856463343E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [   6.6203386636999739E-01,   3.5131512856463343E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [   3.5131512856463343E-01,   6.6203386636999739E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -3.5131512856463343E-01,   6.6203386636999739E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [   3.5131512856463343E-01,  -6.6203386636999739E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [   3.5131512856463343E-01,   6.6203386636999739E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -3.5131512856463343E-01,  -6.6203386636999739E-01,   6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -3.5131512856463343E-01,   6.6203386636999739E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [   3.5131512856463343E-01,  -6.6203386636999739E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [  -3.5131512856463343E-01,  -6.6203386636999739E-01,  -6.6203386636999739E-01,   5.3484123945439596E-02],
            [   8.5065080835203988E-01,   5.2573111211913370E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [  -8.5065080835203988E-01,   5.2573111211913370E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [   8.5065080835203988E-01,  -5.2573111211913370E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [  -8.5065080835203988E-01,  -5.2573111211913370E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [   5.2573111211913370E-01,   8.5065080835203988E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [  -5.2573111211913370E-01,   8.5065080835203988E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [   5.2573111211913370E-01,  -8.5065080835203988E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [  -5.2573111211913370E-01,  -8.5065080835203988E-01,   0.0000000000000000E+00,   5.3150503760415385E-02],
            [   8.5065080835203988E-01,   0.0000000000000000E+00,   5.2573111211913370E-01,   5.3150503760415385E-02],
            [  -8.5065080835203988E-01,   0.0000000000000000E+00,   5.2573111211913370E-01,   5.3150503760415385E-02],
            [   8.5065080835203988E-01,   0.0000000000000000E+00,  -5.2573111211913370E-01,   5.3150503760415385E-02],
            [  -8.5065080835203988E-01,   0.0000000000000000E+00,  -5.2573111211913370E-01,   5.3150503760415385E-02],
            [   5.2573111211913370E-01,   0.0000000000000000E+00,   8.5065080835203988E-01,   5.3150503760415385E-02],
            [  -5.2573111211913370E-01,   0.0000000000000000E+00,   8.5065080835203988E-01,   5.3150503760415385E-02],
            [   5.2573111211913370E-01,   0.0000000000000000E+00,  -8.5065080835203988E-01,   5.3150503760415385E-02],
            [  -5.2573111211913370E-01,   0.0000000000000000E+00,  -8.5065080835203988E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,   8.5065080835203988E-01,   5.2573111211913370E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,  -8.5065080835203988E-01,   5.2573111211913370E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,   8.5065080835203988E-01,  -5.2573111211913370E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,  -8.5065080835203988E-01,  -5.2573111211913370E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,   5.2573111211913370E-01,   8.5065080835203988E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,  -5.2573111211913370E-01,   8.5065080835203988E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,   5.2573111211913370E-01,  -8.5065080835203988E-01,   5.3150503760415385E-02],
            [   0.0000000000000000E+00,  -5.2573111211913370E-01,  -8.5065080835203988E-01,   5.3150503760415385E-02],
            [   3.2334845426928988E-01,   1.1531120110097010E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,   1.1531120110097010E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,  -1.1531120110097010E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,   1.1531120110097010E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,  -1.1531120110097010E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,  -1.1531120110097010E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,   1.1531120110097010E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,  -1.1531120110097010E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,   3.2334845426928988E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,   3.2334845426928988E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,  -3.2334845426928988E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,   3.2334845426928988E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,  -3.2334845426928988E-01,   9.3922792974991576E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,  -3.2334845426928988E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,   3.2334845426928988E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,  -3.2334845426928988E-01,  -9.3922792974991576E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,   3.2334845426928988E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,   3.2334845426928988E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,  -3.2334845426928988E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,   3.2334845426928988E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,  -3.2334845426928988E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,  -3.2334845426928988E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,   3.2334845426928988E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,  -3.2334845426928988E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,   1.1531120110097010E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,   1.1531120110097010E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,  -1.1531120110097010E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,   1.1531120110097010E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,  -1.1531120110097010E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   9.3922792974991576E-01,  -1.1531120110097010E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,   1.1531120110097010E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -9.3922792974991576E-01,  -1.1531120110097010E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,   9.3922792974991576E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,   9.3922792974991576E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,  -9.3922792974991576E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,   9.3922792974991576E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,  -9.3922792974991576E-01,   1.1531120110097010E-01,   5.1282280606568455E-02],
            [   3.2334845426928988E-01,  -9.3922792974991576E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,   9.3922792974991576E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [  -3.2334845426928988E-01,  -9.3922792974991576E-01,  -1.1531120110097010E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,   9.3922792974991576E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,   9.3922792974991576E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,  -9.3922792974991576E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,   9.3922792974991576E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,  -9.3922792974991576E-01,   3.2334845426928988E-01,   5.1282280606568455E-02],
            [   1.1531120110097010E-01,  -9.3922792974991576E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,   9.3922792974991576E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [  -1.1531120110097010E-01,  -9.3922792974991576E-01,  -3.2334845426928988E-01,   5.1282280606568455E-02],
            [   2.3147901587126010E-01,   5.2449392409223650E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,   5.2449392409223650E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,  -5.2449392409223650E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,   5.2449392409223650E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,  -5.2449392409223650E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,  -5.2449392409223650E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,   5.2449392409223650E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,  -5.2449392409223650E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,   2.3147901587126010E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,   2.3147901587126010E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,  -2.3147901587126010E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,   2.3147901587126010E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,  -2.3147901587126010E-01,   8.1934338881912028E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,  -2.3147901587126010E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,   2.3147901587126010E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,  -2.3147901587126010E-01,  -8.1934338881912028E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,   2.3147901587126010E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,   2.3147901587126010E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,  -2.3147901587126010E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,   2.3147901587126010E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,  -2.3147901587126010E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,  -2.3147901587126010E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,   2.3147901587126010E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,  -2.3147901587126010E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,   5.2449392409223650E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,   5.2449392409223650E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,  -5.2449392409223650E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,   5.2449392409223650E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,  -5.2449392409223650E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   8.1934338881912028E-01,  -5.2449392409223650E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,   5.2449392409223650E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -8.1934338881912028E-01,  -5.2449392409223650E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,   8.1934338881912028E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,   8.1934338881912028E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,  -8.1934338881912028E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,   8.1934338881912028E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,  -8.1934338881912028E-01,   5.2449392409223650E-01,   5.1163570728433076E-02],
            [   2.3147901587126010E-01,  -8.1934338881912028E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,   8.1934338881912028E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [  -2.3147901587126010E-01,  -8.1934338881912028E-01,  -5.2449392409223650E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,   8.1934338881912028E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,   8.1934338881912028E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,  -8.1934338881912028E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,   8.1934338881912028E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,  -8.1934338881912028E-01,   2.3147901587126010E-01,   5.1163570728433076E-02],
            [   5.2449392409223650E-01,  -8.1934338881912028E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,   8.1934338881912028E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
            [  -5.2449392409223650E-01,  -8.1934338881912028E-01,  -2.3147901587126010E-01,   5.1163570728433076E-02],
        ])
  
        order = 27
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build302():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0739109397555787E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0739109397555787E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.0739109397555787E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.0739109397555787E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.0739109397555787E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.0739109397555787E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.5227866820918727E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.5227866820918727E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.5227866820918727E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5227866820918727E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.5227866820918727E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5227866820918727E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5227866820918727E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5227866820918727E-02],
            [   3.5156403455701052E-01,   3.5156403455701052E-01,   8.6764362454408339E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,   3.5156403455701052E-01,   8.6764362454408339E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,  -3.5156403455701052E-01,   8.6764362454408339E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,   3.5156403455701052E-01,  -8.6764362454408339E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,  -3.5156403455701052E-01,   8.6764362454408339E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,   3.5156403455701052E-01,  -8.6764362454408339E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,  -3.5156403455701052E-01,  -8.6764362454408339E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,  -3.5156403455701052E-01,  -8.6764362454408339E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,   8.6764362454408339E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,  -8.6764362454408339E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,   8.6764362454408339E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,  -8.6764362454408339E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,   8.6764362454408339E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,  -8.6764362454408339E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -3.5156403455701052E-01,  -8.6764362454408339E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [   3.5156403455701052E-01,   8.6764362454408339E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [   8.6764362454408339E-01,   3.5156403455701052E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -8.6764362454408339E-01,   3.5156403455701052E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [   8.6764362454408339E-01,  -3.5156403455701052E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [   8.6764362454408339E-01,   3.5156403455701052E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -8.6764362454408339E-01,  -3.5156403455701052E-01,   3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -8.6764362454408339E-01,   3.5156403455701052E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [   8.6764362454408339E-01,  -3.5156403455701052E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [  -8.6764362454408339E-01,  -3.5156403455701052E-01,  -3.5156403455701052E-01,   4.3351319880953879E-02],
            [   6.5663294102196124E-01,   6.5663294102196124E-01,   3.7103417838482095E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,   6.5663294102196124E-01,   3.7103417838482095E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,  -6.5663294102196124E-01,   3.7103417838482095E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,   6.5663294102196124E-01,  -3.7103417838482095E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,  -6.5663294102196124E-01,   3.7103417838482095E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,   6.5663294102196124E-01,  -3.7103417838482095E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,  -6.5663294102196124E-01,  -3.7103417838482095E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,  -6.5663294102196124E-01,  -3.7103417838482095E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,   3.7103417838482095E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,  -3.7103417838482095E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,   3.7103417838482095E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,  -3.7103417838482095E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,   3.7103417838482095E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,  -3.7103417838482095E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -6.5663294102196124E-01,  -3.7103417838482095E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [   6.5663294102196124E-01,   3.7103417838482095E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [   3.7103417838482095E-01,   6.5663294102196124E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -3.7103417838482095E-01,   6.5663294102196124E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [   3.7103417838482095E-01,  -6.5663294102196124E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [   3.7103417838482095E-01,   6.5663294102196124E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -3.7103417838482095E-01,  -6.5663294102196124E-01,   6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -3.7103417838482095E-01,   6.5663294102196124E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [   3.7103417838482095E-01,  -6.5663294102196124E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [  -3.7103417838482095E-01,  -6.5663294102196124E-01,  -6.5663294102196124E-01,   4.5299536808460591E-02],
            [   4.7290541325810048E-01,   4.7290541325810048E-01,   7.4345204298755574E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,   4.7290541325810048E-01,   7.4345204298755574E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,  -4.7290541325810048E-01,   7.4345204298755574E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,   4.7290541325810048E-01,  -7.4345204298755574E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,  -4.7290541325810048E-01,   7.4345204298755574E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,   4.7290541325810048E-01,  -7.4345204298755574E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,  -4.7290541325810048E-01,  -7.4345204298755574E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,  -4.7290541325810048E-01,  -7.4345204298755574E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,   7.4345204298755574E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,  -7.4345204298755574E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,   7.4345204298755574E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,  -7.4345204298755574E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,   7.4345204298755574E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,  -7.4345204298755574E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -4.7290541325810048E-01,  -7.4345204298755574E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [   4.7290541325810048E-01,   7.4345204298755574E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [   7.4345204298755574E-01,   4.7290541325810048E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -7.4345204298755574E-01,   4.7290541325810048E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [   7.4345204298755574E-01,  -4.7290541325810048E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [   7.4345204298755574E-01,   4.7290541325810048E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -7.4345204298755574E-01,  -4.7290541325810048E-01,   4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -7.4345204298755574E-01,   4.7290541325810048E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [   7.4345204298755574E-01,  -4.7290541325810048E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [  -7.4345204298755574E-01,  -4.7290541325810048E-01,  -4.7290541325810048E-01,   4.4946510516838671E-02],
            [   9.6183085226147838E-02,   9.6183085226147838E-02,   9.9070562137940810E-01,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,   9.6183085226147838E-02,   9.9070562137940810E-01,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,  -9.6183085226147838E-02,   9.9070562137940810E-01,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,   9.6183085226147838E-02,  -9.9070562137940810E-01,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,  -9.6183085226147838E-02,   9.9070562137940810E-01,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,   9.6183085226147838E-02,  -9.9070562137940810E-01,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,  -9.6183085226147838E-02,  -9.9070562137940810E-01,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,  -9.6183085226147838E-02,  -9.9070562137940810E-01,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,   9.9070562137940810E-01,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,  -9.9070562137940810E-01,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,   9.9070562137940810E-01,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,  -9.9070562137940810E-01,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,   9.9070562137940810E-01,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,  -9.9070562137940810E-01,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.6183085226147838E-02,  -9.9070562137940810E-01,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.6183085226147838E-02,   9.9070562137940810E-01,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.9070562137940810E-01,   9.6183085226147838E-02,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.9070562137940810E-01,   9.6183085226147838E-02,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.9070562137940810E-01,  -9.6183085226147838E-02,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.9070562137940810E-01,   9.6183085226147838E-02,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.9070562137940810E-01,  -9.6183085226147838E-02,   9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.9070562137940810E-01,   9.6183085226147838E-02,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [   9.9070562137940810E-01,  -9.6183085226147838E-02,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [  -9.9070562137940810E-01,  -9.6183085226147838E-02,  -9.6183085226147838E-02,   2.9557378086976182E-02],
            [   2.2196452362941779E-01,   2.2196452362941779E-01,   9.4945431722644313E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,   2.2196452362941779E-01,   9.4945431722644313E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,  -2.2196452362941779E-01,   9.4945431722644313E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,   2.2196452362941779E-01,  -9.4945431722644313E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,  -2.2196452362941779E-01,   9.4945431722644313E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,   2.2196452362941779E-01,  -9.4945431722644313E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,  -2.2196452362941779E-01,  -9.4945431722644313E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,  -2.2196452362941779E-01,  -9.4945431722644313E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,   9.4945431722644313E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,  -9.4945431722644313E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,   9.4945431722644313E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,  -9.4945431722644313E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,   9.4945431722644313E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,  -9.4945431722644313E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -2.2196452362941779E-01,  -9.4945431722644313E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [   2.2196452362941779E-01,   9.4945431722644313E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [   9.4945431722644313E-01,   2.2196452362941779E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -9.4945431722644313E-01,   2.2196452362941779E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [   9.4945431722644313E-01,  -2.2196452362941779E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [   9.4945431722644313E-01,   2.2196452362941779E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -9.4945431722644313E-01,  -2.2196452362941779E-01,   2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -9.4945431722644313E-01,   2.2196452362941779E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [   9.4945431722644313E-01,  -2.2196452362941779E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [  -9.4945431722644313E-01,  -2.2196452362941779E-01,  -2.2196452362941779E-01,   3.9068257158919401E-02],
            [   7.0117664160895454E-01,   7.0117664160895454E-01,   1.2923867271051442E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,   7.0117664160895454E-01,   1.2923867271051442E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,  -7.0117664160895454E-01,   1.2923867271051442E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,   7.0117664160895454E-01,  -1.2923867271051442E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,  -7.0117664160895454E-01,   1.2923867271051442E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,   7.0117664160895454E-01,  -1.2923867271051442E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,  -7.0117664160895454E-01,  -1.2923867271051442E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,  -7.0117664160895454E-01,  -1.2923867271051442E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,   1.2923867271051442E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,  -1.2923867271051442E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,   1.2923867271051442E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,  -1.2923867271051442E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,   1.2923867271051442E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,  -1.2923867271051442E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -7.0117664160895454E-01,  -1.2923867271051442E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [   7.0117664160895454E-01,   1.2923867271051442E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [   1.2923867271051442E-01,   7.0117664160895454E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -1.2923867271051442E-01,   7.0117664160895454E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [   1.2923867271051442E-01,  -7.0117664160895454E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [   1.2923867271051442E-01,   7.0117664160895454E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -1.2923867271051442E-01,  -7.0117664160895454E-01,   7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -1.2923867271051442E-01,   7.0117664160895454E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [   1.2923867271051442E-01,  -7.0117664160895454E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [  -1.2923867271051442E-01,  -7.0117664160895454E-01,  -7.0117664160895454E-01,   4.5867828378660352E-02],
            [   2.6441528870606629E-01,   9.6440891487920599E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [  -2.6441528870606629E-01,   9.6440891487920599E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [   2.6441528870606629E-01,  -9.6440891487920599E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [  -2.6441528870606629E-01,  -9.6440891487920599E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [   9.6440891487920599E-01,   2.6441528870606629E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [  -9.6440891487920599E-01,   2.6441528870606629E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [   9.6440891487920599E-01,  -2.6441528870606629E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [  -9.6440891487920599E-01,  -2.6441528870606629E-01,   0.0000000000000000E+00,   3.7477252107084247E-02],
            [   2.6441528870606629E-01,   0.0000000000000000E+00,   9.6440891487920599E-01,   3.7477252107084247E-02],
            [  -2.6441528870606629E-01,   0.0000000000000000E+00,   9.6440891487920599E-01,   3.7477252107084247E-02],
            [   2.6441528870606629E-01,   0.0000000000000000E+00,  -9.6440891487920599E-01,   3.7477252107084247E-02],
            [  -2.6441528870606629E-01,   0.0000000000000000E+00,  -9.6440891487920599E-01,   3.7477252107084247E-02],
            [   9.6440891487920599E-01,   0.0000000000000000E+00,   2.6441528870606629E-01,   3.7477252107084247E-02],
            [  -9.6440891487920599E-01,   0.0000000000000000E+00,   2.6441528870606629E-01,   3.7477252107084247E-02],
            [   9.6440891487920599E-01,   0.0000000000000000E+00,  -2.6441528870606629E-01,   3.7477252107084247E-02],
            [  -9.6440891487920599E-01,   0.0000000000000000E+00,  -2.6441528870606629E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,   2.6441528870606629E-01,   9.6440891487920599E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,  -2.6441528870606629E-01,   9.6440891487920599E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,   2.6441528870606629E-01,  -9.6440891487920599E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,  -2.6441528870606629E-01,  -9.6440891487920599E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,   9.6440891487920599E-01,   2.6441528870606629E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,  -9.6440891487920599E-01,   2.6441528870606629E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,   9.6440891487920599E-01,  -2.6441528870606629E-01,   3.7477252107084247E-02],
            [   0.0000000000000000E+00,  -9.6440891487920599E-01,  -2.6441528870606629E-01,   3.7477252107084247E-02],
            [   5.7189558918789607E-01,   8.2032641982775933E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [  -5.7189558918789607E-01,   8.2032641982775933E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [   5.7189558918789607E-01,  -8.2032641982775933E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [  -5.7189558918789607E-01,  -8.2032641982775933E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [   8.2032641982775933E-01,   5.7189558918789607E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [  -8.2032641982775933E-01,   5.7189558918789607E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [   8.2032641982775933E-01,  -5.7189558918789607E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [  -8.2032641982775933E-01,  -5.7189558918789607E-01,   0.0000000000000000E+00,   4.5249250350174325E-02],
            [   5.7189558918789607E-01,   0.0000000000000000E+00,   8.2032641982775933E-01,   4.5249250350174325E-02],
            [  -5.7189558918789607E-01,   0.0000000000000000E+00,   8.2032641982775933E-01,   4.5249250350174325E-02],
            [   5.7189558918789607E-01,   0.0000000000000000E+00,  -8.2032641982775933E-01,   4.5249250350174325E-02],
            [  -5.7189558918789607E-01,   0.0000000000000000E+00,  -8.2032641982775933E-01,   4.5249250350174325E-02],
            [   8.2032641982775933E-01,   0.0000000000000000E+00,   5.7189558918789607E-01,   4.5249250350174325E-02],
            [  -8.2032641982775933E-01,   0.0000000000000000E+00,   5.7189558918789607E-01,   4.5249250350174325E-02],
            [   8.2032641982775933E-01,   0.0000000000000000E+00,  -5.7189558918789607E-01,   4.5249250350174325E-02],
            [  -8.2032641982775933E-01,   0.0000000000000000E+00,  -5.7189558918789607E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,   5.7189558918789607E-01,   8.2032641982775933E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,  -5.7189558918789607E-01,   8.2032641982775933E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,   5.7189558918789607E-01,  -8.2032641982775933E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,  -5.7189558918789607E-01,  -8.2032641982775933E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,   8.2032641982775933E-01,   5.7189558918789607E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,  -8.2032641982775933E-01,   5.7189558918789607E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,   8.2032641982775933E-01,  -5.7189558918789607E-01,   4.5249250350174325E-02],
            [   0.0000000000000000E+00,  -8.2032641982775933E-01,  -5.7189558918789607E-01,   4.5249250350174325E-02],
            [   2.5100347517704652E-01,   8.0007274940739515E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,   8.0007274940739515E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,  -8.0007274940739515E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,   8.0007274940739515E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,  -8.0007274940739515E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,  -8.0007274940739515E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,   8.0007274940739515E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,  -8.0007274940739515E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,   2.5100347517704652E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,   2.5100347517704652E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,  -2.5100347517704652E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,   2.5100347517704652E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,  -2.5100347517704652E-01,   5.4486773725807736E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,  -2.5100347517704652E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,   2.5100347517704652E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,  -2.5100347517704652E-01,  -5.4486773725807736E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,   2.5100347517704652E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,   2.5100347517704652E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,  -2.5100347517704652E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,   2.5100347517704652E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,  -2.5100347517704652E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,  -2.5100347517704652E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,   2.5100347517704652E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,  -2.5100347517704652E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,   8.0007274940739515E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,   8.0007274940739515E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,  -8.0007274940739515E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,   8.0007274940739515E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,  -8.0007274940739515E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   5.4486773725807736E-01,  -8.0007274940739515E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,   8.0007274940739515E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -5.4486773725807736E-01,  -8.0007274940739515E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,   5.4486773725807736E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,   5.4486773725807736E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,  -5.4486773725807736E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,   5.4486773725807736E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,  -5.4486773725807736E-01,   8.0007274940739515E-01,   4.4881302269213164E-02],
            [   2.5100347517704652E-01,  -5.4486773725807736E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,   5.4486773725807736E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [  -2.5100347517704652E-01,  -5.4486773725807736E-01,  -8.0007274940739515E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,   5.4486773725807736E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,   5.4486773725807736E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,  -5.4486773725807736E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,   5.4486773725807736E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,  -5.4486773725807736E-01,   2.5100347517704652E-01,   4.4881302269213164E-02],
            [   8.0007274940739515E-01,  -5.4486773725807736E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,   5.4486773725807736E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [  -8.0007274940739515E-01,  -5.4486773725807736E-01,  -2.5100347517704652E-01,   4.4881302269213164E-02],
            [   1.2335485325833270E-01,   4.1277240831685308E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,   4.1277240831685308E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,  -4.1277240831685308E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,   4.1277240831685308E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,  -4.1277240831685308E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,  -4.1277240831685308E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,   4.1277240831685308E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,  -4.1277240831685308E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,   1.2335485325833270E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,   1.2335485325833270E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,  -1.2335485325833270E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,   1.2335485325833270E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,  -1.2335485325833270E-01,   9.0244252953300041E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,  -1.2335485325833270E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,   1.2335485325833270E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,  -1.2335485325833270E-01,  -9.0244252953300041E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,   1.2335485325833270E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,   1.2335485325833270E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,  -1.2335485325833270E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,   1.2335485325833270E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,  -1.2335485325833270E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,  -1.2335485325833270E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,   1.2335485325833270E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,  -1.2335485325833270E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,   4.1277240831685308E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,   4.1277240831685308E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,  -4.1277240831685308E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,   4.1277240831685308E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,  -4.1277240831685308E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   9.0244252953300041E-01,  -4.1277240831685308E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,   4.1277240831685308E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -9.0244252953300041E-01,  -4.1277240831685308E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,   9.0244252953300041E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,   9.0244252953300041E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,  -9.0244252953300041E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,   9.0244252953300041E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,  -9.0244252953300041E-01,   4.1277240831685308E-01,   4.2629052407721503E-02],
            [   1.2335485325833270E-01,  -9.0244252953300041E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,   9.0244252953300041E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [  -1.2335485325833270E-01,  -9.0244252953300041E-01,  -4.1277240831685308E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,   9.0244252953300041E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,   9.0244252953300041E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,  -9.0244252953300041E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,   9.0244252953300041E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,  -9.0244252953300041E-01,   1.2335485325833270E-01,   4.2629052407721503E-02],
            [   4.1277240831685308E-01,  -9.0244252953300041E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,   9.0244252953300041E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
            [  -4.1277240831685308E-01,  -9.0244252953300041E-01,  -1.2335485325833270E-01,   4.2629052407721503E-02],
        ])
  
        order = 29
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build350():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.7784522315688622E-02],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.7784522315688622E-02],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   3.7784522315688622E-02],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   3.7784522315688622E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   3.7784522315688622E-02],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   3.7784522315688622E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.8335318858294616E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.8335318858294616E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.8335318858294616E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.8335318858294616E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.8335318858294616E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.8335318858294616E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.8335318858294616E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.8335318858294616E-02],
            [   7.0689654639123156E-01,   7.0689654639123156E-01,   2.4383301669355525E-02,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,   7.0689654639123156E-01,   2.4383301669355525E-02,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,  -7.0689654639123156E-01,   2.4383301669355525E-02,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,   7.0689654639123156E-01,  -2.4383301669355525E-02,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,  -7.0689654639123156E-01,   2.4383301669355525E-02,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,   7.0689654639123156E-01,  -2.4383301669355525E-02,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,  -7.0689654639123156E-01,  -2.4383301669355525E-02,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,  -7.0689654639123156E-01,  -2.4383301669355525E-02,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,   2.4383301669355525E-02,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,  -2.4383301669355525E-02,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,   2.4383301669355525E-02,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,  -2.4383301669355525E-02,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,   2.4383301669355525E-02,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,  -2.4383301669355525E-02,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -7.0689654639123156E-01,  -2.4383301669355525E-02,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [   7.0689654639123156E-01,   2.4383301669355525E-02,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [   2.4383301669355525E-02,   7.0689654639123156E-01,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -2.4383301669355525E-02,   7.0689654639123156E-01,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [   2.4383301669355525E-02,  -7.0689654639123156E-01,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [   2.4383301669355525E-02,   7.0689654639123156E-01,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -2.4383301669355525E-02,  -7.0689654639123156E-01,   7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -2.4383301669355525E-02,   7.0689654639123156E-01,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [   2.4383301669355525E-02,  -7.0689654639123156E-01,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [  -2.4383301669355525E-02,  -7.0689654639123156E-01,  -7.0689654639123156E-01,   2.0371401211874047E-02],
            [   4.7946826257120251E-01,   4.7946826257120251E-01,   7.3499685058774555E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,   4.7946826257120251E-01,   7.3499685058774555E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,  -4.7946826257120251E-01,   7.3499685058774555E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,   4.7946826257120251E-01,  -7.3499685058774555E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,  -4.7946826257120251E-01,   7.3499685058774555E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,   4.7946826257120251E-01,  -7.3499685058774555E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,  -4.7946826257120251E-01,  -7.3499685058774555E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,  -4.7946826257120251E-01,  -7.3499685058774555E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,   7.3499685058774555E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,  -7.3499685058774555E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,   7.3499685058774555E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,  -7.3499685058774555E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,   7.3499685058774555E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,  -7.3499685058774555E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -4.7946826257120251E-01,  -7.3499685058774555E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [   4.7946826257120251E-01,   7.3499685058774555E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [   7.3499685058774555E-01,   4.7946826257120251E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -7.3499685058774555E-01,   4.7946826257120251E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [   7.3499685058774555E-01,  -4.7946826257120251E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [   7.3499685058774555E-01,   4.7946826257120251E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -7.3499685058774555E-01,  -4.7946826257120251E-01,   4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -7.3499685058774555E-01,   4.7946826257120251E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [   7.3499685058774555E-01,  -4.7946826257120251E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [  -7.3499685058774555E-01,  -4.7946826257120251E-01,  -4.7946826257120251E-01,   3.7770758815405106E-02],
            [   1.9275331548780189E-01,   1.9275331548780189E-01,   9.6212905513601443E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,   1.9275331548780189E-01,   9.6212905513601443E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,  -1.9275331548780189E-01,   9.6212905513601443E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,   1.9275331548780189E-01,  -9.6212905513601443E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,  -1.9275331548780189E-01,   9.6212905513601443E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,   1.9275331548780189E-01,  -9.6212905513601443E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,  -1.9275331548780189E-01,  -9.6212905513601443E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,  -1.9275331548780189E-01,  -9.6212905513601443E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,   9.6212905513601443E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,  -9.6212905513601443E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,   9.6212905513601443E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,  -9.6212905513601443E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,   9.6212905513601443E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,  -9.6212905513601443E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -1.9275331548780189E-01,  -9.6212905513601443E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [   1.9275331548780189E-01,   9.6212905513601443E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [   9.6212905513601443E-01,   1.9275331548780189E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -9.6212905513601443E-01,   1.9275331548780189E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [   9.6212905513601443E-01,  -1.9275331548780189E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [   9.6212905513601443E-01,   1.9275331548780189E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -9.6212905513601443E-01,  -1.9275331548780189E-01,   1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -9.6212905513601443E-01,   1.9275331548780189E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [   9.6212905513601443E-01,  -1.9275331548780189E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [  -9.6212905513601443E-01,  -1.9275331548780189E-01,  -1.9275331548780189E-01,   3.7585920632408988E-02],
            [   6.9303579613271227E-01,   6.9303579613271227E-01,   1.9850131122336542E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,   6.9303579613271227E-01,   1.9850131122336542E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,  -6.9303579613271227E-01,   1.9850131122336542E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,   6.9303579613271227E-01,  -1.9850131122336542E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,  -6.9303579613271227E-01,   1.9850131122336542E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,   6.9303579613271227E-01,  -1.9850131122336542E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,  -6.9303579613271227E-01,  -1.9850131122336542E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,  -6.9303579613271227E-01,  -1.9850131122336542E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,   1.9850131122336542E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,  -1.9850131122336542E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,   1.9850131122336542E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,  -1.9850131122336542E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,   1.9850131122336542E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,  -1.9850131122336542E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -6.9303579613271227E-01,  -1.9850131122336542E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [   6.9303579613271227E-01,   1.9850131122336542E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [   1.9850131122336542E-01,   6.9303579613271227E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -1.9850131122336542E-01,   6.9303579613271227E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [   1.9850131122336542E-01,  -6.9303579613271227E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [   1.9850131122336542E-01,   6.9303579613271227E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -1.9850131122336542E-01,  -6.9303579613271227E-01,   6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -1.9850131122336542E-01,   6.9303579613271227E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [   1.9850131122336542E-01,  -6.9303579613271227E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [  -1.9850131122336542E-01,  -6.9303579613271227E-01,  -6.9303579613271227E-01,   3.7475061549118248E-02],
            [   3.6083021155200912E-01,   3.6083021155200912E-01,   8.6000181212754701E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,   3.6083021155200912E-01,   8.6000181212754701E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,  -3.6083021155200912E-01,   8.6000181212754701E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,   3.6083021155200912E-01,  -8.6000181212754701E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,  -3.6083021155200912E-01,   8.6000181212754701E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,   3.6083021155200912E-01,  -8.6000181212754701E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,  -3.6083021155200912E-01,  -8.6000181212754701E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,  -3.6083021155200912E-01,  -8.6000181212754701E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,   8.6000181212754701E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,  -8.6000181212754701E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,   8.6000181212754701E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,  -8.6000181212754701E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,   8.6000181212754701E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,  -8.6000181212754701E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -3.6083021155200912E-01,  -8.6000181212754701E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [   3.6083021155200912E-01,   8.6000181212754701E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [   8.6000181212754701E-01,   3.6083021155200912E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -8.6000181212754701E-01,   3.6083021155200912E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [   8.6000181212754701E-01,  -3.6083021155200912E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [   8.6000181212754701E-01,   3.6083021155200912E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -8.6000181212754701E-01,  -3.6083021155200912E-01,   3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -8.6000181212754701E-01,   3.6083021155200912E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [   8.6000181212754701E-01,  -3.6083021155200912E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [  -8.6000181212754701E-01,  -3.6083021155200912E-01,  -3.6083021155200912E-01,   3.4200184856835687E-02],
            [   6.4984861614961686E-01,   6.4984861614961686E-01,   3.9419988860583888E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,   6.4984861614961686E-01,   3.9419988860583888E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,  -6.4984861614961686E-01,   3.9419988860583888E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,   6.4984861614961686E-01,  -3.9419988860583888E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,  -6.4984861614961686E-01,   3.9419988860583888E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,   6.4984861614961686E-01,  -3.9419988860583888E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,  -6.4984861614961686E-01,  -3.9419988860583888E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,  -6.4984861614961686E-01,  -3.9419988860583888E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,   3.9419988860583888E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,  -3.9419988860583888E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,   3.9419988860583888E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,  -3.9419988860583888E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,   3.9419988860583888E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,  -3.9419988860583888E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -6.4984861614961686E-01,  -3.9419988860583888E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [   6.4984861614961686E-01,   3.9419988860583888E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [   3.9419988860583888E-01,   6.4984861614961686E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -3.9419988860583888E-01,   6.4984861614961686E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [   3.9419988860583888E-01,  -6.4984861614961686E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [   3.9419988860583888E-01,   6.4984861614961686E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -3.9419988860583888E-01,  -6.4984861614961686E-01,   6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -3.9419988860583888E-01,   6.4984861614961686E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [   3.9419988860583888E-01,  -6.4984861614961686E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [  -3.9419988860583888E-01,  -6.4984861614961686E-01,  -6.4984861614961686E-01,   3.8120258621934279E-02],
            [   1.9329450132303391E-01,   9.8114078284325723E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [  -1.9329450132303391E-01,   9.8114078284325723E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [   1.9329450132303391E-01,  -9.8114078284325723E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [  -1.9329450132303391E-01,  -9.8114078284325723E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [   9.8114078284325723E-01,   1.9329450132303391E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [  -9.8114078284325723E-01,   1.9329450132303391E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [   9.8114078284325723E-01,  -1.9329450132303391E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [  -9.8114078284325723E-01,  -1.9329450132303391E-01,   0.0000000000000000E+00,   3.7799008900172910E-02],
            [   1.9329450132303391E-01,   0.0000000000000000E+00,   9.8114078284325723E-01,   3.7799008900172910E-02],
            [  -1.9329450132303391E-01,   0.0000000000000000E+00,   9.8114078284325723E-01,   3.7799008900172910E-02],
            [   1.9329450132303391E-01,   0.0000000000000000E+00,  -9.8114078284325723E-01,   3.7799008900172910E-02],
            [  -1.9329450132303391E-01,   0.0000000000000000E+00,  -9.8114078284325723E-01,   3.7799008900172910E-02],
            [   9.8114078284325723E-01,   0.0000000000000000E+00,   1.9329450132303391E-01,   3.7799008900172910E-02],
            [  -9.8114078284325723E-01,   0.0000000000000000E+00,   1.9329450132303391E-01,   3.7799008900172910E-02],
            [   9.8114078284325723E-01,   0.0000000000000000E+00,  -1.9329450132303391E-01,   3.7799008900172910E-02],
            [  -9.8114078284325723E-01,   0.0000000000000000E+00,  -1.9329450132303391E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,   1.9329450132303391E-01,   9.8114078284325723E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,  -1.9329450132303391E-01,   9.8114078284325723E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,   1.9329450132303391E-01,  -9.8114078284325723E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,  -1.9329450132303391E-01,  -9.8114078284325723E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,   9.8114078284325723E-01,   1.9329450132303391E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,  -9.8114078284325723E-01,   1.9329450132303391E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,   9.8114078284325723E-01,  -1.9329450132303391E-01,   3.7799008900172910E-02],
            [   0.0000000000000000E+00,  -9.8114078284325723E-01,  -1.9329450132303391E-01,   3.7799008900172910E-02],
            [   3.8004949198993032E-01,   9.2496615269867899E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [  -3.8004949198993032E-01,   9.2496615269867899E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [   3.8004949198993032E-01,  -9.2496615269867899E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [  -3.8004949198993032E-01,  -9.2496615269867899E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [   9.2496615269867899E-01,   3.8004949198993032E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [  -9.2496615269867899E-01,   3.8004949198993032E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [   9.2496615269867899E-01,  -3.8004949198993032E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [  -9.2496615269867899E-01,  -3.8004949198993032E-01,   0.0000000000000000E+00,   3.6215835299457509E-02],
            [   3.8004949198993032E-01,   0.0000000000000000E+00,   9.2496615269867899E-01,   3.6215835299457509E-02],
            [  -3.8004949198993032E-01,   0.0000000000000000E+00,   9.2496615269867899E-01,   3.6215835299457509E-02],
            [   3.8004949198993032E-01,   0.0000000000000000E+00,  -9.2496615269867899E-01,   3.6215835299457509E-02],
            [  -3.8004949198993032E-01,   0.0000000000000000E+00,  -9.2496615269867899E-01,   3.6215835299457509E-02],
            [   9.2496615269867899E-01,   0.0000000000000000E+00,   3.8004949198993032E-01,   3.6215835299457509E-02],
            [  -9.2496615269867899E-01,   0.0000000000000000E+00,   3.8004949198993032E-01,   3.6215835299457509E-02],
            [   9.2496615269867899E-01,   0.0000000000000000E+00,  -3.8004949198993032E-01,   3.6215835299457509E-02],
            [  -9.2496615269867899E-01,   0.0000000000000000E+00,  -3.8004949198993032E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,   3.8004949198993032E-01,   9.2496615269867899E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,  -3.8004949198993032E-01,   9.2496615269867899E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,   3.8004949198993032E-01,  -9.2496615269867899E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,  -3.8004949198993032E-01,  -9.2496615269867899E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,   9.2496615269867899E-01,   3.8004949198993032E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,  -9.2496615269867899E-01,   3.8004949198993032E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,   9.2496615269867899E-01,  -3.8004949198993032E-01,   3.6215835299457509E-02],
            [   0.0000000000000000E+00,  -9.2496615269867899E-01,  -3.8004949198993032E-01,   3.6215835299457509E-02],
            [   2.8995588254995741E-01,   7.9345378565823155E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,   7.9345378565823155E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,  -7.9345378565823155E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,   7.9345378565823155E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,  -7.9345378565823155E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,  -7.9345378565823155E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,   7.9345378565823155E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,  -7.9345378565823155E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,   2.8995588254995741E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,   2.8995588254995741E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,  -2.8995588254995741E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,   2.8995588254995741E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,  -2.8995588254995741E-01,   5.3512304771827623E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,  -2.8995588254995741E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,   2.8995588254995741E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,  -2.8995588254995741E-01,  -5.3512304771827623E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,   2.8995588254995741E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,   2.8995588254995741E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,  -2.8995588254995741E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,   2.8995588254995741E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,  -2.8995588254995741E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,  -2.8995588254995741E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,   2.8995588254995741E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,  -2.8995588254995741E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,   7.9345378565823155E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,   7.9345378565823155E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,  -7.9345378565823155E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,   7.9345378565823155E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,  -7.9345378565823155E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   5.3512304771827623E-01,  -7.9345378565823155E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,   7.9345378565823155E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -5.3512304771827623E-01,  -7.9345378565823155E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,   5.3512304771827623E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,   5.3512304771827623E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,  -5.3512304771827623E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,   5.3512304771827623E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,  -5.3512304771827623E-01,   7.9345378565823155E-01,   3.7175818344863519E-02],
            [   2.8995588254995741E-01,  -5.3512304771827623E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,   5.3512304771827623E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [  -2.8995588254995741E-01,  -5.3512304771827623E-01,  -7.9345378565823155E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,   5.3512304771827623E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,   5.3512304771827623E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,  -5.3512304771827623E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,   5.3512304771827623E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,  -5.3512304771827623E-01,   2.8995588254995741E-01,   3.7175818344863519E-02],
            [   7.9345378565823155E-01,  -5.3512304771827623E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,   5.3512304771827623E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [  -7.9345378565823155E-01,  -5.3512304771827623E-01,  -2.8995588254995741E-01,   3.7175818344863519E-02],
            [   9.6841214551039570E-02,   8.2808015066868623E-01,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,   8.2808015066868623E-01,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,  -8.2808015066868623E-01,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,   8.2808015066868623E-01,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,  -8.2808015066868623E-01,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,  -8.2808015066868623E-01,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,   8.2808015066868623E-01,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,  -8.2808015066868623E-01,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,   9.6841214551039570E-02,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,   9.6841214551039570E-02,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,  -9.6841214551039570E-02,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,   9.6841214551039570E-02,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,  -9.6841214551039570E-02,   5.5218207434939925E-01,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,  -9.6841214551039570E-02,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,   9.6841214551039570E-02,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,  -9.6841214551039570E-02,  -5.5218207434939925E-01,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,   9.6841214551039570E-02,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,   9.6841214551039570E-02,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,  -9.6841214551039570E-02,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,   9.6841214551039570E-02,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,  -9.6841214551039570E-02,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,  -9.6841214551039570E-02,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,   9.6841214551039570E-02,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,  -9.6841214551039570E-02,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,   8.2808015066868623E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,   8.2808015066868623E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,  -8.2808015066868623E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,   8.2808015066868623E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,  -8.2808015066868623E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   5.5218207434939925E-01,  -8.2808015066868623E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,   8.2808015066868623E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -5.5218207434939925E-01,  -8.2808015066868623E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,   5.5218207434939925E-01,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,   5.5218207434939925E-01,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,  -5.5218207434939925E-01,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,   5.5218207434939925E-01,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,  -5.5218207434939925E-01,   8.2808015066868623E-01,   3.8151752844447988E-02],
            [   9.6841214551039570E-02,  -5.5218207434939925E-01,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,   5.5218207434939925E-01,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [  -9.6841214551039570E-02,  -5.5218207434939925E-01,  -8.2808015066868623E-01,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,   5.5218207434939925E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,   5.5218207434939925E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,  -5.5218207434939925E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,   5.5218207434939925E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,  -5.5218207434939925E-01,   9.6841214551039570E-02,   3.8151752844447988E-02],
            [   8.2808015066868623E-01,  -5.5218207434939925E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,   5.5218207434939925E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [  -8.2808015066868623E-01,  -5.5218207434939925E-01,  -9.6841214551039570E-02,   3.8151752844447988E-02],
            [   1.8334346470416590E-01,   9.0746582653051266E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,   9.0746582653051266E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,  -9.0746582653051266E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,   9.0746582653051266E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,  -9.0746582653051266E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,  -9.0746582653051266E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,   9.0746582653051266E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,  -9.0746582653051266E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,   1.8334346470416590E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,   1.8334346470416590E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,  -1.8334346470416590E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,   1.8334346470416590E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,  -1.8334346470416590E-01,   3.7800918987448673E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,  -1.8334346470416590E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,   1.8334346470416590E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,  -1.8334346470416590E-01,  -3.7800918987448673E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,   1.8334346470416590E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,   1.8334346470416590E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,  -1.8334346470416590E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,   1.8334346470416590E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,  -1.8334346470416590E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,  -1.8334346470416590E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,   1.8334346470416590E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,  -1.8334346470416590E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,   9.0746582653051266E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,   9.0746582653051266E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,  -9.0746582653051266E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,   9.0746582653051266E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,  -9.0746582653051266E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   3.7800918987448673E-01,  -9.0746582653051266E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,   9.0746582653051266E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -3.7800918987448673E-01,  -9.0746582653051266E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,   3.7800918987448673E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,   3.7800918987448673E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,  -3.7800918987448673E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,   3.7800918987448673E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,  -3.7800918987448673E-01,   9.0746582653051266E-01,   3.5590316567057682E-02],
            [   1.8334346470416590E-01,  -3.7800918987448673E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,   3.7800918987448673E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [  -1.8334346470416590E-01,  -3.7800918987448673E-01,  -9.0746582653051266E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,   3.7800918987448673E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,   3.7800918987448673E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,  -3.7800918987448673E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,   3.7800918987448673E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,  -3.7800918987448673E-01,   1.8334346470416590E-01,   3.5590316567057682E-02],
            [   9.0746582653051266E-01,  -3.7800918987448673E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,   3.7800918987448673E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
            [  -9.0746582653051266E-01,  -3.7800918987448673E-01,  -1.8334346470416590E-01,   3.5590316567057682E-02],
        ])
  
        order = 31
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build434():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.6173225486109225E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   6.6173225486109225E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   6.6173225486109225E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   6.6173225486109225E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   6.6173225486109225E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   6.6173225486109225E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   3.2021876575096711E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   3.2021876575096711E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   3.2021876575096711E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   3.2021876575096711E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   3.2021876575096711E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   3.2021876575096711E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   3.2021876575096711E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   3.2021876575096711E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   3.2021876575096711E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   3.2021876575096711E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   3.2021876575096711E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   3.2021876575096711E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.1570711787150790E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.1570711787150790E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.1570711787150790E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1570711787150790E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.1570711787150790E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1570711787150790E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1570711787150790E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1570711787150790E-02],
            [   6.9093463075091111E-01,   6.9093463075091111E-01,   2.1264682470755186E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,   6.9093463075091111E-01,   2.1264682470755186E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,  -6.9093463075091111E-01,   2.1264682470755186E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,   6.9093463075091111E-01,  -2.1264682470755186E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,  -6.9093463075091111E-01,   2.1264682470755186E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,   6.9093463075091111E-01,  -2.1264682470755186E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,  -6.9093463075091111E-01,  -2.1264682470755186E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,  -6.9093463075091111E-01,  -2.1264682470755186E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,   2.1264682470755186E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,  -2.1264682470755186E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,   2.1264682470755186E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,  -2.1264682470755186E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,   2.1264682470755186E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,  -2.1264682470755186E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -6.9093463075091111E-01,  -2.1264682470755186E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [   6.9093463075091111E-01,   2.1264682470755186E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [   2.1264682470755186E-01,   6.9093463075091111E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -2.1264682470755186E-01,   6.9093463075091111E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [   2.1264682470755186E-01,  -6.9093463075091111E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [   2.1264682470755186E-01,   6.9093463075091111E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -2.1264682470755186E-01,  -6.9093463075091111E-01,   6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -2.1264682470755186E-01,   6.9093463075091111E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [   2.1264682470755186E-01,  -6.9093463075091111E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [  -2.1264682470755186E-01,  -6.9093463075091111E-01,  -6.9093463075091111E-01,   3.1797991969690964E-02],
            [   1.7748360546091579E-01,   1.7748360546091579E-01,   9.6798715879147279E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,   1.7748360546091579E-01,   9.6798715879147279E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,  -1.7748360546091579E-01,   9.6798715879147279E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,   1.7748360546091579E-01,  -9.6798715879147279E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,  -1.7748360546091579E-01,   9.6798715879147279E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,   1.7748360546091579E-01,  -9.6798715879147279E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,  -1.7748360546091579E-01,  -9.6798715879147279E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,  -1.7748360546091579E-01,  -9.6798715879147279E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,   9.6798715879147279E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,  -9.6798715879147279E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,   9.6798715879147279E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,  -9.6798715879147279E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,   9.6798715879147279E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,  -9.6798715879147279E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -1.7748360546091579E-01,  -9.6798715879147279E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [   1.7748360546091579E-01,   9.6798715879147279E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [   9.6798715879147279E-01,   1.7748360546091579E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -9.6798715879147279E-01,   1.7748360546091579E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [   9.6798715879147279E-01,  -1.7748360546091579E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [   9.6798715879147279E-01,   1.7748360546091579E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -9.6798715879147279E-01,  -1.7748360546091579E-01,   1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -9.6798715879147279E-01,   1.7748360546091579E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [   9.6798715879147279E-01,  -1.7748360546091579E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [  -9.6798715879147279E-01,  -1.7748360546091579E-01,  -1.7748360546091579E-01,   2.5312176697590755E-02],
            [   4.9143426377847460E-01,   4.9143426377847460E-01,   7.1901650104084347E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,   4.9143426377847460E-01,   7.1901650104084347E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,  -4.9143426377847460E-01,   7.1901650104084347E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,   4.9143426377847460E-01,  -7.1901650104084347E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,  -4.9143426377847460E-01,   7.1901650104084347E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,   4.9143426377847460E-01,  -7.1901650104084347E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,  -4.9143426377847460E-01,  -7.1901650104084347E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,  -4.9143426377847460E-01,  -7.1901650104084347E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,   7.1901650104084347E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,  -7.1901650104084347E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,   7.1901650104084347E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,  -7.1901650104084347E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,   7.1901650104084347E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,  -7.1901650104084347E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -4.9143426377847460E-01,  -7.1901650104084347E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [   4.9143426377847460E-01,   7.1901650104084347E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [   7.1901650104084347E-01,   4.9143426377847460E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -7.1901650104084347E-01,   4.9143426377847460E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [   7.1901650104084347E-01,  -4.9143426377847460E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [   7.1901650104084347E-01,   4.9143426377847460E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -7.1901650104084347E-01,  -4.9143426377847460E-01,   4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -7.1901650104084347E-01,   4.9143426377847460E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [   7.1901650104084347E-01,  -4.9143426377847460E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [  -7.1901650104084347E-01,  -4.9143426377847460E-01,  -4.9143426377847460E-01,   3.1437605641421403E-02],
            [   6.4566647074242556E-01,   6.4566647074242556E-01,   4.0771266489776975E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,   6.4566647074242556E-01,   4.0771266489776975E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,  -6.4566647074242556E-01,   4.0771266489776975E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,   6.4566647074242556E-01,  -4.0771266489776975E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,  -6.4566647074242556E-01,   4.0771266489776975E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,   6.4566647074242556E-01,  -4.0771266489776975E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,  -6.4566647074242556E-01,  -4.0771266489776975E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,  -6.4566647074242556E-01,  -4.0771266489776975E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,   4.0771266489776975E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,  -4.0771266489776975E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,   4.0771266489776975E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,  -4.0771266489776975E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,   4.0771266489776975E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,  -4.0771266489776975E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -6.4566647074242556E-01,  -4.0771266489776975E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [   6.4566647074242556E-01,   4.0771266489776975E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [   4.0771266489776975E-01,   6.4566647074242556E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -4.0771266489776975E-01,   6.4566647074242556E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [   4.0771266489776975E-01,  -6.4566647074242556E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [   4.0771266489776975E-01,   6.4566647074242556E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -4.0771266489776975E-01,  -6.4566647074242556E-01,   6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -4.0771266489776975E-01,   6.4566647074242556E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [   4.0771266489776975E-01,  -6.4566647074242556E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [  -4.0771266489776975E-01,  -6.4566647074242556E-01,  -6.4566647074242556E-01,   3.1582646768896327E-02],
            [   2.8612890103076383E-01,   2.8612890103076383E-01,   9.1447280112087248E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,   2.8612890103076383E-01,   9.1447280112087248E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,  -2.8612890103076383E-01,   9.1447280112087248E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,   2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,  -2.8612890103076383E-01,   9.1447280112087248E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,   2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,  -2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,  -2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,   9.1447280112087248E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,   9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,  -9.1447280112087248E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,   9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,  -9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -2.8612890103076383E-01,  -9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [   2.8612890103076383E-01,   9.1447280112087248E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [   9.1447280112087248E-01,   2.8612890103076383E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -9.1447280112087248E-01,   2.8612890103076383E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [   9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [   9.1447280112087248E-01,   2.8612890103076383E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -9.1447280112087248E-01,  -2.8612890103076383E-01,   2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -9.1447280112087248E-01,   2.8612890103076383E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [   9.1447280112087248E-01,  -2.8612890103076383E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [  -9.1447280112087248E-01,  -2.8612890103076383E-01,  -2.8612890103076383E-01,   2.8936516045220798E-02],
            [   7.5680843671780185E-02,   7.5680843671780185E-02,   9.9425591263127788E-01,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,   7.5680843671780185E-02,   9.9425591263127788E-01,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,  -7.5680843671780185E-02,   9.9425591263127788E-01,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,   7.5680843671780185E-02,  -9.9425591263127788E-01,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,  -7.5680843671780185E-02,   9.9425591263127788E-01,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,   7.5680843671780185E-02,  -9.9425591263127788E-01,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,  -7.5680843671780185E-02,  -9.9425591263127788E-01,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,  -7.5680843671780185E-02,  -9.9425591263127788E-01,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,   9.9425591263127788E-01,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,  -9.9425591263127788E-01,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,   9.9425591263127788E-01,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,  -9.9425591263127788E-01,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,   9.9425591263127788E-01,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,  -9.9425591263127788E-01,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -7.5680843671780185E-02,  -9.9425591263127788E-01,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [   7.5680843671780185E-02,   9.9425591263127788E-01,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [   9.9425591263127788E-01,   7.5680843671780185E-02,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -9.9425591263127788E-01,   7.5680843671780185E-02,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [   9.9425591263127788E-01,  -7.5680843671780185E-02,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [   9.9425591263127788E-01,   7.5680843671780185E-02,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -9.9425591263127788E-01,  -7.5680843671780185E-02,   7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -9.9425591263127788E-01,   7.5680843671780185E-02,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [   9.9425591263127788E-01,  -7.5680843671780185E-02,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [  -9.9425591263127788E-01,  -7.5680843671780185E-02,  -7.5680843671780185E-02,   1.8378262002835509E-02],
            [   3.9272597633680018E-01,   3.9272597633680018E-01,   8.3158440041923232E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,   3.9272597633680018E-01,   8.3158440041923232E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,  -3.9272597633680018E-01,   8.3158440041923232E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,   3.9272597633680018E-01,  -8.3158440041923232E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,  -3.9272597633680018E-01,   8.3158440041923232E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,   3.9272597633680018E-01,  -8.3158440041923232E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,  -3.9272597633680018E-01,  -8.3158440041923232E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,  -3.9272597633680018E-01,  -8.3158440041923232E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,   8.3158440041923232E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,  -8.3158440041923232E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,   8.3158440041923232E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,  -8.3158440041923232E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,   8.3158440041923232E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,  -8.3158440041923232E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -3.9272597633680018E-01,  -8.3158440041923232E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [   3.9272597633680018E-01,   8.3158440041923232E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [   8.3158440041923232E-01,   3.9272597633680018E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -8.3158440041923232E-01,   3.9272597633680018E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [   8.3158440041923232E-01,  -3.9272597633680018E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [   8.3158440041923232E-01,   3.9272597633680018E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -8.3158440041923232E-01,  -3.9272597633680018E-01,   3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -8.3158440041923232E-01,   3.9272597633680018E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [   8.3158440041923232E-01,  -3.9272597633680018E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [  -8.3158440041923232E-01,  -3.9272597633680018E-01,  -3.9272597633680018E-01,   3.0729468903784314E-02],
            [   8.8181328777942880E-01,   4.7159869115131597E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [  -8.8181328777942880E-01,   4.7159869115131597E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [   8.8181328777942880E-01,  -4.7159869115131597E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [  -8.8181328777942880E-01,  -4.7159869115131597E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [   4.7159869115131597E-01,   8.8181328777942880E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [  -4.7159869115131597E-01,   8.8181328777942880E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [   4.7159869115131597E-01,  -8.8181328777942880E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [  -4.7159869115131597E-01,  -8.8181328777942880E-01,   0.0000000000000000E+00,   3.0378476831136317E-02],
            [   8.8181328777942880E-01,   0.0000000000000000E+00,   4.7159869115131597E-01,   3.0378476831136317E-02],
            [  -8.8181328777942880E-01,   0.0000000000000000E+00,   4.7159869115131597E-01,   3.0378476831136317E-02],
            [   8.8181328777942880E-01,   0.0000000000000000E+00,  -4.7159869115131597E-01,   3.0378476831136317E-02],
            [  -8.8181328777942880E-01,   0.0000000000000000E+00,  -4.7159869115131597E-01,   3.0378476831136317E-02],
            [   4.7159869115131597E-01,   0.0000000000000000E+00,   8.8181328777942880E-01,   3.0378476831136317E-02],
            [  -4.7159869115131597E-01,   0.0000000000000000E+00,   8.8181328777942880E-01,   3.0378476831136317E-02],
            [   4.7159869115131597E-01,   0.0000000000000000E+00,  -8.8181328777942880E-01,   3.0378476831136317E-02],
            [  -4.7159869115131597E-01,   0.0000000000000000E+00,  -8.8181328777942880E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,   8.8181328777942880E-01,   4.7159869115131597E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,  -8.8181328777942880E-01,   4.7159869115131597E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,   8.8181328777942880E-01,  -4.7159869115131597E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,  -8.8181328777942880E-01,  -4.7159869115131597E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,   4.7159869115131597E-01,   8.8181328777942880E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,  -4.7159869115131597E-01,   8.8181328777942880E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,   4.7159869115131597E-01,  -8.8181328777942880E-01,   3.0378476831136317E-02],
            [   0.0000000000000000E+00,  -4.7159869115131597E-01,  -8.8181328777942880E-01,   3.0378476831136317E-02],
            [   9.7764281111826490E-01,   2.1027252285730680E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [  -9.7764281111826490E-01,   2.1027252285730680E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [   9.7764281111826490E-01,  -2.1027252285730680E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [  -9.7764281111826490E-01,  -2.1027252285730680E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [   2.1027252285730680E-01,   9.7764281111826490E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [  -2.1027252285730680E-01,   9.7764281111826490E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [   2.1027252285730680E-01,  -9.7764281111826490E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [  -2.1027252285730680E-01,  -9.7764281111826490E-01,   0.0000000000000000E+00,   2.4013722037852854E-02],
            [   9.7764281111826490E-01,   0.0000000000000000E+00,   2.1027252285730680E-01,   2.4013722037852854E-02],
            [  -9.7764281111826490E-01,   0.0000000000000000E+00,   2.1027252285730680E-01,   2.4013722037852854E-02],
            [   9.7764281111826490E-01,   0.0000000000000000E+00,  -2.1027252285730680E-01,   2.4013722037852854E-02],
            [  -9.7764281111826490E-01,   0.0000000000000000E+00,  -2.1027252285730680E-01,   2.4013722037852854E-02],
            [   2.1027252285730680E-01,   0.0000000000000000E+00,   9.7764281111826490E-01,   2.4013722037852854E-02],
            [  -2.1027252285730680E-01,   0.0000000000000000E+00,   9.7764281111826490E-01,   2.4013722037852854E-02],
            [   2.1027252285730680E-01,   0.0000000000000000E+00,  -9.7764281111826490E-01,   2.4013722037852854E-02],
            [  -2.1027252285730680E-01,   0.0000000000000000E+00,  -9.7764281111826490E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,   9.7764281111826490E-01,   2.1027252285730680E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,  -9.7764281111826490E-01,   2.1027252285730680E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,   9.7764281111826490E-01,  -2.1027252285730680E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,  -9.7764281111826490E-01,  -2.1027252285730680E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,   2.1027252285730680E-01,   9.7764281111826490E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,  -2.1027252285730680E-01,   9.7764281111826490E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,   2.1027252285730680E-01,  -9.7764281111826490E-01,   2.4013722037852854E-02],
            [   0.0000000000000000E+00,  -2.1027252285730680E-01,  -9.7764281111826490E-01,   2.4013722037852854E-02],
            [   2.0548236964030439E-01,   8.6894603228724121E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,   8.6894603228724121E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,  -8.6894603228724121E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,   8.6894603228724121E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,  -8.6894603228724121E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,  -8.6894603228724121E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,   8.6894603228724121E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,  -8.6894603228724121E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,   2.0548236964030439E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,   2.0548236964030439E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,  -2.0548236964030439E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,   2.0548236964030439E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,  -2.0548236964030439E-01,   4.5023303825826250E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,  -2.0548236964030439E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,   2.0548236964030439E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,  -2.0548236964030439E-01,  -4.5023303825826250E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,   2.0548236964030439E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,   2.0548236964030439E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,  -2.0548236964030439E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,   2.0548236964030439E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,  -2.0548236964030439E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,  -2.0548236964030439E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,   2.0548236964030439E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,  -2.0548236964030439E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,   8.6894603228724121E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,   8.6894603228724121E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,  -8.6894603228724121E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,   8.6894603228724121E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,  -8.6894603228724121E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   4.5023303825826250E-01,  -8.6894603228724121E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,   8.6894603228724121E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -4.5023303825826250E-01,  -8.6894603228724121E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,   4.5023303825826250E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,   4.5023303825826250E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,  -4.5023303825826250E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,   4.5023303825826250E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,  -4.5023303825826250E-01,   8.6894603228724121E-01,   3.0372038685964664E-02],
            [   2.0548236964030439E-01,  -4.5023303825826250E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,   4.5023303825826250E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [  -2.0548236964030439E-01,  -4.5023303825826250E-01,  -8.6894603228724121E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,   4.5023303825826250E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,   4.5023303825826250E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,  -4.5023303825826250E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,   4.5023303825826250E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,  -4.5023303825826250E-01,   2.0548236964030439E-01,   3.0372038685964664E-02],
            [   8.6894603228724121E-01,  -4.5023303825826250E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,   4.5023303825826250E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [  -8.6894603228724121E-01,  -4.5023303825826250E-01,  -2.0548236964030439E-01,   3.0372038685964664E-02],
            [   5.9051570489252714E-01,   7.9992785438572855E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,   7.9992785438572855E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,  -7.9992785438572855E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,   7.9992785438572855E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,  -7.9992785438572855E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,  -7.9992785438572855E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,   7.9992785438572855E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,  -7.9992785438572855E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,   5.9051570489252714E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,   5.9051570489252714E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,  -5.9051570489252714E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,   5.9051570489252714E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,  -5.9051570489252714E-01,   1.0680182607580488E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,  -5.9051570489252714E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,   5.9051570489252714E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,  -5.9051570489252714E-01,  -1.0680182607580488E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,   5.9051570489252714E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,   5.9051570489252714E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,  -5.9051570489252714E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,   5.9051570489252714E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,  -5.9051570489252714E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,  -5.9051570489252714E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,   5.9051570489252714E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,  -5.9051570489252714E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,   7.9992785438572855E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,   7.9992785438572855E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,  -7.9992785438572855E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,   7.9992785438572855E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,  -7.9992785438572855E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   1.0680182607580488E-01,  -7.9992785438572855E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,   7.9992785438572855E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -1.0680182607580488E-01,  -7.9992785438572855E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,   1.0680182607580488E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,   1.0680182607580488E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,  -1.0680182607580488E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,   1.0680182607580488E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,  -1.0680182607580488E-01,   7.9992785438572855E-01,   3.1569699385496822E-02],
            [   5.9051570489252714E-01,  -1.0680182607580488E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,   1.0680182607580488E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [  -5.9051570489252714E-01,  -1.0680182607580488E-01,  -7.9992785438572855E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,   1.0680182607580488E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,   1.0680182607580488E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,  -1.0680182607580488E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,   1.0680182607580488E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,  -1.0680182607580488E-01,   5.9051570489252714E-01,   3.1569699385496822E-02],
            [   7.9992785438572855E-01,  -1.0680182607580488E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,   1.0680182607580488E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [  -7.9992785438572855E-01,  -1.0680182607580488E-01,  -5.9051570489252714E-01,   3.1569699385496822E-02],
            [   5.5501523610768067E-01,   7.7174626269159008E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,   7.7174626269159008E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,   7.7174626269159008E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,  -7.7174626269159008E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,   7.7174626269159008E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,  -7.7174626269159008E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,   5.5501523610768067E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,   5.5501523610768067E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,   5.5501523610768067E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1042840351665446E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,  -5.5501523610768067E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,   5.5501523610768067E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,  -5.5501523610768067E-01,  -3.1042840351665446E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,   5.5501523610768067E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,   5.5501523610768067E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,  -5.5501523610768067E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,   5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,  -5.5501523610768067E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,  -5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,   5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,  -5.5501523610768067E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,   7.7174626269159008E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,   7.7174626269159008E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,  -7.7174626269159008E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,   7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,  -7.7174626269159008E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   3.1042840351665446E-01,  -7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,   7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -3.1042840351665446E-01,  -7.7174626269159008E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,   3.1042840351665446E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,   3.1042840351665446E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,  -3.1042840351665446E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,   3.1042840351665446E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,  -3.1042840351665446E-01,   7.7174626269159008E-01,   3.1373754481650439E-02],
            [   5.5501523610768067E-01,  -3.1042840351665446E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,   3.1042840351665446E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [  -5.5501523610768067E-01,  -3.1042840351665446E-01,  -7.7174626269159008E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,   3.1042840351665446E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,   3.1042840351665446E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,  -3.1042840351665446E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,   3.1042840351665446E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,  -3.1042840351665446E-01,   5.5501523610768067E-01,   3.1373754481650439E-02],
            [   7.7174626269159008E-01,  -3.1042840351665446E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,   3.1042840351665446E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [  -7.7174626269159008E-01,  -3.1042840351665446E-01,  -5.5501523610768067E-01,   3.1373754481650439E-02],
            [   9.3718098585537224E-01,   3.3443631453434552E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,   3.3443631453434552E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,  -3.3443631453434552E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,   3.3443631453434552E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,  -3.3443631453434552E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,  -3.3443631453434552E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,   3.3443631453434552E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,  -3.3443631453434552E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,   9.3718098585537224E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,   9.3718098585537224E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,  -9.3718098585537224E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,   9.3718098585537224E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,  -9.3718098585537224E-01,   9.9217696364292479E-02,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,  -9.3718098585537224E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,   9.3718098585537224E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,  -9.3718098585537224E-01,  -9.9217696364292479E-02,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,   9.3718098585537224E-01,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,   9.3718098585537224E-01,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,  -9.3718098585537224E-01,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,   9.3718098585537224E-01,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,  -9.3718098585537224E-01,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,  -9.3718098585537224E-01,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,   9.3718098585537224E-01,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,  -9.3718098585537224E-01,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,   3.3443631453434552E-01,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,   3.3443631453434552E-01,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,  -3.3443631453434552E-01,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,   3.3443631453434552E-01,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,  -3.3443631453434552E-01,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   9.9217696364292479E-02,  -3.3443631453434552E-01,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,   3.3443631453434552E-01,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -9.9217696364292479E-02,  -3.3443631453434552E-01,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,   9.9217696364292479E-02,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,   9.9217696364292479E-02,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,  -9.9217696364292479E-02,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,   9.9217696364292479E-02,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,  -9.9217696364292479E-02,   3.3443631453434552E-01,   2.8106042036613862E-02],
            [   9.3718098585537224E-01,  -9.9217696364292479E-02,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,   9.9217696364292479E-02,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [  -9.3718098585537224E-01,  -9.9217696364292479E-02,  -3.3443631453434552E-01,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,   9.9217696364292479E-02,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,   9.9217696364292479E-02,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,  -9.9217696364292479E-02,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,   9.9217696364292479E-02,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,  -9.9217696364292479E-02,   9.3718098585537224E-01,   2.8106042036613862E-02],
            [   3.3443631453434552E-01,  -9.9217696364292479E-02,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,   9.9217696364292479E-02,  -9.3718098585537224E-01,   2.8106042036613862E-02],
            [  -3.3443631453434552E-01,  -9.9217696364292479E-02,  -9.3718098585537224E-01,   2.8106042036613862E-02],
        ])
  
        order = 35
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build590():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.8894441293212969E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.8894441293212969E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   3.8894441293212969E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   3.8894441293212969E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   3.8894441293212969E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   3.8894441293212969E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.3277689811090987E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.3277689811090987E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.3277689811090987E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3277689811090987E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.3277689811090987E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3277689811090987E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3277689811090987E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3277689811090987E-02],
            [   7.0409549382274694E-01,   7.0409549382274694E-01,   9.2190407076898254E-02,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,   7.0409549382274694E-01,   9.2190407076898254E-02,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,  -7.0409549382274694E-01,   9.2190407076898254E-02,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,   7.0409549382274694E-01,  -9.2190407076898254E-02,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,  -7.0409549382274694E-01,   9.2190407076898254E-02,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,   7.0409549382274694E-01,  -9.2190407076898254E-02,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,  -7.0409549382274694E-01,  -9.2190407076898254E-02,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,  -7.0409549382274694E-01,  -9.2190407076898254E-02,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,   9.2190407076898254E-02,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,  -9.2190407076898254E-02,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,   9.2190407076898254E-02,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,  -9.2190407076898254E-02,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,   9.2190407076898254E-02,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,  -9.2190407076898254E-02,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -7.0409549382274694E-01,  -9.2190407076898254E-02,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [   7.0409549382274694E-01,   9.2190407076898254E-02,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [   9.2190407076898254E-02,   7.0409549382274694E-01,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -9.2190407076898254E-02,   7.0409549382274694E-01,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [   9.2190407076898254E-02,  -7.0409549382274694E-01,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [   9.2190407076898254E-02,   7.0409549382274694E-01,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -9.2190407076898254E-02,  -7.0409549382274694E-01,   7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -9.2190407076898254E-02,   7.0409549382274694E-01,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [   9.2190407076898254E-02,  -7.0409549382274694E-01,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [  -9.2190407076898254E-02,  -7.0409549382274694E-01,  -7.0409549382274694E-01,   2.3521614885652412E-02],
            [   6.8077440664552435E-01,   6.8077440664552435E-01,   2.7035608835916480E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,   6.8077440664552435E-01,   2.7035608835916480E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,  -6.8077440664552435E-01,   2.7035608835916480E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,   6.8077440664552435E-01,  -2.7035608835916480E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,  -6.8077440664552435E-01,   2.7035608835916480E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,   6.8077440664552435E-01,  -2.7035608835916480E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,  -6.8077440664552435E-01,  -2.7035608835916480E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,  -6.8077440664552435E-01,  -2.7035608835916480E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,   2.7035608835916480E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,  -2.7035608835916480E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,   2.7035608835916480E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,  -2.7035608835916480E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,   2.7035608835916480E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,  -2.7035608835916480E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -6.8077440664552435E-01,  -2.7035608835916480E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [   6.8077440664552435E-01,   2.7035608835916480E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [   2.7035608835916480E-01,   6.8077440664552435E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -2.7035608835916480E-01,   6.8077440664552435E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [   2.7035608835916480E-01,  -6.8077440664552435E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [   2.7035608835916480E-01,   6.8077440664552435E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -2.7035608835916480E-01,  -6.8077440664552435E-01,   6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -2.7035608835916480E-01,   6.8077440664552435E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [   2.7035608835916480E-01,  -6.8077440664552435E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [  -2.7035608835916480E-01,  -6.8077440664552435E-01,  -6.8077440664552435E-01,   2.3358527851253065E-02],
            [   6.3725469392587519E-01,   6.3725469392587519E-01,   4.3337386877715439E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,   6.3725469392587519E-01,   4.3337386877715439E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,  -6.3725469392587519E-01,   4.3337386877715439E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,   6.3725469392587519E-01,  -4.3337386877715439E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,  -6.3725469392587519E-01,   4.3337386877715439E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,   6.3725469392587519E-01,  -4.3337386877715439E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,  -6.3725469392587519E-01,  -4.3337386877715439E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,  -6.3725469392587519E-01,  -4.3337386877715439E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,   4.3337386877715439E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,  -4.3337386877715439E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,   4.3337386877715439E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,  -4.3337386877715439E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,   4.3337386877715439E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,  -4.3337386877715439E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -6.3725469392587519E-01,  -4.3337386877715439E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [   6.3725469392587519E-01,   4.3337386877715439E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [   4.3337386877715439E-01,   6.3725469392587519E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -4.3337386877715439E-01,   6.3725469392587519E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [   4.3337386877715439E-01,  -6.3725469392587519E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [   4.3337386877715439E-01,   6.3725469392587519E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -4.3337386877715439E-01,  -6.3725469392587519E-01,   6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -4.3337386877715439E-01,   6.3725469392587519E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [   4.3337386877715439E-01,  -6.3725469392587519E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [  -4.3337386877715439E-01,  -6.3725469392587519E-01,  -6.3725469392587519E-01,   2.3273280644847582E-02],
            [   5.0444197078003583E-01,   5.0444197078003583E-01,   7.0076857537357296E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,   5.0444197078003583E-01,   7.0076857537357296E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,  -5.0444197078003583E-01,   7.0076857537357296E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,   5.0444197078003583E-01,  -7.0076857537357296E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,  -5.0444197078003583E-01,   7.0076857537357296E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,   5.0444197078003583E-01,  -7.0076857537357296E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,  -5.0444197078003583E-01,  -7.0076857537357296E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,  -5.0444197078003583E-01,  -7.0076857537357296E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,   7.0076857537357296E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,  -7.0076857537357296E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,   7.0076857537357296E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,  -7.0076857537357296E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,   7.0076857537357296E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,  -7.0076857537357296E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -5.0444197078003583E-01,  -7.0076857537357296E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [   5.0444197078003583E-01,   7.0076857537357296E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [   7.0076857537357296E-01,   5.0444197078003583E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -7.0076857537357296E-01,   5.0444197078003583E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [   7.0076857537357296E-01,  -5.0444197078003583E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [   7.0076857537357296E-01,   5.0444197078003583E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -7.0076857537357296E-01,  -5.0444197078003583E-01,   5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -7.0076857537357296E-01,   5.0444197078003583E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [   7.0076857537357296E-01,  -5.0444197078003583E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [  -7.0076857537357296E-01,  -5.0444197078003583E-01,  -5.0444197078003583E-01,   2.3206517124447171E-02],
            [   4.2157617840109668E-01,   4.2157617840109668E-01,   8.0283687733527376E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,   4.2157617840109668E-01,   8.0283687733527376E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,  -4.2157617840109668E-01,   8.0283687733527376E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,   4.2157617840109668E-01,  -8.0283687733527376E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,  -4.2157617840109668E-01,   8.0283687733527376E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,   4.2157617840109668E-01,  -8.0283687733527376E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,  -4.2157617840109668E-01,  -8.0283687733527376E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,  -4.2157617840109668E-01,  -8.0283687733527376E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,   8.0283687733527376E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,  -8.0283687733527376E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,   8.0283687733527376E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,  -8.0283687733527376E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,   8.0283687733527376E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,  -8.0283687733527376E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -4.2157617840109668E-01,  -8.0283687733527376E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [   4.2157617840109668E-01,   8.0283687733527376E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [   8.0283687733527376E-01,   4.2157617840109668E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -8.0283687733527376E-01,   4.2157617840109668E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [   8.0283687733527376E-01,  -4.2157617840109668E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [   8.0283687733527376E-01,   4.2157617840109668E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -8.0283687733527376E-01,  -4.2157617840109668E-01,   4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -8.0283687733527376E-01,   4.2157617840109668E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [   8.0283687733527376E-01,  -4.2157617840109668E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [  -8.0283687733527376E-01,  -4.2157617840109668E-01,  -4.2157617840109668E-01,   2.2851590316146090E-02],
            [   3.3179207364721230E-01,   3.3179207364721230E-01,   8.8307872793413256E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,   3.3179207364721230E-01,   8.8307872793413256E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,  -3.3179207364721230E-01,   8.8307872793413256E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,   3.3179207364721230E-01,  -8.8307872793413256E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,  -3.3179207364721230E-01,   8.8307872793413256E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,   3.3179207364721230E-01,  -8.8307872793413256E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,  -3.3179207364721230E-01,  -8.8307872793413256E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,  -3.3179207364721230E-01,  -8.8307872793413256E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,   8.8307872793413256E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,  -8.8307872793413256E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,   8.8307872793413256E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,  -8.8307872793413256E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,   8.8307872793413256E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,  -8.8307872793413256E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -3.3179207364721230E-01,  -8.8307872793413256E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [   3.3179207364721230E-01,   8.8307872793413256E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [   8.8307872793413256E-01,   3.3179207364721230E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -8.8307872793413256E-01,   3.3179207364721230E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [   8.8307872793413256E-01,  -3.3179207364721230E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [   8.8307872793413256E-01,   3.3179207364721230E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -8.8307872793413256E-01,  -3.3179207364721230E-01,   3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -8.8307872793413256E-01,   3.3179207364721230E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [   8.8307872793413256E-01,  -3.3179207364721230E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [  -8.8307872793413256E-01,  -3.3179207364721230E-01,  -3.3179207364721230E-01,   2.1985677897179270E-02],
            [   2.3847367014218870E-01,   2.3847367014218870E-01,   9.4141415822040253E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,   2.3847367014218870E-01,   9.4141415822040253E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,  -2.3847367014218870E-01,   9.4141415822040253E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,   2.3847367014218870E-01,  -9.4141415822040253E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,  -2.3847367014218870E-01,   9.4141415822040253E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,   2.3847367014218870E-01,  -9.4141415822040253E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,  -2.3847367014218870E-01,  -9.4141415822040253E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,  -2.3847367014218870E-01,  -9.4141415822040253E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,   9.4141415822040253E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,  -9.4141415822040253E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,   9.4141415822040253E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,  -9.4141415822040253E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,   9.4141415822040253E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,  -9.4141415822040253E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -2.3847367014218870E-01,  -9.4141415822040253E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [   2.3847367014218870E-01,   9.4141415822040253E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [   9.4141415822040253E-01,   2.3847367014218870E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -9.4141415822040253E-01,   2.3847367014218870E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [   9.4141415822040253E-01,  -2.3847367014218870E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [   9.4141415822040253E-01,   2.3847367014218870E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -9.4141415822040253E-01,  -2.3847367014218870E-01,   2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -9.4141415822040253E-01,   2.3847367014218870E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [   9.4141415822040253E-01,  -2.3847367014218870E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [  -9.4141415822040253E-01,  -2.3847367014218870E-01,  -2.3847367014218870E-01,   2.0322468354886609E-02],
            [   1.4590364491577629E-01,   1.4590364491577629E-01,   9.7848058376269387E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,   1.4590364491577629E-01,   9.7848058376269387E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,  -1.4590364491577629E-01,   9.7848058376269387E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,   1.4590364491577629E-01,  -9.7848058376269387E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,  -1.4590364491577629E-01,   9.7848058376269387E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,   1.4590364491577629E-01,  -9.7848058376269387E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,  -1.4590364491577629E-01,  -9.7848058376269387E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,  -1.4590364491577629E-01,  -9.7848058376269387E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,   9.7848058376269387E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,  -9.7848058376269387E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,   9.7848058376269387E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,  -9.7848058376269387E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,   9.7848058376269387E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,  -9.7848058376269387E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -1.4590364491577629E-01,  -9.7848058376269387E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [   1.4590364491577629E-01,   9.7848058376269387E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [   9.7848058376269387E-01,   1.4590364491577629E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -9.7848058376269387E-01,   1.4590364491577629E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [   9.7848058376269387E-01,  -1.4590364491577629E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [   9.7848058376269387E-01,   1.4590364491577629E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -9.7848058376269387E-01,  -1.4590364491577629E-01,   1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -9.7848058376269387E-01,   1.4590364491577629E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [   9.7848058376269387E-01,  -1.4590364491577629E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [  -9.7848058376269387E-01,  -1.4590364491577629E-01,  -1.4590364491577629E-01,   1.7401121296649277E-02],
            [   6.0950341155071960E-02,   6.0950341155071960E-02,   9.9627812975401642E-01,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,   6.0950341155071960E-02,   9.9627812975401642E-01,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,  -6.0950341155071960E-02,   9.9627812975401642E-01,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,   6.0950341155071960E-02,  -9.9627812975401642E-01,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,  -6.0950341155071960E-02,   9.9627812975401642E-01,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,   6.0950341155071960E-02,  -9.9627812975401642E-01,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,  -6.0950341155071960E-02,  -9.9627812975401642E-01,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,  -6.0950341155071960E-02,  -9.9627812975401642E-01,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,   9.9627812975401642E-01,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,  -9.9627812975401642E-01,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,   9.9627812975401642E-01,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,  -9.9627812975401642E-01,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,   9.9627812975401642E-01,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,  -9.9627812975401642E-01,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -6.0950341155071960E-02,  -9.9627812975401642E-01,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [   6.0950341155071960E-02,   9.9627812975401642E-01,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [   9.9627812975401642E-01,   6.0950341155071960E-02,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -9.9627812975401642E-01,   6.0950341155071960E-02,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [   9.9627812975401642E-01,  -6.0950341155071960E-02,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [   9.9627812975401642E-01,   6.0950341155071960E-02,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -9.9627812975401642E-01,  -6.0950341155071960E-02,   6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -9.9627812975401642E-01,   6.0950341155071960E-02,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [   9.9627812975401642E-01,  -6.0950341155071960E-02,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [  -9.9627812975401642E-01,  -6.0950341155071960E-02,  -6.0950341155071960E-02,   1.2270220422136898E-02],
            [   6.1168434420098761E-01,   7.9110192962690196E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [  -6.1168434420098761E-01,   7.9110192962690196E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [   6.1168434420098761E-01,  -7.9110192962690196E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [  -6.1168434420098761E-01,  -7.9110192962690196E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [   7.9110192962690196E-01,   6.1168434420098761E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [  -7.9110192962690196E-01,   6.1168434420098761E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [   7.9110192962690196E-01,  -6.1168434420098761E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [  -7.9110192962690196E-01,  -6.1168434420098761E-01,   0.0000000000000000E+00,   2.3337775889269885E-02],
            [   6.1168434420098761E-01,   0.0000000000000000E+00,   7.9110192962690196E-01,   2.3337775889269885E-02],
            [  -6.1168434420098761E-01,   0.0000000000000000E+00,   7.9110192962690196E-01,   2.3337775889269885E-02],
            [   6.1168434420098761E-01,   0.0000000000000000E+00,  -7.9110192962690196E-01,   2.3337775889269885E-02],
            [  -6.1168434420098761E-01,   0.0000000000000000E+00,  -7.9110192962690196E-01,   2.3337775889269885E-02],
            [   7.9110192962690196E-01,   0.0000000000000000E+00,   6.1168434420098761E-01,   2.3337775889269885E-02],
            [  -7.9110192962690196E-01,   0.0000000000000000E+00,   6.1168434420098761E-01,   2.3337775889269885E-02],
            [   7.9110192962690196E-01,   0.0000000000000000E+00,  -6.1168434420098761E-01,   2.3337775889269885E-02],
            [  -7.9110192962690196E-01,   0.0000000000000000E+00,  -6.1168434420098761E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,   6.1168434420098761E-01,   7.9110192962690196E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,  -6.1168434420098761E-01,   7.9110192962690196E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,   6.1168434420098761E-01,  -7.9110192962690196E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,  -6.1168434420098761E-01,  -7.9110192962690196E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,   7.9110192962690196E-01,   6.1168434420098761E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,  -7.9110192962690196E-01,   6.1168434420098761E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,   7.9110192962690196E-01,  -6.1168434420098761E-01,   2.3337775889269885E-02],
            [   0.0000000000000000E+00,  -7.9110192962690196E-01,  -6.1168434420098761E-01,   2.3337775889269885E-02],
            [   3.9647553481998582E-01,   9.1804528771145399E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [  -3.9647553481998582E-01,   9.1804528771145399E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [   3.9647553481998582E-01,  -9.1804528771145399E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [  -3.9647553481998582E-01,  -9.1804528771145399E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [   9.1804528771145399E-01,   3.9647553481998582E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [  -9.1804528771145399E-01,   3.9647553481998582E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [   9.1804528771145399E-01,  -3.9647553481998582E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [  -9.1804528771145399E-01,  -3.9647553481998582E-01,   0.0000000000000000E+00,   2.1427597073266094E-02],
            [   3.9647553481998582E-01,   0.0000000000000000E+00,   9.1804528771145399E-01,   2.1427597073266094E-02],
            [  -3.9647553481998582E-01,   0.0000000000000000E+00,   9.1804528771145399E-01,   2.1427597073266094E-02],
            [   3.9647553481998582E-01,   0.0000000000000000E+00,  -9.1804528771145399E-01,   2.1427597073266094E-02],
            [  -3.9647553481998582E-01,   0.0000000000000000E+00,  -9.1804528771145399E-01,   2.1427597073266094E-02],
            [   9.1804528771145399E-01,   0.0000000000000000E+00,   3.9647553481998582E-01,   2.1427597073266094E-02],
            [  -9.1804528771145399E-01,   0.0000000000000000E+00,   3.9647553481998582E-01,   2.1427597073266094E-02],
            [   9.1804528771145399E-01,   0.0000000000000000E+00,  -3.9647553481998582E-01,   2.1427597073266094E-02],
            [  -9.1804528771145399E-01,   0.0000000000000000E+00,  -3.9647553481998582E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,   3.9647553481998582E-01,   9.1804528771145399E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,  -3.9647553481998582E-01,   9.1804528771145399E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,   3.9647553481998582E-01,  -9.1804528771145399E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,  -3.9647553481998582E-01,  -9.1804528771145399E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,   9.1804528771145399E-01,   3.9647553481998582E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,  -9.1804528771145399E-01,   3.9647553481998582E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,   9.1804528771145399E-01,  -3.9647553481998582E-01,   2.1427597073266094E-02],
            [   0.0000000000000000E+00,  -9.1804528771145399E-01,  -3.9647553481998582E-01,   2.1427597073266094E-02],
            [   1.7247820099077241E-01,   9.8501333502800192E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [  -1.7247820099077241E-01,   9.8501333502800192E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [   1.7247820099077241E-01,  -9.8501333502800192E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [  -1.7247820099077241E-01,  -9.8501333502800192E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [   9.8501333502800192E-01,   1.7247820099077241E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [  -9.8501333502800192E-01,   1.7247820099077241E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [   9.8501333502800192E-01,  -1.7247820099077241E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [  -9.8501333502800192E-01,  -1.7247820099077241E-01,   0.0000000000000000E+00,   1.6340324222732412E-02],
            [   1.7247820099077241E-01,   0.0000000000000000E+00,   9.8501333502800192E-01,   1.6340324222732412E-02],
            [  -1.7247820099077241E-01,   0.0000000000000000E+00,   9.8501333502800192E-01,   1.6340324222732412E-02],
            [   1.7247820099077241E-01,   0.0000000000000000E+00,  -9.8501333502800192E-01,   1.6340324222732412E-02],
            [  -1.7247820099077241E-01,   0.0000000000000000E+00,  -9.8501333502800192E-01,   1.6340324222732412E-02],
            [   9.8501333502800192E-01,   0.0000000000000000E+00,   1.7247820099077241E-01,   1.6340324222732412E-02],
            [  -9.8501333502800192E-01,   0.0000000000000000E+00,   1.7247820099077241E-01,   1.6340324222732412E-02],
            [   9.8501333502800192E-01,   0.0000000000000000E+00,  -1.7247820099077241E-01,   1.6340324222732412E-02],
            [  -9.8501333502800192E-01,   0.0000000000000000E+00,  -1.7247820099077241E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,   1.7247820099077241E-01,   9.8501333502800192E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,  -1.7247820099077241E-01,   9.8501333502800192E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,   1.7247820099077241E-01,  -9.8501333502800192E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,  -1.7247820099077241E-01,  -9.8501333502800192E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,   9.8501333502800192E-01,   1.7247820099077241E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,  -9.8501333502800192E-01,   1.7247820099077241E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,   9.8501333502800192E-01,  -1.7247820099077241E-01,   1.6340324222732412E-02],
            [   0.0000000000000000E+00,  -9.8501333502800192E-01,  -1.7247820099077241E-01,   1.6340324222732412E-02],
            [   5.6102638086220602E-01,   3.5182809277335192E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,   3.5182809277335192E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,  -3.5182809277335192E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,   3.5182809277335192E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,  -3.5182809277335192E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,  -3.5182809277335192E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,   3.5182809277335192E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,  -3.5182809277335192E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,   5.6102638086220602E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,   5.6102638086220602E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,  -5.6102638086220602E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,   5.6102638086220602E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,  -5.6102638086220602E-01,   7.4931061190411585E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,  -5.6102638086220602E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,   5.6102638086220602E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,  -5.6102638086220602E-01,  -7.4931061190411585E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,   5.6102638086220602E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,   5.6102638086220602E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,  -5.6102638086220602E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,   5.6102638086220602E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,  -5.6102638086220602E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,  -5.6102638086220602E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,   5.6102638086220602E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,  -5.6102638086220602E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,   3.5182809277335192E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,   3.5182809277335192E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,  -3.5182809277335192E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,   3.5182809277335192E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,  -3.5182809277335192E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   7.4931061190411585E-01,  -3.5182809277335192E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,   3.5182809277335192E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -7.4931061190411585E-01,  -3.5182809277335192E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,   7.4931061190411585E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,   7.4931061190411585E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,  -7.4931061190411585E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,   7.4931061190411585E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,  -7.4931061190411585E-01,   3.5182809277335192E-01,   2.3158143091304720E-02],
            [   5.6102638086220602E-01,  -7.4931061190411585E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,   7.4931061190411585E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [  -5.6102638086220602E-01,  -7.4931061190411585E-01,  -3.5182809277335192E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,   7.4931061190411585E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,   7.4931061190411585E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,  -7.4931061190411585E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,   7.4931061190411585E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,  -7.4931061190411585E-01,   5.6102638086220602E-01,   2.3158143091304720E-02],
            [   3.5182809277335192E-01,  -7.4931061190411585E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,   7.4931061190411585E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [  -3.5182809277335192E-01,  -7.4931061190411585E-01,  -5.6102638086220602E-01,   2.3158143091304720E-02],
            [   4.7423928425519801E-01,   2.6347166559379498E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,   2.6347166559379498E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,  -2.6347166559379498E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,   2.6347166559379498E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,  -2.6347166559379498E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,  -2.6347166559379498E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,   2.6347166559379498E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,  -2.6347166559379498E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,   4.7423928425519801E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,   4.7423928425519801E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,  -4.7423928425519801E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,   4.7423928425519801E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,  -4.7423928425519801E-01,   8.4004748835905041E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,  -4.7423928425519801E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,   4.7423928425519801E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,  -4.7423928425519801E-01,  -8.4004748835905041E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,   4.7423928425519801E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,   4.7423928425519801E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,  -4.7423928425519801E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,   4.7423928425519801E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,  -4.7423928425519801E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,  -4.7423928425519801E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,   4.7423928425519801E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,  -4.7423928425519801E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,   2.6347166559379498E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,   2.6347166559379498E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,  -2.6347166559379498E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,   2.6347166559379498E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,  -2.6347166559379498E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   8.4004748835905041E-01,  -2.6347166559379498E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,   2.6347166559379498E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -8.4004748835905041E-01,  -2.6347166559379498E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,   8.4004748835905041E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,   8.4004748835905041E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,  -8.4004748835905041E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,   8.4004748835905041E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,  -8.4004748835905041E-01,   2.6347166559379498E-01,   2.2652880260672820E-02],
            [   4.7423928425519801E-01,  -8.4004748835905041E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,   8.4004748835905041E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [  -4.7423928425519801E-01,  -8.4004748835905041E-01,  -2.6347166559379498E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,   8.4004748835905041E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,   8.4004748835905041E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,  -8.4004748835905041E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,   8.4004748835905041E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,  -8.4004748835905041E-01,   4.7423928425519801E-01,   2.2652880260672820E-02],
            [   2.6347166559379498E-01,  -8.4004748835905041E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,   8.4004748835905041E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [  -2.6347166559379498E-01,  -8.4004748835905041E-01,  -4.7423928425519801E-01,   2.2652880260672820E-02],
            [   5.9841264978853803E-01,   1.8166408403602091E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,   1.8166408403602091E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,  -1.8166408403602091E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,   1.8166408403602091E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,  -1.8166408403602091E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,  -1.8166408403602091E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,   1.8166408403602091E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,  -1.8166408403602091E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,   5.9841264978853803E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,   5.9841264978853803E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,  -5.9841264978853803E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,   5.9841264978853803E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,  -5.9841264978853803E-01,   7.8032074247992034E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,  -5.9841264978853803E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,   5.9841264978853803E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,  -5.9841264978853803E-01,  -7.8032074247992034E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,   5.9841264978853803E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,   5.9841264978853803E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,  -5.9841264978853803E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,   5.9841264978853803E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,  -5.9841264978853803E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,  -5.9841264978853803E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,   5.9841264978853803E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,  -5.9841264978853803E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,   1.8166408403602091E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,   1.8166408403602091E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,  -1.8166408403602091E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,   1.8166408403602091E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,  -1.8166408403602091E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   7.8032074247992034E-01,  -1.8166408403602091E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,   1.8166408403602091E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -7.8032074247992034E-01,  -1.8166408403602091E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,   7.8032074247992034E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,   7.8032074247992034E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,  -7.8032074247992034E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,   7.8032074247992034E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,  -7.8032074247992034E-01,   1.8166408403602091E-01,   2.3245656396302768E-02],
            [   5.9841264978853803E-01,  -7.8032074247992034E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,   7.8032074247992034E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [  -5.9841264978853803E-01,  -7.8032074247992034E-01,  -1.8166408403602091E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,   7.8032074247992034E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,   7.8032074247992034E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,  -7.8032074247992034E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,   7.8032074247992034E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,  -7.8032074247992034E-01,   5.9841264978853803E-01,   2.3245656396302768E-02],
            [   1.8166408403602091E-01,  -7.8032074247992034E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,   7.8032074247992034E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [  -1.8166408403602091E-01,  -7.8032074247992034E-01,  -5.9841264978853803E-01,   2.3245656396302768E-02],
            [   3.7910354076955632E-01,   1.7207952256568779E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,   1.7207952256568779E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,  -1.7207952256568779E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,   1.7207952256568779E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,  -1.7207952256568779E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,  -1.7207952256568779E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,   1.7207952256568779E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,  -1.7207952256568779E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,   3.7910354076955632E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,   3.7910354076955632E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,  -3.7910354076955632E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,   3.7910354076955632E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,  -3.7910354076955632E-01,   9.0921347509237360E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,  -3.7910354076955632E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,   3.7910354076955632E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,  -3.7910354076955632E-01,  -9.0921347509237360E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,   3.7910354076955632E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,   3.7910354076955632E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,  -3.7910354076955632E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,   3.7910354076955632E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,  -3.7910354076955632E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,  -3.7910354076955632E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,   3.7910354076955632E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,  -3.7910354076955632E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,   1.7207952256568779E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,   1.7207952256568779E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,  -1.7207952256568779E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,   1.7207952256568779E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,  -1.7207952256568779E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   9.0921347509237360E-01,  -1.7207952256568779E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,   1.7207952256568779E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -9.0921347509237360E-01,  -1.7207952256568779E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,   9.0921347509237360E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,   9.0921347509237360E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,  -9.0921347509237360E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,   9.0921347509237360E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,  -9.0921347509237360E-01,   1.7207952256568779E-01,   2.1537559233923489E-02],
            [   3.7910354076955632E-01,  -9.0921347509237360E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,   9.0921347509237360E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [  -3.7910354076955632E-01,  -9.0921347509237360E-01,  -1.7207952256568779E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,   9.0921347509237360E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,   9.0921347509237360E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,  -9.0921347509237360E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,   9.0921347509237360E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,  -9.0921347509237360E-01,   3.7910354076955632E-01,   2.1537559233923489E-02],
            [   1.7207952256568779E-01,  -9.0921347509237360E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,   9.0921347509237360E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [  -1.7207952256568779E-01,  -9.0921347509237360E-01,  -3.7910354076955632E-01,   2.1537559233923489E-02],
            [   2.7786731905862438E-01,   8.2130215819325114E-02,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,   8.2130215819325114E-02,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,  -8.2130215819325114E-02,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,   8.2130215819325114E-02,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,  -8.2130215819325114E-02,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,  -8.2130215819325114E-02,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,   8.2130215819325114E-02,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,  -8.2130215819325114E-02,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,   2.7786731905862438E-01,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,   2.7786731905862438E-01,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,  -2.7786731905862438E-01,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,   2.7786731905862438E-01,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,  -2.7786731905862438E-01,   9.5710207431007255E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,  -2.7786731905862438E-01,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,   2.7786731905862438E-01,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,  -2.7786731905862438E-01,  -9.5710207431007255E-01,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,   2.7786731905862438E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,   2.7786731905862438E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,  -2.7786731905862438E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,   2.7786731905862438E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,  -2.7786731905862438E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,  -2.7786731905862438E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,   2.7786731905862438E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,  -2.7786731905862438E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,   8.2130215819325114E-02,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,   8.2130215819325114E-02,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,  -8.2130215819325114E-02,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,   8.2130215819325114E-02,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,  -8.2130215819325114E-02,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   9.5710207431007255E-01,  -8.2130215819325114E-02,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,   8.2130215819325114E-02,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -9.5710207431007255E-01,  -8.2130215819325114E-02,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,   9.5710207431007255E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,   9.5710207431007255E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,  -9.5710207431007255E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,   9.5710207431007255E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,  -9.5710207431007255E-01,   8.2130215819325114E-02,   1.9543390524777288E-02],
            [   2.7786731905862438E-01,  -9.5710207431007255E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,   9.5710207431007255E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [  -2.7786731905862438E-01,  -9.5710207431007255E-01,  -8.2130215819325114E-02,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,   9.5710207431007255E-01,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,   9.5710207431007255E-01,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,  -9.5710207431007255E-01,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,   9.5710207431007255E-01,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,  -9.5710207431007255E-01,   2.7786731905862438E-01,   1.9543390524777288E-02],
            [   8.2130215819325114E-02,  -9.5710207431007255E-01,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,   9.5710207431007255E-01,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [  -8.2130215819325114E-02,  -9.5710207431007255E-01,  -2.7786731905862438E-01,   1.9543390524777288E-02],
            [   5.0335642710751172E-01,   8.9992058420748755E-02,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,   8.9992058420748755E-02,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,  -8.9992058420748755E-02,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,   8.9992058420748755E-02,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,  -8.9992058420748755E-02,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,  -8.9992058420748755E-02,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,   8.9992058420748755E-02,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,  -8.9992058420748755E-02,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,   5.0335642710751172E-01,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,   5.0335642710751172E-01,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,  -5.0335642710751172E-01,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,   5.0335642710751172E-01,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,  -5.0335642710751172E-01,   8.5937985589072119E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,  -5.0335642710751172E-01,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,   5.0335642710751172E-01,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,  -5.0335642710751172E-01,  -8.5937985589072119E-01,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,   5.0335642710751172E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,   5.0335642710751172E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,  -5.0335642710751172E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,   5.0335642710751172E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,  -5.0335642710751172E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,  -5.0335642710751172E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,   5.0335642710751172E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,  -5.0335642710751172E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,   8.9992058420748755E-02,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,   8.9992058420748755E-02,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,  -8.9992058420748755E-02,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,   8.9992058420748755E-02,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,  -8.9992058420748755E-02,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.5937985589072119E-01,  -8.9992058420748755E-02,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,   8.9992058420748755E-02,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.5937985589072119E-01,  -8.9992058420748755E-02,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,   8.5937985589072119E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,   8.5937985589072119E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,  -8.5937985589072119E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,   8.5937985589072119E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,  -8.5937985589072119E-01,   8.9992058420748755E-02,   2.2647604818254626E-02],
            [   5.0335642710751172E-01,  -8.5937985589072119E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,   8.5937985589072119E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [  -5.0335642710751172E-01,  -8.5937985589072119E-01,  -8.9992058420748755E-02,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,   8.5937985589072119E-01,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,   8.5937985589072119E-01,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,  -8.5937985589072119E-01,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,   8.5937985589072119E-01,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,  -8.5937985589072119E-01,   5.0335642710751172E-01,   2.2647604818254626E-02],
            [   8.9992058420748755E-02,  -8.5937985589072119E-01,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,   8.5937985589072119E-01,  -5.0335642710751172E-01,   2.2647604818254626E-02],
            [  -8.9992058420748755E-02,  -8.5937985589072119E-01,  -5.0335642710751172E-01,   2.2647604818254626E-02],
        ])
  
        order = 41
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build770():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.7557323015911473E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.7557323015911473E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   2.7557323015911473E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   2.7557323015911473E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   2.7557323015911473E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   2.7557323015911473E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   1.8050757198156134E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   1.8050757198156134E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   1.8050757198156134E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   1.8050757198156134E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   1.8050757198156134E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   1.8050757198156134E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   1.8050757198156134E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   1.8050757198156134E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   1.8050757198156134E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   1.8050757198156134E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   1.8050757198156134E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   1.8050757198156134E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.7868629358434130E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.7868629358434130E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.7868629358434130E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.7868629358434130E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.7868629358434130E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.7868629358434130E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.7868629358434130E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.7868629358434130E-02],
            [   5.0872044105023599E-02,   5.0872044105023599E-02,   9.9740867765282304E-01,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,   5.0872044105023599E-02,   9.9740867765282304E-01,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,  -5.0872044105023599E-02,   9.9740867765282304E-01,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,   5.0872044105023599E-02,  -9.9740867765282304E-01,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,  -5.0872044105023599E-02,   9.9740867765282304E-01,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,   5.0872044105023599E-02,  -9.9740867765282304E-01,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,  -5.0872044105023599E-02,  -9.9740867765282304E-01,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,  -5.0872044105023599E-02,  -9.9740867765282304E-01,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,   9.9740867765282304E-01,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,  -9.9740867765282304E-01,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,   9.9740867765282304E-01,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,  -9.9740867765282304E-01,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,   9.9740867765282304E-01,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,  -9.9740867765282304E-01,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -5.0872044105023599E-02,  -9.9740867765282304E-01,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [   5.0872044105023599E-02,   9.9740867765282304E-01,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [   9.9740867765282304E-01,   5.0872044105023599E-02,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -9.9740867765282304E-01,   5.0872044105023599E-02,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [   9.9740867765282304E-01,  -5.0872044105023599E-02,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [   9.9740867765282304E-01,   5.0872044105023599E-02,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -9.9740867765282304E-01,  -5.0872044105023599E-02,   5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -9.9740867765282304E-01,   5.0872044105023599E-02,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [   9.9740867765282304E-01,  -5.0872044105023599E-02,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [  -9.9740867765282304E-01,  -5.0872044105023599E-02,  -5.0872044105023599E-02,   8.5427739522049226E-03],
            [   1.2281987901788310E-01,   1.2281987901788310E-01,   9.8479975357230121E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,   1.2281987901788310E-01,   9.8479975357230121E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,  -1.2281987901788310E-01,   9.8479975357230121E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,   1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,  -1.2281987901788310E-01,   9.8479975357230121E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,   1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,  -1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,  -1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,   9.8479975357230121E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,   9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,  -9.8479975357230121E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,   9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,  -9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -1.2281987901788310E-01,  -9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [   1.2281987901788310E-01,   9.8479975357230121E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [   9.8479975357230121E-01,   1.2281987901788310E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -9.8479975357230121E-01,   1.2281987901788310E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [   9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [   9.8479975357230121E-01,   1.2281987901788310E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -9.8479975357230121E-01,  -1.2281987901788310E-01,   1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -9.8479975357230121E-01,   1.2281987901788310E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [   9.8479975357230121E-01,  -1.2281987901788310E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [  -9.8479975357230121E-01,  -1.2281987901788310E-01,  -1.2281987901788310E-01,   1.2457274706913858E-02],
            [   2.0268908144087860E-01,   2.0268908144087860E-01,   9.5803667598339137E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,   2.0268908144087860E-01,   9.5803667598339137E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,  -2.0268908144087860E-01,   9.5803667598339137E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,   2.0268908144087860E-01,  -9.5803667598339137E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,  -2.0268908144087860E-01,   9.5803667598339137E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,   2.0268908144087860E-01,  -9.5803667598339137E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,  -2.0268908144087860E-01,  -9.5803667598339137E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,  -2.0268908144087860E-01,  -9.5803667598339137E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,   9.5803667598339137E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,  -9.5803667598339137E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,   9.5803667598339137E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,  -9.5803667598339137E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,   9.5803667598339137E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,  -9.5803667598339137E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -2.0268908144087860E-01,  -9.5803667598339137E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [   2.0268908144087860E-01,   9.5803667598339137E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [   9.5803667598339137E-01,   2.0268908144087860E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -9.5803667598339137E-01,   2.0268908144087860E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [   9.5803667598339137E-01,  -2.0268908144087860E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [   9.5803667598339137E-01,   2.0268908144087860E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -9.5803667598339137E-01,  -2.0268908144087860E-01,   2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -9.5803667598339137E-01,   2.0268908144087860E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [   9.5803667598339137E-01,  -2.0268908144087860E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [  -9.5803667598339137E-01,  -2.0268908144087860E-01,  -2.0268908144087860E-01,   1.4830929034450439E-02],
            [   2.8477451564642942E-01,   2.8477451564642942E-01,   9.1531795048315479E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,   2.8477451564642942E-01,   9.1531795048315479E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,  -2.8477451564642942E-01,   9.1531795048315479E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,   2.8477451564642942E-01,  -9.1531795048315479E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,  -2.8477451564642942E-01,   9.1531795048315479E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,   2.8477451564642942E-01,  -9.1531795048315479E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,  -2.8477451564642942E-01,  -9.1531795048315479E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,  -2.8477451564642942E-01,  -9.1531795048315479E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,   9.1531795048315479E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,  -9.1531795048315479E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,   9.1531795048315479E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,  -9.1531795048315479E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,   9.1531795048315479E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,  -9.1531795048315479E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -2.8477451564642942E-01,  -9.1531795048315479E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [   2.8477451564642942E-01,   9.1531795048315479E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [   9.1531795048315479E-01,   2.8477451564642942E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -9.1531795048315479E-01,   2.8477451564642942E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [   9.1531795048315479E-01,  -2.8477451564642942E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [   9.1531795048315479E-01,   2.8477451564642942E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -9.1531795048315479E-01,  -2.8477451564642942E-01,   2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -9.1531795048315479E-01,   2.8477451564642942E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [   9.1531795048315479E-01,  -2.8477451564642942E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [  -9.1531795048315479E-01,  -2.8477451564642942E-01,  -2.8477451564642942E-01,   1.6293551138179482E-02],
            [   3.6567190789780257E-01,   3.6567190789780257E-01,   8.5590192869788650E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,   3.6567190789780257E-01,   8.5590192869788650E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,  -3.6567190789780257E-01,   8.5590192869788650E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,   3.6567190789780257E-01,  -8.5590192869788650E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,  -3.6567190789780257E-01,   8.5590192869788650E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,   3.6567190789780257E-01,  -8.5590192869788650E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,  -3.6567190789780257E-01,  -8.5590192869788650E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,  -3.6567190789780257E-01,  -8.5590192869788650E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,   8.5590192869788650E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,  -8.5590192869788650E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,   8.5590192869788650E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,  -8.5590192869788650E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,   8.5590192869788650E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,  -8.5590192869788650E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -3.6567190789780257E-01,  -8.5590192869788650E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [   3.6567190789780257E-01,   8.5590192869788650E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [   8.5590192869788650E-01,   3.6567190789780257E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -8.5590192869788650E-01,   3.6567190789780257E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [   8.5590192869788650E-01,  -3.6567190789780257E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [   8.5590192869788650E-01,   3.6567190789780257E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -8.5590192869788650E-01,  -3.6567190789780257E-01,   3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -8.5590192869788650E-01,   3.6567190789780257E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [   8.5590192869788650E-01,  -3.6567190789780257E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [  -8.5590192869788650E-01,  -3.6567190789780257E-01,  -3.6567190789780257E-01,   1.7164046568628008E-02],
            [   4.4282648867134689E-01,   4.4282648867134689E-01,   7.7962131952763514E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,   4.4282648867134689E-01,   7.7962131952763514E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,  -4.4282648867134689E-01,   7.7962131952763514E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,   4.4282648867134689E-01,  -7.7962131952763514E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,  -4.4282648867134689E-01,   7.7962131952763514E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,   4.4282648867134689E-01,  -7.7962131952763514E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,  -4.4282648867134689E-01,  -7.7962131952763514E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,  -4.4282648867134689E-01,  -7.7962131952763514E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,   7.7962131952763514E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,  -7.7962131952763514E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,   7.7962131952763514E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,  -7.7962131952763514E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,   7.7962131952763514E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,  -7.7962131952763514E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -4.4282648867134689E-01,  -7.7962131952763514E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [   4.4282648867134689E-01,   7.7962131952763514E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [   7.7962131952763514E-01,   4.4282648867134689E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -7.7962131952763514E-01,   4.4282648867134689E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [   7.7962131952763514E-01,  -4.4282648867134689E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [   7.7962131952763514E-01,   4.4282648867134689E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -7.7962131952763514E-01,  -4.4282648867134689E-01,   4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -7.7962131952763514E-01,   4.4282648867134689E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [   7.7962131952763514E-01,  -4.4282648867134689E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [  -7.7962131952763514E-01,  -4.4282648867134689E-01,  -4.4282648867134689E-01,   1.7630474775329419E-02],
            [   5.1406196272497351E-01,   5.1406196272497351E-01,   6.8664444726415430E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,   5.1406196272497351E-01,   6.8664444726415430E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,  -5.1406196272497351E-01,   6.8664444726415430E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,   5.1406196272497351E-01,  -6.8664444726415430E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,  -5.1406196272497351E-01,   6.8664444726415430E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,   5.1406196272497351E-01,  -6.8664444726415430E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,  -5.1406196272497351E-01,  -6.8664444726415430E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,  -5.1406196272497351E-01,  -6.8664444726415430E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,   6.8664444726415430E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,  -6.8664444726415430E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,   6.8664444726415430E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,  -6.8664444726415430E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,   6.8664444726415430E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,  -6.8664444726415430E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -5.1406196272497351E-01,  -6.8664444726415430E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [   5.1406196272497351E-01,   6.8664444726415430E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [   6.8664444726415430E-01,   5.1406196272497351E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -6.8664444726415430E-01,   5.1406196272497351E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [   6.8664444726415430E-01,  -5.1406196272497351E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [   6.8664444726415430E-01,   5.1406196272497351E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -6.8664444726415430E-01,  -5.1406196272497351E-01,   5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -6.8664444726415430E-01,   5.1406196272497351E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [   6.8664444726415430E-01,  -5.1406196272497351E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [  -6.8664444726415430E-01,  -5.1406196272497351E-01,  -5.1406196272497351E-01,   1.7827225922558868E-02],
            [   6.3064012191668029E-01,   6.3064012191668029E-01,   4.5231192031365841E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,   6.3064012191668029E-01,   4.5231192031365841E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,  -6.3064012191668029E-01,   4.5231192031365841E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,   6.3064012191668029E-01,  -4.5231192031365841E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,  -6.3064012191668029E-01,   4.5231192031365841E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,   6.3064012191668029E-01,  -4.5231192031365841E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,  -6.3064012191668029E-01,  -4.5231192031365841E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,  -6.3064012191668029E-01,  -4.5231192031365841E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,   4.5231192031365841E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,  -4.5231192031365841E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,   4.5231192031365841E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,  -4.5231192031365841E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,   4.5231192031365841E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,  -4.5231192031365841E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -6.3064012191668029E-01,  -4.5231192031365841E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [   6.3064012191668029E-01,   4.5231192031365841E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [   4.5231192031365841E-01,   6.3064012191668029E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -4.5231192031365841E-01,   6.3064012191668029E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [   4.5231192031365841E-01,  -6.3064012191668029E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [   4.5231192031365841E-01,   6.3064012191668029E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -4.5231192031365841E-01,  -6.3064012191668029E-01,   6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -4.5231192031365841E-01,   6.3064012191668029E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [   4.5231192031365841E-01,  -6.3064012191668029E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [  -4.5231192031365841E-01,  -6.3064012191668029E-01,  -6.3064012191668029E-01,   1.7861546920738307E-02],
            [   6.7168833320226118E-01,   6.7168833320226118E-01,   3.1252130500165326E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,   6.7168833320226118E-01,   3.1252130500165326E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,  -6.7168833320226118E-01,   3.1252130500165326E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,   6.7168833320226118E-01,  -3.1252130500165326E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,  -6.7168833320226118E-01,   3.1252130500165326E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,   6.7168833320226118E-01,  -3.1252130500165326E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,  -6.7168833320226118E-01,  -3.1252130500165326E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,  -6.7168833320226118E-01,  -3.1252130500165326E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,   3.1252130500165326E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,  -3.1252130500165326E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,   3.1252130500165326E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,  -3.1252130500165326E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,   3.1252130500165326E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,  -3.1252130500165326E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -6.7168833320226118E-01,  -3.1252130500165326E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [   6.7168833320226118E-01,   3.1252130500165326E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [   3.1252130500165326E-01,   6.7168833320226118E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -3.1252130500165326E-01,   6.7168833320226118E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [   3.1252130500165326E-01,  -6.7168833320226118E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [   3.1252130500165326E-01,   6.7168833320226118E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -3.1252130500165326E-01,  -6.7168833320226118E-01,   6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -3.1252130500165326E-01,   6.7168833320226118E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [   3.1252130500165326E-01,  -6.7168833320226118E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [  -3.1252130500165326E-01,  -6.7168833320226118E-01,  -6.7168833320226118E-01,   1.7894467464560658E-02],
            [   6.9797926853368808E-01,   6.9797926853368808E-01,   1.6015580349882902E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,   6.9797926853368808E-01,   1.6015580349882902E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,  -6.9797926853368808E-01,   1.6015580349882902E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,   6.9797926853368808E-01,  -1.6015580349882902E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,  -6.9797926853368808E-01,   1.6015580349882902E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,   6.9797926853368808E-01,  -1.6015580349882902E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,  -6.9797926853368808E-01,  -1.6015580349882902E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,  -6.9797926853368808E-01,  -1.6015580349882902E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,   1.6015580349882902E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,  -1.6015580349882902E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,   1.6015580349882902E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,  -1.6015580349882902E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,   1.6015580349882902E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,  -1.6015580349882902E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -6.9797926853368808E-01,  -1.6015580349882902E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [   6.9797926853368808E-01,   1.6015580349882902E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [   1.6015580349882902E-01,   6.9797926853368808E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -1.6015580349882902E-01,   6.9797926853368808E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [   1.6015580349882902E-01,  -6.9797926853368808E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [   1.6015580349882902E-01,   6.9797926853368808E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -1.6015580349882902E-01,  -6.9797926853368808E-01,   6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -1.6015580349882902E-01,   6.9797926853368808E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [   1.6015580349882902E-01,  -6.9797926853368808E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [  -1.6015580349882902E-01,  -6.9797926853368808E-01,  -6.9797926853368808E-01,   1.7989438648499837E-02],
            [   1.4468656741953090E-01,   9.8947753749559852E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [  -1.4468656741953090E-01,   9.8947753749559852E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [   1.4468656741953090E-01,  -9.8947753749559852E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [  -1.4468656741953090E-01,  -9.8947753749559852E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [   9.8947753749559852E-01,   1.4468656741953090E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [  -9.8947753749559852E-01,   1.4468656741953090E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [   9.8947753749559852E-01,  -1.4468656741953090E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [  -9.8947753749559852E-01,  -1.4468656741953090E-01,   0.0000000000000000E+00,   1.1629423906138961E-02],
            [   1.4468656741953090E-01,   0.0000000000000000E+00,   9.8947753749559852E-01,   1.1629423906138961E-02],
            [  -1.4468656741953090E-01,   0.0000000000000000E+00,   9.8947753749559852E-01,   1.1629423906138961E-02],
            [   1.4468656741953090E-01,   0.0000000000000000E+00,  -9.8947753749559852E-01,   1.1629423906138961E-02],
            [  -1.4468656741953090E-01,   0.0000000000000000E+00,  -9.8947753749559852E-01,   1.1629423906138961E-02],
            [   9.8947753749559852E-01,   0.0000000000000000E+00,   1.4468656741953090E-01,   1.1629423906138961E-02],
            [  -9.8947753749559852E-01,   0.0000000000000000E+00,   1.4468656741953090E-01,   1.1629423906138961E-02],
            [   9.8947753749559852E-01,   0.0000000000000000E+00,  -1.4468656741953090E-01,   1.1629423906138961E-02],
            [  -9.8947753749559852E-01,   0.0000000000000000E+00,  -1.4468656741953090E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,   1.4468656741953090E-01,   9.8947753749559852E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,  -1.4468656741953090E-01,   9.8947753749559852E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,   1.4468656741953090E-01,  -9.8947753749559852E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,  -1.4468656741953090E-01,  -9.8947753749559852E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,   9.8947753749559852E-01,   1.4468656741953090E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,  -9.8947753749559852E-01,   1.4468656741953090E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,   9.8947753749559852E-01,  -1.4468656741953090E-01,   1.1629423906138961E-02],
            [   0.0000000000000000E+00,  -9.8947753749559852E-01,  -1.4468656741953090E-01,   1.1629423906138961E-02],
            [   3.3902634754112160E-01,   9.4077687879375871E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [  -3.3902634754112160E-01,   9.4077687879375871E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [   3.3902634754112160E-01,  -9.4077687879375871E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [  -3.3902634754112160E-01,  -9.4077687879375871E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [   9.4077687879375871E-01,   3.3902634754112160E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [  -9.4077687879375871E-01,   3.3902634754112160E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [   9.4077687879375871E-01,  -3.3902634754112160E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [  -9.4077687879375871E-01,  -3.3902634754112160E-01,   0.0000000000000000E+00,   1.5710979134736971E-02],
            [   3.3902634754112160E-01,   0.0000000000000000E+00,   9.4077687879375871E-01,   1.5710979134736971E-02],
            [  -3.3902634754112160E-01,   0.0000000000000000E+00,   9.4077687879375871E-01,   1.5710979134736971E-02],
            [   3.3902634754112160E-01,   0.0000000000000000E+00,  -9.4077687879375871E-01,   1.5710979134736971E-02],
            [  -3.3902634754112160E-01,   0.0000000000000000E+00,  -9.4077687879375871E-01,   1.5710979134736971E-02],
            [   9.4077687879375871E-01,   0.0000000000000000E+00,   3.3902634754112160E-01,   1.5710979134736971E-02],
            [  -9.4077687879375871E-01,   0.0000000000000000E+00,   3.3902634754112160E-01,   1.5710979134736971E-02],
            [   9.4077687879375871E-01,   0.0000000000000000E+00,  -3.3902634754112160E-01,   1.5710979134736971E-02],
            [  -9.4077687879375871E-01,   0.0000000000000000E+00,  -3.3902634754112160E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,   3.3902634754112160E-01,   9.4077687879375871E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,  -3.3902634754112160E-01,   9.4077687879375871E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,   3.3902634754112160E-01,  -9.4077687879375871E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,  -3.3902634754112160E-01,  -9.4077687879375871E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,   9.4077687879375871E-01,   3.3902634754112160E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,  -9.4077687879375871E-01,   3.3902634754112160E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,   9.4077687879375871E-01,  -3.3902634754112160E-01,   1.5710979134736971E-02],
            [   0.0000000000000000E+00,  -9.4077687879375871E-01,  -3.3902634754112160E-01,   1.5710979134736971E-02],
            [   5.3358046512635060E-01,   8.4574930519365332E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [  -5.3358046512635060E-01,   8.4574930519365332E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [   5.3358046512635060E-01,  -8.4574930519365332E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [  -5.3358046512635060E-01,  -8.4574930519365332E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [   8.4574930519365332E-01,   5.3358046512635060E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [  -8.4574930519365332E-01,   5.3358046512635060E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [   8.4574930519365332E-01,  -5.3358046512635060E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [  -8.4574930519365332E-01,  -5.3358046512635060E-01,   0.0000000000000000E+00,   1.7522117959278584E-02],
            [   5.3358046512635060E-01,   0.0000000000000000E+00,   8.4574930519365332E-01,   1.7522117959278584E-02],
            [  -5.3358046512635060E-01,   0.0000000000000000E+00,   8.4574930519365332E-01,   1.7522117959278584E-02],
            [   5.3358046512635060E-01,   0.0000000000000000E+00,  -8.4574930519365332E-01,   1.7522117959278584E-02],
            [  -5.3358046512635060E-01,   0.0000000000000000E+00,  -8.4574930519365332E-01,   1.7522117959278584E-02],
            [   8.4574930519365332E-01,   0.0000000000000000E+00,   5.3358046512635060E-01,   1.7522117959278584E-02],
            [  -8.4574930519365332E-01,   0.0000000000000000E+00,   5.3358046512635060E-01,   1.7522117959278584E-02],
            [   8.4574930519365332E-01,   0.0000000000000000E+00,  -5.3358046512635060E-01,   1.7522117959278584E-02],
            [  -8.4574930519365332E-01,   0.0000000000000000E+00,  -5.3358046512635060E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,   5.3358046512635060E-01,   8.4574930519365332E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,  -5.3358046512635060E-01,   8.4574930519365332E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,   5.3358046512635060E-01,  -8.4574930519365332E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,  -5.3358046512635060E-01,  -8.4574930519365332E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,   8.4574930519365332E-01,   5.3358046512635060E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,  -8.4574930519365332E-01,   5.3358046512635060E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,   8.4574930519365332E-01,  -5.3358046512635060E-01,   1.7522117959278584E-02],
            [   0.0000000000000000E+00,  -8.4574930519365332E-01,  -5.3358046512635060E-01,   1.7522117959278584E-02],
            [   6.9440243933494128E-02,   2.3551878942423260E-01,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,   2.3551878942423260E-01,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,  -2.3551878942423260E-01,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,   2.3551878942423260E-01,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,  -2.3551878942423260E-01,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,  -2.3551878942423260E-01,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,   2.3551878942423260E-01,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,  -2.3551878942423260E-01,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,   6.9440243933494128E-02,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,   6.9440243933494128E-02,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,  -6.9440243933494128E-02,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,   6.9440243933494128E-02,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,  -6.9440243933494128E-02,   9.6938586349843214E-01,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,  -6.9440243933494128E-02,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,   6.9440243933494128E-02,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,  -6.9440243933494128E-02,  -9.6938586349843214E-01,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,   6.9440243933494128E-02,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,   6.9440243933494128E-02,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,  -6.9440243933494128E-02,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,   6.9440243933494128E-02,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,  -6.9440243933494128E-02,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,  -6.9440243933494128E-02,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,   6.9440243933494128E-02,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,  -6.9440243933494128E-02,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,   2.3551878942423260E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,   2.3551878942423260E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,  -2.3551878942423260E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,   2.3551878942423260E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,  -2.3551878942423260E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   9.6938586349843214E-01,  -2.3551878942423260E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,   2.3551878942423260E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -9.6938586349843214E-01,  -2.3551878942423260E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,   9.6938586349843214E-01,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,   9.6938586349843214E-01,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,  -9.6938586349843214E-01,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,   9.6938586349843214E-01,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,  -9.6938586349843214E-01,   2.3551878942423260E-01,   1.4163419279047748E-02],
            [   6.9440243933494128E-02,  -9.6938586349843214E-01,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,   9.6938586349843214E-01,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [  -6.9440243933494128E-02,  -9.6938586349843214E-01,  -2.3551878942423260E-01,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,   9.6938586349843214E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,   9.6938586349843214E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,  -9.6938586349843214E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,   9.6938586349843214E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,  -9.6938586349843214E-01,   6.9440243933494128E-02,   1.4163419279047748E-02],
            [   2.3551878942423260E-01,  -9.6938586349843214E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,   9.6938586349843214E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [  -2.3551878942423260E-01,  -9.6938586349843214E-01,  -6.9440243933494128E-02,   1.4163419279047748E-02],
            [   2.2690041095294600E-01,   4.1021824740457302E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,   4.1021824740457302E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,  -4.1021824740457302E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,   4.1021824740457302E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,  -4.1021824740457302E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,  -4.1021824740457302E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,   4.1021824740457302E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,  -4.1021824740457302E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,   2.2690041095294600E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,   2.2690041095294600E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,  -2.2690041095294600E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,   2.2690041095294600E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,  -2.2690041095294600E-01,   8.8331036052211276E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,  -2.2690041095294600E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,   2.2690041095294600E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,  -2.2690041095294600E-01,  -8.8331036052211276E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,   2.2690041095294600E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,   2.2690041095294600E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,  -2.2690041095294600E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,   2.2690041095294600E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,  -2.2690041095294600E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,  -2.2690041095294600E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,   2.2690041095294600E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,  -2.2690041095294600E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,   4.1021824740457302E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,   4.1021824740457302E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,  -4.1021824740457302E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,   4.1021824740457302E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,  -4.1021824740457302E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   8.8331036052211276E-01,  -4.1021824740457302E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,   4.1021824740457302E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -8.8331036052211276E-01,  -4.1021824740457302E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,   8.8331036052211276E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,   8.8331036052211276E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,  -8.8331036052211276E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,   8.8331036052211276E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,  -8.8331036052211276E-01,   4.1021824740457302E-01,   1.6911240515271184E-02],
            [   2.2690041095294600E-01,  -8.8331036052211276E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,   8.8331036052211276E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [  -2.2690041095294600E-01,  -8.8331036052211276E-01,  -4.1021824740457302E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,   8.8331036052211276E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,   8.8331036052211276E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,  -8.8331036052211276E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,   8.8331036052211276E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,  -8.8331036052211276E-01,   2.2690041095294600E-01,   1.6911240515271184E-02],
            [   4.1021824740457302E-01,  -8.8331036052211276E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,   8.8331036052211276E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [  -4.1021824740457302E-01,  -8.8331036052211276E-01,  -2.2690041095294600E-01,   1.6911240515271184E-02],
            [   8.0255746077753390E-02,   6.2143024174816053E-01,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,   6.2143024174816053E-01,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,  -6.2143024174816053E-01,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,   6.2143024174816053E-01,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,  -6.2143024174816053E-01,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,  -6.2143024174816053E-01,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,   6.2143024174816053E-01,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,  -6.2143024174816053E-01,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,   8.0255746077753390E-02,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,   8.0255746077753390E-02,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,  -8.0255746077753390E-02,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,   8.0255746077753390E-02,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,  -8.0255746077753390E-02,   7.7934810570266089E-01,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,  -8.0255746077753390E-02,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,   8.0255746077753390E-02,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,  -8.0255746077753390E-02,  -7.7934810570266089E-01,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,   8.0255746077753390E-02,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,   8.0255746077753390E-02,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,  -8.0255746077753390E-02,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,   8.0255746077753390E-02,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,  -8.0255746077753390E-02,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,  -8.0255746077753390E-02,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,   8.0255746077753390E-02,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,  -8.0255746077753390E-02,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,   6.2143024174816053E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,   6.2143024174816053E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,  -6.2143024174816053E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,   6.2143024174816053E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,  -6.2143024174816053E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   7.7934810570266089E-01,  -6.2143024174816053E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,   6.2143024174816053E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -7.7934810570266089E-01,  -6.2143024174816053E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,   7.7934810570266089E-01,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,   7.7934810570266089E-01,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,  -7.7934810570266089E-01,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,   7.7934810570266089E-01,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,  -7.7934810570266089E-01,   6.2143024174816053E-01,   1.7906541331789098E-02],
            [   8.0255746077753390E-02,  -7.7934810570266089E-01,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,   7.7934810570266089E-01,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [  -8.0255746077753390E-02,  -7.7934810570266089E-01,  -6.2143024174816053E-01,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,   7.7934810570266089E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,   7.7934810570266089E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,  -7.7934810570266089E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,   7.7934810570266089E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,  -7.7934810570266089E-01,   8.0255746077753390E-02,   1.7906541331789098E-02],
            [   6.2143024174816053E-01,  -7.7934810570266089E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,   7.7934810570266089E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [  -6.2143024174816053E-01,  -7.7934810570266089E-01,  -8.0255746077753390E-02,   1.7906541331789098E-02],
            [   1.4679995278965721E-01,   3.2452843457173941E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,   3.2452843457173941E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,  -3.2452843457173941E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,   3.2452843457173941E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,  -3.2452843457173941E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,  -3.2452843457173941E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,   3.2452843457173941E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,  -3.2452843457173941E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,   1.4679995278965721E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,   1.4679995278965721E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,  -1.4679995278965721E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,   1.4679995278965721E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,  -1.4679995278965721E-01,   9.3441482705240220E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,  -1.4679995278965721E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,   1.4679995278965721E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,  -1.4679995278965721E-01,  -9.3441482705240220E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,   1.4679995278965721E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,   1.4679995278965721E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,  -1.4679995278965721E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,   1.4679995278965721E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,  -1.4679995278965721E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,  -1.4679995278965721E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,   1.4679995278965721E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,  -1.4679995278965721E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,   3.2452843457173941E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,   3.2452843457173941E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,  -3.2452843457173941E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,   3.2452843457173941E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,  -3.2452843457173941E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   9.3441482705240220E-01,  -3.2452843457173941E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,   3.2452843457173941E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -9.3441482705240220E-01,  -3.2452843457173941E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,   9.3441482705240220E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,   9.3441482705240220E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,  -9.3441482705240220E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,   9.3441482705240220E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,  -9.3441482705240220E-01,   3.2452843457173941E-01,   1.5852769844658259E-02],
            [   1.4679995278965721E-01,  -9.3441482705240220E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,   9.3441482705240220E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [  -1.4679995278965721E-01,  -9.3441482705240220E-01,  -3.2452843457173941E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,   9.3441482705240220E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,   9.3441482705240220E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,  -9.3441482705240220E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,   9.3441482705240220E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,  -9.3441482705240220E-01,   1.4679995278965721E-01,   1.5852769844658259E-02],
            [   3.2452843457173941E-01,  -9.3441482705240220E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,   9.3441482705240220E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [  -3.2452843457173941E-01,  -9.3441482705240220E-01,  -1.4679995278965721E-01,   1.5852769844658259E-02],
            [   1.5715077698247271E-01,   5.2244821896966298E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,   5.2244821896966298E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,  -5.2244821896966298E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,   5.2244821896966298E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,  -5.2244821896966298E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,  -5.2244821896966298E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,   5.2244821896966298E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,  -5.2244821896966298E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,   1.5715077698247271E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,   1.5715077698247271E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,  -1.5715077698247271E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,   1.5715077698247271E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,  -1.5715077698247271E-01,   8.3806413345831243E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,  -1.5715077698247271E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,   1.5715077698247271E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,  -1.5715077698247271E-01,  -8.3806413345831243E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,   1.5715077698247271E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,   1.5715077698247271E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,  -1.5715077698247271E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,   1.5715077698247271E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,  -1.5715077698247271E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,  -1.5715077698247271E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,   1.5715077698247271E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,  -1.5715077698247271E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,   5.2244821896966298E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,   5.2244821896966298E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,  -5.2244821896966298E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,   5.2244821896966298E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,  -5.2244821896966298E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   8.3806413345831243E-01,  -5.2244821896966298E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,   5.2244821896966298E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -8.3806413345831243E-01,  -5.2244821896966298E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,   8.3806413345831243E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,   8.3806413345831243E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,  -8.3806413345831243E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,   8.3806413345831243E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,  -8.3806413345831243E-01,   5.2244821896966298E-01,   1.7499263032611505E-02],
            [   1.5715077698247271E-01,  -8.3806413345831243E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,   8.3806413345831243E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [  -1.5715077698247271E-01,  -8.3806413345831243E-01,  -5.2244821896966298E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,   8.3806413345831243E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,   8.3806413345831243E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,  -8.3806413345831243E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,   8.3806413345831243E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,  -8.3806413345831243E-01,   1.5715077698247271E-01,   1.7499263032611505E-02],
            [   5.2244821896966298E-01,  -8.3806413345831243E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,   8.3806413345831243E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [  -5.2244821896966298E-01,  -8.3806413345831243E-01,  -1.5715077698247271E-01,   1.7499263032611505E-02],
            [   2.3657029931572460E-01,   6.0175466340895578E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,   6.0175466340895578E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,  -6.0175466340895578E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,   6.0175466340895578E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,  -6.0175466340895578E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,  -6.0175466340895578E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,   6.0175466340895578E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,  -6.0175466340895578E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,   2.3657029931572460E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,   2.3657029931572460E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,  -2.3657029931572460E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,   2.3657029931572460E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,  -2.3657029931572460E-01,   7.6284062460466984E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,  -2.3657029931572460E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,   2.3657029931572460E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,  -2.3657029931572460E-01,  -7.6284062460466984E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,   2.3657029931572460E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,   2.3657029931572460E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,  -2.3657029931572460E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,   2.3657029931572460E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,  -2.3657029931572460E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,  -2.3657029931572460E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,   2.3657029931572460E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,  -2.3657029931572460E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,   6.0175466340895578E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,   6.0175466340895578E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,  -6.0175466340895578E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,   6.0175466340895578E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,  -6.0175466340895578E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   7.6284062460466984E-01,  -6.0175466340895578E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,   6.0175466340895578E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -7.6284062460466984E-01,  -6.0175466340895578E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,   7.6284062460466984E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,   7.6284062460466984E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,  -7.6284062460466984E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,   7.6284062460466984E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,  -7.6284062460466984E-01,   6.0175466340895578E-01,   1.7828685057660693E-02],
            [   2.3657029931572460E-01,  -7.6284062460466984E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,   7.6284062460466984E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [  -2.3657029931572460E-01,  -7.6284062460466984E-01,  -6.0175466340895578E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,   7.6284062460466984E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,   7.6284062460466984E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,  -7.6284062460466984E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,   7.6284062460466984E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,  -7.6284062460466984E-01,   2.3657029931572460E-01,   1.7828685057660693E-02],
            [   6.0175466340895578E-01,  -7.6284062460466984E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,   7.6284062460466984E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [  -6.0175466340895578E-01,  -7.6284062460466984E-01,  -2.3657029931572460E-01,   1.7828685057660693E-02],
            [   7.7148158667657327E-02,   4.3465755161411629E-01,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,   4.3465755161411629E-01,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,  -4.3465755161411629E-01,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,   4.3465755161411629E-01,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,  -4.3465755161411629E-01,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,  -4.3465755161411629E-01,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,   4.3465755161411629E-01,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,  -4.3465755161411629E-01,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,   7.7148158667657327E-02,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,   7.7148158667657327E-02,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,  -7.7148158667657327E-02,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,   7.7148158667657327E-02,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,  -7.7148158667657327E-02,   8.9728533613283334E-01,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,  -7.7148158667657327E-02,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,   7.7148158667657327E-02,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,  -7.7148158667657327E-02,  -8.9728533613283334E-01,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,   7.7148158667657327E-02,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,   7.7148158667657327E-02,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,  -7.7148158667657327E-02,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,   7.7148158667657327E-02,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,  -7.7148158667657327E-02,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,  -7.7148158667657327E-02,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,   7.7148158667657327E-02,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,  -7.7148158667657327E-02,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,   4.3465755161411629E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,   4.3465755161411629E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,  -4.3465755161411629E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,   4.3465755161411629E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,  -4.3465755161411629E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   8.9728533613283334E-01,  -4.3465755161411629E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,   4.3465755161411629E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -8.9728533613283334E-01,  -4.3465755161411629E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,   8.9728533613283334E-01,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,   8.9728533613283334E-01,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,  -8.9728533613283334E-01,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,   8.9728533613283334E-01,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,  -8.9728533613283334E-01,   4.3465755161411629E-01,   1.6818411775081182E-02],
            [   7.7148158667657327E-02,  -8.9728533613283334E-01,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,   8.9728533613283334E-01,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [  -7.7148158667657327E-02,  -8.9728533613283334E-01,  -4.3465755161411629E-01,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,   8.9728533613283334E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,   8.9728533613283334E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,  -8.9728533613283334E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,   8.9728533613283334E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,  -8.9728533613283334E-01,   7.7148158667657327E-02,   1.6818411775081182E-02],
            [   4.3465755161411629E-01,  -8.9728533613283334E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,   8.9728533613283334E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [  -4.3465755161411629E-01,  -8.9728533613283334E-01,  -7.7148158667657327E-02,   1.6818411775081182E-02],
            [   3.0629366662107299E-01,   4.9088265890376159E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,   4.9088265890376159E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,  -4.9088265890376159E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,   4.9088265890376159E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,  -4.9088265890376159E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,  -4.9088265890376159E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,   4.9088265890376159E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,  -4.9088265890376159E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,   3.0629366662107299E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,   3.0629366662107299E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,  -3.0629366662107299E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,   3.0629366662107299E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,  -3.0629366662107299E-01,   8.1560922320397544E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,  -3.0629366662107299E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,   3.0629366662107299E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,  -3.0629366662107299E-01,  -8.1560922320397544E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,   3.0629366662107299E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,   3.0629366662107299E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,  -3.0629366662107299E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,   3.0629366662107299E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,  -3.0629366662107299E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,  -3.0629366662107299E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,   3.0629366662107299E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,  -3.0629366662107299E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,   4.9088265890376159E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,   4.9088265890376159E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,  -4.9088265890376159E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,   4.9088265890376159E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,  -4.9088265890376159E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   8.1560922320397544E-01,  -4.9088265890376159E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,   4.9088265890376159E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -8.1560922320397544E-01,  -4.9088265890376159E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,   8.1560922320397544E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,   8.1560922320397544E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,  -8.1560922320397544E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,   8.1560922320397544E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,  -8.1560922320397544E-01,   4.9088265890376159E-01,   1.7513761565940360E-02],
            [   3.0629366662107299E-01,  -8.1560922320397544E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,   8.1560922320397544E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [  -3.0629366662107299E-01,  -8.1560922320397544E-01,  -4.9088265890376159E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,   8.1560922320397544E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,   8.1560922320397544E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,  -8.1560922320397544E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,   8.1560922320397544E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,  -8.1560922320397544E-01,   3.0629366662107299E-01,   1.7513761565940360E-02],
            [   4.9088265890376159E-01,  -8.1560922320397544E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,   8.1560922320397544E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [  -4.9088265890376159E-01,  -8.1560922320397544E-01,  -3.0629366662107299E-01,   1.7513761565940360E-02],
            [   3.8224773795247868E-01,   5.6487681490995001E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,   5.6487681490995001E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,  -5.6487681490995001E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,   5.6487681490995001E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,  -5.6487681490995001E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,  -5.6487681490995001E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,   5.6487681490995001E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,  -5.6487681490995001E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,   3.8224773795247868E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,   3.8224773795247868E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,  -3.8224773795247868E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,   3.8224773795247868E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,  -3.8224773795247868E-01,   7.3130079365976575E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,  -3.8224773795247868E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,   3.8224773795247868E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,  -3.8224773795247868E-01,  -7.3130079365976575E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,   3.8224773795247868E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,   3.8224773795247868E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,  -3.8224773795247868E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,   3.8224773795247868E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,  -3.8224773795247868E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,  -3.8224773795247868E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,   3.8224773795247868E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,  -3.8224773795247868E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,   5.6487681490995001E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,   5.6487681490995001E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,  -5.6487681490995001E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,   5.6487681490995001E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,  -5.6487681490995001E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   7.3130079365976575E-01,  -5.6487681490995001E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,   5.6487681490995001E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -7.3130079365976575E-01,  -5.6487681490995001E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,   7.3130079365976575E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,   7.3130079365976575E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,  -7.3130079365976575E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,   7.3130079365976575E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,  -7.3130079365976575E-01,   5.6487681490995001E-01,   1.7792909600669947E-02],
            [   3.8224773795247868E-01,  -7.3130079365976575E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,   7.3130079365976575E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [  -3.8224773795247868E-01,  -7.3130079365976575E-01,  -5.6487681490995001E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,   7.3130079365976575E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,   7.3130079365976575E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,  -7.3130079365976575E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,   7.3130079365976575E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,  -7.3130079365976575E-01,   3.8224773795247868E-01,   1.7792909600669947E-02],
            [   5.6487681490995001E-01,  -7.3130079365976575E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,   7.3130079365976575E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
            [  -5.6487681490995001E-01,  -7.3130079365976575E-01,  -3.8224773795247868E-01,   1.7792909600669947E-02],
        ])
  
        order = 47
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build974():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.8074137850647423E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.8074137850647423E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.8074137850647423E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.8074137850647423E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.8074137850647423E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.8074137850647423E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.4146871801989690E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.4146871801989690E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.4146871801989690E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.4146871801989690E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.4146871801989690E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.4146871801989690E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.4146871801989690E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.4146871801989690E-02],
            [   4.2929635453413467E-02,   4.2929635453413467E-02,   9.9815534502384651E-01,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,   4.2929635453413467E-02,   9.9815534502384651E-01,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,  -4.2929635453413467E-02,   9.9815534502384651E-01,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,   4.2929635453413467E-02,  -9.9815534502384651E-01,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,  -4.2929635453413467E-02,   9.9815534502384651E-01,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,   4.2929635453413467E-02,  -9.9815534502384651E-01,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,  -4.2929635453413467E-02,  -9.9815534502384651E-01,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,  -4.2929635453413467E-02,  -9.9815534502384651E-01,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,   9.9815534502384651E-01,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,  -9.9815534502384651E-01,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,   9.9815534502384651E-01,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,  -9.9815534502384651E-01,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,   9.9815534502384651E-01,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,  -9.9815534502384651E-01,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -4.2929635453413467E-02,  -9.9815534502384651E-01,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [   4.2929635453413467E-02,   9.9815534502384651E-01,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [   9.9815534502384651E-01,   4.2929635453413467E-02,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -9.9815534502384651E-01,   4.2929635453413467E-02,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [   9.9815534502384651E-01,  -4.2929635453413467E-02,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [   9.9815534502384651E-01,   4.2929635453413467E-02,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -9.9815534502384651E-01,  -4.2929635453413467E-02,   4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -9.9815534502384651E-01,   4.2929635453413467E-02,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [   9.9815534502384651E-01,  -4.2929635453413467E-02,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [  -9.9815534502384651E-01,  -4.2929635453413467E-02,  -4.2929635453413467E-02,   6.2178770521657900E-03],
            [   1.0514268540864040E-01,   1.0514268540864040E-01,   9.8888322435468556E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,   1.0514268540864040E-01,   9.8888322435468556E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,  -1.0514268540864040E-01,   9.8888322435468556E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,   1.0514268540864040E-01,  -9.8888322435468556E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,  -1.0514268540864040E-01,   9.8888322435468556E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,   1.0514268540864040E-01,  -9.8888322435468556E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,  -1.0514268540864040E-01,  -9.8888322435468556E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,  -1.0514268540864040E-01,  -9.8888322435468556E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,   9.8888322435468556E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,  -9.8888322435468556E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,   9.8888322435468556E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,  -9.8888322435468556E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,   9.8888322435468556E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,  -9.8888322435468556E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -1.0514268540864040E-01,  -9.8888322435468556E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [   1.0514268540864040E-01,   9.8888322435468556E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [   9.8888322435468556E-01,   1.0514268540864040E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -9.8888322435468556E-01,   1.0514268540864040E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [   9.8888322435468556E-01,  -1.0514268540864040E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [   9.8888322435468556E-01,   1.0514268540864040E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -9.8888322435468556E-01,  -1.0514268540864040E-01,   1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -9.8888322435468556E-01,   1.0514268540864040E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [   9.8888322435468556E-01,  -1.0514268540864040E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [  -9.8888322435468556E-01,  -1.0514268540864040E-01,  -1.0514268540864040E-01,   9.2463230688059738E-03],
            [   1.7500248676230870E-01,   1.7500248676230870E-01,   9.6889022043470741E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,   1.7500248676230870E-01,   9.6889022043470741E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,  -1.7500248676230870E-01,   9.6889022043470741E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,   1.7500248676230870E-01,  -9.6889022043470741E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,  -1.7500248676230870E-01,   9.6889022043470741E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,   1.7500248676230870E-01,  -9.6889022043470741E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,  -1.7500248676230870E-01,  -9.6889022043470741E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,  -1.7500248676230870E-01,  -9.6889022043470741E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,   9.6889022043470741E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,  -9.6889022043470741E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,   9.6889022043470741E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,  -9.6889022043470741E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,   9.6889022043470741E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,  -9.6889022043470741E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -1.7500248676230870E-01,  -9.6889022043470741E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [   1.7500248676230870E-01,   9.6889022043470741E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [   9.6889022043470741E-01,   1.7500248676230870E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -9.6889022043470741E-01,   1.7500248676230870E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [   9.6889022043470741E-01,  -1.7500248676230870E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [   9.6889022043470741E-01,   1.7500248676230870E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -9.6889022043470741E-01,  -1.7500248676230870E-01,   1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -9.6889022043470741E-01,   1.7500248676230870E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [   9.6889022043470741E-01,  -1.7500248676230870E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [  -9.6889022043470741E-01,  -1.7500248676230870E-01,  -1.7500248676230870E-01,   1.1170413684445652E-02],
            [   2.4776533796502570E-01,   2.4776533796502570E-01,   9.3660273040716313E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,   2.4776533796502570E-01,   9.3660273040716313E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,  -2.4776533796502570E-01,   9.3660273040716313E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,   2.4776533796502570E-01,  -9.3660273040716313E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,  -2.4776533796502570E-01,   9.3660273040716313E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,   2.4776533796502570E-01,  -9.3660273040716313E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,  -2.4776533796502570E-01,  -9.3660273040716313E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,  -2.4776533796502570E-01,  -9.3660273040716313E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,   9.3660273040716313E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,  -9.3660273040716313E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,   9.3660273040716313E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,  -9.3660273040716313E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,   9.3660273040716313E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,  -9.3660273040716313E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -2.4776533796502570E-01,  -9.3660273040716313E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [   2.4776533796502570E-01,   9.3660273040716313E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [   9.3660273040716313E-01,   2.4776533796502570E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -9.3660273040716313E-01,   2.4776533796502570E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [   9.3660273040716313E-01,  -2.4776533796502570E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [   9.3660273040716313E-01,   2.4776533796502570E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -9.3660273040716313E-01,  -2.4776533796502570E-01,   2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -9.3660273040716313E-01,   2.4776533796502570E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [   9.3660273040716313E-01,  -2.4776533796502570E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [  -9.3660273040716313E-01,  -2.4776533796502570E-01,  -2.4776533796502570E-01,   1.2426064370758435E-02],
            [   3.2065671239559568E-01,   3.2065671239559568E-01,   8.9126794264760612E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,   3.2065671239559568E-01,   8.9126794264760612E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,  -3.2065671239559568E-01,   8.9126794264760612E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,   3.2065671239559568E-01,  -8.9126794264760612E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,  -3.2065671239559568E-01,   8.9126794264760612E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,   3.2065671239559568E-01,  -8.9126794264760612E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,  -3.2065671239559568E-01,  -8.9126794264760612E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,  -3.2065671239559568E-01,  -8.9126794264760612E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,   8.9126794264760612E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,  -8.9126794264760612E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,   8.9126794264760612E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,  -8.9126794264760612E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,   8.9126794264760612E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,  -8.9126794264760612E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -3.2065671239559568E-01,  -8.9126794264760612E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [   3.2065671239559568E-01,   8.9126794264760612E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [   8.9126794264760612E-01,   3.2065671239559568E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -8.9126794264760612E-01,   3.2065671239559568E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [   8.9126794264760612E-01,  -3.2065671239559568E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [   8.9126794264760612E-01,   3.2065671239559568E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -8.9126794264760612E-01,  -3.2065671239559568E-01,   3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -8.9126794264760612E-01,   3.2065671239559568E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [   8.9126794264760612E-01,  -3.2065671239559568E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [  -8.9126794264760612E-01,  -3.2065671239559568E-01,  -3.2065671239559568E-01,   1.3236154168347765E-02],
            [   3.9165207498499832E-01,   3.9165207498499832E-01,   8.3259672370235194E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,   3.9165207498499832E-01,   8.3259672370235194E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,  -3.9165207498499832E-01,   8.3259672370235194E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,   3.9165207498499832E-01,  -8.3259672370235194E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,  -3.9165207498499832E-01,   8.3259672370235194E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,   3.9165207498499832E-01,  -8.3259672370235194E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,  -3.9165207498499832E-01,  -8.3259672370235194E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,  -3.9165207498499832E-01,  -8.3259672370235194E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,   8.3259672370235194E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,  -8.3259672370235194E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,   8.3259672370235194E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,  -8.3259672370235194E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,   8.3259672370235194E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,  -8.3259672370235194E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -3.9165207498499832E-01,  -8.3259672370235194E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [   3.9165207498499832E-01,   8.3259672370235194E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [   8.3259672370235194E-01,   3.9165207498499832E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -8.3259672370235194E-01,   3.9165207498499832E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [   8.3259672370235194E-01,  -3.9165207498499832E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [   8.3259672370235194E-01,   3.9165207498499832E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -8.3259672370235194E-01,  -3.9165207498499832E-01,   3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -8.3259672370235194E-01,   3.9165207498499832E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [   8.3259672370235194E-01,  -3.9165207498499832E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [  -8.3259672370235194E-01,  -3.9165207498499832E-01,  -3.9165207498499832E-01,   1.3732263488462466E-02],
            [   4.5908258741876240E-01,   4.5908258741876240E-01,   7.6058290531525141E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,   4.5908258741876240E-01,   7.6058290531525141E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,  -4.5908258741876240E-01,   7.6058290531525141E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,   4.5908258741876240E-01,  -7.6058290531525141E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,  -4.5908258741876240E-01,   7.6058290531525141E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,   4.5908258741876240E-01,  -7.6058290531525141E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,  -4.5908258741876240E-01,  -7.6058290531525141E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,  -4.5908258741876240E-01,  -7.6058290531525141E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,   7.6058290531525141E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,  -7.6058290531525141E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,   7.6058290531525141E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,  -7.6058290531525141E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,   7.6058290531525141E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,  -7.6058290531525141E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -4.5908258741876240E-01,  -7.6058290531525141E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [   4.5908258741876240E-01,   7.6058290531525141E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [   7.6058290531525141E-01,   4.5908258741876240E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -7.6058290531525141E-01,   4.5908258741876240E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [   7.6058290531525141E-01,  -4.5908258741876240E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [   7.6058290531525141E-01,   4.5908258741876240E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -7.6058290531525141E-01,  -4.5908258741876240E-01,   4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -7.6058290531525141E-01,   4.5908258741876240E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [   7.6058290531525141E-01,  -4.5908258741876240E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [  -7.6058290531525141E-01,  -4.5908258741876240E-01,  -4.5908258741876240E-01,   1.4003830134509660E-02],
            [   5.2145638884158607E-01,   5.2145638884158607E-01,   6.7540096910841430E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,   5.2145638884158607E-01,   6.7540096910841430E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,  -5.2145638884158607E-01,   6.7540096910841430E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,   5.2145638884158607E-01,  -6.7540096910841430E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,  -5.2145638884158607E-01,   6.7540096910841430E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,   5.2145638884158607E-01,  -6.7540096910841430E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,  -5.2145638884158607E-01,  -6.7540096910841430E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,  -5.2145638884158607E-01,  -6.7540096910841430E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,   6.7540096910841430E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,  -6.7540096910841430E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,   6.7540096910841430E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,  -6.7540096910841430E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,   6.7540096910841430E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,  -6.7540096910841430E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -5.2145638884158607E-01,  -6.7540096910841430E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [   5.2145638884158607E-01,   6.7540096910841430E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [   6.7540096910841430E-01,   5.2145638884158607E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -6.7540096910841430E-01,   5.2145638884158607E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [   6.7540096910841430E-01,  -5.2145638884158607E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [   6.7540096910841430E-01,   5.2145638884158607E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -6.7540096910841430E-01,  -5.2145638884158607E-01,   5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -6.7540096910841430E-01,   5.2145638884158607E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [   6.7540096910841430E-01,  -5.2145638884158607E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [  -6.7540096910841430E-01,  -5.2145638884158607E-01,  -5.2145638884158607E-01,   1.4121142155198050E-02],
            [   6.2531702446541992E-01,   6.2531702446541992E-01,   4.6685890569574318E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,   6.2531702446541992E-01,   4.6685890569574318E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,  -6.2531702446541992E-01,   4.6685890569574318E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,   6.2531702446541992E-01,  -4.6685890569574318E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,  -6.2531702446541992E-01,   4.6685890569574318E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,   6.2531702446541992E-01,  -4.6685890569574318E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,  -6.2531702446541992E-01,  -4.6685890569574318E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,  -6.2531702446541992E-01,  -4.6685890569574318E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,   4.6685890569574318E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,  -4.6685890569574318E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,   4.6685890569574318E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,  -4.6685890569574318E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,   4.6685890569574318E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,  -4.6685890569574318E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -6.2531702446541992E-01,  -4.6685890569574318E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [   6.2531702446541992E-01,   4.6685890569574318E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [   4.6685890569574318E-01,   6.2531702446541992E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -4.6685890569574318E-01,   6.2531702446541992E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [   4.6685890569574318E-01,  -6.2531702446541992E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [   4.6685890569574318E-01,   6.2531702446541992E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -4.6685890569574318E-01,  -6.2531702446541992E-01,   6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -4.6685890569574318E-01,   6.2531702446541992E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [   4.6685890569574318E-01,  -6.2531702446541992E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [  -4.6685890569574318E-01,  -6.2531702446541992E-01,  -6.2531702446541992E-01,   1.4140174390865207E-02],
            [   6.6379267445231704E-01,   6.6379267445231704E-01,   3.4461365423743795E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,   6.6379267445231704E-01,   3.4461365423743795E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,  -6.6379267445231704E-01,   3.4461365423743795E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,   6.6379267445231704E-01,  -3.4461365423743795E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,  -6.6379267445231704E-01,   3.4461365423743795E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,   6.6379267445231704E-01,  -3.4461365423743795E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,  -6.6379267445231704E-01,  -3.4461365423743795E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,  -6.6379267445231704E-01,  -3.4461365423743795E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,   3.4461365423743795E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,  -3.4461365423743795E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,   3.4461365423743795E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,  -3.4461365423743795E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,   3.4461365423743795E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,  -3.4461365423743795E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -6.6379267445231704E-01,  -3.4461365423743795E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [   6.6379267445231704E-01,   3.4461365423743795E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [   3.4461365423743795E-01,   6.6379267445231704E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -3.4461365423743795E-01,   6.6379267445231704E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [   3.4461365423743795E-01,  -6.6379267445231704E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [   3.4461365423743795E-01,   6.6379267445231704E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -3.4461365423743795E-01,  -6.6379267445231704E-01,   6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -3.4461365423743795E-01,   6.6379267445231704E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [   3.4461365423743795E-01,  -6.6379267445231704E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [  -3.4461365423743795E-01,  -6.6379267445231704E-01,  -6.6379267445231704E-01,   1.4151659382211827E-02],
            [   6.9104103984983012E-01,   6.9104103984983012E-01,   2.1195415185018429E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,   6.9104103984983012E-01,   2.1195415185018429E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,  -6.9104103984983012E-01,   2.1195415185018429E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,   6.9104103984983012E-01,  -2.1195415185018429E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,  -6.9104103984983012E-01,   2.1195415185018429E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,   6.9104103984983012E-01,  -2.1195415185018429E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,  -6.9104103984983012E-01,  -2.1195415185018429E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,  -6.9104103984983012E-01,  -2.1195415185018429E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,   2.1195415185018429E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,  -2.1195415185018429E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,   2.1195415185018429E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,  -2.1195415185018429E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,   2.1195415185018429E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,  -2.1195415185018429E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -6.9104103984983012E-01,  -2.1195415185018429E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [   6.9104103984983012E-01,   2.1195415185018429E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [   2.1195415185018429E-01,   6.9104103984983012E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -2.1195415185018429E-01,   6.9104103984983012E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [   2.1195415185018429E-01,  -6.9104103984983012E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [   2.1195415185018429E-01,   6.9104103984983012E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -2.1195415185018429E-01,  -6.9104103984983012E-01,   6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -2.1195415185018429E-01,   6.9104103984983012E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [   2.1195415185018429E-01,  -6.9104103984983012E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [  -2.1195415185018429E-01,  -6.9104103984983012E-01,  -6.9104103984983012E-01,   1.4203604477068846E-02],
            [   7.0529070074577604E-01,   7.0529070074577604E-01,   7.1624401449955549E-02,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,   7.0529070074577604E-01,   7.1624401449955549E-02,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,  -7.0529070074577604E-01,   7.1624401449955549E-02,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,   7.0529070074577604E-01,  -7.1624401449955549E-02,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,  -7.0529070074577604E-01,   7.1624401449955549E-02,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,   7.0529070074577604E-01,  -7.1624401449955549E-02,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,  -7.0529070074577604E-01,  -7.1624401449955549E-02,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,  -7.0529070074577604E-01,  -7.1624401449955549E-02,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,   7.1624401449955549E-02,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,  -7.1624401449955549E-02,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,   7.1624401449955549E-02,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,  -7.1624401449955549E-02,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,   7.1624401449955549E-02,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,  -7.1624401449955549E-02,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.0529070074577604E-01,  -7.1624401449955549E-02,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.0529070074577604E-01,   7.1624401449955549E-02,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.1624401449955549E-02,   7.0529070074577604E-01,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.1624401449955549E-02,   7.0529070074577604E-01,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.1624401449955549E-02,  -7.0529070074577604E-01,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.1624401449955549E-02,   7.0529070074577604E-01,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.1624401449955549E-02,  -7.0529070074577604E-01,   7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.1624401449955549E-02,   7.0529070074577604E-01,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [   7.1624401449955549E-02,  -7.0529070074577604E-01,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [  -7.1624401449955549E-02,  -7.0529070074577604E-01,  -7.0529070074577604E-01,   1.4262661433124560E-02],
            [   1.2366867626579900E-01,   9.9232356543149014E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [  -1.2366867626579900E-01,   9.9232356543149014E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [   1.2366867626579900E-01,  -9.9232356543149014E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [  -1.2366867626579900E-01,  -9.9232356543149014E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [   9.9232356543149014E-01,   1.2366867626579900E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [  -9.9232356543149014E-01,   1.2366867626579900E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [   9.9232356543149014E-01,  -1.2366867626579900E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [  -9.9232356543149014E-01,  -1.2366867626579900E-01,   0.0000000000000000E+00,   8.5744970210195094E-03],
            [   1.2366867626579900E-01,   0.0000000000000000E+00,   9.9232356543149014E-01,   8.5744970210195094E-03],
            [  -1.2366867626579900E-01,   0.0000000000000000E+00,   9.9232356543149014E-01,   8.5744970210195094E-03],
            [   1.2366867626579900E-01,   0.0000000000000000E+00,  -9.9232356543149014E-01,   8.5744970210195094E-03],
            [  -1.2366867626579900E-01,   0.0000000000000000E+00,  -9.9232356543149014E-01,   8.5744970210195094E-03],
            [   9.9232356543149014E-01,   0.0000000000000000E+00,   1.2366867626579900E-01,   8.5744970210195094E-03],
            [  -9.9232356543149014E-01,   0.0000000000000000E+00,   1.2366867626579900E-01,   8.5744970210195094E-03],
            [   9.9232356543149014E-01,   0.0000000000000000E+00,  -1.2366867626579900E-01,   8.5744970210195094E-03],
            [  -9.9232356543149014E-01,   0.0000000000000000E+00,  -1.2366867626579900E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,   1.2366867626579900E-01,   9.9232356543149014E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,  -1.2366867626579900E-01,   9.9232356543149014E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,   1.2366867626579900E-01,  -9.9232356543149014E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,  -1.2366867626579900E-01,  -9.9232356543149014E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,   9.9232356543149014E-01,   1.2366867626579900E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,  -9.9232356543149014E-01,   1.2366867626579900E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,   9.9232356543149014E-01,  -1.2366867626579900E-01,   8.5744970210195094E-03],
            [   0.0000000000000000E+00,  -9.9232356543149014E-01,  -1.2366867626579900E-01,   8.5744970210195094E-03],
            [   2.9407771144683870E-01,   9.5578151249654841E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [  -2.9407771144683870E-01,   9.5578151249654841E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [   2.9407771144683870E-01,  -9.5578151249654841E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [  -2.9407771144683870E-01,  -9.5578151249654841E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [   9.5578151249654841E-01,   2.9407771144683870E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [  -9.5578151249654841E-01,   2.9407771144683870E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [   9.5578151249654841E-01,  -2.9407771144683870E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [  -9.5578151249654841E-01,  -2.9407771144683870E-01,   0.0000000000000000E+00,   1.1880445529094636E-02],
            [   2.9407771144683870E-01,   0.0000000000000000E+00,   9.5578151249654841E-01,   1.1880445529094636E-02],
            [  -2.9407771144683870E-01,   0.0000000000000000E+00,   9.5578151249654841E-01,   1.1880445529094636E-02],
            [   2.9407771144683870E-01,   0.0000000000000000E+00,  -9.5578151249654841E-01,   1.1880445529094636E-02],
            [  -2.9407771144683870E-01,   0.0000000000000000E+00,  -9.5578151249654841E-01,   1.1880445529094636E-02],
            [   9.5578151249654841E-01,   0.0000000000000000E+00,   2.9407771144683870E-01,   1.1880445529094636E-02],
            [  -9.5578151249654841E-01,   0.0000000000000000E+00,   2.9407771144683870E-01,   1.1880445529094636E-02],
            [   9.5578151249654841E-01,   0.0000000000000000E+00,  -2.9407771144683870E-01,   1.1880445529094636E-02],
            [  -9.5578151249654841E-01,   0.0000000000000000E+00,  -2.9407771144683870E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,   2.9407771144683870E-01,   9.5578151249654841E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,  -2.9407771144683870E-01,   9.5578151249654841E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,   2.9407771144683870E-01,  -9.5578151249654841E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,  -2.9407771144683870E-01,  -9.5578151249654841E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,   9.5578151249654841E-01,   2.9407771144683870E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,  -9.5578151249654841E-01,   2.9407771144683870E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,   9.5578151249654841E-01,  -2.9407771144683870E-01,   1.1880445529094636E-02],
            [   0.0000000000000000E+00,  -9.5578151249654841E-01,  -2.9407771144683870E-01,   1.1880445529094636E-02],
            [   4.6977538492076493E-01,   8.8278598070118164E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [  -4.6977538492076493E-01,   8.8278598070118164E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [   4.6977538492076493E-01,  -8.8278598070118164E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [  -4.6977538492076493E-01,  -8.8278598070118164E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [   8.8278598070118164E-01,   4.6977538492076493E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [  -8.8278598070118164E-01,   4.6977538492076493E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [   8.8278598070118164E-01,  -4.6977538492076493E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [  -8.8278598070118164E-01,  -4.6977538492076493E-01,   0.0000000000000000E+00,   1.3501685269873245E-02],
            [   4.6977538492076493E-01,   0.0000000000000000E+00,   8.8278598070118164E-01,   1.3501685269873245E-02],
            [  -4.6977538492076493E-01,   0.0000000000000000E+00,   8.8278598070118164E-01,   1.3501685269873245E-02],
            [   4.6977538492076493E-01,   0.0000000000000000E+00,  -8.8278598070118164E-01,   1.3501685269873245E-02],
            [  -4.6977538492076493E-01,   0.0000000000000000E+00,  -8.8278598070118164E-01,   1.3501685269873245E-02],
            [   8.8278598070118164E-01,   0.0000000000000000E+00,   4.6977538492076493E-01,   1.3501685269873245E-02],
            [  -8.8278598070118164E-01,   0.0000000000000000E+00,   4.6977538492076493E-01,   1.3501685269873245E-02],
            [   8.8278598070118164E-01,   0.0000000000000000E+00,  -4.6977538492076493E-01,   1.3501685269873245E-02],
            [  -8.8278598070118164E-01,   0.0000000000000000E+00,  -4.6977538492076493E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,   4.6977538492076493E-01,   8.8278598070118164E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,  -4.6977538492076493E-01,   8.8278598070118164E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,   4.6977538492076493E-01,  -8.8278598070118164E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,  -4.6977538492076493E-01,  -8.8278598070118164E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,   8.8278598070118164E-01,   4.6977538492076493E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,  -8.8278598070118164E-01,   4.6977538492076493E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,   8.8278598070118164E-01,  -4.6977538492076493E-01,   1.3501685269873245E-02],
            [   0.0000000000000000E+00,  -8.8278598070118164E-01,  -4.6977538492076493E-01,   1.3501685269873245E-02],
            [   6.3345632411395669E-01,   7.7377844725737477E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [  -6.3345632411395669E-01,   7.7377844725737477E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [   6.3345632411395669E-01,  -7.7377844725737477E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [  -6.3345632411395669E-01,  -7.7377844725737477E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [   7.7377844725737477E-01,   6.3345632411395669E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [  -7.7377844725737477E-01,   6.3345632411395669E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [   7.7377844725737477E-01,  -6.3345632411395669E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [  -7.7377844725737477E-01,  -6.3345632411395669E-01,   0.0000000000000000E+00,   1.4191203422655610E-02],
            [   6.3345632411395669E-01,   0.0000000000000000E+00,   7.7377844725737477E-01,   1.4191203422655610E-02],
            [  -6.3345632411395669E-01,   0.0000000000000000E+00,   7.7377844725737477E-01,   1.4191203422655610E-02],
            [   6.3345632411395669E-01,   0.0000000000000000E+00,  -7.7377844725737477E-01,   1.4191203422655610E-02],
            [  -6.3345632411395669E-01,   0.0000000000000000E+00,  -7.7377844725737477E-01,   1.4191203422655610E-02],
            [   7.7377844725737477E-01,   0.0000000000000000E+00,   6.3345632411395669E-01,   1.4191203422655610E-02],
            [  -7.7377844725737477E-01,   0.0000000000000000E+00,   6.3345632411395669E-01,   1.4191203422655610E-02],
            [   7.7377844725737477E-01,   0.0000000000000000E+00,  -6.3345632411395669E-01,   1.4191203422655610E-02],
            [  -7.7377844725737477E-01,   0.0000000000000000E+00,  -6.3345632411395669E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,   6.3345632411395669E-01,   7.7377844725737477E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,  -6.3345632411395669E-01,   7.7377844725737477E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,   6.3345632411395669E-01,  -7.7377844725737477E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,  -6.3345632411395669E-01,  -7.7377844725737477E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,   7.7377844725737477E-01,   6.3345632411395669E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,  -7.7377844725737477E-01,   6.3345632411395669E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,   7.7377844725737477E-01,  -6.3345632411395669E-01,   1.4191203422655610E-02],
            [   0.0000000000000000E+00,  -7.7377844725737477E-01,  -6.3345632411395669E-01,   1.4191203422655610E-02],
            [   5.9740486141813418E-02,   2.0291287527775231E-01,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,   2.0291287527775231E-01,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,  -2.0291287527775231E-01,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,   2.0291287527775231E-01,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,  -2.0291287527775231E-01,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,  -2.0291287527775231E-01,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,   2.0291287527775231E-01,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,  -2.0291287527775231E-01,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,   5.9740486141813418E-02,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,   5.9740486141813418E-02,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,  -5.9740486141813418E-02,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,   5.9740486141813418E-02,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,  -5.9740486141813418E-02,   9.7737272284530996E-01,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,  -5.9740486141813418E-02,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,   5.9740486141813418E-02,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,  -5.9740486141813418E-02,  -9.7737272284530996E-01,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,   5.9740486141813418E-02,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,   5.9740486141813418E-02,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,  -5.9740486141813418E-02,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,   5.9740486141813418E-02,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,  -5.9740486141813418E-02,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,  -5.9740486141813418E-02,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,   5.9740486141813418E-02,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,  -5.9740486141813418E-02,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,   2.0291287527775231E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,   2.0291287527775231E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,  -2.0291287527775231E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,   2.0291287527775231E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,  -2.0291287527775231E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   9.7737272284530996E-01,  -2.0291287527775231E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,   2.0291287527775231E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -9.7737272284530996E-01,  -2.0291287527775231E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,   9.7737272284530996E-01,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,   9.7737272284530996E-01,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,  -9.7737272284530996E-01,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,   9.7737272284530996E-01,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,  -9.7737272284530996E-01,   2.0291287527775231E-01,   1.0602101746887665E-02],
            [   5.9740486141813418E-02,  -9.7737272284530996E-01,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,   9.7737272284530996E-01,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [  -5.9740486141813418E-02,  -9.7737272284530996E-01,  -2.0291287527775231E-01,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,   9.7737272284530996E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,   9.7737272284530996E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,  -9.7737272284530996E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,   9.7737272284530996E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,  -9.7737272284530996E-01,   5.9740486141813418E-02,   1.0602101746887665E-02],
            [   2.0291287527775231E-01,  -9.7737272284530996E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,   9.7737272284530996E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [  -2.0291287527775231E-01,  -9.7737272284530996E-01,  -5.9740486141813418E-02,   1.0602101746887665E-02],
            [   1.3757604084736361E-01,   4.6026219424840542E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,   4.6026219424840542E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,  -4.6026219424840542E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,   4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,  -4.6026219424840542E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,  -4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,   4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,  -4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,   1.3757604084736361E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,   1.3757604084736361E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,  -1.3757604084736361E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,   1.3757604084736361E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,  -1.3757604084736361E-01,   8.7705846186580272E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,  -1.3757604084736361E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,   1.3757604084736361E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,  -1.3757604084736361E-01,  -8.7705846186580272E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,   1.3757604084736361E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,   1.3757604084736361E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,  -1.3757604084736361E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,   1.3757604084736361E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,  -1.3757604084736361E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,  -1.3757604084736361E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,   1.3757604084736361E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,  -1.3757604084736361E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,   4.6026219424840542E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,   4.6026219424840542E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,   4.6026219424840542E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   8.7705846186580272E-01,  -4.6026219424840542E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,   4.6026219424840542E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -8.7705846186580272E-01,  -4.6026219424840542E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,   8.7705846186580272E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,   8.7705846186580272E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,  -8.7705846186580272E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,   8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,  -8.7705846186580272E-01,   4.6026219424840542E-01,   1.3512061888370470E-02],
            [   1.3757604084736361E-01,  -8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,   8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [  -1.3757604084736361E-01,  -8.7705846186580272E-01,  -4.6026219424840542E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,   8.7705846186580272E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,   8.7705846186580272E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,   8.7705846186580272E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,  -8.7705846186580272E-01,   1.3757604084736361E-01,   1.3512061888370470E-02],
            [   4.6026219424840542E-01,  -8.7705846186580272E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,   8.7705846186580272E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [  -4.6026219424840542E-01,  -8.7705846186580272E-01,  -1.3757604084736361E-01,   1.3512061888370470E-02],
            [   3.3910165263362863E-01,   5.0306739996620364E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,   5.0306739996620364E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,  -5.0306739996620364E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,   5.0306739996620364E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,  -5.0306739996620364E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,  -5.0306739996620364E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,   5.0306739996620364E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,  -5.0306739996620364E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,   3.3910165263362863E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,   3.3910165263362863E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,  -3.3910165263362863E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,   3.3910165263362863E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,  -3.3910165263362863E-01,   7.9494229996420840E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,  -3.3910165263362863E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,   3.3910165263362863E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,  -3.3910165263362863E-01,  -7.9494229996420840E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,   3.3910165263362863E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,   3.3910165263362863E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,  -3.3910165263362863E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,   3.3910165263362863E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,  -3.3910165263362863E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,  -3.3910165263362863E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,   3.3910165263362863E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,  -3.3910165263362863E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,   5.0306739996620364E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,   5.0306739996620364E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,  -5.0306739996620364E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,   5.0306739996620364E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,  -5.0306739996620364E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   7.9494229996420840E-01,  -5.0306739996620364E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,   5.0306739996620364E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -7.9494229996420840E-01,  -5.0306739996620364E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,   7.9494229996420840E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,   7.9494229996420840E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,  -7.9494229996420840E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,   7.9494229996420840E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,  -7.9494229996420840E-01,   5.0306739996620364E-01,   1.3930792413081063E-02],
            [   3.3910165263362863E-01,  -7.9494229996420840E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,   7.9494229996420840E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [  -3.3910165263362863E-01,  -7.9494229996420840E-01,  -5.0306739996620364E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,   7.9494229996420840E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,   7.9494229996420840E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,  -7.9494229996420840E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,   7.9494229996420840E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,  -7.9494229996420840E-01,   3.3910165263362863E-01,   1.3930792413081063E-02],
            [   5.0306739996620364E-01,  -7.9494229996420840E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,   7.9494229996420840E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [  -5.0306739996620364E-01,  -7.9494229996420840E-01,  -3.3910165263362863E-01,   1.3930792413081063E-02],
            [   1.2716751914398200E-01,   2.8176064224421338E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,   2.8176064224421338E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,  -2.8176064224421338E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,   2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,  -2.8176064224421338E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,  -2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,   2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,  -2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,   1.2716751914398200E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,   1.2716751914398200E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,  -1.2716751914398200E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,   1.2716751914398200E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,  -1.2716751914398200E-01,   9.5102016937438993E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,  -1.2716751914398200E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,   1.2716751914398200E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,  -1.2716751914398200E-01,  -9.5102016937438993E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,   1.2716751914398200E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,   1.2716751914398200E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,  -1.2716751914398200E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,   1.2716751914398200E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,  -1.2716751914398200E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,  -1.2716751914398200E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,   1.2716751914398200E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,  -1.2716751914398200E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,   2.8176064224421338E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,   2.8176064224421338E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,   2.8176064224421338E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   9.5102016937438993E-01,  -2.8176064224421338E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,   2.8176064224421338E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -9.5102016937438993E-01,  -2.8176064224421338E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,   9.5102016937438993E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,   9.5102016937438993E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,  -9.5102016937438993E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,   9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,  -9.5102016937438993E-01,   2.8176064224421338E-01,   1.2021587439178333E-02],
            [   1.2716751914398200E-01,  -9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,   9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [  -1.2716751914398200E-01,  -9.5102016937438993E-01,  -2.8176064224421338E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,   9.5102016937438993E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,   9.5102016937438993E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,   9.5102016937438993E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,  -9.5102016937438993E-01,   1.2716751914398200E-01,   1.2021587439178333E-02],
            [   2.8176064224421338E-01,  -9.5102016937438993E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,   9.5102016937438993E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [  -2.8176064224421338E-01,  -9.5102016937438993E-01,  -1.2716751914398200E-01,   1.2021587439178333E-02],
            [   2.6931207404135121E-01,   4.3315612917201568E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,   4.3315612917201568E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,  -4.3315612917201568E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,   4.3315612917201568E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,  -4.3315612917201568E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,  -4.3315612917201568E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,   4.3315612917201568E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,  -4.3315612917201568E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,   2.6931207404135121E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,   2.6931207404135121E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,  -2.6931207404135121E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,   2.6931207404135121E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,  -2.6931207404135121E-01,   8.6014346160176203E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,  -2.6931207404135121E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,   2.6931207404135121E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,  -2.6931207404135121E-01,  -8.6014346160176203E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,   2.6931207404135121E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,   2.6931207404135121E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,  -2.6931207404135121E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,   2.6931207404135121E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,  -2.6931207404135121E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,  -2.6931207404135121E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,   2.6931207404135121E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,  -2.6931207404135121E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,   4.3315612917201568E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,   4.3315612917201568E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,  -4.3315612917201568E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,   4.3315612917201568E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,  -4.3315612917201568E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   8.6014346160176203E-01,  -4.3315612917201568E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,   4.3315612917201568E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -8.6014346160176203E-01,  -4.3315612917201568E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,   8.6014346160176203E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,   8.6014346160176203E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,  -8.6014346160176203E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,   8.6014346160176203E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,  -8.6014346160176203E-01,   4.3315612917201568E-01,   1.3580014917832881E-02],
            [   2.6931207404135121E-01,  -8.6014346160176203E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,   8.6014346160176203E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [  -2.6931207404135121E-01,  -8.6014346160176203E-01,  -4.3315612917201568E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,   8.6014346160176203E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,   8.6014346160176203E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,  -8.6014346160176203E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,   8.6014346160176203E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,  -8.6014346160176203E-01,   2.6931207404135121E-01,   1.3580014917832881E-02],
            [   4.3315612917201568E-01,  -8.6014346160176203E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,   8.6014346160176203E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [  -4.3315612917201568E-01,  -8.6014346160176203E-01,  -2.6931207404135121E-01,   1.3580014917832881E-02],
            [   1.4197864526019180E-01,   6.2561673585808142E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,   6.2561673585808142E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,  -6.2561673585808142E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,   6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,  -6.2561673585808142E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,  -6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,   6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,  -6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,   1.4197864526019180E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,   1.4197864526019180E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,  -1.4197864526019180E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,   1.4197864526019180E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,  -1.4197864526019180E-01,   7.6710218622055826E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,  -1.4197864526019180E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,   1.4197864526019180E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,  -1.4197864526019180E-01,  -7.6710218622055826E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,   1.4197864526019180E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,   1.4197864526019180E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,  -1.4197864526019180E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,   1.4197864526019180E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,  -1.4197864526019180E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,  -1.4197864526019180E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,   1.4197864526019180E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,  -1.4197864526019180E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,   6.2561673585808142E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,   6.2561673585808142E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,   6.2561673585808142E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   7.6710218622055826E-01,  -6.2561673585808142E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,   6.2561673585808142E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -7.6710218622055826E-01,  -6.2561673585808142E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,   7.6710218622055826E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,   7.6710218622055826E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,  -7.6710218622055826E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,   7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,  -7.6710218622055826E-01,   6.2561673585808142E-01,   1.4159750357809340E-02],
            [   1.4197864526019180E-01,  -7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,   7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [  -1.4197864526019180E-01,  -7.6710218622055826E-01,  -6.2561673585808142E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,   7.6710218622055826E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,   7.6710218622055826E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,   7.6710218622055826E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,  -7.6710218622055826E-01,   1.4197864526019180E-01,   1.4159750357809340E-02],
            [   6.2561673585808142E-01,  -7.6710218622055826E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,   7.6710218622055826E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [  -6.2561673585808142E-01,  -7.6710218622055826E-01,  -1.4197864526019180E-01,   1.4159750357809340E-02],
            [   6.7092846007382551E-02,   3.7983952168591573E-01,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,   3.7983952168591573E-01,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,  -3.7983952168591573E-01,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,   3.7983952168591573E-01,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,  -3.7983952168591573E-01,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,  -3.7983952168591573E-01,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,   3.7983952168591573E-01,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,  -3.7983952168591573E-01,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,   6.7092846007382551E-02,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,   6.7092846007382551E-02,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,  -6.7092846007382551E-02,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,   6.7092846007382551E-02,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,  -6.7092846007382551E-02,   9.2261611073080896E-01,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,  -6.7092846007382551E-02,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,   6.7092846007382551E-02,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,  -6.7092846007382551E-02,  -9.2261611073080896E-01,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,   6.7092846007382551E-02,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,   6.7092846007382551E-02,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,  -6.7092846007382551E-02,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,   6.7092846007382551E-02,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,  -6.7092846007382551E-02,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,  -6.7092846007382551E-02,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,   6.7092846007382551E-02,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,  -6.7092846007382551E-02,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,   3.7983952168591573E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,   3.7983952168591573E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,  -3.7983952168591573E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,   3.7983952168591573E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,  -3.7983952168591573E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   9.2261611073080896E-01,  -3.7983952168591573E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,   3.7983952168591573E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -9.2261611073080896E-01,  -3.7983952168591573E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,   9.2261611073080896E-01,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,   9.2261611073080896E-01,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,  -9.2261611073080896E-01,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,   9.2261611073080896E-01,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,  -9.2261611073080896E-01,   3.7983952168591573E-01,   1.2849977455838546E-02],
            [   6.7092846007382551E-02,  -9.2261611073080896E-01,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,   9.2261611073080896E-01,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [  -6.7092846007382551E-02,  -9.2261611073080896E-01,  -3.7983952168591573E-01,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,   9.2261611073080896E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,   9.2261611073080896E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,  -9.2261611073080896E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,   9.2261611073080896E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,  -9.2261611073080896E-01,   6.7092846007382551E-02,   1.2849977455838546E-02],
            [   3.7983952168591573E-01,  -9.2261611073080896E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,   9.2261611073080896E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [  -3.7983952168591573E-01,  -9.2261611073080896E-01,  -6.7092846007382551E-02,   1.2849977455838546E-02],
            [   7.0577381832561722E-02,   5.5175054214235197E-01,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,   5.5175054214235197E-01,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,  -5.5175054214235197E-01,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,   5.5175054214235197E-01,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,  -5.5175054214235197E-01,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,  -5.5175054214235197E-01,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,   5.5175054214235197E-01,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,  -5.5175054214235197E-01,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,   7.0577381832561722E-02,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,   7.0577381832561722E-02,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,  -7.0577381832561722E-02,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,   7.0577381832561722E-02,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,  -7.0577381832561722E-02,   8.3101755241347430E-01,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,  -7.0577381832561722E-02,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,   7.0577381832561722E-02,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,  -7.0577381832561722E-02,  -8.3101755241347430E-01,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,   7.0577381832561722E-02,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,   7.0577381832561722E-02,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,  -7.0577381832561722E-02,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,   7.0577381832561722E-02,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,  -7.0577381832561722E-02,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,  -7.0577381832561722E-02,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,   7.0577381832561722E-02,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,  -7.0577381832561722E-02,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,   5.5175054214235197E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,   5.5175054214235197E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,  -5.5175054214235197E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,   5.5175054214235197E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,  -5.5175054214235197E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   8.3101755241347430E-01,  -5.5175054214235197E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,   5.5175054214235197E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -8.3101755241347430E-01,  -5.5175054214235197E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,   8.3101755241347430E-01,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,   8.3101755241347430E-01,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,  -8.3101755241347430E-01,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,   8.3101755241347430E-01,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,  -8.3101755241347430E-01,   5.5175054214235197E-01,   1.3935605720681881E-02],
            [   7.0577381832561722E-02,  -8.3101755241347430E-01,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,   8.3101755241347430E-01,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [  -7.0577381832561722E-02,  -8.3101755241347430E-01,  -5.5175054214235197E-01,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,   8.3101755241347430E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,   8.3101755241347430E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,  -8.3101755241347430E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,   8.3101755241347430E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,  -8.3101755241347430E-01,   7.0577381832561722E-02,   1.3935605720681881E-02],
            [   5.5175054214235197E-01,  -8.3101755241347430E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,   8.3101755241347430E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [  -5.5175054214235197E-01,  -8.3101755241347430E-01,  -7.0577381832561722E-02,   1.3935605720681881E-02],
            [   2.7838884778821549E-01,   6.0296191561591872E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,   6.0296191561591872E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,  -6.0296191561591872E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,   6.0296191561591872E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,  -6.0296191561591872E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,  -6.0296191561591872E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,   6.0296191561591872E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,  -6.0296191561591872E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,   2.7838884778821549E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,   2.7838884778821549E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,  -2.7838884778821549E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,   2.7838884778821549E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,  -2.7838884778821549E-01,   7.4762061083408571E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,  -2.7838884778821549E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,   2.7838884778821549E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,  -2.7838884778821549E-01,  -7.4762061083408571E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,   2.7838884778821549E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,   2.7838884778821549E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,  -2.7838884778821549E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,   2.7838884778821549E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,  -2.7838884778821549E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,  -2.7838884778821549E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,   2.7838884778821549E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,  -2.7838884778821549E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,   6.0296191561591872E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,   6.0296191561591872E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,  -6.0296191561591872E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,   6.0296191561591872E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,  -6.0296191561591872E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   7.4762061083408571E-01,  -6.0296191561591872E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,   6.0296191561591872E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -7.4762061083408571E-01,  -6.0296191561591872E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,   7.4762061083408571E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,   7.4762061083408571E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,  -7.4762061083408571E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,   7.4762061083408571E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,  -7.4762061083408571E-01,   6.0296191561591872E-01,   1.4109403473412344E-02],
            [   2.7838884778821549E-01,  -7.4762061083408571E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,   7.4762061083408571E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [  -2.7838884778821549E-01,  -7.4762061083408571E-01,  -6.0296191561591872E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,   7.4762061083408571E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,   7.4762061083408571E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,  -7.4762061083408571E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,   7.4762061083408571E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,  -7.4762061083408571E-01,   2.7838884778821549E-01,   1.4109403473412344E-02],
            [   6.0296191561591872E-01,  -7.4762061083408571E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,   7.4762061083408571E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [  -6.0296191561591872E-01,  -7.4762061083408571E-01,  -2.7838884778821549E-01,   1.4109403473412344E-02],
            [   1.9795789389174070E-01,   3.5896063295890962E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,   3.5896063295890962E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,  -3.5896063295890962E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,   3.5896063295890962E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,  -3.5896063295890962E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,  -3.5896063295890962E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,   3.5896063295890962E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,  -3.5896063295890962E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,   1.9795789389174070E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,   1.9795789389174070E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,  -1.9795789389174070E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,   1.9795789389174070E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,  -1.9795789389174070E-01,   9.1211837840912147E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,  -1.9795789389174070E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,   1.9795789389174070E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,  -1.9795789389174070E-01,  -9.1211837840912147E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,   1.9795789389174070E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,   1.9795789389174070E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,  -1.9795789389174070E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,   1.9795789389174070E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,  -1.9795789389174070E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,  -1.9795789389174070E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,   1.9795789389174070E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,  -1.9795789389174070E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,   3.5896063295890962E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,   3.5896063295890962E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,  -3.5896063295890962E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,   3.5896063295890962E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,  -3.5896063295890962E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   9.1211837840912147E-01,  -3.5896063295890962E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,   3.5896063295890962E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -9.1211837840912147E-01,  -3.5896063295890962E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,   9.1211837840912147E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,   9.1211837840912147E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,  -9.1211837840912147E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,   9.1211837840912147E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,  -9.1211837840912147E-01,   3.5896063295890962E-01,   1.2973544233826980E-02],
            [   1.9795789389174070E-01,  -9.1211837840912147E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,   9.1211837840912147E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [  -1.9795789389174070E-01,  -9.1211837840912147E-01,  -3.5896063295890962E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,   9.1211837840912147E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,   9.1211837840912147E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,  -9.1211837840912147E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,   9.1211837840912147E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,  -9.1211837840912147E-01,   1.9795789389174070E-01,   1.2973544233826980E-02],
            [   3.5896063295890962E-01,  -9.1211837840912147E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,   9.1211837840912147E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [  -3.5896063295890962E-01,  -9.1211837840912147E-01,  -1.9795789389174070E-01,   1.2973544233826980E-02],
            [   2.0873070611032740E-01,   5.3486664381354765E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,   5.3486664381354765E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,  -5.3486664381354765E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,   5.3486664381354765E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,  -5.3486664381354765E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,  -5.3486664381354765E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,   5.3486664381354765E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,  -5.3486664381354765E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,   2.0873070611032740E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,   2.0873070611032740E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,  -2.0873070611032740E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,   2.0873070611032740E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,  -2.0873070611032740E-01,   8.1874853628102184E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,  -2.0873070611032740E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,   2.0873070611032740E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,  -2.0873070611032740E-01,  -8.1874853628102184E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,   2.0873070611032740E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,   2.0873070611032740E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,  -2.0873070611032740E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,   2.0873070611032740E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,  -2.0873070611032740E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,  -2.0873070611032740E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,   2.0873070611032740E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,  -2.0873070611032740E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,   5.3486664381354765E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,   5.3486664381354765E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,  -5.3486664381354765E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,   5.3486664381354765E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,  -5.3486664381354765E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   8.1874853628102184E-01,  -5.3486664381354765E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,   5.3486664381354765E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -8.1874853628102184E-01,  -5.3486664381354765E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,   8.1874853628102184E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,   8.1874853628102184E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,  -8.1874853628102184E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,   8.1874853628102184E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,  -8.1874853628102184E-01,   5.3486664381354765E-01,   1.3914106100299167E-02],
            [   2.0873070611032740E-01,  -8.1874853628102184E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,   8.1874853628102184E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [  -2.0873070611032740E-01,  -8.1874853628102184E-01,  -5.3486664381354765E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,   8.1874853628102184E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,   8.1874853628102184E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,  -8.1874853628102184E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,   8.1874853628102184E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,  -8.1874853628102184E-01,   2.0873070611032740E-01,   1.3914106100299167E-02],
            [   5.3486664381354765E-01,  -8.1874853628102184E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,   8.1874853628102184E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [  -5.3486664381354765E-01,  -8.1874853628102184E-01,  -2.0873070611032740E-01,   1.3914106100299167E-02],
            [   4.0551221378728358E-01,   5.6749975460743729E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,   5.6749975460743729E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,  -5.6749975460743729E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,   5.6749975460743729E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,  -5.6749975460743729E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,  -5.6749975460743729E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,   5.6749975460743729E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,  -5.6749975460743729E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,   4.0551221378728358E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,   4.0551221378728358E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,  -4.0551221378728358E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,   4.0551221378728358E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,  -4.0551221378728358E-01,   7.1659184546702381E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,  -4.0551221378728358E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,   4.0551221378728358E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,  -4.0551221378728358E-01,  -7.1659184546702381E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,   4.0551221378728358E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,   4.0551221378728358E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,  -4.0551221378728358E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,   4.0551221378728358E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,  -4.0551221378728358E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,  -4.0551221378728358E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,   4.0551221378728358E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,  -4.0551221378728358E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,   5.6749975460743729E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,   5.6749975460743729E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,  -5.6749975460743729E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,   5.6749975460743729E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,  -5.6749975460743729E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   7.1659184546702381E-01,  -5.6749975460743729E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,   5.6749975460743729E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -7.1659184546702381E-01,  -5.6749975460743729E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,   7.1659184546702381E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,   7.1659184546702381E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,  -7.1659184546702381E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,   7.1659184546702381E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,  -7.1659184546702381E-01,   5.6749975460743729E-01,   1.4096703837495783E-02],
            [   4.0551221378728358E-01,  -7.1659184546702381E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,   7.1659184546702381E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [  -4.0551221378728358E-01,  -7.1659184546702381E-01,  -5.6749975460743729E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,   7.1659184546702381E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,   7.1659184546702381E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,  -7.1659184546702381E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,   7.1659184546702381E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,  -7.1659184546702381E-01,   4.0551221378728358E-01,   1.4096703837495783E-02],
            [   5.6749975460743729E-01,  -7.1659184546702381E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,   7.1659184546702381E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
            [  -5.6749975460743729E-01,  -7.1659184546702381E-01,  -4.0551221378728358E-01,   1.4096703837495783E-02],
        ])
  
        order = 53
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build1202():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.3888217504239762E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.3888217504239762E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.3888217504239762E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.3888217504239762E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.3888217504239762E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.3888217504239762E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   1.1567636617828050E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   1.1567636617828050E-02],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   1.1567636617828050E-02],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   1.1567636617828050E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   1.1567636617828050E-02],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   1.1567636617828050E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   1.1567636617828050E-02],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   1.1567636617828050E-02],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   1.1567636617828050E-02],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   1.1567636617828050E-02],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   1.1567636617828050E-02],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   1.1567636617828050E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.1477067075661127E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   1.1477067075661127E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.1477067075661127E-02],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.1477067075661127E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   1.1477067075661127E-02],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.1477067075661127E-02],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   1.1477067075661127E-02],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   1.1477067075661127E-02],
            [   3.7126364496570891E-02,   3.7126364496570891E-02,   9.9862068179991925E-01,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,   3.7126364496570891E-02,   9.9862068179991925E-01,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,  -3.7126364496570891E-02,   9.9862068179991925E-01,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,   3.7126364496570891E-02,  -9.9862068179991925E-01,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,  -3.7126364496570891E-02,   9.9862068179991925E-01,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,   3.7126364496570891E-02,  -9.9862068179991925E-01,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,  -3.7126364496570891E-02,  -9.9862068179991925E-01,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,  -3.7126364496570891E-02,  -9.9862068179991925E-01,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,   9.9862068179991925E-01,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,  -9.9862068179991925E-01,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,   9.9862068179991925E-01,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,  -9.9862068179991925E-01,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,   9.9862068179991925E-01,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,  -9.9862068179991925E-01,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -3.7126364496570891E-02,  -9.9862068179991925E-01,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [   3.7126364496570891E-02,   9.9862068179991925E-01,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [   9.9862068179991925E-01,   3.7126364496570891E-02,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -9.9862068179991925E-01,   3.7126364496570891E-02,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [   9.9862068179991925E-01,  -3.7126364496570891E-02,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [   9.9862068179991925E-01,   3.7126364496570891E-02,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -9.9862068179991925E-01,  -3.7126364496570891E-02,   3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -9.9862068179991925E-01,   3.7126364496570891E-02,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [   9.9862068179991925E-01,  -3.7126364496570891E-02,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [  -9.9862068179991925E-01,  -3.7126364496570891E-02,  -3.7126364496570891E-02,   4.6375209293839726E-03],
            [   9.1400604122622228E-02,   9.1400604122622228E-02,   9.9161073972201386E-01,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,   9.1400604122622228E-02,   9.9161073972201386E-01,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,  -9.1400604122622228E-02,   9.9161073972201386E-01,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,   9.1400604122622228E-02,  -9.9161073972201386E-01,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,  -9.1400604122622228E-02,   9.9161073972201386E-01,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,   9.1400604122622228E-02,  -9.9161073972201386E-01,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,  -9.1400604122622228E-02,  -9.9161073972201386E-01,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,  -9.1400604122622228E-02,  -9.9161073972201386E-01,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,   9.9161073972201386E-01,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,  -9.9161073972201386E-01,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,   9.9161073972201386E-01,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,  -9.9161073972201386E-01,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,   9.9161073972201386E-01,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,  -9.9161073972201386E-01,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.1400604122622228E-02,  -9.9161073972201386E-01,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.1400604122622228E-02,   9.9161073972201386E-01,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.9161073972201386E-01,   9.1400604122622228E-02,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.9161073972201386E-01,   9.1400604122622228E-02,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.9161073972201386E-01,  -9.1400604122622228E-02,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.9161073972201386E-01,   9.1400604122622228E-02,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.9161073972201386E-01,  -9.1400604122622228E-02,   9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.9161073972201386E-01,   9.1400604122622228E-02,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [   9.9161073972201386E-01,  -9.1400604122622228E-02,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [  -9.9161073972201386E-01,  -9.1400604122622228E-02,  -9.1400604122622228E-02,   7.0421826929308023E-03],
            [   1.5310778524699059E-01,   1.5310778524699059E-01,   9.7627660639468505E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,   1.5310778524699059E-01,   9.7627660639468505E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,  -1.5310778524699059E-01,   9.7627660639468505E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,   1.5310778524699059E-01,  -9.7627660639468505E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,  -1.5310778524699059E-01,   9.7627660639468505E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,   1.5310778524699059E-01,  -9.7627660639468505E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,  -1.5310778524699059E-01,  -9.7627660639468505E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,  -1.5310778524699059E-01,  -9.7627660639468505E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,   9.7627660639468505E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,  -9.7627660639468505E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,   9.7627660639468505E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,  -9.7627660639468505E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,   9.7627660639468505E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,  -9.7627660639468505E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -1.5310778524699059E-01,  -9.7627660639468505E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [   1.5310778524699059E-01,   9.7627660639468505E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [   9.7627660639468505E-01,   1.5310778524699059E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -9.7627660639468505E-01,   1.5310778524699059E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [   9.7627660639468505E-01,  -1.5310778524699059E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [   9.7627660639468505E-01,   1.5310778524699059E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -9.7627660639468505E-01,  -1.5310778524699059E-01,   1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -9.7627660639468505E-01,   1.5310778524699059E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [   9.7627660639468505E-01,  -1.5310778524699059E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [  -9.7627660639468505E-01,  -1.5310778524699059E-01,  -1.5310778524699059E-01,   8.6271874387446670E-03],
            [   2.1809288916606120E-01,   2.1809288916606120E-01,   9.5124706748057852E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,   2.1809288916606120E-01,   9.5124706748057852E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,  -2.1809288916606120E-01,   9.5124706748057852E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,   2.1809288916606120E-01,  -9.5124706748057852E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,  -2.1809288916606120E-01,   9.5124706748057852E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,   2.1809288916606120E-01,  -9.5124706748057852E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,  -2.1809288916606120E-01,  -9.5124706748057852E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,  -2.1809288916606120E-01,  -9.5124706748057852E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,   9.5124706748057852E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,  -9.5124706748057852E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,   9.5124706748057852E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,  -9.5124706748057852E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,   9.5124706748057852E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,  -9.5124706748057852E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -2.1809288916606120E-01,  -9.5124706748057852E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [   2.1809288916606120E-01,   9.5124706748057852E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [   9.5124706748057852E-01,   2.1809288916606120E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -9.5124706748057852E-01,   2.1809288916606120E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [   9.5124706748057852E-01,  -2.1809288916606120E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [   9.5124706748057852E-01,   2.1809288916606120E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -9.5124706748057852E-01,  -2.1809288916606120E-01,   2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -9.5124706748057852E-01,   2.1809288916606120E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [   9.5124706748057852E-01,  -2.1809288916606120E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [  -9.5124706748057852E-01,  -2.1809288916606120E-01,  -2.1809288916606120E-01,   9.7016635502020724E-03],
            [   2.8398745322001751E-01,   2.8398745322001751E-01,   9.1580688620866835E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,   2.8398745322001751E-01,   9.1580688620866835E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,  -2.8398745322001751E-01,   9.1580688620866835E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,   2.8398745322001751E-01,  -9.1580688620866835E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,  -2.8398745322001751E-01,   9.1580688620866835E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,   2.8398745322001751E-01,  -9.1580688620866835E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,  -2.8398745322001751E-01,  -9.1580688620866835E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,  -2.8398745322001751E-01,  -9.1580688620866835E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,   9.1580688620866835E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,  -9.1580688620866835E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,   9.1580688620866835E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,  -9.1580688620866835E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,   9.1580688620866835E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,  -9.1580688620866835E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -2.8398745322001751E-01,  -9.1580688620866835E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [   2.8398745322001751E-01,   9.1580688620866835E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [   9.1580688620866835E-01,   2.8398745322001751E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -9.1580688620866835E-01,   2.8398745322001751E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [   9.1580688620866835E-01,  -2.8398745322001751E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [   9.1580688620866835E-01,   2.8398745322001751E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -9.1580688620866835E-01,  -2.8398745322001751E-01,   2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -9.1580688620866835E-01,   2.8398745322001751E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [   9.1580688620866835E-01,  -2.8398745322001751E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [  -9.1580688620866835E-01,  -2.8398745322001751E-01,  -2.8398745322001751E-01,   1.0432030319160769E-02],
            [   3.4911776009637641E-01,   3.4911776009637641E-01,   8.6961691518195405E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,   3.4911776009637641E-01,   8.6961691518195405E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,  -3.4911776009637641E-01,   8.6961691518195405E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,   3.4911776009637641E-01,  -8.6961691518195405E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,  -3.4911776009637641E-01,   8.6961691518195405E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,   3.4911776009637641E-01,  -8.6961691518195405E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,  -3.4911776009637641E-01,  -8.6961691518195405E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,  -3.4911776009637641E-01,  -8.6961691518195405E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,   8.6961691518195405E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,  -8.6961691518195405E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,   8.6961691518195405E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,  -8.6961691518195405E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,   8.6961691518195405E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,  -8.6961691518195405E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -3.4911776009637641E-01,  -8.6961691518195405E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [   3.4911776009637641E-01,   8.6961691518195405E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [   8.6961691518195405E-01,   3.4911776009637641E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -8.6961691518195405E-01,   3.4911776009637641E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [   8.6961691518195405E-01,  -3.4911776009637641E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [   8.6961691518195405E-01,   3.4911776009637641E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -8.6961691518195405E-01,  -3.4911776009637641E-01,   3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -8.6961691518195405E-01,   3.4911776009637641E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [   8.6961691518195405E-01,  -3.4911776009637641E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [  -8.6961691518195405E-01,  -3.4911776009637641E-01,  -3.4911776009637641E-01,   1.0916019799855001E-02],
            [   4.1214314614443093E-01,   4.1214314614443093E-01,   8.1257372229991565E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,   4.1214314614443093E-01,   8.1257372229991565E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,  -4.1214314614443093E-01,   8.1257372229991565E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,   4.1214314614443093E-01,  -8.1257372229991565E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,  -4.1214314614443093E-01,   8.1257372229991565E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,   4.1214314614443093E-01,  -8.1257372229991565E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,  -4.1214314614443093E-01,  -8.1257372229991565E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,  -4.1214314614443093E-01,  -8.1257372229991565E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,   8.1257372229991565E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,  -8.1257372229991565E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,   8.1257372229991565E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,  -8.1257372229991565E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,   8.1257372229991565E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,  -8.1257372229991565E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -4.1214314614443093E-01,  -8.1257372229991565E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [   4.1214314614443093E-01,   8.1257372229991565E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [   8.1257372229991565E-01,   4.1214314614443093E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -8.1257372229991565E-01,   4.1214314614443093E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [   8.1257372229991565E-01,  -4.1214314614443093E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [   8.1257372229991565E-01,   4.1214314614443093E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -8.1257372229991565E-01,  -4.1214314614443093E-01,   4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -8.1257372229991565E-01,   4.1214314614443093E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [   8.1257372229991565E-01,  -4.1214314614443093E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [  -8.1257372229991565E-01,  -4.1214314614443093E-01,  -4.1214314614443093E-01,   1.1218094911060898E-02],
            [   4.7189936271491267E-01,   4.7189936271491267E-01,   7.4472946963210651E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,   4.7189936271491267E-01,   7.4472946963210651E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,  -4.7189936271491267E-01,   7.4472946963210651E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,   4.7189936271491267E-01,  -7.4472946963210651E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,  -4.7189936271491267E-01,   7.4472946963210651E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,   4.7189936271491267E-01,  -7.4472946963210651E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,  -4.7189936271491267E-01,  -7.4472946963210651E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,  -4.7189936271491267E-01,  -7.4472946963210651E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,   7.4472946963210651E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,  -7.4472946963210651E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,   7.4472946963210651E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,  -7.4472946963210651E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,   7.4472946963210651E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,  -7.4472946963210651E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -4.7189936271491267E-01,  -7.4472946963210651E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [   4.7189936271491267E-01,   7.4472946963210651E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [   7.4472946963210651E-01,   4.7189936271491267E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -7.4472946963210651E-01,   4.7189936271491267E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [   7.4472946963210651E-01,  -4.7189936271491267E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [   7.4472946963210651E-01,   4.7189936271491267E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -7.4472946963210651E-01,  -4.7189936271491267E-01,   4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -7.4472946963210651E-01,   4.7189936271491267E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [   7.4472946963210651E-01,  -4.7189936271491267E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [  -7.4472946963210651E-01,  -4.7189936271491267E-01,  -4.7189936271491267E-01,   1.1386162518793453E-02],
            [   5.2731454528423372E-01,   5.2731454528423372E-01,   6.6624225373610435E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,   5.2731454528423372E-01,   6.6624225373610435E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,  -5.2731454528423372E-01,   6.6624225373610435E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,   5.2731454528423372E-01,  -6.6624225373610435E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,  -5.2731454528423372E-01,   6.6624225373610435E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,   5.2731454528423372E-01,  -6.6624225373610435E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,  -5.2731454528423372E-01,  -6.6624225373610435E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,  -5.2731454528423372E-01,  -6.6624225373610435E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,   6.6624225373610435E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,  -6.6624225373610435E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,   6.6624225373610435E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,  -6.6624225373610435E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,   6.6624225373610435E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,  -6.6624225373610435E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -5.2731454528423372E-01,  -6.6624225373610435E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [   5.2731454528423372E-01,   6.6624225373610435E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [   6.6624225373610435E-01,   5.2731454528423372E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -6.6624225373610435E-01,   5.2731454528423372E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [   6.6624225373610435E-01,  -5.2731454528423372E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [   6.6624225373610435E-01,   5.2731454528423372E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -6.6624225373610435E-01,  -5.2731454528423372E-01,   5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -6.6624225373610435E-01,   5.2731454528423372E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [   6.6624225373610435E-01,  -5.2731454528423372E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [  -6.6624225373610435E-01,  -5.2731454528423372E-01,  -5.2731454528423372E-01,   1.1460250090599007E-02],
            [   6.2094753324440188E-01,   6.2094753324440188E-01,   4.7838093807695226E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,   6.2094753324440188E-01,   4.7838093807695226E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,  -6.2094753324440188E-01,   4.7838093807695226E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,   6.2094753324440188E-01,  -4.7838093807695226E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,  -6.2094753324440188E-01,   4.7838093807695226E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,   6.2094753324440188E-01,  -4.7838093807695226E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,  -6.2094753324440188E-01,  -4.7838093807695226E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,  -6.2094753324440188E-01,  -4.7838093807695226E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,   4.7838093807695226E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,  -4.7838093807695226E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,   4.7838093807695226E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,  -4.7838093807695226E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,   4.7838093807695226E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,  -4.7838093807695226E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -6.2094753324440188E-01,  -4.7838093807695226E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [   6.2094753324440188E-01,   4.7838093807695226E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [   4.7838093807695226E-01,   6.2094753324440188E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -4.7838093807695226E-01,   6.2094753324440188E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [   4.7838093807695226E-01,  -6.2094753324440188E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [   4.7838093807695226E-01,   6.2094753324440188E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -4.7838093807695226E-01,  -6.2094753324440188E-01,   6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -4.7838093807695226E-01,   6.2094753324440188E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [   4.7838093807695226E-01,  -6.2094753324440188E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [  -4.7838093807695226E-01,  -6.2094753324440188E-01,  -6.2094753324440188E-01,   1.1471488049646438E-02],
            [   6.5697227118572910E-01,   6.5697227118572910E-01,   3.6983086645942581E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,   6.5697227118572910E-01,   3.6983086645942581E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,  -6.5697227118572910E-01,   3.6983086645942581E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,   6.5697227118572910E-01,  -3.6983086645942581E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,  -6.5697227118572910E-01,   3.6983086645942581E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,   6.5697227118572910E-01,  -3.6983086645942581E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,  -6.5697227118572910E-01,  -3.6983086645942581E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,  -6.5697227118572910E-01,  -3.6983086645942581E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,   3.6983086645942581E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,  -3.6983086645942581E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,   3.6983086645942581E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,  -3.6983086645942581E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,   3.6983086645942581E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,  -3.6983086645942581E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -6.5697227118572910E-01,  -3.6983086645942581E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [   6.5697227118572910E-01,   3.6983086645942581E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [   3.6983086645942581E-01,   6.5697227118572910E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -3.6983086645942581E-01,   6.5697227118572910E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [   3.6983086645942581E-01,  -6.5697227118572910E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [   3.6983086645942581E-01,   6.5697227118572910E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -3.6983086645942581E-01,  -6.5697227118572910E-01,   6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -3.6983086645942581E-01,   6.5697227118572910E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [   3.6983086645942581E-01,  -6.5697227118572910E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [  -3.6983086645942581E-01,  -6.5697227118572910E-01,  -6.5697227118572910E-01,   1.1473994785596702E-02],
            [   6.8417883090701426E-01,   6.8417883090701426E-01,   2.5258395570071829E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,   6.8417883090701426E-01,   2.5258395570071829E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,  -6.8417883090701426E-01,   2.5258395570071829E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,   6.8417883090701426E-01,  -2.5258395570071829E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,  -6.8417883090701426E-01,   2.5258395570071829E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,   6.8417883090701426E-01,  -2.5258395570071829E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,  -6.8417883090701426E-01,  -2.5258395570071829E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,  -6.8417883090701426E-01,  -2.5258395570071829E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,   2.5258395570071829E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,  -2.5258395570071829E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,   2.5258395570071829E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,  -2.5258395570071829E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,   2.5258395570071829E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,  -2.5258395570071829E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -6.8417883090701426E-01,  -2.5258395570071829E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [   6.8417883090701426E-01,   2.5258395570071829E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [   2.5258395570071829E-01,   6.8417883090701426E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -2.5258395570071829E-01,   6.8417883090701426E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [   2.5258395570071829E-01,  -6.8417883090701426E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [   2.5258395570071829E-01,   6.8417883090701426E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -2.5258395570071829E-01,  -6.8417883090701426E-01,   6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -2.5258395570071829E-01,   6.8417883090701426E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [   2.5258395570071829E-01,  -6.8417883090701426E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [  -2.5258395570071829E-01,  -6.8417883090701426E-01,  -6.8417883090701426E-01,   1.1501840416315927E-02],
            [   7.0126043301236307E-01,   7.0126043301236307E-01,   1.2832618665972312E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,   7.0126043301236307E-01,   1.2832618665972312E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,  -7.0126043301236307E-01,   1.2832618665972312E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,   7.0126043301236307E-01,  -1.2832618665972312E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,  -7.0126043301236307E-01,   1.2832618665972312E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,   7.0126043301236307E-01,  -1.2832618665972312E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,  -7.0126043301236307E-01,  -1.2832618665972312E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,  -7.0126043301236307E-01,  -1.2832618665972312E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,   1.2832618665972312E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,  -1.2832618665972312E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,   1.2832618665972312E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,  -1.2832618665972312E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,   1.2832618665972312E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,  -1.2832618665972312E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -7.0126043301236307E-01,  -1.2832618665972312E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [   7.0126043301236307E-01,   1.2832618665972312E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [   1.2832618665972312E-01,   7.0126043301236307E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -1.2832618665972312E-01,   7.0126043301236307E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [   1.2832618665972312E-01,  -7.0126043301236307E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [   1.2832618665972312E-01,   7.0126043301236307E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -1.2832618665972312E-01,  -7.0126043301236307E-01,   7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -1.2832618665972312E-01,   7.0126043301236307E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [   1.2832618665972312E-01,  -7.0126043301236307E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [  -1.2832618665972312E-01,  -7.0126043301236307E-01,  -7.0126043301236307E-01,   1.1545272921893316E-02],
            [   1.0723822154781661E-01,   9.9423335482132236E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [  -1.0723822154781661E-01,   9.9423335482132236E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [   1.0723822154781661E-01,  -9.9423335482132236E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [  -1.0723822154781661E-01,  -9.9423335482132236E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [   9.9423335482132236E-01,   1.0723822154781661E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [  -9.9423335482132236E-01,   1.0723822154781661E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [   9.9423335482132236E-01,  -1.0723822154781661E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [  -9.9423335482132236E-01,  -1.0723822154781661E-01,   0.0000000000000000E+00,   6.5055815576856206E-03],
            [   1.0723822154781661E-01,   0.0000000000000000E+00,   9.9423335482132236E-01,   6.5055815576856206E-03],
            [  -1.0723822154781661E-01,   0.0000000000000000E+00,   9.9423335482132236E-01,   6.5055815576856206E-03],
            [   1.0723822154781661E-01,   0.0000000000000000E+00,  -9.9423335482132236E-01,   6.5055815576856206E-03],
            [  -1.0723822154781661E-01,   0.0000000000000000E+00,  -9.9423335482132236E-01,   6.5055815576856206E-03],
            [   9.9423335482132236E-01,   0.0000000000000000E+00,   1.0723822154781661E-01,   6.5055815576856206E-03],
            [  -9.9423335482132236E-01,   0.0000000000000000E+00,   1.0723822154781661E-01,   6.5055815576856206E-03],
            [   9.9423335482132236E-01,   0.0000000000000000E+00,  -1.0723822154781661E-01,   6.5055815576856206E-03],
            [  -9.9423335482132236E-01,   0.0000000000000000E+00,  -1.0723822154781661E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,   1.0723822154781661E-01,   9.9423335482132236E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,  -1.0723822154781661E-01,   9.9423335482132236E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,   1.0723822154781661E-01,  -9.9423335482132236E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,  -1.0723822154781661E-01,  -9.9423335482132236E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,   9.9423335482132236E-01,   1.0723822154781661E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,  -9.9423335482132236E-01,   1.0723822154781661E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,   9.9423335482132236E-01,  -1.0723822154781661E-01,   6.5055815576856206E-03],
            [   0.0000000000000000E+00,  -9.9423335482132236E-01,  -1.0723822154781661E-01,   6.5055815576856206E-03],
            [   2.5820689594969681E-01,   9.6608964329611902E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [  -2.5820689594969681E-01,   9.6608964329611902E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [   2.5820689594969681E-01,  -9.6608964329611902E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [  -2.5820689594969681E-01,  -9.6608964329611902E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [   9.6608964329611902E-01,   2.5820689594969681E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [  -9.6608964329611902E-01,   2.5820689594969681E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [   9.6608964329611902E-01,  -2.5820689594969681E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [  -9.6608964329611902E-01,  -2.5820689594969681E-01,   0.0000000000000000E+00,   9.2125868536404153E-03],
            [   2.5820689594969681E-01,   0.0000000000000000E+00,   9.6608964329611902E-01,   9.2125868536404153E-03],
            [  -2.5820689594969681E-01,   0.0000000000000000E+00,   9.6608964329611902E-01,   9.2125868536404153E-03],
            [   2.5820689594969681E-01,   0.0000000000000000E+00,  -9.6608964329611902E-01,   9.2125868536404153E-03],
            [  -2.5820689594969681E-01,   0.0000000000000000E+00,  -9.6608964329611902E-01,   9.2125868536404153E-03],
            [   9.6608964329611902E-01,   0.0000000000000000E+00,   2.5820689594969681E-01,   9.2125868536404153E-03],
            [  -9.6608964329611902E-01,   0.0000000000000000E+00,   2.5820689594969681E-01,   9.2125868536404153E-03],
            [   9.6608964329611902E-01,   0.0000000000000000E+00,  -2.5820689594969681E-01,   9.2125868536404153E-03],
            [  -9.6608964329611902E-01,   0.0000000000000000E+00,  -2.5820689594969681E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,   2.5820689594969681E-01,   9.6608964329611902E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,  -2.5820689594969681E-01,   9.6608964329611902E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,   2.5820689594969681E-01,  -9.6608964329611902E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,  -2.5820689594969681E-01,  -9.6608964329611902E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,   9.6608964329611902E-01,   2.5820689594969681E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,  -9.6608964329611902E-01,   2.5820689594969681E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,   9.6608964329611902E-01,  -2.5820689594969681E-01,   9.2125868536404153E-03],
            [   0.0000000000000000E+00,  -9.6608964329611902E-01,  -2.5820689594969681E-01,   9.2125868536404153E-03],
            [   4.1727529553067172E-01,   9.0878013168191052E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [  -4.1727529553067172E-01,   9.0878013168191052E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [   4.1727529553067172E-01,  -9.0878013168191052E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [  -4.1727529553067172E-01,  -9.0878013168191052E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [   9.0878013168191052E-01,   4.1727529553067172E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [  -9.0878013168191052E-01,   4.1727529553067172E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [   9.0878013168191052E-01,  -4.1727529553067172E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [  -9.0878013168191052E-01,  -4.1727529553067172E-01,   0.0000000000000000E+00,   1.0635212041756437E-02],
            [   4.1727529553067172E-01,   0.0000000000000000E+00,   9.0878013168191052E-01,   1.0635212041756437E-02],
            [  -4.1727529553067172E-01,   0.0000000000000000E+00,   9.0878013168191052E-01,   1.0635212041756437E-02],
            [   4.1727529553067172E-01,   0.0000000000000000E+00,  -9.0878013168191052E-01,   1.0635212041756437E-02],
            [  -4.1727529553067172E-01,   0.0000000000000000E+00,  -9.0878013168191052E-01,   1.0635212041756437E-02],
            [   9.0878013168191052E-01,   0.0000000000000000E+00,   4.1727529553067172E-01,   1.0635212041756437E-02],
            [  -9.0878013168191052E-01,   0.0000000000000000E+00,   4.1727529553067172E-01,   1.0635212041756437E-02],
            [   9.0878013168191052E-01,   0.0000000000000000E+00,  -4.1727529553067172E-01,   1.0635212041756437E-02],
            [  -9.0878013168191052E-01,   0.0000000000000000E+00,  -4.1727529553067172E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,   4.1727529553067172E-01,   9.0878013168191052E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,  -4.1727529553067172E-01,   9.0878013168191052E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,   4.1727529553067172E-01,  -9.0878013168191052E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,  -4.1727529553067172E-01,  -9.0878013168191052E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,   9.0878013168191052E-01,   4.1727529553067172E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,  -9.0878013168191052E-01,   4.1727529553067172E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,   9.0878013168191052E-01,  -4.1727529553067172E-01,   1.0635212041756437E-02],
            [   0.0000000000000000E+00,  -9.0878013168191052E-01,  -4.1727529553067172E-01,   1.0635212041756437E-02],
            [   5.7003669117925027E-01,   8.2161923706143347E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [  -5.7003669117925027E-01,   8.2161923706143347E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [   5.7003669117925027E-01,  -8.2161923706143347E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [  -5.7003669117925027E-01,  -8.2161923706143347E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [   8.2161923706143347E-01,   5.7003669117925027E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [  -8.2161923706143347E-01,   5.7003669117925027E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [   8.2161923706143347E-01,  -5.7003669117925027E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [  -8.2161923706143347E-01,  -5.7003669117925027E-01,   0.0000000000000000E+00,   1.1348843483974559E-02],
            [   5.7003669117925027E-01,   0.0000000000000000E+00,   8.2161923706143347E-01,   1.1348843483974559E-02],
            [  -5.7003669117925027E-01,   0.0000000000000000E+00,   8.2161923706143347E-01,   1.1348843483974559E-02],
            [   5.7003669117925027E-01,   0.0000000000000000E+00,  -8.2161923706143347E-01,   1.1348843483974559E-02],
            [  -5.7003669117925027E-01,   0.0000000000000000E+00,  -8.2161923706143347E-01,   1.1348843483974559E-02],
            [   8.2161923706143347E-01,   0.0000000000000000E+00,   5.7003669117925027E-01,   1.1348843483974559E-02],
            [  -8.2161923706143347E-01,   0.0000000000000000E+00,   5.7003669117925027E-01,   1.1348843483974559E-02],
            [   8.2161923706143347E-01,   0.0000000000000000E+00,  -5.7003669117925027E-01,   1.1348843483974559E-02],
            [  -8.2161923706143347E-01,   0.0000000000000000E+00,  -5.7003669117925027E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,   5.7003669117925027E-01,   8.2161923706143347E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,  -5.7003669117925027E-01,   8.2161923706143347E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,   5.7003669117925027E-01,  -8.2161923706143347E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,  -5.7003669117925027E-01,  -8.2161923706143347E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,   8.2161923706143347E-01,   5.7003669117925027E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,  -8.2161923706143347E-01,   5.7003669117925027E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,   8.2161923706143347E-01,  -5.7003669117925027E-01,   1.1348843483974559E-02],
            [   0.0000000000000000E+00,  -8.2161923706143347E-01,  -5.7003669117925027E-01,   1.1348843483974559E-02],
            [   9.8279860182639467E-01,   1.7717740226153250E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,   1.7717740226153250E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,  -1.7717740226153250E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,   1.7717740226153250E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,  -1.7717740226153250E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,  -1.7717740226153250E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,   1.7717740226153250E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,  -1.7717740226153250E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,   9.8279860182639467E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,   9.8279860182639467E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,  -9.8279860182639467E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,   9.8279860182639467E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,  -9.8279860182639467E-01,   5.2106394770112544E-02,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,  -9.8279860182639467E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,   9.8279860182639467E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,  -9.8279860182639467E-01,  -5.2106394770112544E-02,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,   9.8279860182639467E-01,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,   9.8279860182639467E-01,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,  -9.8279860182639467E-01,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,   9.8279860182639467E-01,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,  -9.8279860182639467E-01,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,  -9.8279860182639467E-01,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,   9.8279860182639467E-01,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,  -9.8279860182639467E-01,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,   1.7717740226153250E-01,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,   1.7717740226153250E-01,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,  -1.7717740226153250E-01,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,   1.7717740226153250E-01,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,  -1.7717740226153250E-01,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   5.2106394770112544E-02,  -1.7717740226153250E-01,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,   1.7717740226153250E-01,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -5.2106394770112544E-02,  -1.7717740226153250E-01,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,   5.2106394770112544E-02,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,   5.2106394770112544E-02,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,  -5.2106394770112544E-02,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,   5.2106394770112544E-02,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,  -5.2106394770112544E-02,   1.7717740226153250E-01,   8.1502695765074649E-03],
            [   9.8279860182639467E-01,  -5.2106394770112544E-02,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,   5.2106394770112544E-02,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [  -9.8279860182639467E-01,  -5.2106394770112544E-02,  -1.7717740226153250E-01,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,   5.2106394770112544E-02,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,   5.2106394770112544E-02,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,  -5.2106394770112544E-02,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,   5.2106394770112544E-02,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,  -5.2106394770112544E-02,   9.8279860182639467E-01,   8.1502695765074649E-03],
            [   1.7717740226153250E-01,  -5.2106394770112544E-02,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,   5.2106394770112544E-02,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [  -1.7717740226153250E-01,  -5.2106394770112544E-02,  -9.8279860182639467E-01,   8.1502695765074649E-03],
            [   9.6242492303262284E-01,   2.4757164634262879E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,   2.4757164634262879E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,  -2.4757164634262879E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,   2.4757164634262879E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,  -2.4757164634262879E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,  -2.4757164634262879E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,   2.4757164634262879E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,  -2.4757164634262879E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,   9.6242492303262284E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,   9.6242492303262284E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,  -9.6242492303262284E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,   9.6242492303262284E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,  -9.6242492303262284E-01,   1.1156409571564851E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,  -9.6242492303262284E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,   9.6242492303262284E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,  -9.6242492303262284E-01,  -1.1156409571564851E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,   9.6242492303262284E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,   9.6242492303262284E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,  -9.6242492303262284E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,   9.6242492303262284E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,  -9.6242492303262284E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,  -9.6242492303262284E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,   9.6242492303262284E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,  -9.6242492303262284E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,   2.4757164634262879E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,   2.4757164634262879E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,  -2.4757164634262879E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,   2.4757164634262879E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,  -2.4757164634262879E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   1.1156409571564851E-01,  -2.4757164634262879E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,   2.4757164634262879E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -1.1156409571564851E-01,  -2.4757164634262879E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,   1.1156409571564851E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,   1.1156409571564851E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,  -1.1156409571564851E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,   1.1156409571564851E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,  -1.1156409571564851E-01,   2.4757164634262879E-01,   9.3431353956620940E-03],
            [   9.6242492303262284E-01,  -1.1156409571564851E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,   1.1156409571564851E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [  -9.6242492303262284E-01,  -1.1156409571564851E-01,  -2.4757164634262879E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,   1.1156409571564851E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,   1.1156409571564851E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,  -1.1156409571564851E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,   1.1156409571564851E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,  -1.1156409571564851E-01,   9.6242492303262284E-01,   9.3431353956620940E-03],
            [   2.4757164634262879E-01,  -1.1156409571564851E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,   1.1156409571564851E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [  -2.4757164634262879E-01,  -1.1156409571564851E-01,  -9.6242492303262284E-01,   9.3431353956620940E-03],
            [   9.4020079941288115E-01,   3.3546162890664888E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,   3.3546162890664888E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,  -3.3546162890664888E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,   3.3546162890664888E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,  -3.3546162890664888E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,  -3.3546162890664888E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,   3.3546162890664888E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,  -3.3546162890664888E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,   9.4020079941288115E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,   9.4020079941288115E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,  -9.4020079941288115E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,   9.4020079941288115E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,  -9.4020079941288115E-01,   5.9058888532353720E-02,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,  -9.4020079941288115E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,   9.4020079941288115E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,  -9.4020079941288115E-01,  -5.9058888532353720E-02,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,   9.4020079941288115E-01,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,   9.4020079941288115E-01,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,  -9.4020079941288115E-01,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,   9.4020079941288115E-01,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,  -9.4020079941288115E-01,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,  -9.4020079941288115E-01,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,   9.4020079941288115E-01,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,  -9.4020079941288115E-01,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,   3.3546162890664888E-01,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,   3.3546162890664888E-01,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,  -3.3546162890664888E-01,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,   3.3546162890664888E-01,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,  -3.3546162890664888E-01,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   5.9058888532353720E-02,  -3.3546162890664888E-01,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,   3.3546162890664888E-01,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -5.9058888532353720E-02,  -3.3546162890664888E-01,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,   5.9058888532353720E-02,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,   5.9058888532353720E-02,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,  -5.9058888532353720E-02,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,   5.9058888532353720E-02,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,  -5.9058888532353720E-02,   3.3546162890664888E-01,   1.0051246585813850E-02],
            [   9.4020079941288115E-01,  -5.9058888532353720E-02,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,   5.9058888532353720E-02,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [  -9.4020079941288115E-01,  -5.9058888532353720E-02,  -3.3546162890664888E-01,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,   5.9058888532353720E-02,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,   5.9058888532353720E-02,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,  -5.9058888532353720E-02,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,   5.9058888532353720E-02,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,  -5.9058888532353720E-02,   9.4020079941288115E-01,   1.0051246585813850E-02],
            [   3.3546162890664888E-01,  -5.9058888532353720E-02,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,   5.9058888532353720E-02,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [  -3.3546162890664888E-01,  -5.9058888532353720E-02,  -9.4020079941288115E-01,   1.0051246585813850E-02],
            [   9.3208220401432018E-01,   3.1736152466119771E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,   3.1736152466119771E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,  -3.1736152466119771E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,   3.1736152466119771E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,  -3.1736152466119771E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,  -3.1736152466119771E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,   3.1736152466119771E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,  -3.1736152466119771E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,   9.3208220401432018E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,   9.3208220401432018E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,  -9.3208220401432018E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,   9.3208220401432018E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,  -9.3208220401432018E-01,   1.7465516775786288E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,  -9.3208220401432018E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,   9.3208220401432018E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,  -9.3208220401432018E-01,  -1.7465516775786288E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,   9.3208220401432018E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,   9.3208220401432018E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,  -9.3208220401432018E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,   9.3208220401432018E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,  -9.3208220401432018E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,  -9.3208220401432018E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,   9.3208220401432018E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,  -9.3208220401432018E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,   3.1736152466119771E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,   3.1736152466119771E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,  -3.1736152466119771E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,   3.1736152466119771E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,  -3.1736152466119771E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   1.7465516775786288E-01,  -3.1736152466119771E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,   3.1736152466119771E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -1.7465516775786288E-01,  -3.1736152466119771E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,   1.7465516775786288E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,   1.7465516775786288E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,  -1.7465516775786288E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,   1.7465516775786288E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,  -1.7465516775786288E-01,   3.1736152466119771E-01,   1.0180936061521024E-02],
            [   9.3208220401432018E-01,  -1.7465516775786288E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,   1.7465516775786288E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [  -9.3208220401432018E-01,  -1.7465516775786288E-01,  -3.1736152466119771E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,   1.7465516775786288E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,   1.7465516775786288E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,  -1.7465516775786288E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,   1.7465516775786288E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,  -1.7465516775786288E-01,   9.3208220401432018E-01,   1.0180936061521024E-02],
            [   3.1736152466119771E-01,  -1.7465516775786288E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,   1.7465516775786288E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [  -3.1736152466119771E-01,  -1.7465516775786288E-01,  -9.3208220401432018E-01,   1.0180936061521024E-02],
            [   9.0436741993932990E-01,   4.0902684270853568E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,   4.0902684270853568E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,  -4.0902684270853568E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,   4.0902684270853568E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,  -4.0902684270853568E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,  -4.0902684270853568E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,   4.0902684270853568E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,  -4.0902684270853568E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,   9.0436741993932990E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,   9.0436741993932990E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,  -9.0436741993932990E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,   9.0436741993932990E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,  -9.0436741993932990E-01,   1.2172350510959890E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,  -9.0436741993932990E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,   9.0436741993932990E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,  -9.0436741993932990E-01,  -1.2172350510959890E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,   9.0436741993932990E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,   9.0436741993932990E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,  -9.0436741993932990E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,   9.0436741993932990E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,  -9.0436741993932990E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,  -9.0436741993932990E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,   9.0436741993932990E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,  -9.0436741993932990E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,   4.0902684270853568E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,   4.0902684270853568E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,  -4.0902684270853568E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,   4.0902684270853568E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,  -4.0902684270853568E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   1.2172350510959890E-01,  -4.0902684270853568E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,   4.0902684270853568E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -1.2172350510959890E-01,  -4.0902684270853568E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,   1.2172350510959890E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,   1.2172350510959890E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,  -1.2172350510959890E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,   1.2172350510959890E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,  -1.2172350510959890E-01,   4.0902684270853568E-01,   1.0660541746034315E-02],
            [   9.0436741993932990E-01,  -1.2172350510959890E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,   1.2172350510959890E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [  -9.0436741993932990E-01,  -1.2172350510959890E-01,  -4.0902684270853568E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,   1.2172350510959890E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,   1.2172350510959890E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,  -1.2172350510959890E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,   1.2172350510959890E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,  -1.2172350510959890E-01,   9.0436741993932990E-01,   1.0660541746034315E-02],
            [   4.0902684270853568E-01,  -1.2172350510959890E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,   1.2172350510959890E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [  -4.0902684270853568E-01,  -1.2172350510959890E-01,  -9.0436741993932990E-01,   1.0660541746034315E-02],
            [   8.9124075600747465E-01,   3.8542911506692240E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,   3.8542911506692240E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,  -3.8542911506692240E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,   3.8542911506692240E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,  -3.8542911506692240E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,  -3.8542911506692240E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,   3.8542911506692240E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,  -3.8542911506692240E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,   8.9124075600747465E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,   8.9124075600747465E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,  -8.9124075600747465E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,   8.9124075600747465E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,  -8.9124075600747465E-01,   2.3902784793817244E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,  -8.9124075600747465E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,   8.9124075600747465E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,  -8.9124075600747465E-01,  -2.3902784793817244E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,   8.9124075600747465E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,   8.9124075600747465E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,  -8.9124075600747465E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,   8.9124075600747465E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,  -8.9124075600747465E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,  -8.9124075600747465E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,   8.9124075600747465E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,  -8.9124075600747465E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,   3.8542911506692240E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,   3.8542911506692240E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,  -3.8542911506692240E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,   3.8542911506692240E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,  -3.8542911506692240E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   2.3902784793817244E-01,  -3.8542911506692240E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,   3.8542911506692240E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -2.3902784793817244E-01,  -3.8542911506692240E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,   2.3902784793817244E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,   2.3902784793817244E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,  -2.3902784793817244E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,   2.3902784793817244E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,  -2.3902784793817244E-01,   3.8542911506692240E-01,   1.0752162755474637E-02],
            [   8.9124075600747465E-01,  -2.3902784793817244E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,   2.3902784793817244E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [  -8.9124075600747465E-01,  -2.3902784793817244E-01,  -3.8542911506692240E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,   2.3902784793817244E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,   2.3902784793817244E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,  -2.3902784793817244E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,   2.3902784793817244E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,  -2.3902784793817244E-01,   8.9124075600747465E-01,   1.0752162755474637E-02],
            [   3.8542911506692240E-01,  -2.3902784793817244E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,   2.3902784793817244E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [  -3.8542911506692240E-01,  -2.3902784793817244E-01,  -8.9124075600747465E-01,   1.0752162755474637E-02],
            [   8.6764356284627075E-01,   4.9322211848512848E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,   4.9322211848512848E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,  -4.9322211848512848E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,   4.9322211848512848E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,  -4.9322211848512848E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,  -4.9322211848512848E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,   4.9322211848512848E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,  -4.9322211848512848E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,   8.6764356284627075E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,   8.6764356284627075E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,  -8.6764356284627075E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,   8.6764356284627075E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,  -8.6764356284627075E-01,   6.2662506241541988E-02,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,  -8.6764356284627075E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,   8.6764356284627075E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,  -8.6764356284627075E-01,  -6.2662506241541988E-02,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,   8.6764356284627075E-01,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,   8.6764356284627075E-01,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,  -8.6764356284627075E-01,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,   8.6764356284627075E-01,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,  -8.6764356284627075E-01,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,  -8.6764356284627075E-01,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,   8.6764356284627075E-01,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,  -8.6764356284627075E-01,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,   4.9322211848512848E-01,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,   4.9322211848512848E-01,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,  -4.9322211848512848E-01,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,   4.9322211848512848E-01,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,  -4.9322211848512848E-01,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   6.2662506241541988E-02,  -4.9322211848512848E-01,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,   4.9322211848512848E-01,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -6.2662506241541988E-02,  -4.9322211848512848E-01,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,   6.2662506241541988E-02,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,   6.2662506241541988E-02,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,  -6.2662506241541988E-02,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,   6.2662506241541988E-02,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,  -6.2662506241541988E-02,   4.9322211848512848E-01,   1.1062438286513447E-02],
            [   8.6764356284627075E-01,  -6.2662506241541988E-02,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,   6.2662506241541988E-02,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [  -8.6764356284627075E-01,  -6.2662506241541988E-02,  -4.9322211848512848E-01,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,   6.2662506241541988E-02,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,   6.2662506241541988E-02,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,  -6.2662506241541988E-02,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,   6.2662506241541988E-02,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,  -6.2662506241541988E-02,   8.6764356284627075E-01,   1.1062438286513447E-02],
            [   4.9322211848512848E-01,  -6.2662506241541988E-02,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,   6.2662506241541988E-02,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [  -4.9322211848512848E-01,  -6.2662506241541988E-02,  -8.6764356284627075E-01,   1.1062438286513447E-02],
            [   8.5819799860416190E-01,   4.7853206759224348E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,   4.7853206759224348E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,  -4.7853206759224348E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,   4.7853206759224348E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,  -4.7853206759224348E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,  -4.7853206759224348E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,   4.7853206759224348E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,  -4.7853206759224348E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,   8.5819799860416190E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,   8.5819799860416190E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,  -8.5819799860416190E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,   8.5819799860416190E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,  -8.5819799860416190E-01,   1.8575051945473373E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,  -8.5819799860416190E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,   8.5819799860416190E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,  -8.5819799860416190E-01,  -1.8575051945473373E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,   8.5819799860416190E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,   8.5819799860416190E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,  -8.5819799860416190E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,   8.5819799860416190E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,  -8.5819799860416190E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,  -8.5819799860416190E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,   8.5819799860416190E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,  -8.5819799860416190E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,   4.7853206759224348E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,   4.7853206759224348E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,  -4.7853206759224348E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,   4.7853206759224348E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,  -4.7853206759224348E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   1.8575051945473373E-01,  -4.7853206759224348E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,   4.7853206759224348E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -1.8575051945473373E-01,  -4.7853206759224348E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,   1.8575051945473373E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,   1.8575051945473373E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,  -1.8575051945473373E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,   1.8575051945473373E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,  -1.8575051945473373E-01,   4.7853206759224348E-01,   1.1072289696133737E-02],
            [   8.5819799860416190E-01,  -1.8575051945473373E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,   1.8575051945473373E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [  -8.5819799860416190E-01,  -1.8575051945473373E-01,  -4.7853206759224348E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,   1.8575051945473373E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,   1.8575051945473373E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,  -1.8575051945473373E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,   1.8575051945473373E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,  -1.8575051945473373E-01,   8.5819799860416190E-01,   1.1072289696133737E-02],
            [   4.7853206759224348E-01,  -1.8575051945473373E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,   1.8575051945473373E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [  -4.7853206759224348E-01,  -1.8575051945473373E-01,  -8.5819799860416190E-01,   1.1072289696133737E-02],
            [   8.3967536240498564E-01,   4.5074225931570638E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,   4.5074225931570638E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,  -4.5074225931570638E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,   4.5074225931570638E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,  -4.5074225931570638E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,  -4.5074225931570638E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,   4.5074225931570638E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,  -4.5074225931570638E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,   8.3967536240498564E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,   8.3967536240498564E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,  -8.3967536240498564E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,   8.3967536240498564E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,  -8.3967536240498564E-01,   3.0294669735289831E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,  -8.3967536240498564E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,   8.3967536240498564E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,  -8.3967536240498564E-01,  -3.0294669735289831E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,   8.3967536240498564E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,   8.3967536240498564E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,  -8.3967536240498564E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,   8.3967536240498564E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,  -8.3967536240498564E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,  -8.3967536240498564E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,   8.3967536240498564E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,  -8.3967536240498564E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,   4.5074225931570638E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,   4.5074225931570638E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,  -4.5074225931570638E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,   4.5074225931570638E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,  -4.5074225931570638E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   3.0294669735289831E-01,  -4.5074225931570638E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,   4.5074225931570638E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -3.0294669735289831E-01,  -4.5074225931570638E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,   3.0294669735289831E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,   3.0294669735289831E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,  -3.0294669735289831E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,   3.0294669735289831E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,  -3.0294669735289831E-01,   4.5074225931570638E-01,   1.1121592794205997E-02],
            [   8.3967536240498564E-01,  -3.0294669735289831E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,   3.0294669735289831E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [  -8.3967536240498564E-01,  -3.0294669735289831E-01,  -4.5074225931570638E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,   3.0294669735289831E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,   3.0294669735289831E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,  -3.0294669735289831E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,   3.0294669735289831E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,  -3.0294669735289831E-01,   8.3967536240498564E-01,   1.1121592794205997E-02],
            [   4.5074225931570638E-01,  -3.0294669735289831E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,   3.0294669735289831E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [  -4.5074225931570638E-01,  -3.0294669735289831E-01,  -8.3967536240498564E-01,   1.1121592794205997E-02],
            [   8.1652885640221884E-01,   5.6321230207620998E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,   5.6321230207620998E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,  -5.6321230207620998E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,   5.6321230207620998E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,  -5.6321230207620998E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,  -5.6321230207620998E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,   5.6321230207620998E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,  -5.6321230207620998E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,   8.1652885640221884E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,   8.1652885640221884E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,  -8.1652885640221884E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,   8.1652885640221884E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,  -8.1652885640221884E-01,   1.2677748006842818E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,  -8.1652885640221884E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,   8.1652885640221884E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,  -8.1652885640221884E-01,  -1.2677748006842818E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,   8.1652885640221884E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,   8.1652885640221884E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,  -8.1652885640221884E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,   8.1652885640221884E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,  -8.1652885640221884E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,  -8.1652885640221884E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,   8.1652885640221884E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,  -8.1652885640221884E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,   5.6321230207620998E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,   5.6321230207620998E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,  -5.6321230207620998E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,   5.6321230207620998E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,  -5.6321230207620998E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   1.2677748006842818E-01,  -5.6321230207620998E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,   5.6321230207620998E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -1.2677748006842818E-01,  -5.6321230207620998E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,   1.2677748006842818E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,   1.2677748006842818E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,  -1.2677748006842818E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,   1.2677748006842818E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,  -1.2677748006842818E-01,   5.6321230207620998E-01,   1.1336553076873987E-02],
            [   8.1652885640221884E-01,  -1.2677748006842818E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,   1.2677748006842818E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [  -8.1652885640221884E-01,  -1.2677748006842818E-01,  -5.6321230207620998E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,   1.2677748006842818E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,   1.2677748006842818E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,  -1.2677748006842818E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,   1.2677748006842818E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,  -1.2677748006842818E-01,   8.1652885640221884E-01,   1.1336553076873987E-02],
            [   5.6321230207620998E-01,  -1.2677748006842818E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,   1.2677748006842818E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [  -5.6321230207620998E-01,  -1.2677748006842818E-01,  -8.1652885640221884E-01,   1.1336553076873987E-02],
            [   8.0154693707835289E-01,   5.4343035696939002E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,   5.4343035696939002E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,  -5.4343035696939002E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,   5.4343035696939002E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,  -5.4343035696939002E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,  -5.4343035696939002E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,   5.4343035696939002E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,  -5.4343035696939002E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,   8.0154693707835289E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,   8.0154693707835289E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,  -8.0154693707835289E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,   8.0154693707835289E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,  -8.0154693707835289E-01,   2.4941121623622375E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,  -8.0154693707835289E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,   8.0154693707835289E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,  -8.0154693707835289E-01,  -2.4941121623622375E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,   8.0154693707835289E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,   8.0154693707835289E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,  -8.0154693707835289E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,   8.0154693707835289E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,  -8.0154693707835289E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,  -8.0154693707835289E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,   8.0154693707835289E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,  -8.0154693707835289E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,   5.4343035696939002E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,   5.4343035696939002E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,  -5.4343035696939002E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,   5.4343035696939002E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,  -5.4343035696939002E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   2.4941121623622375E-01,  -5.4343035696939002E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,   5.4343035696939002E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -2.4941121623622375E-01,  -5.4343035696939002E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,   2.4941121623622375E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,   2.4941121623622375E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,  -2.4941121623622375E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,   2.4941121623622375E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,  -2.4941121623622375E-01,   5.4343035696939002E-01,   1.1322415128385551E-02],
            [   8.0154693707835289E-01,  -2.4941121623622375E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,   2.4941121623622375E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [  -8.0154693707835289E-01,  -2.4941121623622375E-01,  -5.4343035696939002E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,   2.4941121623622375E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,   2.4941121623622375E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,  -2.4941121623622375E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,   2.4941121623622375E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,  -2.4941121623622375E-01,   8.0154693707835289E-01,   1.1322415128385551E-02],
            [   5.4343035696939002E-01,  -2.4941121623622375E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,   2.4941121623622375E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [  -5.4343035696939002E-01,  -2.4941121623622375E-01,  -8.0154693707835289E-01,   1.1322415128385551E-02],
            [   7.7735630690703506E-01,   5.1235184864198713E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,   5.1235184864198713E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,  -5.1235184864198713E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,   5.1235184864198713E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,  -5.1235184864198713E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,  -5.1235184864198713E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,   5.1235184864198713E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,  -5.1235184864198713E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,   7.7735630690703506E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,   7.7735630690703506E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,  -7.7735630690703506E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,   7.7735630690703506E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,  -7.7735630690703506E-01,   3.6498322605976541E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,  -7.7735630690703506E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,   7.7735630690703506E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,  -7.7735630690703506E-01,  -3.6498322605976541E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,   7.7735630690703506E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,   7.7735630690703506E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,  -7.7735630690703506E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,   7.7735630690703506E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,  -7.7735630690703506E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,  -7.7735630690703506E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,   7.7735630690703506E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,  -7.7735630690703506E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,   5.1235184864198713E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,   5.1235184864198713E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,  -5.1235184864198713E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,   5.1235184864198713E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,  -5.1235184864198713E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   3.6498322605976541E-01,  -5.1235184864198713E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,   5.1235184864198713E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -3.6498322605976541E-01,  -5.1235184864198713E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,   3.6498322605976541E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,   3.6498322605976541E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,  -3.6498322605976541E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,   3.6498322605976541E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,  -3.6498322605976541E-01,   5.1235184864198713E-01,   1.1338250340383400E-02],
            [   7.7735630690703506E-01,  -3.6498322605976541E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,   3.6498322605976541E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [  -7.7735630690703506E-01,  -3.6498322605976541E-01,  -5.1235184864198713E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,   3.6498322605976541E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,   3.6498322605976541E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,  -3.6498322605976541E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,   3.6498322605976541E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,  -3.6498322605976541E-01,   7.7735630690703506E-01,   1.1338250340383400E-02],
            [   5.1235184864198713E-01,  -3.6498322605976541E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,   3.6498322605976541E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [  -5.1235184864198713E-01,  -3.6498322605976541E-01,  -7.7735630690703506E-01,   1.1338250340383400E-02],
            [   7.6616212139003936E-01,   6.3942796347491015E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,   6.3942796347491015E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,  -6.3942796347491015E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,   6.3942796347491015E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,  -6.3942796347491015E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,  -6.3942796347491015E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,   6.3942796347491015E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,  -6.3942796347491015E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,   7.6616212139003936E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,   7.6616212139003936E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,  -7.6616212139003936E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,   7.6616212139003936E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,  -7.6616212139003936E-01,   6.4245492242207852E-02,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,  -7.6616212139003936E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,   7.6616212139003936E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,  -7.6616212139003936E-01,  -6.4245492242207852E-02,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,   7.6616212139003936E-01,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,   7.6616212139003936E-01,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,  -7.6616212139003936E-01,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,   7.6616212139003936E-01,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,  -7.6616212139003936E-01,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,  -7.6616212139003936E-01,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,   7.6616212139003936E-01,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,  -7.6616212139003936E-01,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,   6.3942796347491015E-01,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,   6.3942796347491015E-01,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,  -6.3942796347491015E-01,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,   6.3942796347491015E-01,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,  -6.3942796347491015E-01,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.4245492242207852E-02,  -6.3942796347491015E-01,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,   6.3942796347491015E-01,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.4245492242207852E-02,  -6.3942796347491015E-01,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,   6.4245492242207852E-02,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,   6.4245492242207852E-02,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,  -6.4245492242207852E-02,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,   6.4245492242207852E-02,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,  -6.4245492242207852E-02,   6.3942796347491015E-01,   1.1508302534349396E-02],
            [   7.6616212139003936E-01,  -6.4245492242207852E-02,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,   6.4245492242207852E-02,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [  -7.6616212139003936E-01,  -6.4245492242207852E-02,  -6.3942796347491015E-01,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,   6.4245492242207852E-02,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,   6.4245492242207852E-02,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,  -6.4245492242207852E-02,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,   6.4245492242207852E-02,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,  -6.4245492242207852E-02,   7.6616212139003936E-01,   1.1508302534349396E-02],
            [   6.3942796347491015E-01,  -6.4245492242207852E-02,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,   6.4245492242207852E-02,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [  -6.3942796347491015E-01,  -6.4245492242207852E-02,  -7.6616212139003936E-01,   1.1508302534349396E-02],
            [   7.5535841435335105E-01,   6.2698055090243920E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,   6.2698055090243920E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,  -6.2698055090243920E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,   6.2698055090243920E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,  -6.2698055090243920E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,  -6.2698055090243920E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,   6.2698055090243920E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,  -6.2698055090243920E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,   7.5535841435335105E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,   7.5535841435335105E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,  -7.5535841435335105E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,   7.5535841435335105E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,  -7.5535841435335105E-01,   1.9060182227792313E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,  -7.5535841435335105E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,   7.5535841435335105E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,  -7.5535841435335105E-01,  -1.9060182227792313E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,   7.5535841435335105E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,   7.5535841435335105E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,  -7.5535841435335105E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,   7.5535841435335105E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,  -7.5535841435335105E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,  -7.5535841435335105E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,   7.5535841435335105E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,  -7.5535841435335105E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,   6.2698055090243920E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,   6.2698055090243920E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,  -6.2698055090243920E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,   6.2698055090243920E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,  -6.2698055090243920E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   1.9060182227792313E-01,  -6.2698055090243920E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,   6.2698055090243920E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -1.9060182227792313E-01,  -6.2698055090243920E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,   1.9060182227792313E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,   1.9060182227792313E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,  -1.9060182227792313E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,   1.9060182227792313E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,  -1.9060182227792313E-01,   6.2698055090243920E-01,   1.1475079348200834E-02],
            [   7.5535841435335105E-01,  -1.9060182227792313E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,   1.9060182227792313E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [  -7.5535841435335105E-01,  -1.9060182227792313E-01,  -6.2698055090243920E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,   1.9060182227792313E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,   1.9060182227792313E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,  -1.9060182227792313E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,   1.9060182227792313E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,  -1.9060182227792313E-01,   7.5535841435335105E-01,   1.1475079348200834E-02],
            [   6.2698055090243920E-01,  -1.9060182227792313E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,   1.9060182227792313E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [  -6.2698055090243920E-01,  -1.9060182227792313E-01,  -7.5535841435335105E-01,   1.1475079348200834E-02],
            [   7.3443057575595028E-01,   6.0311616930963097E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,   6.0311616930963097E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,  -6.0311616930963097E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,   6.0311616930963097E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,  -6.0311616930963097E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,  -6.0311616930963097E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,   6.0311616930963097E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,  -6.0311616930963097E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,   7.3443057575595028E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,   7.3443057575595028E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,  -7.3443057575595028E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,   7.3443057575595028E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,  -7.3443057575595028E-01,   3.1122759471496081E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,  -7.3443057575595028E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,   7.3443057575595028E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,  -7.3443057575595028E-01,  -3.1122759471496081E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,   7.3443057575595028E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,   7.3443057575595028E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,  -7.3443057575595028E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,   7.3443057575595028E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,  -7.3443057575595028E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,  -7.3443057575595028E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,   7.3443057575595028E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,  -7.3443057575595028E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,   6.0311616930963097E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,   6.0311616930963097E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,  -6.0311616930963097E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,   6.0311616930963097E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,  -6.0311616930963097E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   3.1122759471496081E-01,  -6.0311616930963097E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,   6.0311616930963097E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -3.1122759471496081E-01,  -6.0311616930963097E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,   3.1122759471496081E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,   3.1122759471496081E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,  -3.1122759471496081E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,   3.1122759471496081E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,  -3.1122759471496081E-01,   6.0311616930963097E-01,   1.1445216092627289E-02],
            [   7.3443057575595028E-01,  -3.1122759471496081E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,   3.1122759471496081E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [  -7.3443057575595028E-01,  -3.1122759471496081E-01,  -6.0311616930963097E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,   3.1122759471496081E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,   3.1122759471496081E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,  -3.1122759471496081E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,   3.1122759471496081E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,  -3.1122759471496081E-01,   7.3443057575595028E-01,   1.1445216092627289E-02],
            [   6.0311616930963097E-01,  -3.1122759471496081E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,   3.1122759471496081E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [  -6.0311616930963097E-01,  -3.1122759471496081E-01,  -7.3443057575595028E-01,   1.1445216092627289E-02],
            [   7.0438371840217651E-01,   5.6937024984684415E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,   5.6937024984684415E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,  -5.6937024984684415E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,   5.6937024984684415E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,  -5.6937024984684415E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,  -5.6937024984684415E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,   5.6937024984684415E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,  -5.6937024984684415E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,   7.0438371840217651E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,   7.0438371840217651E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,  -7.0438371840217651E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,   7.0438371840217651E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,  -7.0438371840217651E-01,   4.2386447815223383E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,  -7.0438371840217651E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,   7.0438371840217651E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,  -7.0438371840217651E-01,  -4.2386447815223383E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,   7.0438371840217651E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,   7.0438371840217651E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,  -7.0438371840217651E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,   7.0438371840217651E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,  -7.0438371840217651E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,  -7.0438371840217651E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,   7.0438371840217651E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,  -7.0438371840217651E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,   5.6937024984684415E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,   5.6937024984684415E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,  -5.6937024984684415E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,   5.6937024984684415E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,  -5.6937024984684415E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   4.2386447815223383E-01,  -5.6937024984684415E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,   5.6937024984684415E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -4.2386447815223383E-01,  -5.6937024984684415E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,   4.2386447815223383E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,   4.2386447815223383E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,  -4.2386447815223383E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,   4.2386447815223383E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,  -4.2386447815223383E-01,   5.6937024984684415E-01,   1.1442635813972176E-02],
            [   7.0438371840217651E-01,  -4.2386447815223383E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,   4.2386447815223383E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [  -7.0438371840217651E-01,  -4.2386447815223383E-01,  -5.6937024984684415E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,   4.2386447815223383E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,   4.2386447815223383E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,  -4.2386447815223383E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,   4.2386447815223383E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,  -4.2386447815223383E-01,   7.0438371840217651E-01,   1.1442635813972176E-02],
            [   5.6937024984684415E-01,  -4.2386447815223383E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,   4.2386447815223383E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
            [  -5.6937024984684415E-01,  -4.2386447815223383E-01,  -7.0438371840217651E-01,   1.1442635813972176E-02],
        ])
  
        order = 59
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build1454():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   9.7730684227265879E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   9.7730684227265879E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   9.7730684227265879E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   9.7730684227265879E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   9.7730684227265879E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   9.7730684227265879E-04],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.4972185798099275E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   9.4972185798099275E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.4972185798099275E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4972185798099275E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   9.4972185798099275E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4972185798099275E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4972185798099275E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   9.4972185798099275E-03],
            [   3.2292906634138543E-02,   3.2292906634138543E-02,   9.9895662386423845E-01,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,   3.2292906634138543E-02,   9.9895662386423845E-01,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,  -3.2292906634138543E-02,   9.9895662386423845E-01,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,   3.2292906634138543E-02,  -9.9895662386423845E-01,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,  -3.2292906634138543E-02,   9.9895662386423845E-01,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,   3.2292906634138543E-02,  -9.9895662386423845E-01,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,  -3.2292906634138543E-02,  -9.9895662386423845E-01,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,  -3.2292906634138543E-02,  -9.9895662386423845E-01,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,   9.9895662386423845E-01,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,  -9.9895662386423845E-01,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,   9.9895662386423845E-01,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,  -9.9895662386423845E-01,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,   9.9895662386423845E-01,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,  -9.9895662386423845E-01,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -3.2292906634138543E-02,  -9.9895662386423845E-01,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [   3.2292906634138543E-02,   9.9895662386423845E-01,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [   9.9895662386423845E-01,   3.2292906634138543E-02,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -9.9895662386423845E-01,   3.2292906634138543E-02,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [   9.9895662386423845E-01,  -3.2292906634138543E-02,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [   9.9895662386423845E-01,   3.2292906634138543E-02,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -9.9895662386423845E-01,  -3.2292906634138543E-02,   3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -9.9895662386423845E-01,   3.2292906634138543E-02,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [   9.9895662386423845E-01,  -3.2292906634138543E-02,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [  -9.9895662386423845E-01,  -3.2292906634138543E-02,  -3.2292906634138543E-02,   3.5709023557626745E-03],
            [   8.0367332714622222E-02,   8.0367332714622222E-02,   9.9352009726259405E-01,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,   8.0367332714622222E-02,   9.9352009726259405E-01,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,  -8.0367332714622222E-02,   9.9352009726259405E-01,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,   8.0367332714622222E-02,  -9.9352009726259405E-01,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,  -8.0367332714622222E-02,   9.9352009726259405E-01,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,   8.0367332714622222E-02,  -9.9352009726259405E-01,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,  -8.0367332714622222E-02,  -9.9352009726259405E-01,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,  -8.0367332714622222E-02,  -9.9352009726259405E-01,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,   9.9352009726259405E-01,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,  -9.9352009726259405E-01,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,   9.9352009726259405E-01,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,  -9.9352009726259405E-01,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,   9.9352009726259405E-01,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,  -9.9352009726259405E-01,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -8.0367332714622222E-02,  -9.9352009726259405E-01,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [   8.0367332714622222E-02,   9.9352009726259405E-01,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [   9.9352009726259405E-01,   8.0367332714622222E-02,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -9.9352009726259405E-01,   8.0367332714622222E-02,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [   9.9352009726259405E-01,  -8.0367332714622222E-02,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [   9.9352009726259405E-01,   8.0367332714622222E-02,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -9.9352009726259405E-01,  -8.0367332714622222E-02,   8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -9.9352009726259405E-01,   8.0367332714622222E-02,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [   9.9352009726259405E-01,  -8.0367332714622222E-02,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [  -9.9352009726259405E-01,  -8.0367332714622222E-02,  -8.0367332714622222E-02,   5.4970571973096500E-03],
            [   1.3542899605316530E-01,   1.3542899605316530E-01,   9.8148763316511711E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,   1.3542899605316530E-01,   9.8148763316511711E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,  -1.3542899605316530E-01,   9.8148763316511711E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,   1.3542899605316530E-01,  -9.8148763316511711E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,  -1.3542899605316530E-01,   9.8148763316511711E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,   1.3542899605316530E-01,  -9.8148763316511711E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,  -1.3542899605316530E-01,  -9.8148763316511711E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,  -1.3542899605316530E-01,  -9.8148763316511711E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,   9.8148763316511711E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,  -9.8148763316511711E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,   9.8148763316511711E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,  -9.8148763316511711E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,   9.8148763316511711E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,  -9.8148763316511711E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -1.3542899605316530E-01,  -9.8148763316511711E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [   1.3542899605316530E-01,   9.8148763316511711E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [   9.8148763316511711E-01,   1.3542899605316530E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -9.8148763316511711E-01,   1.3542899605316530E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [   9.8148763316511711E-01,  -1.3542899605316530E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [   9.8148763316511711E-01,   1.3542899605316530E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -9.8148763316511711E-01,  -1.3542899605316530E-01,   1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -9.8148763316511711E-01,   1.3542899605316530E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [   9.8148763316511711E-01,  -1.3542899605316530E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [  -9.8148763316511711E-01,  -1.3542899605316530E-01,  -1.3542899605316530E-01,   6.8074225476544830E-03],
            [   1.9389638611144261E-01,   1.9389638611144261E-01,   9.6166958094027533E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,   1.9389638611144261E-01,   9.6166958094027533E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,  -1.9389638611144261E-01,   9.6166958094027533E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,   1.9389638611144261E-01,  -9.6166958094027533E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,  -1.9389638611144261E-01,   9.6166958094027533E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,   1.9389638611144261E-01,  -9.6166958094027533E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,  -1.9389638611144261E-01,  -9.6166958094027533E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,  -1.9389638611144261E-01,  -9.6166958094027533E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,   9.6166958094027533E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,  -9.6166958094027533E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,   9.6166958094027533E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,  -9.6166958094027533E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,   9.6166958094027533E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,  -9.6166958094027533E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -1.9389638611144261E-01,  -9.6166958094027533E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [   1.9389638611144261E-01,   9.6166958094027533E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [   9.6166958094027533E-01,   1.9389638611144261E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -9.6166958094027533E-01,   1.9389638611144261E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [   9.6166958094027533E-01,  -1.9389638611144261E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [   9.6166958094027533E-01,   1.9389638611144261E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -9.6166958094027533E-01,  -1.9389638611144261E-01,   1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -9.6166958094027533E-01,   1.9389638611144261E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [   9.6166958094027533E-01,  -1.9389638611144261E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [  -9.6166958094027533E-01,  -1.9389638611144261E-01,  -1.9389638611144261E-01,   7.7258057738222620E-03],
            [   2.5373437150112749E-01,   2.5373437150112749E-01,   9.3340116640052240E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,   2.5373437150112749E-01,   9.3340116640052240E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,  -2.5373437150112749E-01,   9.3340116640052240E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,   2.5373437150112749E-01,  -9.3340116640052240E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,  -2.5373437150112749E-01,   9.3340116640052240E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,   2.5373437150112749E-01,  -9.3340116640052240E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,  -2.5373437150112749E-01,  -9.3340116640052240E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,  -2.5373437150112749E-01,  -9.3340116640052240E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,   9.3340116640052240E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,  -9.3340116640052240E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,   9.3340116640052240E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,  -9.3340116640052240E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,   9.3340116640052240E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,  -9.3340116640052240E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -2.5373437150112749E-01,  -9.3340116640052240E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [   2.5373437150112749E-01,   9.3340116640052240E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [   9.3340116640052240E-01,   2.5373437150112749E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -9.3340116640052240E-01,   2.5373437150112749E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [   9.3340116640052240E-01,  -2.5373437150112749E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [   9.3340116640052240E-01,   2.5373437150112749E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -9.3340116640052240E-01,  -2.5373437150112749E-01,   2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -9.3340116640052240E-01,   2.5373437150112749E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [   9.3340116640052240E-01,  -2.5373437150112749E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [  -9.3340116640052240E-01,  -2.5373437150112749E-01,  -2.5373437150112749E-01,   8.3747251028863275E-03],
            [   3.1352514347525701E-01,   3.1352514347525701E-01,   8.9632804754600814E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,   3.1352514347525701E-01,   8.9632804754600814E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,  -3.1352514347525701E-01,   8.9632804754600814E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,   3.1352514347525701E-01,  -8.9632804754600814E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,  -3.1352514347525701E-01,   8.9632804754600814E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,   3.1352514347525701E-01,  -8.9632804754600814E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,  -3.1352514347525701E-01,  -8.9632804754600814E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,  -3.1352514347525701E-01,  -8.9632804754600814E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,   8.9632804754600814E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,  -8.9632804754600814E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,   8.9632804754600814E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,  -8.9632804754600814E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,   8.9632804754600814E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,  -8.9632804754600814E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -3.1352514347525701E-01,  -8.9632804754600814E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [   3.1352514347525701E-01,   8.9632804754600814E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [   8.9632804754600814E-01,   3.1352514347525701E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -8.9632804754600814E-01,   3.1352514347525701E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [   8.9632804754600814E-01,  -3.1352514347525701E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [   8.9632804754600814E-01,   3.1352514347525701E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -8.9632804754600814E-01,  -3.1352514347525701E-01,   3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -8.9632804754600814E-01,   3.1352514347525701E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [   8.9632804754600814E-01,  -3.1352514347525701E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [  -8.9632804754600814E-01,  -3.1352514347525701E-01,  -3.1352514347525701E-01,   8.8279248139556607E-03],
            [   3.7215583393753382E-01,   3.7215583393753382E-01,   8.5029410825461882E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,   3.7215583393753382E-01,   8.5029410825461882E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,  -3.7215583393753382E-01,   8.5029410825461882E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,   3.7215583393753382E-01,  -8.5029410825461882E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,  -3.7215583393753382E-01,   8.5029410825461882E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,   3.7215583393753382E-01,  -8.5029410825461882E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,  -3.7215583393753382E-01,  -8.5029410825461882E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,  -3.7215583393753382E-01,  -8.5029410825461882E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,   8.5029410825461882E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,  -8.5029410825461882E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,   8.5029410825461882E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,  -8.5029410825461882E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,   8.5029410825461882E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,  -8.5029410825461882E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -3.7215583393753382E-01,  -8.5029410825461882E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [   3.7215583393753382E-01,   8.5029410825461882E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [   8.5029410825461882E-01,   3.7215583393753382E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -8.5029410825461882E-01,   3.7215583393753382E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [   8.5029410825461882E-01,  -3.7215583393753382E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [   8.5029410825461882E-01,   3.7215583393753382E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -8.5029410825461882E-01,  -3.7215583393753382E-01,   3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -8.5029410825461882E-01,   3.7215583393753382E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [   8.5029410825461882E-01,  -3.7215583393753382E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [  -8.5029410825461882E-01,  -3.7215583393753382E-01,  -3.7215583393753382E-01,   9.1338812958549724E-03],
            [   4.2868095751956958E-01,   4.2868095751956958E-01,   7.9527685325313602E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,   4.2868095751956958E-01,   7.9527685325313602E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,  -4.2868095751956958E-01,   7.9527685325313602E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,   4.2868095751956958E-01,  -7.9527685325313602E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,  -4.2868095751956958E-01,   7.9527685325313602E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,   4.2868095751956958E-01,  -7.9527685325313602E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,  -4.2868095751956958E-01,  -7.9527685325313602E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,  -4.2868095751956958E-01,  -7.9527685325313602E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,   7.9527685325313602E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,  -7.9527685325313602E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,   7.9527685325313602E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,  -7.9527685325313602E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,   7.9527685325313602E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,  -7.9527685325313602E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -4.2868095751956958E-01,  -7.9527685325313602E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [   4.2868095751956958E-01,   7.9527685325313602E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [   7.9527685325313602E-01,   4.2868095751956958E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -7.9527685325313602E-01,   4.2868095751956958E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [   7.9527685325313602E-01,  -4.2868095751956958E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [   7.9527685325313602E-01,   4.2868095751956958E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -7.9527685325313602E-01,  -4.2868095751956958E-01,   4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -7.9527685325313602E-01,   4.2868095751956958E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [   7.9527685325313602E-01,  -4.2868095751956958E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [  -7.9527685325313602E-01,  -4.2868095751956958E-01,  -4.2868095751956958E-01,   9.3275614190918739E-03],
            [   4.8225101282829941E-01,   4.8225101282829941E-01,   7.3134664916998060E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,   4.8225101282829941E-01,   7.3134664916998060E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,  -4.8225101282829941E-01,   7.3134664916998060E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,   4.8225101282829941E-01,  -7.3134664916998060E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,  -4.8225101282829941E-01,   7.3134664916998060E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,   4.8225101282829941E-01,  -7.3134664916998060E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,  -4.8225101282829941E-01,  -7.3134664916998060E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,  -4.8225101282829941E-01,  -7.3134664916998060E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,   7.3134664916998060E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,  -7.3134664916998060E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,   7.3134664916998060E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,  -7.3134664916998060E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,   7.3134664916998060E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,  -7.3134664916998060E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -4.8225101282829941E-01,  -7.3134664916998060E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [   4.8225101282829941E-01,   7.3134664916998060E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [   7.3134664916998060E-01,   4.8225101282829941E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -7.3134664916998060E-01,   4.8225101282829941E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [   7.3134664916998060E-01,  -4.8225101282829941E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [   7.3134664916998060E-01,   4.8225101282829941E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -7.3134664916998060E-01,  -4.8225101282829941E-01,   4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -7.3134664916998060E-01,   4.8225101282829941E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [   7.3134664916998060E-01,  -4.8225101282829941E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [  -7.3134664916998060E-01,  -4.8225101282829941E-01,  -4.8225101282829941E-01,   9.4367726065601835E-03],
            [   5.3206793335662628E-01,   5.3206793335662628E-01,   6.5864059136012676E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,   5.3206793335662628E-01,   6.5864059136012676E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,  -5.3206793335662628E-01,   6.5864059136012676E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,   5.3206793335662628E-01,  -6.5864059136012676E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,  -5.3206793335662628E-01,   6.5864059136012676E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,   5.3206793335662628E-01,  -6.5864059136012676E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,  -5.3206793335662628E-01,  -6.5864059136012676E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,  -5.3206793335662628E-01,  -6.5864059136012676E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,   6.5864059136012676E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,  -6.5864059136012676E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,   6.5864059136012676E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,  -6.5864059136012676E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,   6.5864059136012676E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,  -6.5864059136012676E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -5.3206793335662628E-01,  -6.5864059136012676E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [   5.3206793335662628E-01,   6.5864059136012676E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [   6.5864059136012676E-01,   5.3206793335662628E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -6.5864059136012676E-01,   5.3206793335662628E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [   6.5864059136012676E-01,  -5.3206793335662628E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [   6.5864059136012676E-01,   5.3206793335662628E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -6.5864059136012676E-01,  -5.3206793335662628E-01,   5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -6.5864059136012676E-01,   5.3206793335662628E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [   6.5864059136012676E-01,  -5.3206793335662628E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [  -6.5864059136012676E-01,  -5.3206793335662628E-01,  -5.3206793335662628E-01,   9.4857689130772530E-03],
            [   6.1729981953942736E-01,   6.1729981953942736E-01,   4.8773134571522136E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,   6.1729981953942736E-01,   4.8773134571522136E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,  -6.1729981953942736E-01,   4.8773134571522136E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,   6.1729981953942736E-01,  -4.8773134571522136E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,  -6.1729981953942736E-01,   4.8773134571522136E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,   6.1729981953942736E-01,  -4.8773134571522136E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,  -6.1729981953942736E-01,  -4.8773134571522136E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,  -6.1729981953942736E-01,  -4.8773134571522136E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,   4.8773134571522136E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,  -4.8773134571522136E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,   4.8773134571522136E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,  -4.8773134571522136E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,   4.8773134571522136E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,  -4.8773134571522136E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -6.1729981953942736E-01,  -4.8773134571522136E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [   6.1729981953942736E-01,   4.8773134571522136E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [   4.8773134571522136E-01,   6.1729981953942736E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -4.8773134571522136E-01,   6.1729981953942736E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [   4.8773134571522136E-01,  -6.1729981953942736E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [   4.8773134571522136E-01,   6.1729981953942736E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -4.8773134571522136E-01,  -6.1729981953942736E-01,   6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -4.8773134571522136E-01,   6.1729981953942736E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [   4.8773134571522136E-01,  -6.1729981953942736E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [  -4.8773134571522136E-01,  -6.1729981953942736E-01,  -6.1729981953942736E-01,   9.4927481648022765E-03],
            [   6.5106798491274809E-01,   6.5106798491274809E-01,   3.9015504359588543E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,   6.5106798491274809E-01,   3.9015504359588543E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,  -6.5106798491274809E-01,   3.9015504359588543E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,   6.5106798491274809E-01,  -3.9015504359588543E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,  -6.5106798491274809E-01,   3.9015504359588543E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,   6.5106798491274809E-01,  -3.9015504359588543E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,  -6.5106798491274809E-01,  -3.9015504359588543E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,  -6.5106798491274809E-01,  -3.9015504359588543E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,   3.9015504359588543E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,  -3.9015504359588543E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,   3.9015504359588543E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,  -3.9015504359588543E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,   3.9015504359588543E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,  -3.9015504359588543E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -6.5106798491274809E-01,  -3.9015504359588543E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [   6.5106798491274809E-01,   3.9015504359588543E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [   3.9015504359588543E-01,   6.5106798491274809E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -3.9015504359588543E-01,   6.5106798491274809E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [   3.9015504359588543E-01,  -6.5106798491274809E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [   3.9015504359588543E-01,   6.5106798491274809E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -3.9015504359588543E-01,  -6.5106798491274809E-01,   6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -3.9015504359588543E-01,   6.5106798491274809E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [   3.9015504359588543E-01,  -6.5106798491274809E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [  -3.9015504359588543E-01,  -6.5106798491274809E-01,  -6.5106798491274809E-01,   9.4915646698848118E-03],
            [   6.7773152516873603E-01,   6.7773152516873603E-01,   2.8523667293130073E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,   6.7773152516873603E-01,   2.8523667293130073E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,  -6.7773152516873603E-01,   2.8523667293130073E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,   6.7773152516873603E-01,  -2.8523667293130073E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,  -6.7773152516873603E-01,   2.8523667293130073E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,   6.7773152516873603E-01,  -2.8523667293130073E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,  -6.7773152516873603E-01,  -2.8523667293130073E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,  -6.7773152516873603E-01,  -2.8523667293130073E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,   2.8523667293130073E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,  -2.8523667293130073E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,   2.8523667293130073E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,  -2.8523667293130073E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,   2.8523667293130073E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,  -2.8523667293130073E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -6.7773152516873603E-01,  -2.8523667293130073E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [   6.7773152516873603E-01,   2.8523667293130073E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [   2.8523667293130073E-01,   6.7773152516873603E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -2.8523667293130073E-01,   6.7773152516873603E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [   2.8523667293130073E-01,  -6.7773152516873603E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [   2.8523667293130073E-01,   6.7773152516873603E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -2.8523667293130073E-01,  -6.7773152516873603E-01,   6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -2.8523667293130073E-01,   6.7773152516873603E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [   2.8523667293130073E-01,  -6.7773152516873603E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [  -2.8523667293130073E-01,  -6.7773152516873603E-01,  -6.7773152516873603E-01,   9.5061673942787115E-03],
            [   6.9631094106487412E-01,   6.9631094106487412E-01,   1.7407511799995667E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,   6.9631094106487412E-01,   1.7407511799995667E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,  -6.9631094106487412E-01,   1.7407511799995667E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,   6.9631094106487412E-01,  -1.7407511799995667E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,  -6.9631094106487412E-01,   1.7407511799995667E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,   6.9631094106487412E-01,  -1.7407511799995667E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,  -6.9631094106487412E-01,  -1.7407511799995667E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,  -6.9631094106487412E-01,  -1.7407511799995667E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,   1.7407511799995667E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,  -1.7407511799995667E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,   1.7407511799995667E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,  -1.7407511799995667E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,   1.7407511799995667E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,  -1.7407511799995667E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -6.9631094106487412E-01,  -1.7407511799995667E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [   6.9631094106487412E-01,   1.7407511799995667E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [   1.7407511799995667E-01,   6.9631094106487412E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -1.7407511799995667E-01,   6.9631094106487412E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [   1.7407511799995667E-01,  -6.9631094106487412E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [   1.7407511799995667E-01,   6.9631094106487412E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -1.7407511799995667E-01,  -6.9631094106487412E-01,   6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -1.7407511799995667E-01,   6.9631094106487412E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [   1.7407511799995667E-01,  -6.9631094106487412E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [  -1.7407511799995667E-01,  -6.9631094106487412E-01,  -6.9631094106487412E-01,   9.5353517284567871E-03],
            [   7.0589350098317494E-01,   7.0589350098317494E-01,   5.8555363028785182E-02,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,   7.0589350098317494E-01,   5.8555363028785182E-02,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,  -7.0589350098317494E-01,   5.8555363028785182E-02,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,   7.0589350098317494E-01,  -5.8555363028785182E-02,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,  -7.0589350098317494E-01,   5.8555363028785182E-02,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,   7.0589350098317494E-01,  -5.8555363028785182E-02,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,  -7.0589350098317494E-01,  -5.8555363028785182E-02,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,  -7.0589350098317494E-01,  -5.8555363028785182E-02,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,   5.8555363028785182E-02,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,  -5.8555363028785182E-02,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,   5.8555363028785182E-02,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,  -5.8555363028785182E-02,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,   5.8555363028785182E-02,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,  -5.8555363028785182E-02,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -7.0589350098317494E-01,  -5.8555363028785182E-02,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [   7.0589350098317494E-01,   5.8555363028785182E-02,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [   5.8555363028785182E-02,   7.0589350098317494E-01,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -5.8555363028785182E-02,   7.0589350098317494E-01,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [   5.8555363028785182E-02,  -7.0589350098317494E-01,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [   5.8555363028785182E-02,   7.0589350098317494E-01,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -5.8555363028785182E-02,  -7.0589350098317494E-01,   7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -5.8555363028785182E-02,   7.0589350098317494E-01,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [   5.8555363028785182E-02,  -7.0589350098317494E-01,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [  -5.8555363028785182E-02,  -7.0589350098317494E-01,  -7.0589350098317494E-01,   9.5608237912410323E-03],
            [   9.9555461940918566E-01,   9.4185985013862425E-02,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [  -9.9555461940918566E-01,   9.4185985013862425E-02,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [   9.9555461940918566E-01,  -9.4185985013862425E-02,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [  -9.9555461940918566E-01,  -9.4185985013862425E-02,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [   9.4185985013862425E-02,   9.9555461940918566E-01,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [  -9.4185985013862425E-02,   9.9555461940918566E-01,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [   9.4185985013862425E-02,  -9.9555461940918566E-01,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [  -9.4185985013862425E-02,  -9.9555461940918566E-01,   0.0000000000000000E+00,   5.0537927000518183E-03],
            [   9.9555461940918566E-01,   0.0000000000000000E+00,   9.4185985013862425E-02,   5.0537927000518183E-03],
            [  -9.9555461940918566E-01,   0.0000000000000000E+00,   9.4185985013862425E-02,   5.0537927000518183E-03],
            [   9.9555461940918566E-01,   0.0000000000000000E+00,  -9.4185985013862425E-02,   5.0537927000518183E-03],
            [  -9.9555461940918566E-01,   0.0000000000000000E+00,  -9.4185985013862425E-02,   5.0537927000518183E-03],
            [   9.4185985013862425E-02,   0.0000000000000000E+00,   9.9555461940918566E-01,   5.0537927000518183E-03],
            [  -9.4185985013862425E-02,   0.0000000000000000E+00,   9.9555461940918566E-01,   5.0537927000518183E-03],
            [   9.4185985013862425E-02,   0.0000000000000000E+00,  -9.9555461940918566E-01,   5.0537927000518183E-03],
            [  -9.4185985013862425E-02,   0.0000000000000000E+00,  -9.9555461940918566E-01,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,   9.9555461940918566E-01,   9.4185985013862425E-02,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,  -9.9555461940918566E-01,   9.4185985013862425E-02,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,   9.9555461940918566E-01,  -9.4185985013862425E-02,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,  -9.9555461940918566E-01,  -9.4185985013862425E-02,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,   9.4185985013862425E-02,   9.9555461940918566E-01,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,  -9.4185985013862425E-02,   9.9555461940918566E-01,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,   9.4185985013862425E-02,  -9.9555461940918566E-01,   5.0537927000518183E-03],
            [   0.0000000000000000E+00,  -9.4185985013862425E-02,  -9.9555461940918566E-01,   5.0537927000518183E-03],
            [   9.7341159017942092E-01,   2.2906303958598634E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [  -9.7341159017942092E-01,   2.2906303958598634E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [   9.7341159017942092E-01,  -2.2906303958598634E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [  -9.7341159017942092E-01,  -2.2906303958598634E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [   2.2906303958598634E-01,   9.7341159017942092E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [  -2.2906303958598634E-01,   9.7341159017942092E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [   2.2906303958598634E-01,  -9.7341159017942092E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [  -2.2906303958598634E-01,  -9.7341159017942092E-01,   0.0000000000000000E+00,   7.2946170331564973E-03],
            [   9.7341159017942092E-01,   0.0000000000000000E+00,   2.2906303958598634E-01,   7.2946170331564973E-03],
            [  -9.7341159017942092E-01,   0.0000000000000000E+00,   2.2906303958598634E-01,   7.2946170331564973E-03],
            [   9.7341159017942092E-01,   0.0000000000000000E+00,  -2.2906303958598634E-01,   7.2946170331564973E-03],
            [  -9.7341159017942092E-01,   0.0000000000000000E+00,  -2.2906303958598634E-01,   7.2946170331564973E-03],
            [   2.2906303958598634E-01,   0.0000000000000000E+00,   9.7341159017942092E-01,   7.2946170331564973E-03],
            [  -2.2906303958598634E-01,   0.0000000000000000E+00,   9.7341159017942092E-01,   7.2946170331564973E-03],
            [   2.2906303958598634E-01,   0.0000000000000000E+00,  -9.7341159017942092E-01,   7.2946170331564973E-03],
            [  -2.2906303958598634E-01,   0.0000000000000000E+00,  -9.7341159017942092E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,   9.7341159017942092E-01,   2.2906303958598634E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,  -9.7341159017942092E-01,   2.2906303958598634E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,   9.7341159017942092E-01,  -2.2906303958598634E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,  -9.7341159017942092E-01,  -2.2906303958598634E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,   2.2906303958598634E-01,   9.7341159017942092E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,  -2.2906303958598634E-01,   9.7341159017942092E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,   2.2906303958598634E-01,  -9.7341159017942092E-01,   7.2946170331564973E-03],
            [   0.0000000000000000E+00,  -2.2906303958598634E-01,  -9.7341159017942092E-01,   7.2946170331564973E-03],
            [   9.2756937323886257E-01,   3.7365098398005542E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [  -9.2756937323886257E-01,   3.7365098398005542E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [   9.2756937323886257E-01,  -3.7365098398005542E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [  -9.2756937323886257E-01,  -3.7365098398005542E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [   3.7365098398005542E-01,   9.2756937323886257E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [  -3.7365098398005542E-01,   9.2756937323886257E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [   3.7365098398005542E-01,  -9.2756937323886257E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [  -3.7365098398005542E-01,  -9.2756937323886257E-01,   0.0000000000000000E+00,   8.5352698747451425E-03],
            [   9.2756937323886257E-01,   0.0000000000000000E+00,   3.7365098398005542E-01,   8.5352698747451425E-03],
            [  -9.2756937323886257E-01,   0.0000000000000000E+00,   3.7365098398005542E-01,   8.5352698747451425E-03],
            [   9.2756937323886257E-01,   0.0000000000000000E+00,  -3.7365098398005542E-01,   8.5352698747451425E-03],
            [  -9.2756937323886257E-01,   0.0000000000000000E+00,  -3.7365098398005542E-01,   8.5352698747451425E-03],
            [   3.7365098398005542E-01,   0.0000000000000000E+00,   9.2756937323886257E-01,   8.5352698747451425E-03],
            [  -3.7365098398005542E-01,   0.0000000000000000E+00,   9.2756937323886257E-01,   8.5352698747451425E-03],
            [   3.7365098398005542E-01,   0.0000000000000000E+00,  -9.2756937323886257E-01,   8.5352698747451425E-03],
            [  -3.7365098398005542E-01,   0.0000000000000000E+00,  -9.2756937323886257E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,   9.2756937323886257E-01,   3.7365098398005542E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,  -9.2756937323886257E-01,   3.7365098398005542E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,   9.2756937323886257E-01,  -3.7365098398005542E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,  -9.2756937323886257E-01,  -3.7365098398005542E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,   3.7365098398005542E-01,   9.2756937323886257E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,  -3.7365098398005542E-01,   9.2756937323886257E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,   3.7365098398005542E-01,  -9.2756937323886257E-01,   8.5352698747451425E-03],
            [   0.0000000000000000E+00,  -3.7365098398005542E-01,  -9.2756937323886257E-01,   8.5352698747451425E-03],
            [   8.5680224227951030E-01,   5.1564514700014707E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [  -8.5680224227951030E-01,   5.1564514700014707E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [   8.5680224227951030E-01,  -5.1564514700014707E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [  -8.5680224227951030E-01,  -5.1564514700014707E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [   5.1564514700014707E-01,   8.5680224227951030E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [  -5.1564514700014707E-01,   8.5680224227951030E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [   5.1564514700014707E-01,  -8.5680224227951030E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [  -5.1564514700014707E-01,  -8.5680224227951030E-01,   0.0000000000000000E+00,   9.2196209162666003E-03],
            [   8.5680224227951030E-01,   0.0000000000000000E+00,   5.1564514700014707E-01,   9.2196209162666003E-03],
            [  -8.5680224227951030E-01,   0.0000000000000000E+00,   5.1564514700014707E-01,   9.2196209162666003E-03],
            [   8.5680224227951030E-01,   0.0000000000000000E+00,  -5.1564514700014707E-01,   9.2196209162666003E-03],
            [  -8.5680224227951030E-01,   0.0000000000000000E+00,  -5.1564514700014707E-01,   9.2196209162666003E-03],
            [   5.1564514700014707E-01,   0.0000000000000000E+00,   8.5680224227951030E-01,   9.2196209162666003E-03],
            [  -5.1564514700014707E-01,   0.0000000000000000E+00,   8.5680224227951030E-01,   9.2196209162666003E-03],
            [   5.1564514700014707E-01,   0.0000000000000000E+00,  -8.5680224227951030E-01,   9.2196209162666003E-03],
            [  -5.1564514700014707E-01,   0.0000000000000000E+00,  -8.5680224227951030E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,   8.5680224227951030E-01,   5.1564514700014707E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,  -8.5680224227951030E-01,   5.1564514700014707E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,   8.5680224227951030E-01,  -5.1564514700014707E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,  -8.5680224227951030E-01,  -5.1564514700014707E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,   5.1564514700014707E-01,   8.5680224227951030E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,  -5.1564514700014707E-01,   8.5680224227951030E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,   5.1564514700014707E-01,  -8.5680224227951030E-01,   9.2196209162666003E-03],
            [   0.0000000000000000E+00,  -5.1564514700014707E-01,  -8.5680224227951030E-01,   9.2196209162666003E-03],
            [   7.6234955537193716E-01,   6.4716547762083976E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [  -7.6234955537193716E-01,   6.4716547762083976E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [   7.6234955537193716E-01,  -6.4716547762083976E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [  -7.6234955537193716E-01,  -6.4716547762083976E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [   6.4716547762083976E-01,   7.6234955537193716E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [  -6.4716547762083976E-01,   7.6234955537193716E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [   6.4716547762083976E-01,  -7.6234955537193716E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [  -6.4716547762083976E-01,  -7.6234955537193716E-01,   0.0000000000000000E+00,   9.5276541886755890E-03],
            [   7.6234955537193716E-01,   0.0000000000000000E+00,   6.4716547762083976E-01,   9.5276541886755890E-03],
            [  -7.6234955537193716E-01,   0.0000000000000000E+00,   6.4716547762083976E-01,   9.5276541886755890E-03],
            [   7.6234955537193716E-01,   0.0000000000000000E+00,  -6.4716547762083976E-01,   9.5276541886755890E-03],
            [  -7.6234955537193716E-01,   0.0000000000000000E+00,  -6.4716547762083976E-01,   9.5276541886755890E-03],
            [   6.4716547762083976E-01,   0.0000000000000000E+00,   7.6234955537193716E-01,   9.5276541886755890E-03],
            [  -6.4716547762083976E-01,   0.0000000000000000E+00,   7.6234955537193716E-01,   9.5276541886755890E-03],
            [   6.4716547762083976E-01,   0.0000000000000000E+00,  -7.6234955537193716E-01,   9.5276541886755890E-03],
            [  -6.4716547762083976E-01,   0.0000000000000000E+00,  -7.6234955537193716E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,   7.6234955537193716E-01,   6.4716547762083976E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,  -7.6234955537193716E-01,   6.4716547762083976E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,   7.6234955537193716E-01,  -6.4716547762083976E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,  -7.6234955537193716E-01,  -6.4716547762083976E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,   6.4716547762083976E-01,   7.6234955537193716E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,  -6.4716547762083976E-01,   7.6234955537193716E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,   6.4716547762083976E-01,  -7.6234955537193716E-01,   9.5276541886755890E-03],
            [   0.0000000000000000E+00,  -6.4716547762083976E-01,  -7.6234955537193716E-01,   9.5276541886755890E-03],
            [   5.7075229088922230E-01,   4.3870280398895012E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,   4.3870280398895012E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,  -4.3870280398895012E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,   4.3870280398895012E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,  -4.3870280398895012E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,  -4.3870280398895012E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,   4.3870280398895012E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,  -4.3870280398895012E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,   5.7075229088922230E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,   5.7075229088922230E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,  -5.7075229088922230E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,   5.7075229088922230E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,  -5.7075229088922230E-01,   6.9410494323044358E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,  -5.7075229088922230E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,   5.7075229088922230E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,  -5.7075229088922230E-01,  -6.9410494323044358E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,   5.7075229088922230E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,   5.7075229088922230E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,  -5.7075229088922230E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,   5.7075229088922230E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,  -5.7075229088922230E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,  -5.7075229088922230E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,   5.7075229088922230E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,  -5.7075229088922230E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,   4.3870280398895012E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,   4.3870280398895012E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,  -4.3870280398895012E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,   4.3870280398895012E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,  -4.3870280398895012E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   6.9410494323044358E-01,  -4.3870280398895012E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,   4.3870280398895012E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -6.9410494323044358E-01,  -4.3870280398895012E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,   6.9410494323044358E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,   6.9410494323044358E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,  -6.9410494323044358E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,   6.9410494323044358E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,  -6.9410494323044358E-01,   4.3870280398895012E-01,   9.4728542052862127E-03],
            [   5.7075229088922230E-01,  -6.9410494323044358E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,   6.9410494323044358E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [  -5.7075229088922230E-01,  -6.9410494323044358E-01,  -4.3870280398895012E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,   6.9410494323044358E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,   6.9410494323044358E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,  -6.9410494323044358E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,   6.9410494323044358E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,  -6.9410494323044358E-01,   5.7075229088922230E-01,   9.4728542052862127E-03],
            [   4.3870280398895012E-01,  -6.9410494323044358E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,   6.9410494323044358E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [  -4.3870280398895012E-01,  -6.9410494323044358E-01,  -5.7075229088922230E-01,   9.4728542052862127E-03],
            [   5.1964633884030831E-01,   3.8589084147626168E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,   3.8589084147626168E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,  -3.8589084147626168E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,   3.8589084147626168E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,  -3.8589084147626168E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,  -3.8589084147626168E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,   3.8589084147626168E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,  -3.8589084147626168E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,   5.1964633884030831E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,   5.1964633884030831E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,  -5.1964633884030831E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,   5.1964633884030831E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,  -5.1964633884030831E-01,   7.6227025456501074E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,  -5.1964633884030831E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,   5.1964633884030831E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,  -5.1964633884030831E-01,  -7.6227025456501074E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,   5.1964633884030831E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,   5.1964633884030831E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,  -5.1964633884030831E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,   5.1964633884030831E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,  -5.1964633884030831E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,  -5.1964633884030831E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,   5.1964633884030831E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,  -5.1964633884030831E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,   3.8589084147626168E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,   3.8589084147626168E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,  -3.8589084147626168E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,   3.8589084147626168E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,  -3.8589084147626168E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   7.6227025456501074E-01,  -3.8589084147626168E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,   3.8589084147626168E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -7.6227025456501074E-01,  -3.8589084147626168E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,   7.6227025456501074E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,   7.6227025456501074E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,  -7.6227025456501074E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,   7.6227025456501074E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,  -7.6227025456501074E-01,   3.8589084147626168E-01,   9.4040651225418426E-03],
            [   5.1964633884030831E-01,  -7.6227025456501074E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,   7.6227025456501074E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [  -5.1964633884030831E-01,  -7.6227025456501074E-01,  -3.8589084147626168E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,   7.6227025456501074E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,   7.6227025456501074E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,  -7.6227025456501074E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,   7.6227025456501074E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,  -7.6227025456501074E-01,   5.1964633884030831E-01,   9.4040651225418426E-03],
            [   3.8589084147626168E-01,  -7.6227025456501074E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,   7.6227025456501074E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [  -3.8589084147626168E-01,  -7.6227025456501074E-01,  -5.1964633884030831E-01,   9.4040651225418426E-03],
            [   4.6463375312153510E-01,   3.3019373723438539E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,   3.3019373723438539E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,  -3.3019373723438539E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,   3.3019373723438539E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,  -3.3019373723438539E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,  -3.3019373723438539E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,   3.3019373723438539E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,  -3.3019373723438539E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,   4.6463375312153510E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,   4.6463375312153510E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,  -4.6463375312153510E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,   4.6463375312153510E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,  -4.6463375312153510E-01,   8.2163712875659778E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,  -4.6463375312153510E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,   4.6463375312153510E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,  -4.6463375312153510E-01,  -8.2163712875659778E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,   4.6463375312153510E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,   4.6463375312153510E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,  -4.6463375312153510E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,   4.6463375312153510E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,  -4.6463375312153510E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,  -4.6463375312153510E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,   4.6463375312153510E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,  -4.6463375312153510E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,   3.3019373723438539E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,   3.3019373723438539E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,  -3.3019373723438539E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,   3.3019373723438539E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,  -3.3019373723438539E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   8.2163712875659778E-01,  -3.3019373723438539E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,   3.3019373723438539E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -8.2163712875659778E-01,  -3.3019373723438539E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,   8.2163712875659778E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,   8.2163712875659778E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,  -8.2163712875659778E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,   8.2163712875659778E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,  -8.2163712875659778E-01,   3.3019373723438539E-01,   9.2636314246999363E-03],
            [   4.6463375312153510E-01,  -8.2163712875659778E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,   8.2163712875659778E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [  -4.6463375312153510E-01,  -8.2163712875659778E-01,  -3.3019373723438539E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,   8.2163712875659778E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,   8.2163712875659778E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,  -8.2163712875659778E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,   8.2163712875659778E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,  -8.2163712875659778E-01,   4.6463375312153510E-01,   9.2636314246999363E-03],
            [   3.3019373723438539E-01,  -8.2163712875659778E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,   8.2163712875659778E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [  -3.3019373723438539E-01,  -8.2163712875659778E-01,  -4.6463375312153510E-01,   9.2636314246999363E-03],
            [   4.0639016975576908E-01,   2.7254235735637772E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,   2.7254235735637772E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,  -2.7254235735637772E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,   2.7254235735637772E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,  -2.7254235735637772E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,  -2.7254235735637772E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,   2.7254235735637772E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,  -2.7254235735637772E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,   4.0639016975576908E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,   4.0639016975576908E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,  -4.0639016975576908E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,   4.0639016975576908E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,  -4.0639016975576908E-01,   8.7210532240808258E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,  -4.0639016975576908E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,   4.0639016975576908E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,  -4.0639016975576908E-01,  -8.7210532240808258E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,   4.0639016975576908E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,   4.0639016975576908E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,  -4.0639016975576908E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,   4.0639016975576908E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,  -4.0639016975576908E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,  -4.0639016975576908E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,   4.0639016975576908E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,  -4.0639016975576908E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,   2.7254235735637772E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,   2.7254235735637772E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,  -2.7254235735637772E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,   2.7254235735637772E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,  -2.7254235735637772E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   8.7210532240808258E-01,  -2.7254235735637772E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,   2.7254235735637772E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -8.7210532240808258E-01,  -2.7254235735637772E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,   8.7210532240808258E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,   8.7210532240808258E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,  -8.7210532240808258E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,   8.7210532240808258E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,  -8.7210532240808258E-01,   2.7254235735637772E-01,   9.0269881113390783E-03],
            [   4.0639016975576908E-01,  -8.7210532240808258E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,   8.7210532240808258E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [  -4.0639016975576908E-01,  -8.7210532240808258E-01,  -2.7254235735637772E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,   8.7210532240808258E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,   8.7210532240808258E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,  -8.7210532240808258E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,   8.7210532240808258E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,  -8.7210532240808258E-01,   4.0639016975576908E-01,   9.0269881113390783E-03],
            [   2.7254235735637772E-01,  -8.7210532240808258E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,   8.7210532240808258E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [  -2.7254235735637772E-01,  -8.7210532240808258E-01,  -4.0639016975576908E-01,   9.0269881113390783E-03],
            [   3.4563294666430872E-01,   2.1395102374952499E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,   2.1395102374952499E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,  -2.1395102374952499E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,   2.1395102374952499E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,  -2.1395102374952499E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,  -2.1395102374952499E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,   2.1395102374952499E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,  -2.1395102374952499E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,   3.4563294666430872E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,   3.4563294666430872E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,  -3.4563294666430872E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,   3.4563294666430872E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,  -3.4563294666430872E-01,   9.1365355885952593E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,  -3.4563294666430872E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,   3.4563294666430872E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,  -3.4563294666430872E-01,  -9.1365355885952593E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,   3.4563294666430872E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,   3.4563294666430872E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,  -3.4563294666430872E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,   3.4563294666430872E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,  -3.4563294666430872E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,  -3.4563294666430872E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,   3.4563294666430872E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,  -3.4563294666430872E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,   2.1395102374952499E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,   2.1395102374952499E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,  -2.1395102374952499E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,   2.1395102374952499E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,  -2.1395102374952499E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   9.1365355885952593E-01,  -2.1395102374952499E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,   2.1395102374952499E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -9.1365355885952593E-01,  -2.1395102374952499E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,   9.1365355885952593E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,   9.1365355885952593E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,  -9.1365355885952593E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,   9.1365355885952593E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,  -9.1365355885952593E-01,   2.1395102374952499E-01,   8.6655373635999219E-03],
            [   3.4563294666430872E-01,  -9.1365355885952593E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,   9.1365355885952593E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [  -3.4563294666430872E-01,  -9.1365355885952593E-01,  -2.1395102374952499E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,   9.1365355885952593E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,   9.1365355885952593E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,  -9.1365355885952593E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,   9.1365355885952593E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,  -9.1365355885952593E-01,   3.4563294666430872E-01,   8.6655373635999219E-03],
            [   2.1395102374952499E-01,  -9.1365355885952593E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,   9.1365355885952593E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [  -2.1395102374952499E-01,  -9.1365355885952593E-01,  -3.4563294666430872E-01,   8.6655373635999219E-03],
            [   2.8313951210503319E-01,   1.5559223097866470E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,   1.5559223097866470E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,  -1.5559223097866470E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,   1.5559223097866470E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,  -1.5559223097866470E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,  -1.5559223097866470E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,   1.5559223097866470E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,  -1.5559223097866470E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,   2.8313951210503319E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,   2.8313951210503319E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,  -2.8313951210503319E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,   2.8313951210503319E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,  -2.8313951210503319E-01,   9.4637364415119130E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,  -2.8313951210503319E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,   2.8313951210503319E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,  -2.8313951210503319E-01,  -9.4637364415119130E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,   2.8313951210503319E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,   2.8313951210503319E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,  -2.8313951210503319E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,   2.8313951210503319E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,  -2.8313951210503319E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,  -2.8313951210503319E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,   2.8313951210503319E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,  -2.8313951210503319E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,   1.5559223097866470E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,   1.5559223097866470E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,  -1.5559223097866470E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,   1.5559223097866470E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,  -1.5559223097866470E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   9.4637364415119130E-01,  -1.5559223097866470E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,   1.5559223097866470E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -9.4637364415119130E-01,  -1.5559223097866470E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,   9.4637364415119130E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,   9.4637364415119130E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,  -9.4637364415119130E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,   9.4637364415119130E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,  -9.4637364415119130E-01,   1.5559223097866470E-01,   8.1431411125588507E-03],
            [   2.8313951210503319E-01,  -9.4637364415119130E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,   9.4637364415119130E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [  -2.8313951210503319E-01,  -9.4637364415119130E-01,  -1.5559223097866470E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,   9.4637364415119130E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,   9.4637364415119130E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,  -9.4637364415119130E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,   9.4637364415119130E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,  -9.4637364415119130E-01,   2.8313951210503319E-01,   8.1431411125588507E-03],
            [   1.5559223097866470E-01,  -9.4637364415119130E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,   9.4637364415119130E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [  -1.5559223097866470E-01,  -9.4637364415119130E-01,  -2.8313951210503319E-01,   8.1431411125588507E-03],
            [   2.1976820229253299E-01,   9.8928789796860969E-02,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,   9.8928789796860969E-02,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,  -9.8928789796860969E-02,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,   9.8928789796860969E-02,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,  -9.8928789796860969E-02,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,  -9.8928789796860969E-02,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,   9.8928789796860969E-02,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,  -9.8928789796860969E-02,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,   2.1976820229253299E-01,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,   2.1976820229253299E-01,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,  -2.1976820229253299E-01,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,   2.1976820229253299E-01,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,  -2.1976820229253299E-01,   9.7052307124067727E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,  -2.1976820229253299E-01,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,   2.1976820229253299E-01,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,  -2.1976820229253299E-01,  -9.7052307124067727E-01,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,   2.1976820229253299E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,   2.1976820229253299E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,  -2.1976820229253299E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,   2.1976820229253299E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,  -2.1976820229253299E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,  -2.1976820229253299E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,   2.1976820229253299E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,  -2.1976820229253299E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,   9.8928789796860969E-02,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,   9.8928789796860969E-02,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,  -9.8928789796860969E-02,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,   9.8928789796860969E-02,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,  -9.8928789796860969E-02,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.7052307124067727E-01,  -9.8928789796860969E-02,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,   9.8928789796860969E-02,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.7052307124067727E-01,  -9.8928789796860969E-02,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,   9.7052307124067727E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,   9.7052307124067727E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,  -9.7052307124067727E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,   9.7052307124067727E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,  -9.7052307124067727E-01,   9.8928789796860969E-02,   7.4110910814619334E-03],
            [   2.1976820229253299E-01,  -9.7052307124067727E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,   9.7052307124067727E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [  -2.1976820229253299E-01,  -9.7052307124067727E-01,  -9.8928789796860969E-02,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,   9.7052307124067727E-01,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,   9.7052307124067727E-01,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,  -9.7052307124067727E-01,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,   9.7052307124067727E-01,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,  -9.7052307124067727E-01,   2.1976820229253299E-01,   7.4110910814619334E-03],
            [   9.8928789796860969E-02,  -9.7052307124067727E-01,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,   9.7052307124067727E-01,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [  -9.8928789796860969E-02,  -9.7052307124067727E-01,  -2.1976820229253299E-01,   7.4110910814619334E-03],
            [   1.5646960986503550E-01,   4.5986429106755100E-02,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,   4.5986429106755100E-02,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,  -4.5986429106755100E-02,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,   4.5986429106755100E-02,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,  -4.5986429106755100E-02,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,  -4.5986429106755100E-02,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,   4.5986429106755100E-02,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,  -4.5986429106755100E-02,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,   1.5646960986503550E-01,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,   1.5646960986503550E-01,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,  -1.5646960986503550E-01,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,   1.5646960986503550E-01,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,  -1.5646960986503550E-01,   9.8661163054501488E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,  -1.5646960986503550E-01,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,   1.5646960986503550E-01,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,  -1.5646960986503550E-01,  -9.8661163054501488E-01,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,   1.5646960986503550E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,   1.5646960986503550E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,  -1.5646960986503550E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,   1.5646960986503550E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,  -1.5646960986503550E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,  -1.5646960986503550E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,   1.5646960986503550E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,  -1.5646960986503550E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,   4.5986429106755100E-02,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,   4.5986429106755100E-02,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,  -4.5986429106755100E-02,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,   4.5986429106755100E-02,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,  -4.5986429106755100E-02,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   9.8661163054501488E-01,  -4.5986429106755100E-02,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,   4.5986429106755100E-02,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -9.8661163054501488E-01,  -4.5986429106755100E-02,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,   9.8661163054501488E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,   9.8661163054501488E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,  -9.8661163054501488E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,   9.8661163054501488E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,  -9.8661163054501488E-01,   4.5986429106755100E-02,   6.4034565942511848E-03],
            [   1.5646960986503550E-01,  -9.8661163054501488E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,   9.8661163054501488E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [  -1.5646960986503550E-01,  -9.8661163054501488E-01,  -4.5986429106755100E-02,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,   9.8661163054501488E-01,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,   9.8661163054501488E-01,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,  -9.8661163054501488E-01,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,   9.8661163054501488E-01,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,  -9.8661163054501488E-01,   1.5646960986503550E-01,   6.4034565942511848E-03],
            [   4.5986429106755100E-02,  -9.8661163054501488E-01,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,   9.8661163054501488E-01,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [  -4.5986429106755100E-02,  -9.8661163054501488E-01,  -1.5646960986503550E-01,   6.4034565942511848E-03],
            [   6.0273566737212947E-01,   3.3766251401734260E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,   3.3766251401734260E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,  -3.3766251401734260E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,   3.3766251401734260E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,  -3.3766251401734260E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,  -3.3766251401734260E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,   3.3766251401734260E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,  -3.3766251401734260E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,   6.0273566737212947E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,   6.0273566737212947E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,  -6.0273566737212947E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,   6.0273566737212947E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,  -6.0273566737212947E-01,   7.2297561639723473E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,  -6.0273566737212947E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,   6.0273566737212947E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,  -6.0273566737212947E-01,  -7.2297561639723473E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,   6.0273566737212947E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,   6.0273566737212947E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,  -6.0273566737212947E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,   6.0273566737212947E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,  -6.0273566737212947E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,  -6.0273566737212947E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,   6.0273566737212947E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,  -6.0273566737212947E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,   3.3766251401734260E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,   3.3766251401734260E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,  -3.3766251401734260E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,   3.3766251401734260E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,  -3.3766251401734260E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   7.2297561639723473E-01,  -3.3766251401734260E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,   3.3766251401734260E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -7.2297561639723473E-01,  -3.3766251401734260E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,   7.2297561639723473E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,   7.2297561639723473E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,  -7.2297561639723473E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,   7.2297561639723473E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,  -7.2297561639723473E-01,   3.3766251401734260E-01,   9.4711559471426267E-03],
            [   6.0273566737212947E-01,  -7.2297561639723473E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,   7.2297561639723473E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [  -6.0273566737212947E-01,  -7.2297561639723473E-01,  -3.3766251401734260E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,   7.2297561639723473E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,   7.2297561639723473E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,  -7.2297561639723473E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,   7.2297561639723473E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,  -7.2297561639723473E-01,   6.0273566737212947E-01,   9.4711559471426267E-03],
            [   3.3766251401734260E-01,  -7.2297561639723473E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,   7.2297561639723473E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [  -3.3766251401734260E-01,  -7.2297561639723473E-01,  -6.0273566737212947E-01,   9.4711559471426267E-03],
            [   5.4960323202550965E-01,   2.8223013097279881E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,   2.8223013097279881E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,  -2.8223013097279881E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,   2.8223013097279881E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,  -2.8223013097279881E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,  -2.8223013097279881E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,   2.8223013097279881E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,  -2.8223013097279881E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,   5.4960323202550965E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,   5.4960323202550965E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,  -5.4960323202550965E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,   5.4960323202550965E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,  -5.4960323202550965E-01,   7.8630937964530889E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,  -5.4960323202550965E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,   5.4960323202550965E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,  -5.4960323202550965E-01,  -7.8630937964530889E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,   5.4960323202550965E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,   5.4960323202550965E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,  -5.4960323202550965E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,   5.4960323202550965E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,  -5.4960323202550965E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,  -5.4960323202550965E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,   5.4960323202550965E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,  -5.4960323202550965E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,   2.8223013097279881E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,   2.8223013097279881E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,  -2.8223013097279881E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,   2.8223013097279881E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,  -2.8223013097279881E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   7.8630937964530889E-01,  -2.8223013097279881E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,   2.8223013097279881E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -7.8630937964530889E-01,  -2.8223013097279881E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,   7.8630937964530889E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,   7.8630937964530889E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,  -7.8630937964530889E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,   7.8630937964530889E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,  -7.8630937964530889E-01,   2.8223013097279881E-01,   9.3902279381426774E-03],
            [   5.4960323202550965E-01,  -7.8630937964530889E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,   7.8630937964530889E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [  -5.4960323202550965E-01,  -7.8630937964530889E-01,  -2.8223013097279881E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,   7.8630937964530889E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,   7.8630937964530889E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,  -7.8630937964530889E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,   7.8630937964530889E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,  -7.8630937964530889E-01,   5.4960323202550965E-01,   9.3902279381426774E-03],
            [   2.8223013097279881E-01,  -7.8630937964530889E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,   7.8630937964530889E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [  -2.8223013097279881E-01,  -7.8630937964530889E-01,  -5.4960323202550965E-01,   9.3902279381426774E-03],
            [   4.9217077552345673E-01,   2.2486323425925400E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,   2.2486323425925400E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,  -2.2486323425925400E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,   2.2486323425925400E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,  -2.2486323425925400E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,  -2.2486323425925400E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,   2.2486323425925400E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,  -2.2486323425925400E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,   4.9217077552345673E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,   4.9217077552345673E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,  -4.9217077552345673E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,   4.9217077552345673E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,  -4.9217077552345673E-01,   8.4095448961231367E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,  -4.9217077552345673E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,   4.9217077552345673E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,  -4.9217077552345673E-01,  -8.4095448961231367E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,   4.9217077552345673E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,   4.9217077552345673E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,  -4.9217077552345673E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,   4.9217077552345673E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,  -4.9217077552345673E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,  -4.9217077552345673E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,   4.9217077552345673E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,  -4.9217077552345673E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,   2.2486323425925400E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,   2.2486323425925400E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,  -2.2486323425925400E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,   2.2486323425925400E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,  -2.2486323425925400E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   8.4095448961231367E-01,  -2.2486323425925400E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,   2.2486323425925400E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -8.4095448961231367E-01,  -2.2486323425925400E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,   8.4095448961231367E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,   8.4095448961231367E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,  -8.4095448961231367E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,   8.4095448961231367E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,  -8.4095448961231367E-01,   2.2486323425925400E-01,   9.2275074711815550E-03],
            [   4.9217077552345673E-01,  -8.4095448961231367E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,   8.4095448961231367E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [  -4.9217077552345673E-01,  -8.4095448961231367E-01,  -2.2486323425925400E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,   8.4095448961231367E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,   8.4095448961231367E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,  -8.4095448961231367E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,   8.4095448961231367E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,  -8.4095448961231367E-01,   4.9217077552345673E-01,   9.2275074711815550E-03],
            [   2.2486323425925400E-01,  -8.4095448961231367E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,   8.4095448961231367E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [  -2.2486323425925400E-01,  -8.4095448961231367E-01,  -4.9217077552345673E-01,   9.2275074711815550E-03],
            [   4.3094229985984828E-01,   1.6662247234564789E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,   1.6662247234564789E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,  -1.6662247234564789E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,   1.6662247234564789E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,  -1.6662247234564789E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,  -1.6662247234564789E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,   1.6662247234564789E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,  -1.6662247234564789E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,   4.3094229985984828E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,   4.3094229985984828E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,  -4.3094229985984828E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,   4.3094229985984828E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,  -4.3094229985984828E-01,   8.8686283375780750E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,  -4.3094229985984828E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,   4.3094229985984828E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,  -4.3094229985984828E-01,  -8.8686283375780750E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,   4.3094229985984828E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,   4.3094229985984828E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,  -4.3094229985984828E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,   4.3094229985984828E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,  -4.3094229985984828E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,  -4.3094229985984828E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,   4.3094229985984828E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,  -4.3094229985984828E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,   1.6662247234564789E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,   1.6662247234564789E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,  -1.6662247234564789E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,   1.6662247234564789E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,  -1.6662247234564789E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   8.8686283375780750E-01,  -1.6662247234564789E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,   1.6662247234564789E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -8.8686283375780750E-01,  -1.6662247234564789E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,   8.8686283375780750E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,   8.8686283375780750E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,  -8.8686283375780750E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,   8.8686283375780750E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,  -8.8686283375780750E-01,   1.6662247234564789E-01,   8.9609175105043546E-03],
            [   4.3094229985984828E-01,  -8.8686283375780750E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,   8.8686283375780750E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [  -4.3094229985984828E-01,  -8.8686283375780750E-01,  -1.6662247234564789E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,   8.8686283375780750E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,   8.8686283375780750E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,  -8.8686283375780750E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,   8.8686283375780750E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,  -8.8686283375780750E-01,   4.3094229985984828E-01,   8.9609175105043546E-03],
            [   1.6662247234564789E-01,  -8.8686283375780750E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,   8.8686283375780750E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [  -1.6662247234564789E-01,  -8.8686283375780750E-01,  -4.3094229985984828E-01,   8.9609175105043546E-03],
            [   3.6641081823136717E-01,   1.0869649018221690E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,   1.0869649018221690E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,  -1.0869649018221690E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,   1.0869649018221690E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,  -1.0869649018221690E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,  -1.0869649018221690E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,   1.0869649018221690E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,  -1.0869649018221690E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,   3.6641081823136717E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,   3.6641081823136717E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,  -3.6641081823136717E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,   3.6641081823136717E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,  -3.6641081823136717E-01,   9.2408234768611786E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,  -3.6641081823136717E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,   3.6641081823136717E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,  -3.6641081823136717E-01,  -9.2408234768611786E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,   3.6641081823136717E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,   3.6641081823136717E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,  -3.6641081823136717E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,   3.6641081823136717E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,  -3.6641081823136717E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,  -3.6641081823136717E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,   3.6641081823136717E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,  -3.6641081823136717E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,   1.0869649018221690E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,   1.0869649018221690E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,  -1.0869649018221690E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,   1.0869649018221690E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,  -1.0869649018221690E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   9.2408234768611786E-01,  -1.0869649018221690E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,   1.0869649018221690E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -9.2408234768611786E-01,  -1.0869649018221690E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,   9.2408234768611786E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,   9.2408234768611786E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,  -9.2408234768611786E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,   9.2408234768611786E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,  -9.2408234768611786E-01,   1.0869649018221690E-01,   8.5665225341781046E-03],
            [   3.6641081823136717E-01,  -9.2408234768611786E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,   9.2408234768611786E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [  -3.6641081823136717E-01,  -9.2408234768611786E-01,  -1.0869649018221690E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,   9.2408234768611786E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,   9.2408234768611786E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,  -9.2408234768611786E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,   9.2408234768611786E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,  -9.2408234768611786E-01,   3.6641081823136717E-01,   8.5665225341781046E-03],
            [   1.0869649018221690E-01,  -9.2408234768611786E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,   9.2408234768611786E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [  -1.0869649018221690E-01,  -9.2408234768611786E-01,  -3.6641081823136717E-01,   8.5665225341781046E-03],
            [   2.9901890577584361E-01,   5.2519897841200848E-02,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,   5.2519897841200848E-02,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,  -5.2519897841200848E-02,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,   5.2519897841200848E-02,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,  -5.2519897841200848E-02,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,  -5.2519897841200848E-02,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,   5.2519897841200848E-02,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,  -5.2519897841200848E-02,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,   2.9901890577584361E-01,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,   2.9901890577584361E-01,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,  -2.9901890577584361E-01,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,   2.9901890577584361E-01,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,  -2.9901890577584361E-01,   9.5280079466768230E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,  -2.9901890577584361E-01,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,   2.9901890577584361E-01,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,  -2.9901890577584361E-01,  -9.5280079466768230E-01,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,   2.9901890577584361E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,   2.9901890577584361E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,  -2.9901890577584361E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,   2.9901890577584361E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,  -2.9901890577584361E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,  -2.9901890577584361E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,   2.9901890577584361E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,  -2.9901890577584361E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,   5.2519897841200848E-02,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,   5.2519897841200848E-02,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,  -5.2519897841200848E-02,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,   5.2519897841200848E-02,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,  -5.2519897841200848E-02,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   9.5280079466768230E-01,  -5.2519897841200848E-02,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,   5.2519897841200848E-02,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -9.5280079466768230E-01,  -5.2519897841200848E-02,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,   9.5280079466768230E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,   9.5280079466768230E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,  -9.5280079466768230E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,   9.5280079466768230E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,  -9.5280079466768230E-01,   5.2519897841200848E-02,   8.0185271304074983E-03],
            [   2.9901890577584361E-01,  -9.5280079466768230E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,   9.5280079466768230E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [  -2.9901890577584361E-01,  -9.5280079466768230E-01,  -5.2519897841200848E-02,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,   9.5280079466768230E-01,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,   9.5280079466768230E-01,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,  -9.5280079466768230E-01,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,   9.5280079466768230E-01,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,  -9.5280079466768230E-01,   2.9901890577584361E-01,   8.0185271304074983E-03],
            [   5.2519897841200848E-02,  -9.5280079466768230E-01,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,   9.5280079466768230E-01,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [  -5.2519897841200848E-02,  -9.5280079466768230E-01,  -2.9901890577584361E-01,   8.0185271304074983E-03],
            [   6.2687240131449984E-01,   2.2975236575500230E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,   2.2975236575500230E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,  -2.2975236575500230E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,   2.2975236575500230E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,  -2.2975236575500230E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,  -2.2975236575500230E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,   2.2975236575500230E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,  -2.2975236575500230E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,   6.2687240131449984E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,   6.2687240131449984E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,  -6.2687240131449984E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,   6.2687240131449984E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,  -6.2687240131449984E-01,   7.4447622050685558E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,  -6.2687240131449984E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,   6.2687240131449984E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,  -6.2687240131449984E-01,  -7.4447622050685558E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,   6.2687240131449984E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,   6.2687240131449984E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,  -6.2687240131449984E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,   6.2687240131449984E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,  -6.2687240131449984E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,  -6.2687240131449984E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,   6.2687240131449984E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,  -6.2687240131449984E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,   2.2975236575500230E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,   2.2975236575500230E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,  -2.2975236575500230E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,   2.2975236575500230E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,  -2.2975236575500230E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   7.4447622050685558E-01,  -2.2975236575500230E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,   2.2975236575500230E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -7.4447622050685558E-01,  -2.2975236575500230E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,   7.4447622050685558E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,   7.4447622050685558E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,  -7.4447622050685558E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,   7.4447622050685558E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,  -7.4447622050685558E-01,   2.2975236575500230E-01,   9.4880890674702498E-03],
            [   6.2687240131449984E-01,  -7.4447622050685558E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,   7.4447622050685558E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [  -6.2687240131449984E-01,  -7.4447622050685558E-01,  -2.2975236575500230E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,   7.4447622050685558E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,   7.4447622050685558E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,  -7.4447622050685558E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,   7.4447622050685558E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,  -7.4447622050685558E-01,   6.2687240131449984E-01,   9.4880890674702498E-03],
            [   2.2975236575500230E-01,  -7.4447622050685558E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,   7.4447622050685558E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [  -2.2975236575500230E-01,  -7.4447622050685558E-01,  -6.2687240131449984E-01,   9.4880890674702498E-03],
            [   5.7073241448346068E-01,   1.7230806070938001E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,   1.7230806070938001E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,  -1.7230806070938001E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,   1.7230806070938001E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,  -1.7230806070938001E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,  -1.7230806070938001E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,   1.7230806070938001E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,  -1.7230806070938001E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,   5.7073241448346068E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,   5.7073241448346068E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,  -5.7073241448346068E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,   5.7073241448346068E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,  -5.7073241448346068E-01,   8.0285393644949632E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,  -5.7073241448346068E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,   5.7073241448346068E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,  -5.7073241448346068E-01,  -8.0285393644949632E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,   5.7073241448346068E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,   5.7073241448346068E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,  -5.7073241448346068E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,   5.7073241448346068E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,  -5.7073241448346068E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,  -5.7073241448346068E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,   5.7073241448346068E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,  -5.7073241448346068E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,   1.7230806070938001E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,   1.7230806070938001E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,  -1.7230806070938001E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,   1.7230806070938001E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,  -1.7230806070938001E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   8.0285393644949632E-01,  -1.7230806070938001E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,   1.7230806070938001E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -8.0285393644949632E-01,  -1.7230806070938001E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,   8.0285393644949632E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,   8.0285393644949632E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,  -8.0285393644949632E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,   8.0285393644949632E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,  -8.0285393644949632E-01,   1.7230806070938001E-01,   9.3979445373891593E-03],
            [   5.7073241448346068E-01,  -8.0285393644949632E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,   8.0285393644949632E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [  -5.7073241448346068E-01,  -8.0285393644949632E-01,  -1.7230806070938001E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,   8.0285393644949632E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,   8.0285393644949632E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,  -8.0285393644949632E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,   8.0285393644949632E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,  -8.0285393644949632E-01,   5.7073241448346068E-01,   9.3979445373891593E-03],
            [   1.7230806070938001E-01,  -8.0285393644949632E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,   8.0285393644949632E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [  -1.7230806070938001E-01,  -8.0285393644949632E-01,  -5.7073241448346068E-01,   9.3979445373891593E-03],
            [   5.0963609019603651E-01,   1.1402384653905130E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,   1.1402384653905130E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,  -1.1402384653905130E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,   1.1402384653905130E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,  -1.1402384653905130E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,  -1.1402384653905130E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,   1.1402384653905130E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,  -1.1402384653905130E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,   5.0963609019603651E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,   5.0963609019603651E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,  -5.0963609019603651E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,   5.0963609019603651E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,  -5.0963609019603651E-01,   8.5280104244198507E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,  -5.0963609019603651E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,   5.0963609019603651E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,  -5.0963609019603651E-01,  -8.5280104244198507E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,   5.0963609019603651E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,   5.0963609019603651E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,  -5.0963609019603651E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,   5.0963609019603651E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,  -5.0963609019603651E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,  -5.0963609019603651E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,   5.0963609019603651E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,  -5.0963609019603651E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,   1.1402384653905130E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,   1.1402384653905130E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,  -1.1402384653905130E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,   1.1402384653905130E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,  -1.1402384653905130E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   8.5280104244198507E-01,  -1.1402384653905130E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,   1.1402384653905130E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -8.5280104244198507E-01,  -1.1402384653905130E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,   8.5280104244198507E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,   8.5280104244198507E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,  -8.5280104244198507E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,   8.5280104244198507E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,  -8.5280104244198507E-01,   1.1402384653905130E-01,   9.2185873439890511E-03],
            [   5.0963609019603651E-01,  -8.5280104244198507E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,   8.5280104244198507E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [  -5.0963609019603651E-01,  -8.5280104244198507E-01,  -1.1402384653905130E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,   8.5280104244198507E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,   8.5280104244198507E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,  -8.5280104244198507E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,   8.5280104244198507E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,  -8.5280104244198507E-01,   5.0963609019603651E-01,   9.2185873439890511E-03],
            [   1.1402384653905130E-01,  -8.5280104244198507E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,   8.5280104244198507E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [  -1.1402384653905130E-01,  -8.5280104244198507E-01,  -5.0963609019603651E-01,   9.2185873439890511E-03],
            [   4.4387299383124562E-01,   5.6115220958825367E-02,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,   5.6115220958825367E-02,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,   5.6115220958825367E-02,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,  -5.6115220958825367E-02,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,   5.6115220958825367E-02,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,  -5.6115220958825367E-02,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,   4.4387299383124562E-01,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,   4.4387299383124562E-01,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,   4.4387299383124562E-01,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9433094955057280E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,  -4.4387299383124562E-01,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,   4.4387299383124562E-01,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,  -4.4387299383124562E-01,  -8.9433094955057280E-01,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,   4.4387299383124562E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,   4.4387299383124562E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,  -4.4387299383124562E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,   4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,  -4.4387299383124562E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,  -4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,   4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,  -4.4387299383124562E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,   5.6115220958825367E-02,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,   5.6115220958825367E-02,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,  -5.6115220958825367E-02,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,   5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,  -5.6115220958825367E-02,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   8.9433094955057280E-01,  -5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,   5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -8.9433094955057280E-01,  -5.6115220958825367E-02,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,   8.9433094955057280E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,   8.9433094955057280E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,  -8.9433094955057280E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,   8.9433094955057280E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,  -8.9433094955057280E-01,   5.6115220958825367E-02,   8.9348409663314917E-03],
            [   4.4387299383124562E-01,  -8.9433094955057280E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,   8.9433094955057280E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [  -4.4387299383124562E-01,  -8.9433094955057280E-01,  -5.6115220958825367E-02,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,   8.9433094955057280E-01,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,   8.9433094955057280E-01,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,  -8.9433094955057280E-01,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,   8.9433094955057280E-01,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,  -8.9433094955057280E-01,   4.4387299383124562E-01,   8.9348409663314917E-03],
            [   5.6115220958825367E-02,  -8.9433094955057280E-01,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,   8.9433094955057280E-01,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [  -5.6115220958825367E-02,  -8.9433094955057280E-01,  -4.4387299383124562E-01,   8.9348409663314917E-03],
            [   6.4199784710823893E-01,   1.1641744231408729E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,   1.1641744231408729E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,  -1.1641744231408729E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,   1.1641744231408729E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,  -1.1641744231408729E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,  -1.1641744231408729E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,   1.1641744231408729E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,  -1.1641744231408729E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,   6.4199784710823893E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,   6.4199784710823893E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,  -6.4199784710823893E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,   6.4199784710823893E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,  -6.4199784710823893E-01,   7.5781643122423281E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,  -6.4199784710823893E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,   6.4199784710823893E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,  -6.4199784710823893E-01,  -7.5781643122423281E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,   6.4199784710823893E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,   6.4199784710823893E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,  -6.4199784710823893E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,   6.4199784710823893E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,  -6.4199784710823893E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,  -6.4199784710823893E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,   6.4199784710823893E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,  -6.4199784710823893E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,   1.1641744231408729E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,   1.1641744231408729E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,  -1.1641744231408729E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,   1.1641744231408729E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,  -1.1641744231408729E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   7.5781643122423281E-01,  -1.1641744231408729E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,   1.1641744231408729E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -7.5781643122423281E-01,  -1.1641744231408729E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,   7.5781643122423281E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,   7.5781643122423281E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,  -7.5781643122423281E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,   7.5781643122423281E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,  -7.5781643122423281E-01,   1.1641744231408729E-01,   9.5144565812421283E-03],
            [   6.4199784710823893E-01,  -7.5781643122423281E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,   7.5781643122423281E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [  -6.4199784710823893E-01,  -7.5781643122423281E-01,  -1.1641744231408729E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,   7.5781643122423281E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,   7.5781643122423281E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,  -7.5781643122423281E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,   7.5781643122423281E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,  -7.5781643122423281E-01,   6.4199784710823893E-01,   9.5144565812421283E-03],
            [   1.1641744231408729E-01,  -7.5781643122423281E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,   7.5781643122423281E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [  -1.1641744231408729E-01,  -7.5781643122423281E-01,  -6.4199784710823893E-01,   9.5144565812421283E-03],
            [   5.8172180618026115E-01,   5.7975895314452193E-02,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,   5.7975895314452193E-02,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,  -5.7975895314452193E-02,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,   5.7975895314452193E-02,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,  -5.7975895314452193E-02,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,  -5.7975895314452193E-02,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,   5.7975895314452193E-02,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,  -5.7975895314452193E-02,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,   5.8172180618026115E-01,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,   5.8172180618026115E-01,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,  -5.8172180618026115E-01,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,   5.8172180618026115E-01,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,  -5.8172180618026115E-01,   8.1131900987026206E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,  -5.8172180618026115E-01,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,   5.8172180618026115E-01,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,  -5.8172180618026115E-01,  -8.1131900987026206E-01,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,   5.8172180618026115E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,   5.8172180618026115E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,  -5.8172180618026115E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,   5.8172180618026115E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,  -5.8172180618026115E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,  -5.8172180618026115E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,   5.8172180618026115E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,  -5.8172180618026115E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,   5.7975895314452193E-02,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,   5.7975895314452193E-02,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,  -5.7975895314452193E-02,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,   5.7975895314452193E-02,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,  -5.7975895314452193E-02,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   8.1131900987026206E-01,  -5.7975895314452193E-02,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,   5.7975895314452193E-02,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -8.1131900987026206E-01,  -5.7975895314452193E-02,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,   8.1131900987026206E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,   8.1131900987026206E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,  -8.1131900987026206E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,   8.1131900987026206E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,  -8.1131900987026206E-01,   5.7975895314452193E-02,   9.4120963930785298E-03],
            [   5.8172180618026115E-01,  -8.1131900987026206E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,   8.1131900987026206E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [  -5.8172180618026115E-01,  -8.1131900987026206E-01,  -5.7975895314452193E-02,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,   8.1131900987026206E-01,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,   8.1131900987026206E-01,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,  -8.1131900987026206E-01,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,   8.1131900987026206E-01,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,  -8.1131900987026206E-01,   5.8172180618026115E-01,   9.4120963930785298E-03],
            [   5.7975895314452193E-02,  -8.1131900987026206E-01,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,   8.1131900987026206E-01,  -5.8172180618026115E-01,   9.4120963930785298E-03],
            [  -5.7975895314452193E-02,  -8.1131900987026206E-01,  -5.8172180618026115E-01,   9.4120963930785298E-03],
        ])
  
        order = 65
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build1730():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   7.9281853454946224E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   7.9281853454946224E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   7.9281853454946224E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   7.9281853454946224E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   7.9281853454946224E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   7.9281853454946224E-04],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   8.0403254605512387E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   8.0403254605512387E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   8.0403254605512387E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   8.0403254605512387E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   8.0403254605512387E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   8.0403254605512387E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   8.0403254605512387E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   8.0403254605512387E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   8.0403254605512387E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   8.0403254605512387E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   8.0403254605512387E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   8.0403254605512387E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   7.9886743698059197E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   7.9886743698059197E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   7.9886743698059197E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   7.9886743698059197E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   7.9886743698059197E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   7.9886743698059197E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   7.9886743698059197E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   7.9886743698059197E-03],
            [   2.8609231261946620E-02,   2.8609231261946620E-02,   9.9918117665076189E-01,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,   2.8609231261946620E-02,   9.9918117665076189E-01,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,  -2.8609231261946620E-02,   9.9918117665076189E-01,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,   2.8609231261946620E-02,  -9.9918117665076189E-01,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,  -2.8609231261946620E-02,   9.9918117665076189E-01,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,   2.8609231261946620E-02,  -9.9918117665076189E-01,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,  -2.8609231261946620E-02,  -9.9918117665076189E-01,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,  -2.8609231261946620E-02,  -9.9918117665076189E-01,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,   9.9918117665076189E-01,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,  -9.9918117665076189E-01,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,   9.9918117665076189E-01,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,  -9.9918117665076189E-01,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,   9.9918117665076189E-01,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,  -9.9918117665076189E-01,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -2.8609231261946620E-02,  -9.9918117665076189E-01,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [   2.8609231261946620E-02,   9.9918117665076189E-01,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [   9.9918117665076189E-01,   2.8609231261946620E-02,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -9.9918117665076189E-01,   2.8609231261946620E-02,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [   9.9918117665076189E-01,  -2.8609231261946620E-02,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [   9.9918117665076189E-01,   2.8609231261946620E-02,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -9.9918117665076189E-01,  -2.8609231261946620E-02,   2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -9.9918117665076189E-01,   2.8609231261946620E-02,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [   9.9918117665076189E-01,  -2.8609231261946620E-02,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [  -9.9918117665076189E-01,  -2.8609231261946620E-02,  -2.8609231261946620E-02,   2.7912512411325525E-03],
            [   7.1425567677115220E-02,   7.1425567677115220E-02,   9.9488530824613330E-01,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,   7.1425567677115220E-02,   9.9488530824613330E-01,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,  -7.1425567677115220E-02,   9.9488530824613330E-01,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,   7.1425567677115220E-02,  -9.9488530824613330E-01,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,  -7.1425567677115220E-02,   9.9488530824613330E-01,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,   7.1425567677115220E-02,  -9.9488530824613330E-01,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,  -7.1425567677115220E-02,  -9.9488530824613330E-01,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,  -7.1425567677115220E-02,  -9.9488530824613330E-01,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,   9.9488530824613330E-01,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,  -9.9488530824613330E-01,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,   9.9488530824613330E-01,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,  -9.9488530824613330E-01,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,   9.9488530824613330E-01,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,  -9.9488530824613330E-01,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -7.1425567677115220E-02,  -9.9488530824613330E-01,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [   7.1425567677115220E-02,   9.9488530824613330E-01,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [   9.9488530824613330E-01,   7.1425567677115220E-02,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -9.9488530824613330E-01,   7.1425567677115220E-02,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [   9.9488530824613330E-01,  -7.1425567677115220E-02,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [   9.9488530824613330E-01,   7.1425567677115220E-02,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -9.9488530824613330E-01,  -7.1425567677115220E-02,   7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -9.9488530824613330E-01,   7.1425567677115220E-02,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [   9.9488530824613330E-01,  -7.1425567677115220E-02,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [  -9.9488530824613330E-01,  -7.1425567677115220E-02,  -7.1425567677115220E-02,   4.3677990199524576E-03],
            [   1.2091995409955590E-01,   1.2091995409955590E-01,   9.8526987643037300E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,   1.2091995409955590E-01,   9.8526987643037300E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,  -1.2091995409955590E-01,   9.8526987643037300E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,   1.2091995409955590E-01,  -9.8526987643037300E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,  -1.2091995409955590E-01,   9.8526987643037300E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,   1.2091995409955590E-01,  -9.8526987643037300E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,  -1.2091995409955590E-01,  -9.8526987643037300E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,  -1.2091995409955590E-01,  -9.8526987643037300E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,   9.8526987643037300E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,  -9.8526987643037300E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,   9.8526987643037300E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,  -9.8526987643037300E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,   9.8526987643037300E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,  -9.8526987643037300E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -1.2091995409955590E-01,  -9.8526987643037300E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [   1.2091995409955590E-01,   9.8526987643037300E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [   9.8526987643037300E-01,   1.2091995409955590E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -9.8526987643037300E-01,   1.2091995409955590E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [   9.8526987643037300E-01,  -1.2091995409955590E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [   9.8526987643037300E-01,   1.2091995409955590E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -9.8526987643037300E-01,  -1.2091995409955590E-01,   1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -9.8526987643037300E-01,   1.2091995409955590E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [   9.8526987643037300E-01,  -1.2091995409955590E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [  -9.8526987643037300E-01,  -1.2091995409955590E-01,  -1.2091995409955590E-01,   5.4673041993772136E-03],
            [   1.7386731065943789E-01,   1.7386731065943789E-01,   9.6929887886456823E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,   1.7386731065943789E-01,   9.6929887886456823E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,  -1.7386731065943789E-01,   9.6929887886456823E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,   1.7386731065943789E-01,  -9.6929887886456823E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,  -1.7386731065943789E-01,   9.6929887886456823E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,   1.7386731065943789E-01,  -9.6929887886456823E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,  -1.7386731065943789E-01,  -9.6929887886456823E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,  -1.7386731065943789E-01,  -9.6929887886456823E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,   9.6929887886456823E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,  -9.6929887886456823E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,   9.6929887886456823E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,  -9.6929887886456823E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,   9.6929887886456823E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,  -9.6929887886456823E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -1.7386731065943789E-01,  -9.6929887886456823E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [   1.7386731065943789E-01,   9.6929887886456823E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [   9.6929887886456823E-01,   1.7386731065943789E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -9.6929887886456823E-01,   1.7386731065943789E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [   9.6929887886456823E-01,  -1.7386731065943789E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [   9.6929887886456823E-01,   1.7386731065943789E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -9.6929887886456823E-01,  -1.7386731065943789E-01,   1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -9.6929887886456823E-01,   1.7386731065943789E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [   9.6929887886456823E-01,  -1.7386731065943789E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [  -9.6929887886456823E-01,  -1.7386731065943789E-01,  -1.7386731065943789E-01,   6.2562544898747173E-03],
            [   2.2846454384677339E-01,   2.2846454384677339E-01,   9.4636562934722623E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,   2.2846454384677339E-01,   9.4636562934722623E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,  -2.2846454384677339E-01,   9.4636562934722623E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,   2.2846454384677339E-01,  -9.4636562934722623E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,  -2.2846454384677339E-01,   9.4636562934722623E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,   2.2846454384677339E-01,  -9.4636562934722623E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,  -2.2846454384677339E-01,  -9.4636562934722623E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,  -2.2846454384677339E-01,  -9.4636562934722623E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,   9.4636562934722623E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,  -9.4636562934722623E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,   9.4636562934722623E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,  -9.4636562934722623E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,   9.4636562934722623E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,  -9.4636562934722623E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -2.2846454384677339E-01,  -9.4636562934722623E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [   2.2846454384677339E-01,   9.4636562934722623E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [   9.4636562934722623E-01,   2.2846454384677339E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -9.4636562934722623E-01,   2.2846454384677339E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [   9.4636562934722623E-01,  -2.2846454384677339E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [   9.4636562934722623E-01,   2.2846454384677339E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -9.4636562934722623E-01,  -2.2846454384677339E-01,   2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -9.4636562934722623E-01,   2.2846454384677339E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [   9.4636562934722623E-01,  -2.2846454384677339E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [  -9.4636562934722623E-01,  -2.2846454384677339E-01,  -2.2846454384677339E-01,   6.8298679468094033E-03],
            [   2.8348076717015119E-01,   2.8348076717015119E-01,   9.1612079404914992E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,   2.8348076717015119E-01,   9.1612079404914992E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,  -2.8348076717015119E-01,   9.1612079404914992E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,   2.8348076717015119E-01,  -9.1612079404914992E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,  -2.8348076717015119E-01,   9.1612079404914992E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,   2.8348076717015119E-01,  -9.1612079404914992E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,  -2.8348076717015119E-01,  -9.1612079404914992E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,  -2.8348076717015119E-01,  -9.1612079404914992E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,   9.1612079404914992E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,  -9.1612079404914992E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,   9.1612079404914992E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,  -9.1612079404914992E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,   9.1612079404914992E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,  -9.1612079404914992E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -2.8348076717015119E-01,  -9.1612079404914992E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [   2.8348076717015119E-01,   9.1612079404914992E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [   9.1612079404914992E-01,   2.8348076717015119E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -9.1612079404914992E-01,   2.8348076717015119E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [   9.1612079404914992E-01,  -2.8348076717015119E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [   9.1612079404914992E-01,   2.8348076717015119E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -9.1612079404914992E-01,  -2.8348076717015119E-01,   2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -9.1612079404914992E-01,   2.8348076717015119E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [   9.1612079404914992E-01,  -2.8348076717015119E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [  -9.1612079404914992E-01,  -2.8348076717015119E-01,  -2.8348076717015119E-01,   7.2456604566662189E-03],
            [   3.3796801454673392E-01,   3.3796801454673392E-01,   8.7838217325186951E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,   3.3796801454673392E-01,   8.7838217325186951E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,  -3.3796801454673392E-01,   8.7838217325186951E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,   3.3796801454673392E-01,  -8.7838217325186951E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,  -3.3796801454673392E-01,   8.7838217325186951E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,   3.3796801454673392E-01,  -8.7838217325186951E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,  -3.3796801454673392E-01,  -8.7838217325186951E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,  -3.3796801454673392E-01,  -8.7838217325186951E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,   8.7838217325186951E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,  -8.7838217325186951E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,   8.7838217325186951E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,  -8.7838217325186951E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,   8.7838217325186951E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,  -8.7838217325186951E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -3.3796801454673392E-01,  -8.7838217325186951E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [   3.3796801454673392E-01,   8.7838217325186951E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [   8.7838217325186951E-01,   3.3796801454673392E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -8.7838217325186951E-01,   3.3796801454673392E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [   8.7838217325186951E-01,  -3.3796801454673392E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [   8.7838217325186951E-01,   3.3796801454673392E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -8.7838217325186951E-01,  -3.3796801454673392E-01,   3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -8.7838217325186951E-01,   3.3796801454673392E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [   8.7838217325186951E-01,  -3.3796801454673392E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [  -8.7838217325186951E-01,  -3.3796801454673392E-01,  -3.3796801454673392E-01,   7.5413307845059348E-03],
            [   3.9113554548195367E-01,   3.9113554548195367E-01,   8.3308221090182277E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,   3.9113554548195367E-01,   8.3308221090182277E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,  -3.9113554548195367E-01,   8.3308221090182277E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,   3.9113554548195367E-01,  -8.3308221090182277E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,  -3.9113554548195367E-01,   8.3308221090182277E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,   3.9113554548195367E-01,  -8.3308221090182277E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,  -3.9113554548195367E-01,  -8.3308221090182277E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,  -3.9113554548195367E-01,  -8.3308221090182277E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,   8.3308221090182277E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,  -8.3308221090182277E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,   8.3308221090182277E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,  -8.3308221090182277E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,   8.3308221090182277E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,  -8.3308221090182277E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -3.9113554548195367E-01,  -8.3308221090182277E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [   3.9113554548195367E-01,   8.3308221090182277E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [   8.3308221090182277E-01,   3.9113554548195367E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -8.3308221090182277E-01,   3.9113554548195367E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [   8.3308221090182277E-01,  -3.9113554548195367E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [   8.3308221090182277E-01,   3.9113554548195367E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -8.3308221090182277E-01,  -3.9113554548195367E-01,   3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -8.3308221090182277E-01,   3.9113554548195367E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [   8.3308221090182277E-01,  -3.9113554548195367E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [  -8.3308221090182277E-01,  -3.9113554548195367E-01,  -3.9113554548195367E-01,   7.7436214710082845E-03],
            [   4.4228603530014032E-01,   4.4228603530014032E-01,   7.8023466082773207E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,   4.4228603530014032E-01,   7.8023466082773207E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8023466082773207E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,   4.4228603530014032E-01,  -7.8023466082773207E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8023466082773207E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,   4.4228603530014032E-01,  -7.8023466082773207E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,  -4.4228603530014032E-01,  -7.8023466082773207E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,  -4.4228603530014032E-01,  -7.8023466082773207E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,   7.8023466082773207E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,  -7.8023466082773207E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,   7.8023466082773207E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,  -7.8023466082773207E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,   7.8023466082773207E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,  -7.8023466082773207E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -4.4228603530014032E-01,  -7.8023466082773207E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [   4.4228603530014032E-01,   7.8023466082773207E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [   7.8023466082773207E-01,   4.4228603530014032E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -7.8023466082773207E-01,   4.4228603530014032E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [   7.8023466082773207E-01,  -4.4228603530014032E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [   7.8023466082773207E-01,   4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -7.8023466082773207E-01,  -4.4228603530014032E-01,   4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -7.8023466082773207E-01,   4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [   7.8023466082773207E-01,  -4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [  -7.8023466082773207E-01,  -4.4228603530014032E-01,  -4.4228603530014032E-01,   7.8731053283352635E-03],
            [   4.9077815687260568E-01,   4.9077815687260568E-01,   7.1991221789427640E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,   4.9077815687260568E-01,   7.1991221789427640E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,  -4.9077815687260568E-01,   7.1991221789427640E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,   4.9077815687260568E-01,  -7.1991221789427640E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,  -4.9077815687260568E-01,   7.1991221789427640E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,   4.9077815687260568E-01,  -7.1991221789427640E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,  -4.9077815687260568E-01,  -7.1991221789427640E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,  -4.9077815687260568E-01,  -7.1991221789427640E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,   7.1991221789427640E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,  -7.1991221789427640E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,   7.1991221789427640E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,  -7.1991221789427640E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,   7.1991221789427640E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,  -7.1991221789427640E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -4.9077815687260568E-01,  -7.1991221789427640E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [   4.9077815687260568E-01,   7.1991221789427640E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [   7.1991221789427640E-01,   4.9077815687260568E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -7.1991221789427640E-01,   4.9077815687260568E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [   7.1991221789427640E-01,  -4.9077815687260568E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [   7.1991221789427640E-01,   4.9077815687260568E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -7.1991221789427640E-01,  -4.9077815687260568E-01,   4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -7.1991221789427640E-01,   4.9077815687260568E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [   7.1991221789427640E-01,  -4.9077815687260568E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [  -7.1991221789427640E-01,  -4.9077815687260568E-01,  -4.9077815687260568E-01,   7.9469566425251024E-03],
            [   5.3600061532114684E-01,   5.3600061532114684E-01,   6.5223207583704734E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,   5.3600061532114684E-01,   6.5223207583704734E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,  -5.3600061532114684E-01,   6.5223207583704734E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,   5.3600061532114684E-01,  -6.5223207583704734E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,  -5.3600061532114684E-01,   6.5223207583704734E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,   5.3600061532114684E-01,  -6.5223207583704734E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,  -5.3600061532114684E-01,  -6.5223207583704734E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,  -5.3600061532114684E-01,  -6.5223207583704734E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,   6.5223207583704734E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,  -6.5223207583704734E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,   6.5223207583704734E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,  -6.5223207583704734E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,   6.5223207583704734E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,  -6.5223207583704734E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -5.3600061532114684E-01,  -6.5223207583704734E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [   5.3600061532114684E-01,   6.5223207583704734E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [   6.5223207583704734E-01,   5.3600061532114684E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -6.5223207583704734E-01,   5.3600061532114684E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [   6.5223207583704734E-01,  -5.3600061532114684E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [   6.5223207583704734E-01,   5.3600061532114684E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -6.5223207583704734E-01,  -5.3600061532114684E-01,   5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -6.5223207583704734E-01,   5.3600061532114684E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [   6.5223207583704734E-01,  -5.3600061532114684E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [  -6.5223207583704734E-01,  -5.3600061532114684E-01,  -5.3600061532114684E-01,   7.9806102508216351E-03],
            [   6.1421059735966033E-01,   6.1421059735966033E-01,   4.9547016477501293E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,   6.1421059735966033E-01,   4.9547016477501293E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,  -6.1421059735966033E-01,   4.9547016477501293E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,   6.1421059735966033E-01,  -4.9547016477501293E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,  -6.1421059735966033E-01,   4.9547016477501293E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,   6.1421059735966033E-01,  -4.9547016477501293E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,  -6.1421059735966033E-01,  -4.9547016477501293E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,  -6.1421059735966033E-01,  -4.9547016477501293E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,   4.9547016477501293E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,  -4.9547016477501293E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,   4.9547016477501293E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,  -4.9547016477501293E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,   4.9547016477501293E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,  -4.9547016477501293E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -6.1421059735966033E-01,  -4.9547016477501293E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [   6.1421059735966033E-01,   4.9547016477501293E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [   4.9547016477501293E-01,   6.1421059735966033E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -4.9547016477501293E-01,   6.1421059735966033E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [   4.9547016477501293E-01,  -6.1421059735966033E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [   4.9547016477501293E-01,   6.1421059735966033E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -4.9547016477501293E-01,  -6.1421059735966033E-01,   6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -4.9547016477501293E-01,   6.1421059735966033E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [   4.9547016477501293E-01,  -6.1421059735966033E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [  -4.9547016477501293E-01,  -6.1421059735966033E-01,  -6.1421059735966033E-01,   7.9851277652471363E-03],
            [   6.4593003879775035E-01,   6.4593003879775035E-01,   4.0687684863785684E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,   6.4593003879775035E-01,   4.0687684863785684E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,  -6.4593003879775035E-01,   4.0687684863785684E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,   6.4593003879775035E-01,  -4.0687684863785684E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,  -6.4593003879775035E-01,   4.0687684863785684E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,   6.4593003879775035E-01,  -4.0687684863785684E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,  -6.4593003879775035E-01,  -4.0687684863785684E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,  -6.4593003879775035E-01,  -4.0687684863785684E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,   4.0687684863785684E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,  -4.0687684863785684E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,   4.0687684863785684E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,  -4.0687684863785684E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,   4.0687684863785684E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,  -4.0687684863785684E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -6.4593003879775035E-01,  -4.0687684863785684E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [   6.4593003879775035E-01,   4.0687684863785684E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [   4.0687684863785684E-01,   6.4593003879775035E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -4.0687684863785684E-01,   6.4593003879775035E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [   4.0687684863785684E-01,  -6.4593003879775035E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [   4.0687684863785684E-01,   6.4593003879775035E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -4.0687684863785684E-01,  -6.4593003879775035E-01,   6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -4.0687684863785684E-01,   6.4593003879775035E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [   4.0687684863785684E-01,  -6.4593003879775035E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [  -4.0687684863785684E-01,  -6.4593003879775035E-01,  -6.4593003879775035E-01,   7.9825387000873049E-03],
            [   6.7180561250892246E-01,   6.7180561250892246E-01,   3.1201672712055523E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,   6.7180561250892246E-01,   3.1201672712055523E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,  -6.7180561250892246E-01,   3.1201672712055523E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,   6.7180561250892246E-01,  -3.1201672712055523E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,  -6.7180561250892246E-01,   3.1201672712055523E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,   6.7180561250892246E-01,  -3.1201672712055523E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,  -6.7180561250892246E-01,  -3.1201672712055523E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,  -6.7180561250892246E-01,  -3.1201672712055523E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,   3.1201672712055523E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,  -3.1201672712055523E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,   3.1201672712055523E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,  -3.1201672712055523E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,   3.1201672712055523E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,  -3.1201672712055523E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -6.7180561250892246E-01,  -3.1201672712055523E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [   6.7180561250892246E-01,   3.1201672712055523E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [   3.1201672712055523E-01,   6.7180561250892246E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -3.1201672712055523E-01,   6.7180561250892246E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [   3.1201672712055523E-01,  -6.7180561250892246E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [   3.1201672712055523E-01,   6.7180561250892246E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -3.1201672712055523E-01,  -6.7180561250892246E-01,   6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -3.1201672712055523E-01,   6.7180561250892246E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [   3.1201672712055523E-01,  -6.7180561250892246E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [  -3.1201672712055523E-01,  -6.7180561250892246E-01,  -6.7180561250892246E-01,   7.9898465707682401E-03],
            [   6.9108885331862535E-01,   6.9108885331862535E-01,   2.1164213577994129E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,   6.9108885331862535E-01,   2.1164213577994129E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,  -6.9108885331862535E-01,   2.1164213577994129E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,   6.9108885331862535E-01,  -2.1164213577994129E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,  -6.9108885331862535E-01,   2.1164213577994129E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,   6.9108885331862535E-01,  -2.1164213577994129E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,  -6.9108885331862535E-01,  -2.1164213577994129E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,  -6.9108885331862535E-01,  -2.1164213577994129E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,   2.1164213577994129E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,  -2.1164213577994129E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,   2.1164213577994129E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,  -2.1164213577994129E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,   2.1164213577994129E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,  -2.1164213577994129E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -6.9108885331862535E-01,  -2.1164213577994129E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [   6.9108885331862535E-01,   2.1164213577994129E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [   2.1164213577994129E-01,   6.9108885331862535E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -2.1164213577994129E-01,   6.9108885331862535E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [   2.1164213577994129E-01,  -6.9108885331862535E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [   2.1164213577994129E-01,   6.9108885331862535E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -2.1164213577994129E-01,  -6.9108885331862535E-01,   6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -2.1164213577994129E-01,   6.9108885331862535E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [   2.1164213577994129E-01,  -6.9108885331862535E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [  -2.1164213577994129E-01,  -6.9108885331862535E-01,  -6.9108885331862535E-01,   8.0086756546798761E-03],
            [   7.0304674168232517E-01,   7.0304674168232517E-01,   1.0700728021836615E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,   7.0304674168232517E-01,   1.0700728021836615E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,  -7.0304674168232517E-01,   1.0700728021836615E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,   7.0304674168232517E-01,  -1.0700728021836615E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,  -7.0304674168232517E-01,   1.0700728021836615E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,   7.0304674168232517E-01,  -1.0700728021836615E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,  -7.0304674168232517E-01,  -1.0700728021836615E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,  -7.0304674168232517E-01,  -1.0700728021836615E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,   1.0700728021836615E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,  -1.0700728021836615E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,   1.0700728021836615E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,  -1.0700728021836615E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,   1.0700728021836615E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,  -1.0700728021836615E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -7.0304674168232517E-01,  -1.0700728021836615E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [   7.0304674168232517E-01,   1.0700728021836615E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [   1.0700728021836615E-01,   7.0304674168232517E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -1.0700728021836615E-01,   7.0304674168232517E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [   1.0700728021836615E-01,  -7.0304674168232517E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [   1.0700728021836615E-01,   7.0304674168232517E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -1.0700728021836615E-01,  -7.0304674168232517E-01,   7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -1.0700728021836615E-01,   7.0304674168232517E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [   1.0700728021836615E-01,  -7.0304674168232517E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [  -1.0700728021836615E-01,  -7.0304674168232517E-01,  -7.0304674168232517E-01,   8.0304498713292989E-03],
            [   8.3549511663546461E-02,   9.9650362723915009E-01,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [  -8.3549511663546461E-02,   9.9650362723915009E-01,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [   8.3549511663546461E-02,  -9.9650362723915009E-01,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [  -8.3549511663546461E-02,  -9.9650362723915009E-01,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [   9.9650362723915009E-01,   8.3549511663546461E-02,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [  -9.9650362723915009E-01,   8.3549511663546461E-02,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [   9.9650362723915009E-01,  -8.3549511663546461E-02,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [  -9.9650362723915009E-01,  -8.3549511663546461E-02,   0.0000000000000000E+00,   4.0047935527914667E-03],
            [   8.3549511663546461E-02,   0.0000000000000000E+00,   9.9650362723915009E-01,   4.0047935527914667E-03],
            [  -8.3549511663546461E-02,   0.0000000000000000E+00,   9.9650362723915009E-01,   4.0047935527914667E-03],
            [   8.3549511663546461E-02,   0.0000000000000000E+00,  -9.9650362723915009E-01,   4.0047935527914667E-03],
            [  -8.3549511663546461E-02,   0.0000000000000000E+00,  -9.9650362723915009E-01,   4.0047935527914667E-03],
            [   9.9650362723915009E-01,   0.0000000000000000E+00,   8.3549511663546461E-02,   4.0047935527914667E-03],
            [  -9.9650362723915009E-01,   0.0000000000000000E+00,   8.3549511663546461E-02,   4.0047935527914667E-03],
            [   9.9650362723915009E-01,   0.0000000000000000E+00,  -8.3549511663546461E-02,   4.0047935527914667E-03],
            [  -9.9650362723915009E-01,   0.0000000000000000E+00,  -8.3549511663546461E-02,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,   8.3549511663546461E-02,   9.9650362723915009E-01,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,  -8.3549511663546461E-02,   9.9650362723915009E-01,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,   8.3549511663546461E-02,  -9.9650362723915009E-01,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,  -8.3549511663546461E-02,  -9.9650362723915009E-01,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,   9.9650362723915009E-01,   8.3549511663546461E-02,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,  -9.9650362723915009E-01,   8.3549511663546461E-02,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,   9.9650362723915009E-01,  -8.3549511663546461E-02,   4.0047935527914667E-03],
            [   0.0000000000000000E+00,  -9.9650362723915009E-01,  -8.3549511663546461E-02,   4.0047935527914667E-03],
            [   2.0501430090994860E-01,   9.7875897769696341E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [  -2.0501430090994860E-01,   9.7875897769696341E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [   2.0501430090994860E-01,  -9.7875897769696341E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [  -2.0501430090994860E-01,  -9.7875897769696341E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [   9.7875897769696341E-01,   2.0501430090994860E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [  -9.7875897769696341E-01,   2.0501430090994860E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [   9.7875897769696341E-01,  -2.0501430090994860E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [  -9.7875897769696341E-01,  -2.0501430090994860E-01,   0.0000000000000000E+00,   5.8785840611819875E-03],
            [   2.0501430090994860E-01,   0.0000000000000000E+00,   9.7875897769696341E-01,   5.8785840611819875E-03],
            [  -2.0501430090994860E-01,   0.0000000000000000E+00,   9.7875897769696341E-01,   5.8785840611819875E-03],
            [   2.0501430090994860E-01,   0.0000000000000000E+00,  -9.7875897769696341E-01,   5.8785840611819875E-03],
            [  -2.0501430090994860E-01,   0.0000000000000000E+00,  -9.7875897769696341E-01,   5.8785840611819875E-03],
            [   9.7875897769696341E-01,   0.0000000000000000E+00,   2.0501430090994860E-01,   5.8785840611819875E-03],
            [  -9.7875897769696341E-01,   0.0000000000000000E+00,   2.0501430090994860E-01,   5.8785840611819875E-03],
            [   9.7875897769696341E-01,   0.0000000000000000E+00,  -2.0501430090994860E-01,   5.8785840611819875E-03],
            [  -9.7875897769696341E-01,   0.0000000000000000E+00,  -2.0501430090994860E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,   2.0501430090994860E-01,   9.7875897769696341E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,  -2.0501430090994860E-01,   9.7875897769696341E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,   2.0501430090994860E-01,  -9.7875897769696341E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,  -2.0501430090994860E-01,  -9.7875897769696341E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,   9.7875897769696341E-01,   2.0501430090994860E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,  -9.7875897769696341E-01,   2.0501430090994860E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,   9.7875897769696341E-01,  -2.0501430090994860E-01,   5.8785840611819875E-03],
            [   0.0000000000000000E+00,  -9.7875897769696341E-01,  -2.0501430090994860E-01,   5.8785840611819875E-03],
            [   3.3702082907066372E-01,   9.4149719105928431E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [  -3.3702082907066372E-01,   9.4149719105928431E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [   3.3702082907066372E-01,  -9.4149719105928431E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [  -3.3702082907066372E-01,  -9.4149719105928431E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [   9.4149719105928431E-01,   3.3702082907066372E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [  -9.4149719105928431E-01,   3.3702082907066372E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [   9.4149719105928431E-01,  -3.3702082907066372E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [  -9.4149719105928431E-01,  -3.3702082907066372E-01,   0.0000000000000000E+00,   6.9602986749843273E-03],
            [   3.3702082907066372E-01,   0.0000000000000000E+00,   9.4149719105928431E-01,   6.9602986749843273E-03],
            [  -3.3702082907066372E-01,   0.0000000000000000E+00,   9.4149719105928431E-01,   6.9602986749843273E-03],
            [   3.3702082907066372E-01,   0.0000000000000000E+00,  -9.4149719105928431E-01,   6.9602986749843273E-03],
            [  -3.3702082907066372E-01,   0.0000000000000000E+00,  -9.4149719105928431E-01,   6.9602986749843273E-03],
            [   9.4149719105928431E-01,   0.0000000000000000E+00,   3.3702082907066372E-01,   6.9602986749843273E-03],
            [  -9.4149719105928431E-01,   0.0000000000000000E+00,   3.3702082907066372E-01,   6.9602986749843273E-03],
            [   9.4149719105928431E-01,   0.0000000000000000E+00,  -3.3702082907066372E-01,   6.9602986749843273E-03],
            [  -9.4149719105928431E-01,   0.0000000000000000E+00,  -3.3702082907066372E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,   3.3702082907066372E-01,   9.4149719105928431E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,  -3.3702082907066372E-01,   9.4149719105928431E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,   3.3702082907066372E-01,  -9.4149719105928431E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,  -3.3702082907066372E-01,  -9.4149719105928431E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,   9.4149719105928431E-01,   3.3702082907066372E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,  -9.4149719105928431E-01,   3.3702082907066372E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,   9.4149719105928431E-01,  -3.3702082907066372E-01,   6.9602986749843273E-03],
            [   0.0000000000000000E+00,  -9.4149719105928431E-01,  -3.3702082907066372E-01,   6.9602986749843273E-03],
            [   4.6890514842339631E-01,   8.8324852775537233E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [  -4.6890514842339631E-01,   8.8324852775537233E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [   4.6890514842339631E-01,  -8.8324852775537233E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [  -4.6890514842339631E-01,  -8.8324852775537233E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [   8.8324852775537233E-01,   4.6890514842339631E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [  -8.8324852775537233E-01,   4.6890514842339631E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [   8.8324852775537233E-01,  -4.6890514842339631E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [  -8.8324852775537233E-01,  -4.6890514842339631E-01,   0.0000000000000000E+00,   7.5957124419320397E-03],
            [   4.6890514842339631E-01,   0.0000000000000000E+00,   8.8324852775537233E-01,   7.5957124419320397E-03],
            [  -4.6890514842339631E-01,   0.0000000000000000E+00,   8.8324852775537233E-01,   7.5957124419320397E-03],
            [   4.6890514842339631E-01,   0.0000000000000000E+00,  -8.8324852775537233E-01,   7.5957124419320397E-03],
            [  -4.6890514842339631E-01,   0.0000000000000000E+00,  -8.8324852775537233E-01,   7.5957124419320397E-03],
            [   8.8324852775537233E-01,   0.0000000000000000E+00,   4.6890514842339631E-01,   7.5957124419320397E-03],
            [  -8.8324852775537233E-01,   0.0000000000000000E+00,   4.6890514842339631E-01,   7.5957124419320397E-03],
            [   8.8324852775537233E-01,   0.0000000000000000E+00,  -4.6890514842339631E-01,   7.5957124419320397E-03],
            [  -8.8324852775537233E-01,   0.0000000000000000E+00,  -4.6890514842339631E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,   4.6890514842339631E-01,   8.8324852775537233E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,  -4.6890514842339631E-01,   8.8324852775537233E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,   4.6890514842339631E-01,  -8.8324852775537233E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,  -4.6890514842339631E-01,  -8.8324852775537233E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,   8.8324852775537233E-01,   4.6890514842339631E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,  -8.8324852775537233E-01,   4.6890514842339631E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,   8.8324852775537233E-01,  -4.6890514842339631E-01,   7.5957124419320397E-03],
            [   0.0000000000000000E+00,  -8.8324852775537233E-01,  -4.6890514842339631E-01,   7.5957124419320397E-03],
            [   5.9394004245573340E-01,   8.0450930757057226E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [  -5.9394004245573340E-01,   8.0450930757057226E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [   5.9394004245573340E-01,  -8.0450930757057226E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [  -5.9394004245573340E-01,  -8.0450930757057226E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [   8.0450930757057226E-01,   5.9394004245573340E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [  -8.0450930757057226E-01,   5.9394004245573340E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [   8.0450930757057226E-01,  -5.9394004245573340E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [  -8.0450930757057226E-01,  -5.9394004245573340E-01,   0.0000000000000000E+00,   7.9338724652285326E-03],
            [   5.9394004245573340E-01,   0.0000000000000000E+00,   8.0450930757057226E-01,   7.9338724652285326E-03],
            [  -5.9394004245573340E-01,   0.0000000000000000E+00,   8.0450930757057226E-01,   7.9338724652285326E-03],
            [   5.9394004245573340E-01,   0.0000000000000000E+00,  -8.0450930757057226E-01,   7.9338724652285326E-03],
            [  -5.9394004245573340E-01,   0.0000000000000000E+00,  -8.0450930757057226E-01,   7.9338724652285326E-03],
            [   8.0450930757057226E-01,   0.0000000000000000E+00,   5.9394004245573340E-01,   7.9338724652285326E-03],
            [  -8.0450930757057226E-01,   0.0000000000000000E+00,   5.9394004245573340E-01,   7.9338724652285326E-03],
            [   8.0450930757057226E-01,   0.0000000000000000E+00,  -5.9394004245573340E-01,   7.9338724652285326E-03],
            [  -8.0450930757057226E-01,   0.0000000000000000E+00,  -5.9394004245573340E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,   5.9394004245573340E-01,   8.0450930757057226E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,  -5.9394004245573340E-01,   8.0450930757057226E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,   5.9394004245573340E-01,  -8.0450930757057226E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,  -5.9394004245573340E-01,  -8.0450930757057226E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,   8.0450930757057226E-01,   5.9394004245573340E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,  -8.0450930757057226E-01,   5.9394004245573340E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,   8.0450930757057226E-01,  -5.9394004245573340E-01,   7.9338724652285326E-03],
            [   0.0000000000000000E+00,  -8.0450930757057226E-01,  -5.9394004245573340E-01,   7.9338724652285326E-03],
            [   1.3949833118322610E-01,   4.0975811620503427E-02,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,   4.0975811620503427E-02,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,  -4.0975811620503427E-02,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,   4.0975811620503427E-02,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,  -4.0975811620503427E-02,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,  -4.0975811620503427E-02,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,   4.0975811620503427E-02,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,  -4.0975811620503427E-02,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,   1.3949833118322610E-01,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,   1.3949833118322610E-01,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,  -1.3949833118322610E-01,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,   1.3949833118322610E-01,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,  -1.3949833118322610E-01,   9.8937414483052666E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,  -1.3949833118322610E-01,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,   1.3949833118322610E-01,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,  -1.3949833118322610E-01,  -9.8937414483052666E-01,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,   1.3949833118322610E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,   1.3949833118322610E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,  -1.3949833118322610E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,   1.3949833118322610E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,  -1.3949833118322610E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,  -1.3949833118322610E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,   1.3949833118322610E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,  -1.3949833118322610E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,   4.0975811620503427E-02,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,   4.0975811620503427E-02,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,  -4.0975811620503427E-02,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,   4.0975811620503427E-02,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,  -4.0975811620503427E-02,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   9.8937414483052666E-01,  -4.0975811620503427E-02,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,   4.0975811620503427E-02,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -9.8937414483052666E-01,  -4.0975811620503427E-02,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,   9.8937414483052666E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,   9.8937414483052666E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,  -9.8937414483052666E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,   9.8937414483052666E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,  -9.8937414483052666E-01,   4.0975811620503427E-02,   5.1253531340219195E-03],
            [   1.3949833118322610E-01,  -9.8937414483052666E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,   9.8937414483052666E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [  -1.3949833118322610E-01,  -9.8937414483052666E-01,  -4.0975811620503427E-02,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,   9.8937414483052666E-01,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,   9.8937414483052666E-01,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,  -9.8937414483052666E-01,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,   9.8937414483052666E-01,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,  -9.8937414483052666E-01,   1.3949833118322610E-01,   5.1253531340219195E-03],
            [   4.0975811620503427E-02,  -9.8937414483052666E-01,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,   9.8937414483052666E-01,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [  -4.0975811620503427E-02,  -9.8937414483052666E-01,  -1.3949833118322610E-01,   5.1253531340219195E-03],
            [   1.9679991804850139E-01,   8.8519873912933478E-02,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,   8.8519873912933478E-02,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,  -8.8519873912933478E-02,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,   8.8519873912933478E-02,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,  -8.8519873912933478E-02,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,  -8.8519873912933478E-02,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,   8.8519873912933478E-02,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,  -8.8519873912933478E-02,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,   1.9679991804850139E-01,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,   1.9679991804850139E-01,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,  -1.9679991804850139E-01,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,   1.9679991804850139E-01,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,  -1.9679991804850139E-01,   9.7643946262865755E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,  -1.9679991804850139E-01,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,   1.9679991804850139E-01,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,  -1.9679991804850139E-01,  -9.7643946262865755E-01,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,   1.9679991804850139E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,   1.9679991804850139E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,  -1.9679991804850139E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,   1.9679991804850139E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,  -1.9679991804850139E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,  -1.9679991804850139E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,   1.9679991804850139E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,  -1.9679991804850139E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,   8.8519873912933478E-02,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,   8.8519873912933478E-02,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,  -8.8519873912933478E-02,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,   8.8519873912933478E-02,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,  -8.8519873912933478E-02,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   9.7643946262865755E-01,  -8.8519873912933478E-02,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,   8.8519873912933478E-02,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -9.7643946262865755E-01,  -8.8519873912933478E-02,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,   9.7643946262865755E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,   9.7643946262865755E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,  -9.7643946262865755E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,   9.7643946262865755E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,  -9.7643946262865755E-01,   8.8519873912933478E-02,   5.9815082904014624E-03],
            [   1.9679991804850139E-01,  -9.7643946262865755E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,   9.7643946262865755E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [  -1.9679991804850139E-01,  -9.7643946262865755E-01,  -8.8519873912933478E-02,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,   9.7643946262865755E-01,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,   9.7643946262865755E-01,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,  -9.7643946262865755E-01,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,   9.7643946262865755E-01,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,  -9.7643946262865755E-01,   1.9679991804850139E-01,   5.9815082904014624E-03],
            [   8.8519873912933478E-02,  -9.7643946262865755E-01,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,   9.7643946262865755E-01,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [  -8.8519873912933478E-02,  -9.7643946262865755E-01,  -1.9679991804850139E-01,   5.9815082904014624E-03],
            [   2.5461837325489672E-01,   1.3976801829698191E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,   1.3976801829698191E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,  -1.3976801829698191E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,   1.3976801829698191E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,  -1.3976801829698191E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,  -1.3976801829698191E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,   1.3976801829698191E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,  -1.3976801829698191E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,   2.5461837325489672E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,   2.5461837325489672E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,  -2.5461837325489672E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,   2.5461837325489672E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,  -2.5461837325489672E-01,   9.5688786441378004E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,  -2.5461837325489672E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,   2.5461837325489672E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,  -2.5461837325489672E-01,  -9.5688786441378004E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,   2.5461837325489672E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,   2.5461837325489672E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,  -2.5461837325489672E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,   2.5461837325489672E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,  -2.5461837325489672E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,  -2.5461837325489672E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,   2.5461837325489672E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,  -2.5461837325489672E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,   1.3976801829698191E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,   1.3976801829698191E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,  -1.3976801829698191E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,   1.3976801829698191E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,  -1.3976801829698191E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   9.5688786441378004E-01,  -1.3976801829698191E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,   1.3976801829698191E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -9.5688786441378004E-01,  -1.3976801829698191E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,   9.5688786441378004E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,   9.5688786441378004E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,  -9.5688786441378004E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,   9.5688786441378004E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,  -9.5688786441378004E-01,   1.3976801829698191E-01,   6.6201540260947258E-03],
            [   2.5461837325489672E-01,  -9.5688786441378004E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,   9.5688786441378004E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [  -2.5461837325489672E-01,  -9.5688786441378004E-01,  -1.3976801829698191E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,   9.5688786441378004E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,   9.5688786441378004E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,  -9.5688786441378004E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,   9.5688786441378004E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,  -9.5688786441378004E-01,   2.5461837325489672E-01,   6.6201540260947258E-03],
            [   1.3976801829698191E-01,  -9.5688786441378004E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,   9.5688786441378004E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [  -1.3976801829698191E-01,  -9.5688786441378004E-01,  -2.5461837325489672E-01,   6.6201540260947258E-03],
            [   3.1212810747138747E-01,   1.9294525422265260E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,   1.9294525422265260E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,  -1.9294525422265260E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,   1.9294525422265260E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,  -1.9294525422265260E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,  -1.9294525422265260E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,   1.9294525422265260E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,  -1.9294525422265260E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,   3.1212810747138747E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,   3.1212810747138747E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,  -3.1212810747138747E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,   3.1212810747138747E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,  -3.1212810747138747E-01,   9.3024092223428112E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,  -3.1212810747138747E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,   3.1212810747138747E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,  -3.1212810747138747E-01,  -9.3024092223428112E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,   3.1212810747138747E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,   3.1212810747138747E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,  -3.1212810747138747E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,   3.1212810747138747E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,  -3.1212810747138747E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,  -3.1212810747138747E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,   3.1212810747138747E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,  -3.1212810747138747E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,   1.9294525422265260E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,   1.9294525422265260E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,  -1.9294525422265260E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,   1.9294525422265260E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,  -1.9294525422265260E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   9.3024092223428112E-01,  -1.9294525422265260E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,   1.9294525422265260E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -9.3024092223428112E-01,  -1.9294525422265260E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,   9.3024092223428112E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,   9.3024092223428112E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,  -9.3024092223428112E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,   9.3024092223428112E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,  -9.3024092223428112E-01,   1.9294525422265260E-01,   7.0912639606160958E-03],
            [   3.1212810747138747E-01,  -9.3024092223428112E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,   9.3024092223428112E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [  -3.1212810747138747E-01,  -9.3024092223428112E-01,  -1.9294525422265260E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,   9.3024092223428112E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,   9.3024092223428112E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,  -9.3024092223428112E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,   9.3024092223428112E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,  -9.3024092223428112E-01,   3.1212810747138747E-01,   7.0912639606160958E-03],
            [   1.9294525422265260E-01,  -9.3024092223428112E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,   9.3024092223428112E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [  -1.9294525422265260E-01,  -9.3024092223428112E-01,  -3.1212810747138747E-01,   7.0912639606160958E-03],
            [   3.6859810785024921E-01,   2.4678983370615620E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,   2.4678983370615620E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,  -2.4678983370615620E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,   2.4678983370615620E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,  -2.4678983370615620E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,  -2.4678983370615620E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,   2.4678983370615620E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,  -2.4678983370615620E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,   3.6859810785024921E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,   3.6859810785024921E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,  -3.6859810785024921E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,   3.6859810785024921E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,  -3.6859810785024921E-01,   8.9623111576674452E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,  -3.6859810785024921E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,   3.6859810785024921E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,  -3.6859810785024921E-01,  -8.9623111576674452E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,   3.6859810785024921E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,   3.6859810785024921E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,  -3.6859810785024921E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,   3.6859810785024921E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,  -3.6859810785024921E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,  -3.6859810785024921E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,   3.6859810785024921E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,  -3.6859810785024921E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,   2.4678983370615620E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,   2.4678983370615620E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,  -2.4678983370615620E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,   2.4678983370615620E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,  -2.4678983370615620E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   8.9623111576674452E-01,  -2.4678983370615620E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,   2.4678983370615620E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -8.9623111576674452E-01,  -2.4678983370615620E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,   8.9623111576674452E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,   8.9623111576674452E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,  -8.9623111576674452E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,   8.9623111576674452E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,  -8.9623111576674452E-01,   2.4678983370615620E-01,   7.4323812527746207E-03],
            [   3.6859810785024921E-01,  -8.9623111576674452E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,   8.9623111576674452E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [  -3.6859810785024921E-01,  -8.9623111576674452E-01,  -2.4678983370615620E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,   8.9623111576674452E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,   8.9623111576674452E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,  -8.9623111576674452E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,   8.9623111576674452E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,  -8.9623111576674452E-01,   3.6859810785024921E-01,   7.4323812527746207E-03],
            [   2.4678983370615620E-01,  -8.9623111576674452E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,   8.9623111576674452E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [  -2.4678983370615620E-01,  -8.9623111576674452E-01,  -3.6859810785024921E-01,   7.4323812527746207E-03],
            [   4.2337603215478559E-01,   3.0031041247854090E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,   3.0031041247854090E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,  -3.0031041247854090E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,   3.0031041247854090E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,  -3.0031041247854090E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,  -3.0031041247854090E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,   3.0031041247854090E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,  -3.0031041247854090E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,   4.2337603215478559E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,   4.2337603215478559E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,  -4.2337603215478559E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,   4.2337603215478559E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,  -4.2337603215478559E-01,   8.5473176585045596E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,  -4.2337603215478559E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,   4.2337603215478559E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,  -4.2337603215478559E-01,  -8.5473176585045596E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,   4.2337603215478559E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,   4.2337603215478559E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,  -4.2337603215478559E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,   4.2337603215478559E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,  -4.2337603215478559E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,  -4.2337603215478559E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,   4.2337603215478559E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,  -4.2337603215478559E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,   3.0031041247854090E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,   3.0031041247854090E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,  -3.0031041247854090E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,   3.0031041247854090E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,  -3.0031041247854090E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   8.5473176585045596E-01,  -3.0031041247854090E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,   3.0031041247854090E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -8.5473176585045596E-01,  -3.0031041247854090E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,   8.5473176585045596E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,   8.5473176585045596E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,  -8.5473176585045596E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,   8.5473176585045596E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,  -8.5473176585045596E-01,   3.0031041247854090E-01,   7.6712179204505753E-03],
            [   4.2337603215478559E-01,  -8.5473176585045596E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,   8.5473176585045596E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [  -4.2337603215478559E-01,  -8.5473176585045596E-01,  -3.0031041247854090E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,   8.5473176585045596E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,   8.5473176585045596E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,  -8.5473176585045596E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,   8.5473176585045596E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,  -8.5473176585045596E-01,   4.2337603215478559E-01,   7.6712179204505753E-03],
            [   3.0031041247854090E-01,  -8.5473176585045596E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,   8.5473176585045596E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [  -3.0031041247854090E-01,  -8.5473176585045596E-01,  -4.2337603215478559E-01,   7.6712179204505753E-03],
            [   4.7586712360592459E-01,   3.5266843281750332E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,   3.5266843281750332E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,  -3.5266843281750332E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,   3.5266843281750332E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,  -3.5266843281750332E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,  -3.5266843281750332E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,   3.5266843281750332E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,  -3.5266843281750332E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,   4.7586712360592459E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,   4.7586712360592459E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,  -4.7586712360592459E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,   4.7586712360592459E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,  -4.7586712360592459E-01,   8.0571425280000464E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,  -4.7586712360592459E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,   4.7586712360592459E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,  -4.7586712360592459E-01,  -8.0571425280000464E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,   4.7586712360592459E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,   4.7586712360592459E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,  -4.7586712360592459E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,   4.7586712360592459E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,  -4.7586712360592459E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,  -4.7586712360592459E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,   4.7586712360592459E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,  -4.7586712360592459E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,   3.5266843281750332E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,   3.5266843281750332E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,  -3.5266843281750332E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,   3.5266843281750332E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,  -3.5266843281750332E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   8.0571425280000464E-01,  -3.5266843281750332E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,   3.5266843281750332E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -8.0571425280000464E-01,  -3.5266843281750332E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,   8.0571425280000464E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,   8.0571425280000464E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,  -8.0571425280000464E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,   8.0571425280000464E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,  -8.0571425280000464E-01,   3.5266843281750332E-01,   7.8291666468825738E-03],
            [   4.7586712360592459E-01,  -8.0571425280000464E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,   8.0571425280000464E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [  -4.7586712360592459E-01,  -8.0571425280000464E-01,  -3.5266843281750332E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,   8.0571425280000464E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,   8.0571425280000464E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,  -8.0571425280000464E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,   8.0571425280000464E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,  -8.0571425280000464E-01,   4.7586712360592459E-01,   7.8291666468825738E-03],
            [   3.5266843281750332E-01,  -8.0571425280000464E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,   8.0571425280000464E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [  -3.5266843281750332E-01,  -8.0571425280000464E-01,  -4.7586712360592459E-01,   7.8291666468825738E-03],
            [   5.2551785797964634E-01,   4.0311348611457132E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,   4.0311348611457132E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,  -4.0311348611457132E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,   4.0311348611457132E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,  -4.0311348611457132E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,  -4.0311348611457132E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,   4.0311348611457132E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,  -4.0311348611457132E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,   5.2551785797964634E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,   5.2551785797964634E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,  -5.2551785797964634E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,   5.2551785797964634E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,  -5.2551785797964634E-01,   7.4921992649491220E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,  -5.2551785797964634E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,   5.2551785797964634E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,  -5.2551785797964634E-01,  -7.4921992649491220E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,   5.2551785797964634E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,   5.2551785797964634E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,  -5.2551785797964634E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,   5.2551785797964634E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,  -5.2551785797964634E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,  -5.2551785797964634E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,   5.2551785797964634E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,  -5.2551785797964634E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,   4.0311348611457132E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,   4.0311348611457132E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,  -4.0311348611457132E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,   4.0311348611457132E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,  -4.0311348611457132E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   7.4921992649491220E-01,  -4.0311348611457132E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,   4.0311348611457132E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -7.4921992649491220E-01,  -4.0311348611457132E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,   7.4921992649491220E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,   7.4921992649491220E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,  -7.4921992649491220E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,   7.4921992649491220E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,  -7.4921992649491220E-01,   4.0311348611457132E-01,   7.9238742313142742E-03],
            [   5.2551785797964634E-01,  -7.4921992649491220E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,   7.4921992649491220E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [  -5.2551785797964634E-01,  -7.4921992649491220E-01,  -4.0311348611457132E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,   7.4921992649491220E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,   7.4921992649491220E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,  -7.4921992649491220E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,   7.4921992649491220E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,  -7.4921992649491220E-01,   5.2551785797964634E-01,   7.9238742313142742E-03],
            [   4.0311348611457132E-01,  -7.4921992649491220E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,   7.4921992649491220E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [  -4.0311348611457132E-01,  -7.4921992649491220E-01,  -5.2551785797964634E-01,   7.9238742313142742E-03],
            [   5.7180256337345892E-01,   4.5094264483423507E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,   4.5094264483423507E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,  -4.5094264483423507E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,   4.5094264483423507E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,  -4.5094264483423507E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,  -4.5094264483423507E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,   4.5094264483423507E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,  -4.5094264483423507E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,   5.7180256337345892E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,   5.7180256337345892E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,  -5.7180256337345892E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,   5.7180256337345892E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,  -5.7180256337345892E-01,   6.8534119939592597E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,  -5.7180256337345892E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,   5.7180256337345892E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,  -5.7180256337345892E-01,  -6.8534119939592597E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,   5.7180256337345892E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,   5.7180256337345892E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,  -5.7180256337345892E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,   5.7180256337345892E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,  -5.7180256337345892E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,  -5.7180256337345892E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,   5.7180256337345892E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,  -5.7180256337345892E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,   4.5094264483423507E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,   4.5094264483423507E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,  -4.5094264483423507E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,   4.5094264483423507E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,  -4.5094264483423507E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   6.8534119939592597E-01,  -4.5094264483423507E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,   4.5094264483423507E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -6.8534119939592597E-01,  -4.5094264483423507E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,   6.8534119939592597E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,   6.8534119939592597E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,  -6.8534119939592597E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,   6.8534119939592597E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,  -6.8534119939592597E-01,   4.5094264483423507E-01,   7.9709654558896316E-03],
            [   5.7180256337345892E-01,  -6.8534119939592597E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,   6.8534119939592597E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [  -5.7180256337345892E-01,  -6.8534119939592597E-01,  -4.5094264483423507E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,   6.8534119939592597E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,   6.8534119939592597E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,  -6.8534119939592597E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,   6.8534119939592597E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,  -6.8534119939592597E-01,   5.7180256337345892E-01,   7.9709654558896316E-03],
            [   4.5094264483423507E-01,  -6.8534119939592597E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,   6.8534119939592597E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [  -4.5094264483423507E-01,  -6.8534119939592597E-01,  -5.7180256337345892E-01,   7.9709654558896316E-03],
            [   2.6869277727234148E-01,   4.7113225024232479E-02,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,   4.7113225024232479E-02,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,  -4.7113225024232479E-02,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,   4.7113225024232479E-02,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,  -4.7113225024232479E-02,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,  -4.7113225024232479E-02,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,   4.7113225024232479E-02,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,  -4.7113225024232479E-02,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,   2.6869277727234148E-01,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,   2.6869277727234148E-01,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,  -2.6869277727234148E-01,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,   2.6869277727234148E-01,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,  -2.6869277727234148E-01,   9.6207304061047882E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,  -2.6869277727234148E-01,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,   2.6869277727234148E-01,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,  -2.6869277727234148E-01,  -9.6207304061047882E-01,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,   2.6869277727234148E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,   2.6869277727234148E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,  -2.6869277727234148E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,   2.6869277727234148E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,  -2.6869277727234148E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,  -2.6869277727234148E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,   2.6869277727234148E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,  -2.6869277727234148E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,   4.7113225024232479E-02,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,   4.7113225024232479E-02,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,  -4.7113225024232479E-02,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,   4.7113225024232479E-02,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,  -4.7113225024232479E-02,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   9.6207304061047882E-01,  -4.7113225024232479E-02,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,   4.7113225024232479E-02,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -9.6207304061047882E-01,  -4.7113225024232479E-02,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,   9.6207304061047882E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,   9.6207304061047882E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,  -9.6207304061047882E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,   9.6207304061047882E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,  -9.6207304061047882E-01,   4.7113225024232479E-02,   6.5046913971739759E-03],
            [   2.6869277727234148E-01,  -9.6207304061047882E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,   9.6207304061047882E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [  -2.6869277727234148E-01,  -9.6207304061047882E-01,  -4.7113225024232479E-02,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,   9.6207304061047882E-01,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,   9.6207304061047882E-01,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,  -9.6207304061047882E-01,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,   9.6207304061047882E-01,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,  -9.6207304061047882E-01,   2.6869277727234148E-01,   6.5046913971739759E-03],
            [   4.7113225024232479E-02,  -9.6207304061047882E-01,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,   9.6207304061047882E-01,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [  -4.7113225024232479E-02,  -9.6207304061047882E-01,  -2.6869277727234148E-01,   6.5046913971739759E-03],
            [   3.3060068199048093E-01,   9.7844873039426947E-02,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,   9.7844873039426947E-02,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,  -9.7844873039426947E-02,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,   9.7844873039426947E-02,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,  -9.7844873039426947E-02,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,  -9.7844873039426947E-02,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,   9.7844873039426947E-02,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,  -9.7844873039426947E-02,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,   3.3060068199048093E-01,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,   3.3060068199048093E-01,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,  -3.3060068199048093E-01,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,   3.3060068199048093E-01,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,  -3.3060068199048093E-01,   9.3868502165919709E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,  -3.3060068199048093E-01,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,   3.3060068199048093E-01,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,  -3.3060068199048093E-01,  -9.3868502165919709E-01,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,   3.3060068199048093E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,   3.3060068199048093E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,  -3.3060068199048093E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,   3.3060068199048093E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,  -3.3060068199048093E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,  -3.3060068199048093E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,   3.3060068199048093E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,  -3.3060068199048093E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,   9.7844873039426947E-02,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,   9.7844873039426947E-02,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,  -9.7844873039426947E-02,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,   9.7844873039426947E-02,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,  -9.7844873039426947E-02,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.3868502165919709E-01,  -9.7844873039426947E-02,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,   9.7844873039426947E-02,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.3868502165919709E-01,  -9.7844873039426947E-02,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,   9.3868502165919709E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,   9.3868502165919709E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,  -9.3868502165919709E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,   9.3868502165919709E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,  -9.3868502165919709E-01,   9.7844873039426947E-02,   6.9929845786826476E-03],
            [   3.3060068199048093E-01,  -9.3868502165919709E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,   9.3868502165919709E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [  -3.3060068199048093E-01,  -9.3868502165919709E-01,  -9.7844873039426947E-02,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,   9.3868502165919709E-01,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,   9.3868502165919709E-01,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,  -9.3868502165919709E-01,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,   9.3868502165919709E-01,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,  -9.3868502165919709E-01,   3.3060068199048093E-01,   6.9929845786826476E-03],
            [   9.7844873039426947E-02,  -9.3868502165919709E-01,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,   9.3868502165919709E-01,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [  -9.7844873039426947E-02,  -9.3868502165919709E-01,  -3.3060068199048093E-01,   6.9929845786826476E-03],
            [   3.9049068505949830E-01,   1.5053958100252729E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,   1.5053958100252729E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,  -1.5053958100252729E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,   1.5053958100252729E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,  -1.5053958100252729E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,  -1.5053958100252729E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,   1.5053958100252729E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,  -1.5053958100252729E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,   3.9049068505949830E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,   3.9049068505949830E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,  -3.9049068505949830E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,   3.9049068505949830E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,  -3.9049068505949830E-01,   9.0821520546253087E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,  -3.9049068505949830E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,   3.9049068505949830E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,  -3.9049068505949830E-01,  -9.0821520546253087E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,   3.9049068505949830E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,   3.9049068505949830E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,  -3.9049068505949830E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,   3.9049068505949830E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,  -3.9049068505949830E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,  -3.9049068505949830E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,   3.9049068505949830E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,  -3.9049068505949830E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,   1.5053958100252729E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,   1.5053958100252729E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,  -1.5053958100252729E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,   1.5053958100252729E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,  -1.5053958100252729E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   9.0821520546253087E-01,  -1.5053958100252729E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,   1.5053958100252729E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -9.0821520546253087E-01,  -1.5053958100252729E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,   9.0821520546253087E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,   9.0821520546253087E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,  -9.0821520546253087E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,   9.0821520546253087E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,  -9.0821520546253087E-01,   1.5053958100252729E-01,   7.3594028024093552E-03],
            [   3.9049068505949830E-01,  -9.0821520546253087E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,   9.0821520546253087E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [  -3.9049068505949830E-01,  -9.0821520546253087E-01,  -1.5053958100252729E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,   9.0821520546253087E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,   9.0821520546253087E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,  -9.0821520546253087E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,   9.0821520546253087E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,  -9.0821520546253087E-01,   3.9049068505949830E-01,   7.3594028024093552E-03],
            [   1.5053958100252729E-01,  -9.0821520546253087E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,   9.0821520546253087E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [  -1.5053958100252729E-01,  -9.0821520546253087E-01,  -3.9049068505949830E-01,   7.3594028024093552E-03],
            [   4.4799579519043897E-01,   2.0397281562960501E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,   2.0397281562960501E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,  -2.0397281562960501E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,   2.0397281562960501E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,  -2.0397281562960501E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,  -2.0397281562960501E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,   2.0397281562960501E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,  -2.0397281562960501E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,   4.4799579519043897E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,   4.4799579519043897E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,  -4.4799579519043897E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,   4.4799579519043897E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,  -4.4799579519043897E-01,   8.7045669506059720E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,  -4.4799579519043897E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,   4.4799579519043897E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,  -4.4799579519043897E-01,  -8.7045669506059720E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,   4.4799579519043897E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,   4.4799579519043897E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,  -4.4799579519043897E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,   4.4799579519043897E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,  -4.4799579519043897E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,  -4.4799579519043897E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,   4.4799579519043897E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,  -4.4799579519043897E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,   2.0397281562960501E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,   2.0397281562960501E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,  -2.0397281562960501E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,   2.0397281562960501E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,  -2.0397281562960501E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   8.7045669506059720E-01,  -2.0397281562960501E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,   2.0397281562960501E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -8.7045669506059720E-01,  -2.0397281562960501E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,   8.7045669506059720E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,   8.7045669506059720E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,  -8.7045669506059720E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,   8.7045669506059720E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,  -8.7045669506059720E-01,   2.0397281562960501E-01,   7.6232466399417916E-03],
            [   4.4799579519043897E-01,  -8.7045669506059720E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,   8.7045669506059720E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [  -4.4799579519043897E-01,  -8.7045669506059720E-01,  -2.0397281562960501E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,   8.7045669506059720E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,   8.7045669506059720E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,  -8.7045669506059720E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,   8.7045669506059720E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,  -8.7045669506059720E-01,   4.4799579519043897E-01,   7.6232466399417916E-03],
            [   2.0397281562960501E-01,  -8.7045669506059720E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,   8.7045669506059720E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [  -2.0397281562960501E-01,  -8.7045669506059720E-01,  -4.4799579519043897E-01,   7.6232466399417916E-03],
            [   5.0270768489197803E-01,   2.5715299411211068E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,   2.5715299411211068E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,  -2.5715299411211068E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,   2.5715299411211068E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,  -2.5715299411211068E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,  -2.5715299411211068E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,   2.5715299411211068E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,  -2.5715299411211068E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,   5.0270768489197803E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,   5.0270768489197803E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,  -5.0270768489197803E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,   5.0270768489197803E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,  -5.0270768489197803E-01,   8.2532255583482295E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,  -5.0270768489197803E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,   5.0270768489197803E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,  -5.0270768489197803E-01,  -8.2532255583482295E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,   5.0270768489197803E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,   5.0270768489197803E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,  -5.0270768489197803E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,   5.0270768489197803E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,  -5.0270768489197803E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,  -5.0270768489197803E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,   5.0270768489197803E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,  -5.0270768489197803E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,   2.5715299411211068E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,   2.5715299411211068E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,  -2.5715299411211068E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,   2.5715299411211068E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,  -2.5715299411211068E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   8.2532255583482295E-01,  -2.5715299411211068E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,   2.5715299411211068E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -8.2532255583482295E-01,  -2.5715299411211068E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,   8.2532255583482295E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,   8.2532255583482295E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,  -8.2532255583482295E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,   8.2532255583482295E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,  -8.2532255583482295E-01,   2.5715299411211068E-01,   7.8022395555122793E-03],
            [   5.0270768489197803E-01,  -8.2532255583482295E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,   8.2532255583482295E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [  -5.0270768489197803E-01,  -8.2532255583482295E-01,  -2.5715299411211068E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,   8.2532255583482295E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,   8.2532255583482295E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,  -8.2532255583482295E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,   8.2532255583482295E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,  -8.2532255583482295E-01,   5.0270768489197803E-01,   7.8022395555122793E-03],
            [   2.5715299411211068E-01,  -8.2532255583482295E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,   8.2532255583482295E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [  -2.5715299411211068E-01,  -8.2532255583482295E-01,  -5.0270768489197803E-01,   7.8022395555122793E-03],
            [   5.5420873922602165E-01,   3.0921913758156699E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,   3.0921913758156699E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,  -3.0921913758156699E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,   3.0921913758156699E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,  -3.0921913758156699E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,  -3.0921913758156699E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,   3.0921913758156699E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,  -3.0921913758156699E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,   5.5420873922602165E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,   5.5420873922602165E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,  -5.5420873922602165E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,   5.5420873922602165E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,  -5.5420873922602165E-01,   7.7281058372593192E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,  -5.5420873922602165E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,   5.5420873922602165E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,  -5.5420873922602165E-01,  -7.7281058372593192E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,   5.5420873922602165E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,   5.5420873922602165E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,  -5.5420873922602165E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,   5.5420873922602165E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,  -5.5420873922602165E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,  -5.5420873922602165E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,   5.5420873922602165E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,  -5.5420873922602165E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,   3.0921913758156699E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,   3.0921913758156699E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,  -3.0921913758156699E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,   3.0921913758156699E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,  -3.0921913758156699E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   7.7281058372593192E-01,  -3.0921913758156699E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,   3.0921913758156699E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -7.7281058372593192E-01,  -3.0921913758156699E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,   7.7281058372593192E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,   7.7281058372593192E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,  -7.7281058372593192E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,   7.7281058372593192E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,  -7.7281058372593192E-01,   3.0921913758156699E-01,   7.9121818970931280E-03],
            [   5.5420873922602165E-01,  -7.7281058372593192E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,   7.7281058372593192E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [  -5.5420873922602165E-01,  -7.7281058372593192E-01,  -3.0921913758156699E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,   7.7281058372593192E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,   7.7281058372593192E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,  -7.7281058372593192E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,   7.7281058372593192E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,  -7.7281058372593192E-01,   5.5420873922602165E-01,   7.9121818970931280E-03],
            [   3.0921913758156699E-01,  -7.7281058372593192E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,   7.7281058372593192E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [  -3.0921913758156699E-01,  -7.7281058372593192E-01,  -5.5420873922602165E-01,   7.9121818970931280E-03],
            [   6.0208508873751865E-01,   3.5938075061302760E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,   3.5938075061302760E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,  -3.5938075061302760E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,   3.5938075061302760E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,  -3.5938075061302760E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,  -3.5938075061302760E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,   3.5938075061302760E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,  -3.5938075061302760E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,   6.0208508873751865E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,   6.0208508873751865E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,  -6.0208508873751865E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,   6.0208508873751865E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,  -6.0208508873751865E-01,   7.1297897725581727E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,  -6.0208508873751865E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,   6.0208508873751865E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,  -6.0208508873751865E-01,  -7.1297897725581727E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,   6.0208508873751865E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,   6.0208508873751865E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,  -6.0208508873751865E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,   6.0208508873751865E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,  -6.0208508873751865E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,  -6.0208508873751865E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,   6.0208508873751865E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,  -6.0208508873751865E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,   3.5938075061302760E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,   3.5938075061302760E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,  -3.5938075061302760E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,   3.5938075061302760E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,  -3.5938075061302760E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   7.1297897725581727E-01,  -3.5938075061302760E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,   3.5938075061302760E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -7.1297897725581727E-01,  -3.5938075061302760E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,   7.1297897725581727E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,   7.1297897725581727E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,  -7.1297897725581727E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,   7.1297897725581727E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,  -7.1297897725581727E-01,   3.5938075061302760E-01,   7.9676114779934012E-03],
            [   6.0208508873751865E-01,  -7.1297897725581727E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,   7.1297897725581727E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [  -6.0208508873751865E-01,  -7.1297897725581727E-01,  -3.5938075061302760E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,   7.1297897725581727E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,   7.1297897725581727E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,  -7.1297897725581727E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,   7.1297897725581727E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,  -7.1297897725581727E-01,   6.0208508873751865E-01,   7.9676114779934012E-03],
            [   3.5938075061302760E-01,  -7.1297897725581727E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,   7.1297897725581727E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [  -3.5938075061302760E-01,  -7.1297897725581727E-01,  -6.0208508873751865E-01,   7.9676114779934012E-03],
            [   4.0198514091795939E-01,   5.0633899343786710E-02,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,   5.0633899343786710E-02,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,  -5.0633899343786710E-02,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,   5.0633899343786710E-02,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,  -5.0633899343786710E-02,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,  -5.0633899343786710E-02,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,   5.0633899343786710E-02,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,  -5.0633899343786710E-02,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,   4.0198514091795939E-01,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,   4.0198514091795939E-01,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,  -4.0198514091795939E-01,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,   4.0198514091795939E-01,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,  -4.0198514091795939E-01,   9.1424512835366623E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,  -4.0198514091795939E-01,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,   4.0198514091795939E-01,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,  -4.0198514091795939E-01,  -9.1424512835366623E-01,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,   4.0198514091795939E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,   4.0198514091795939E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,  -4.0198514091795939E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,   4.0198514091795939E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,  -4.0198514091795939E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,  -4.0198514091795939E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,   4.0198514091795939E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,  -4.0198514091795939E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,   5.0633899343786710E-02,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,   5.0633899343786710E-02,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,  -5.0633899343786710E-02,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,   5.0633899343786710E-02,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,  -5.0633899343786710E-02,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   9.1424512835366623E-01,  -5.0633899343786710E-02,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,   5.0633899343786710E-02,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -9.1424512835366623E-01,  -5.0633899343786710E-02,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,   9.1424512835366623E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,   9.1424512835366623E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,  -9.1424512835366623E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,   9.1424512835366623E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,  -9.1424512835366623E-01,   5.0633899343786710E-02,   7.3257261934256621E-03],
            [   4.0198514091795939E-01,  -9.1424512835366623E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,   9.1424512835366623E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [  -4.0198514091795939E-01,  -9.1424512835366623E-01,  -5.0633899343786710E-02,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,   9.1424512835366623E-01,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,   9.1424512835366623E-01,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,  -9.1424512835366623E-01,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,   9.1424512835366623E-01,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,  -9.1424512835366623E-01,   4.0198514091795939E-01,   7.3257261934256621E-03],
            [   5.0633899343786710E-02,  -9.1424512835366623E-01,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,   9.1424512835366623E-01,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [  -5.0633899343786710E-02,  -9.1424512835366623E-01,  -4.0198514091795939E-01,   7.3257261934256621E-03],
            [   4.6356145674498000E-01,   1.0324222691606121E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,   1.0324222691606121E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,  -1.0324222691606121E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,   1.0324222691606121E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,  -1.0324222691606121E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,  -1.0324222691606121E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,   1.0324222691606121E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,  -1.0324222691606121E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,   4.6356145674498000E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,   4.6356145674498000E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,  -4.6356145674498000E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,   4.6356145674498000E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,  -4.6356145674498000E-01,   8.8002944178128761E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,  -4.6356145674498000E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,   4.6356145674498000E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,  -4.6356145674498000E-01,  -8.8002944178128761E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,   4.6356145674498000E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,   4.6356145674498000E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,  -4.6356145674498000E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,   4.6356145674498000E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,  -4.6356145674498000E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,  -4.6356145674498000E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,   4.6356145674498000E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,  -4.6356145674498000E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,   1.0324222691606121E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,   1.0324222691606121E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,  -1.0324222691606121E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,   1.0324222691606121E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,  -1.0324222691606121E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   8.8002944178128761E-01,  -1.0324222691606121E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,   1.0324222691606121E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -8.8002944178128761E-01,  -1.0324222691606121E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,   8.8002944178128761E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,   8.8002944178128761E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,  -8.8002944178128761E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,   8.8002944178128761E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,  -8.8002944178128761E-01,   1.0324222691606121E-01,   7.6010122696454638E-03],
            [   4.6356145674498000E-01,  -8.8002944178128761E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,   8.8002944178128761E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [  -4.6356145674498000E-01,  -8.8002944178128761E-01,  -1.0324222691606121E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,   8.8002944178128761E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,   8.8002944178128761E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,  -8.8002944178128761E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,   8.8002944178128761E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,  -8.8002944178128761E-01,   4.6356145674498000E-01,   7.6010122696454638E-03],
            [   1.0324222691606121E-01,  -8.8002944178128761E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,   8.8002944178128761E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [  -1.0324222691606121E-01,  -8.8002944178128761E-01,  -4.6356145674498000E-01,   7.6010122696454638E-03],
            [   5.2158609315915749E-01,   1.5663220940062539E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,   1.5663220940062539E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,  -1.5663220940062539E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,   1.5663220940062539E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,  -1.5663220940062539E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,  -1.5663220940062539E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,   1.5663220940062539E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,  -1.5663220940062539E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,   5.2158609315915749E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,   5.2158609315915749E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,  -5.2158609315915749E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,   5.2158609315915749E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,  -5.2158609315915749E-01,   8.3869797805959045E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,  -5.2158609315915749E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,   5.2158609315915749E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,  -5.2158609315915749E-01,  -8.3869797805959045E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,   5.2158609315915749E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,   5.2158609315915749E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,  -5.2158609315915749E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,   5.2158609315915749E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,  -5.2158609315915749E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,  -5.2158609315915749E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,   5.2158609315915749E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,  -5.2158609315915749E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,   1.5663220940062539E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,   1.5663220940062539E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,  -1.5663220940062539E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,   1.5663220940062539E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,  -1.5663220940062539E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   8.3869797805959045E-01,  -1.5663220940062539E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,   1.5663220940062539E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -8.3869797805959045E-01,  -1.5663220940062539E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,   8.3869797805959045E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,   8.3869797805959045E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,  -8.3869797805959045E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,   8.3869797805959045E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,  -8.3869797805959045E-01,   1.5663220940062539E-01,   7.7941183569161850E-03],
            [   5.2158609315915749E-01,  -8.3869797805959045E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,   8.3869797805959045E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [  -5.2158609315915749E-01,  -8.3869797805959045E-01,  -1.5663220940062539E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,   8.3869797805959045E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,   8.3869797805959045E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,  -8.3869797805959045E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,   8.3869797805959045E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,  -8.3869797805959045E-01,   5.2158609315915749E-01,   7.7941183569161850E-03],
            [   1.5663220940062539E-01,  -8.3869797805959045E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,   8.3869797805959045E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [  -1.5663220940062539E-01,  -8.3869797805959045E-01,  -5.2158609315915749E-01,   7.7941183569161850E-03],
            [   5.7582024990992708E-01,   2.0980828274910990E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,   2.0980828274910990E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,   2.0980828274910990E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,  -2.0980828274910990E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,   2.0980828274910990E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,  -2.0980828274910990E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,   5.7582024990992708E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,   5.7582024990992708E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,   5.7582024990992708E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9019714266981411E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,  -5.7582024990992708E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,   5.7582024990992708E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,  -5.7582024990992708E-01,  -7.9019714266981411E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,   5.7582024990992708E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,   5.7582024990992708E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,  -5.7582024990992708E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,   5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,  -5.7582024990992708E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,  -5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,   5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,  -5.7582024990992708E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,   2.0980828274910990E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,   2.0980828274910990E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,  -2.0980828274910990E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,   2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,  -2.0980828274910990E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   7.9019714266981411E-01,  -2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,   2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -7.9019714266981411E-01,  -2.0980828274910990E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,   7.9019714266981411E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,   7.9019714266981411E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,  -7.9019714266981411E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,   7.9019714266981411E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,  -7.9019714266981411E-01,   2.0980828274910990E-01,   7.9155635458545096E-03],
            [   5.7582024990992708E-01,  -7.9019714266981411E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,   7.9019714266981411E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [  -5.7582024990992708E-01,  -7.9019714266981411E-01,  -2.0980828274910990E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,   7.9019714266981411E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,   7.9019714266981411E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,  -7.9019714266981411E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,   7.9019714266981411E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,  -7.9019714266981411E-01,   5.7582024990992708E-01,   7.9155635458545096E-03],
            [   2.0980828274910990E-01,  -7.9019714266981411E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,   7.9019714266981411E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [  -2.0980828274910990E-01,  -7.9019714266981411E-01,  -5.7582024990992708E-01,   7.9155635458545096E-03],
            [   6.2598936838767949E-01,   2.6188241145533908E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,   2.6188241145533908E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,  -2.6188241145533908E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,   2.6188241145533908E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,  -2.6188241145533908E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,  -2.6188241145533908E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,   2.6188241145533908E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,  -2.6188241145533908E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,   6.2598936838767949E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,   6.2598936838767949E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,  -6.2598936838767949E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,   6.2598936838767949E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,  -6.2598936838767949E-01,   7.3454401722152129E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,  -6.2598936838767949E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,   6.2598936838767949E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,  -6.2598936838767949E-01,  -7.3454401722152129E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,   6.2598936838767949E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,   6.2598936838767949E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,  -6.2598936838767949E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,   6.2598936838767949E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,  -6.2598936838767949E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,  -6.2598936838767949E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,   6.2598936838767949E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,  -6.2598936838767949E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,   2.6188241145533908E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,   2.6188241145533908E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,  -2.6188241145533908E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,   2.6188241145533908E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,  -2.6188241145533908E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   7.3454401722152129E-01,  -2.6188241145533908E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,   2.6188241145533908E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -7.3454401722152129E-01,  -2.6188241145533908E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,   7.3454401722152129E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,   7.3454401722152129E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,  -7.3454401722152129E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,   7.3454401722152129E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,  -7.3454401722152129E-01,   2.6188241145533908E-01,   7.9767832117463126E-03],
            [   6.2598936838767949E-01,  -7.3454401722152129E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,   7.3454401722152129E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [  -6.2598936838767949E-01,  -7.3454401722152129E-01,  -2.6188241145533908E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,   7.3454401722152129E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,   7.3454401722152129E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,  -7.3454401722152129E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,   7.3454401722152129E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,  -7.3454401722152129E-01,   6.2598936838767949E-01,   7.9767832117463126E-03],
            [   2.6188241145533908E-01,  -7.3454401722152129E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,   7.3454401722152129E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [  -2.6188241145533908E-01,  -7.3454401722152129E-01,  -6.2598936838767949E-01,   7.9767832117463126E-03],
            [   5.3137951248118909E-01,   5.2632450193385562E-02,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,   5.2632450193385562E-02,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,  -5.2632450193385562E-02,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,   5.2632450193385562E-02,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,  -5.2632450193385562E-02,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,  -5.2632450193385562E-02,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,   5.2632450193385562E-02,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,  -5.2632450193385562E-02,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,   5.3137951248118909E-01,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,   5.3137951248118909E-01,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,  -5.3137951248118909E-01,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,   5.3137951248118909E-01,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,  -5.3137951248118909E-01,   8.4549727314870426E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,  -5.3137951248118909E-01,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,   5.3137951248118909E-01,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,  -5.3137951248118909E-01,  -8.4549727314870426E-01,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,   5.3137951248118909E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,   5.3137951248118909E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,  -5.3137951248118909E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,   5.3137951248118909E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,  -5.3137951248118909E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,  -5.3137951248118909E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,   5.3137951248118909E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,  -5.3137951248118909E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,   5.2632450193385562E-02,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,   5.2632450193385562E-02,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,  -5.2632450193385562E-02,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,   5.2632450193385562E-02,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,  -5.2632450193385562E-02,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   8.4549727314870426E-01,  -5.2632450193385562E-02,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,   5.2632450193385562E-02,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -8.4549727314870426E-01,  -5.2632450193385562E-02,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,   8.4549727314870426E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,   8.4549727314870426E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,  -8.4549727314870426E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,   8.4549727314870426E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,  -8.4549727314870426E-01,   5.2632450193385562E-02,   7.7958985887818764E-03],
            [   5.3137951248118909E-01,  -8.4549727314870426E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,   8.4549727314870426E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [  -5.3137951248118909E-01,  -8.4549727314870426E-01,  -5.2632450193385562E-02,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,   8.4549727314870426E-01,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,   8.4549727314870426E-01,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,  -8.4549727314870426E-01,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,   8.4549727314870426E-01,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,  -8.4549727314870426E-01,   5.3137951248118909E-01,   7.7958985887818764E-03],
            [   5.2632450193385562E-02,  -8.4549727314870426E-01,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,   8.4549727314870426E-01,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [  -5.2632450193385562E-02,  -8.4549727314870426E-01,  -5.3137951248118909E-01,   7.7958985887818764E-03],
            [   5.8933179559319948E-01,   1.0610597309820050E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,   1.0610597309820050E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,  -1.0610597309820050E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,   1.0610597309820050E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,  -1.0610597309820050E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,  -1.0610597309820050E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,   1.0610597309820050E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,  -1.0610597309820050E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,   5.8933179559319948E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,   5.8933179559319948E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,  -5.8933179559319948E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,   5.8933179559319948E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,  -5.8933179559319948E-01,   8.0089297485730226E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,  -5.8933179559319948E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,   5.8933179559319948E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,  -5.8933179559319948E-01,  -8.0089297485730226E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,   5.8933179559319948E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,   5.8933179559319948E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,  -5.8933179559319948E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,   5.8933179559319948E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,  -5.8933179559319948E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,  -5.8933179559319948E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,   5.8933179559319948E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,  -5.8933179559319948E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,   1.0610597309820050E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,   1.0610597309820050E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,  -1.0610597309820050E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,   1.0610597309820050E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,  -1.0610597309820050E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   8.0089297485730226E-01,  -1.0610597309820050E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,   1.0610597309820050E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -8.0089297485730226E-01,  -1.0610597309820050E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,   8.0089297485730226E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,   8.0089297485730226E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,  -8.0089297485730226E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,   8.0089297485730226E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,  -8.0089297485730226E-01,   1.0610597309820050E-01,   7.9273876747862366E-03],
            [   5.8933179559319948E-01,  -8.0089297485730226E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,   8.0089297485730226E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [  -5.8933179559319948E-01,  -8.0089297485730226E-01,  -1.0610597309820050E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,   8.0089297485730226E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,   8.0089297485730226E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,  -8.0089297485730226E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,   8.0089297485730226E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,  -8.0089297485730226E-01,   5.8933179559319948E-01,   7.9273876747862366E-03],
            [   1.0610597309820050E-01,  -8.0089297485730226E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,   8.0089297485730226E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [  -1.0610597309820050E-01,  -8.0089297485730226E-01,  -5.8933179559319948E-01,   7.9273876747862366E-03],
            [   6.4262463212158005E-01,   1.5941715640342211E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,   1.5941715640342211E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,  -1.5941715640342211E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,   1.5941715640342211E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,  -1.5941715640342211E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,  -1.5941715640342211E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,   1.5941715640342211E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,  -1.5941715640342211E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,   6.4262463212158005E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,   6.4262463212158005E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,  -6.4262463212158005E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,   6.4262463212158005E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,  -6.4262463212158005E-01,   7.4941293852912005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,  -6.4262463212158005E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,   6.4262463212158005E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,  -6.4262463212158005E-01,  -7.4941293852912005E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,   6.4262463212158005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,   6.4262463212158005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,  -6.4262463212158005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,   6.4262463212158005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,  -6.4262463212158005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,  -6.4262463212158005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,   6.4262463212158005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,  -6.4262463212158005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,   1.5941715640342211E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,   1.5941715640342211E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,  -1.5941715640342211E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,   1.5941715640342211E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,  -1.5941715640342211E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   7.4941293852912005E-01,  -1.5941715640342211E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,   1.5941715640342211E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -7.4941293852912005E-01,  -1.5941715640342211E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,   7.4941293852912005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,   7.4941293852912005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,  -7.4941293852912005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,   7.4941293852912005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,  -7.4941293852912005E-01,   1.5941715640342211E-01,   7.9956127574192914E-03],
            [   6.4262463212158005E-01,  -7.4941293852912005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,   7.4941293852912005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [  -6.4262463212158005E-01,  -7.4941293852912005E-01,  -1.5941715640342211E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,   7.4941293852912005E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,   7.4941293852912005E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,  -7.4941293852912005E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,   7.4941293852912005E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,  -7.4941293852912005E-01,   6.4262463212158005E-01,   7.9956127574192914E-03],
            [   1.5941715640342211E-01,  -7.4941293852912005E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,   7.4941293852912005E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [  -1.5941715640342211E-01,  -7.4941293852912005E-01,  -6.4262463212158005E-01,   7.9956127574192914E-03],
            [   6.5119043673761134E-01,   5.3547895365655400E-02,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,   5.3547895365655400E-02,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,  -5.3547895365655400E-02,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,   5.3547895365655400E-02,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,  -5.3547895365655400E-02,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,  -5.3547895365655400E-02,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,   5.3547895365655400E-02,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,  -5.3547895365655400E-02,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,   6.5119043673761134E-01,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,   6.5119043673761134E-01,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,  -6.5119043673761134E-01,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,   6.5119043673761134E-01,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,  -6.5119043673761134E-01,   7.5702287812416069E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,  -6.5119043673761134E-01,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,   6.5119043673761134E-01,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,  -6.5119043673761134E-01,  -7.5702287812416069E-01,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,   6.5119043673761134E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,   6.5119043673761134E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,  -6.5119043673761134E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,   6.5119043673761134E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,  -6.5119043673761134E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,  -6.5119043673761134E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,   6.5119043673761134E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,  -6.5119043673761134E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,   5.3547895365655400E-02,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,   5.3547895365655400E-02,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,  -5.3547895365655400E-02,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,   5.3547895365655400E-02,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,  -5.3547895365655400E-02,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   7.5702287812416069E-01,  -5.3547895365655400E-02,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,   5.3547895365655400E-02,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -7.5702287812416069E-01,  -5.3547895365655400E-02,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,   7.5702287812416069E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,   7.5702287812416069E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,  -7.5702287812416069E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,   7.5702287812416069E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,  -7.5702287812416069E-01,   5.3547895365655400E-02,   8.0115817284444595E-03],
            [   6.5119043673761134E-01,  -7.5702287812416069E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,   7.5702287812416069E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [  -6.5119043673761134E-01,  -7.5702287812416069E-01,  -5.3547895365655400E-02,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,   7.5702287812416069E-01,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,   7.5702287812416069E-01,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,  -7.5702287812416069E-01,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,   7.5702287812416069E-01,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,  -7.5702287812416069E-01,   6.5119043673761134E-01,   8.0115817284444595E-03],
            [   5.3547895365655400E-02,  -7.5702287812416069E-01,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,   7.5702287812416069E-01,  -6.5119043673761134E-01,   8.0115817284444595E-03],
            [  -5.3547895365655400E-02,  -7.5702287812416069E-01,  -6.5119043673761134E-01,   8.0115817284444595E-03],
        ])
  
        order = 71
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build2030():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   5.8509422437593524E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   5.8509422437593524E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   5.8509422437593524E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   5.8509422437593524E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   5.8509422437593524E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   5.8509422437593524E-04],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   6.8129196492064080E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   6.8129196492064080E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   6.8129196492064080E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   6.8129196492064080E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   6.8129196492064080E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   6.8129196492064080E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   6.8129196492064080E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   6.8129196492064080E-03],
            [   2.5408353368143479E-02,   2.5408353368143479E-02,   9.9935420705485556E-01,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,   2.5408353368143479E-02,   9.9935420705485556E-01,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,  -2.5408353368143479E-02,   9.9935420705485556E-01,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,   2.5408353368143479E-02,  -9.9935420705485556E-01,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,  -2.5408353368143479E-02,   9.9935420705485556E-01,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,   2.5408353368143479E-02,  -9.9935420705485556E-01,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,  -2.5408353368143479E-02,  -9.9935420705485556E-01,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,  -2.5408353368143479E-02,  -9.9935420705485556E-01,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,   9.9935420705485556E-01,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,  -9.9935420705485556E-01,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,   9.9935420705485556E-01,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,  -9.9935420705485556E-01,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,   9.9935420705485556E-01,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,  -9.9935420705485556E-01,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -2.5408353368143479E-02,  -9.9935420705485556E-01,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [   2.5408353368143479E-02,   9.9935420705485556E-01,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [   9.9935420705485556E-01,   2.5408353368143479E-02,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -9.9935420705485556E-01,   2.5408353368143479E-02,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [   9.9935420705485556E-01,  -2.5408353368143479E-02,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [   9.9935420705485556E-01,   2.5408353368143479E-02,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -9.9935420705485556E-01,  -2.5408353368143479E-02,   2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -9.9935420705485556E-01,   2.5408353368143479E-02,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [   9.9935420705485556E-01,  -2.5408353368143479E-02,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [  -9.9935420705485556E-01,  -2.5408353368143479E-02,  -2.5408353368143479E-02,   2.2349568273473510E-03],
            [   6.3993228005049155E-02,   6.3993228005049155E-02,   9.9589644719668902E-01,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,   6.3993228005049155E-02,   9.9589644719668902E-01,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,  -6.3993228005049155E-02,   9.9589644719668902E-01,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,   6.3993228005049155E-02,  -9.9589644719668902E-01,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,  -6.3993228005049155E-02,   9.9589644719668902E-01,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,   6.3993228005049155E-02,  -9.9589644719668902E-01,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,  -6.3993228005049155E-02,  -9.9589644719668902E-01,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,  -6.3993228005049155E-02,  -9.9589644719668902E-01,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,   9.9589644719668902E-01,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,  -9.9589644719668902E-01,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,   9.9589644719668902E-01,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,  -9.9589644719668902E-01,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,   9.9589644719668902E-01,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,  -9.9589644719668902E-01,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -6.3993228005049155E-02,  -9.9589644719668902E-01,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [   6.3993228005049155E-02,   9.9589644719668902E-01,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [   9.9589644719668902E-01,   6.3993228005049155E-02,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -9.9589644719668902E-01,   6.3993228005049155E-02,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [   9.9589644719668902E-01,  -6.3993228005049155E-02,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [   9.9589644719668902E-01,   6.3993228005049155E-02,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -9.9589644719668902E-01,  -6.3993228005049155E-02,   6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -9.9589644719668902E-01,   6.3993228005049155E-02,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [   9.9589644719668902E-01,  -6.3993228005049155E-02,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [  -9.9589644719668902E-01,  -6.3993228005049155E-02,  -6.3993228005049155E-02,   3.5328156965373668E-03],
            [   1.0882694698041250E-01,   1.0882694698041250E-01,   9.8808572058392030E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,   1.0882694698041250E-01,   9.8808572058392030E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,  -1.0882694698041250E-01,   9.8808572058392030E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,   1.0882694698041250E-01,  -9.8808572058392030E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,  -1.0882694698041250E-01,   9.8808572058392030E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,   1.0882694698041250E-01,  -9.8808572058392030E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,  -1.0882694698041250E-01,  -9.8808572058392030E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,  -1.0882694698041250E-01,  -9.8808572058392030E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,   9.8808572058392030E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,  -9.8808572058392030E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,   9.8808572058392030E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,  -9.8808572058392030E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,   9.8808572058392030E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,  -9.8808572058392030E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -1.0882694698041250E-01,  -9.8808572058392030E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [   1.0882694698041250E-01,   9.8808572058392030E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [   9.8808572058392030E-01,   1.0882694698041250E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -9.8808572058392030E-01,   1.0882694698041250E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [   9.8808572058392030E-01,  -1.0882694698041250E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [   9.8808572058392030E-01,   1.0882694698041250E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -9.8808572058392030E-01,  -1.0882694698041250E-01,   1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -9.8808572058392030E-01,   1.0882694698041250E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [   9.8808572058392030E-01,  -1.0882694698041250E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [  -9.8808572058392030E-01,  -1.0882694698041250E-01,  -1.0882694698041250E-01,   4.4596746336459589E-03],
            [   1.5706707988182869E-01,   1.5706707988182869E-01,   9.7501787923852479E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,   1.5706707988182869E-01,   9.7501787923852479E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,  -1.5706707988182869E-01,   9.7501787923852479E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,   1.5706707988182869E-01,  -9.7501787923852479E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,  -1.5706707988182869E-01,   9.7501787923852479E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,   1.5706707988182869E-01,  -9.7501787923852479E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,  -1.5706707988182869E-01,  -9.7501787923852479E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,  -1.5706707988182869E-01,  -9.7501787923852479E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,   9.7501787923852479E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,  -9.7501787923852479E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,   9.7501787923852479E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,  -9.7501787923852479E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,   9.7501787923852479E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,  -9.7501787923852479E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -1.5706707988182869E-01,  -9.7501787923852479E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [   1.5706707988182869E-01,   9.7501787923852479E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [   9.7501787923852479E-01,   1.5706707988182869E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -9.7501787923852479E-01,   1.5706707988182869E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [   9.7501787923852479E-01,  -1.5706707988182869E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [   9.7501787923852479E-01,   1.5706707988182869E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -9.7501787923852479E-01,  -1.5706707988182869E-01,   1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -9.7501787923852479E-01,   1.5706707988182869E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [   9.7501787923852479E-01,  -1.5706707988182869E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [  -9.7501787923852479E-01,  -1.5706707988182869E-01,  -1.5706707988182869E-01,   5.1400362661832462E-03],
            [   2.0711639322825140E-01,   2.0711639322825140E-01,   9.5614099342735048E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,   2.0711639322825140E-01,   9.5614099342735048E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,  -2.0711639322825140E-01,   9.5614099342735048E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,   2.0711639322825140E-01,  -9.5614099342735048E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,  -2.0711639322825140E-01,   9.5614099342735048E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,   2.0711639322825140E-01,  -9.5614099342735048E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,  -2.0711639322825140E-01,  -9.5614099342735048E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,  -2.0711639322825140E-01,  -9.5614099342735048E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,   9.5614099342735048E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,  -9.5614099342735048E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,   9.5614099342735048E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,  -9.5614099342735048E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,   9.5614099342735048E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,  -9.5614099342735048E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -2.0711639322825140E-01,  -9.5614099342735048E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [   2.0711639322825140E-01,   9.5614099342735048E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [   9.5614099342735048E-01,   2.0711639322825140E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -9.5614099342735048E-01,   2.0711639322825140E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [   9.5614099342735048E-01,  -2.0711639322825140E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [   9.5614099342735048E-01,   2.0711639322825140E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -9.5614099342735048E-01,  -2.0711639322825140E-01,   2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -9.5614099342735048E-01,   2.0711639322825140E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [   9.5614099342735048E-01,  -2.0711639322825140E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [  -9.5614099342735048E-01,  -2.0711639322825140E-01,  -2.0711639322825140E-01,   5.6464298838340976E-03],
            [   2.5789140444508440E-01,   2.5789140444508440E-01,   9.3111978124550865E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,   2.5789140444508440E-01,   9.3111978124550865E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,  -2.5789140444508440E-01,   9.3111978124550865E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,   2.5789140444508440E-01,  -9.3111978124550865E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,  -2.5789140444508440E-01,   9.3111978124550865E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,   2.5789140444508440E-01,  -9.3111978124550865E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,  -2.5789140444508440E-01,  -9.3111978124550865E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,  -2.5789140444508440E-01,  -9.3111978124550865E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,   9.3111978124550865E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,  -9.3111978124550865E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,   9.3111978124550865E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,  -9.3111978124550865E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,   9.3111978124550865E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,  -9.3111978124550865E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -2.5789140444508440E-01,  -9.3111978124550865E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [   2.5789140444508440E-01,   9.3111978124550865E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [   9.3111978124550865E-01,   2.5789140444508440E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -9.3111978124550865E-01,   2.5789140444508440E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [   9.3111978124550865E-01,  -2.5789140444508440E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [   9.3111978124550865E-01,   2.5789140444508440E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -9.3111978124550865E-01,  -2.5789140444508440E-01,   2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -9.3111978124550865E-01,   2.5789140444508440E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [   9.3111978124550865E-01,  -2.5789140444508440E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [  -9.3111978124550865E-01,  -2.5789140444508440E-01,  -2.5789140444508440E-01,   6.0239768301696365E-03],
            [   3.0856875581696230E-01,   3.0856875581696230E-01,   8.9976143830859068E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,   3.0856875581696230E-01,   8.9976143830859068E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,  -3.0856875581696230E-01,   8.9976143830859068E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,   3.0856875581696230E-01,  -8.9976143830859068E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,  -3.0856875581696230E-01,   8.9976143830859068E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,   3.0856875581696230E-01,  -8.9976143830859068E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,  -3.0856875581696230E-01,  -8.9976143830859068E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,  -3.0856875581696230E-01,  -8.9976143830859068E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,   8.9976143830859068E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,  -8.9976143830859068E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,   8.9976143830859068E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,  -8.9976143830859068E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,   8.9976143830859068E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,  -8.9976143830859068E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -3.0856875581696230E-01,  -8.9976143830859068E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [   3.0856875581696230E-01,   8.9976143830859068E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [   8.9976143830859068E-01,   3.0856875581696230E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -8.9976143830859068E-01,   3.0856875581696230E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [   8.9976143830859068E-01,  -3.0856875581696230E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [   8.9976143830859068E-01,   3.0856875581696230E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -8.9976143830859068E-01,  -3.0856875581696230E-01,   3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -8.9976143830859068E-01,   3.0856875581696230E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [   8.9976143830859068E-01,  -3.0856875581696230E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [  -8.9976143830859068E-01,  -3.0856875581696230E-01,  -3.0856875581696230E-01,   6.3025567685552645E-03],
            [   3.5847197062670239E-01,   3.5847197062670239E-01,   8.6197197898192557E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,   3.5847197062670239E-01,   8.6197197898192557E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,  -3.5847197062670239E-01,   8.6197197898192557E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,   3.5847197062670239E-01,  -8.6197197898192557E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,  -3.5847197062670239E-01,   8.6197197898192557E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,   3.5847197062670239E-01,  -8.6197197898192557E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,  -3.5847197062670239E-01,  -8.6197197898192557E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,  -3.5847197062670239E-01,  -8.6197197898192557E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,   8.6197197898192557E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,  -8.6197197898192557E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,   8.6197197898192557E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,  -8.6197197898192557E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,   8.6197197898192557E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,  -8.6197197898192557E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -3.5847197062670239E-01,  -8.6197197898192557E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [   3.5847197062670239E-01,   8.6197197898192557E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [   8.6197197898192557E-01,   3.5847197062670239E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -8.6197197898192557E-01,   3.5847197062670239E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [   8.6197197898192557E-01,  -3.5847197062670239E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [   8.6197197898192557E-01,   3.5847197062670239E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -8.6197197898192557E-01,  -3.5847197062670239E-01,   3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -8.6197197898192557E-01,   3.5847197062670239E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [   8.6197197898192557E-01,  -3.5847197062670239E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [  -8.6197197898192557E-01,  -3.5847197062670239E-01,  -3.5847197062670239E-01,   6.5032568541585822E-03],
            [   4.0701355944287088E-01,   4.0701355944287088E-01,   8.1772851537615410E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,   4.0701355944287088E-01,   8.1772851537615410E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,  -4.0701355944287088E-01,   8.1772851537615410E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,   4.0701355944287088E-01,  -8.1772851537615410E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,  -4.0701355944287088E-01,   8.1772851537615410E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,   4.0701355944287088E-01,  -8.1772851537615410E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,  -4.0701355944287088E-01,  -8.1772851537615410E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,  -4.0701355944287088E-01,  -8.1772851537615410E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,   8.1772851537615410E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,  -8.1772851537615410E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,   8.1772851537615410E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,  -8.1772851537615410E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,   8.1772851537615410E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,  -8.1772851537615410E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -4.0701355944287088E-01,  -8.1772851537615410E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [   4.0701355944287088E-01,   8.1772851537615410E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [   8.1772851537615410E-01,   4.0701355944287088E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -8.1772851537615410E-01,   4.0701355944287088E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [   8.1772851537615410E-01,  -4.0701355944287088E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [   8.1772851537615410E-01,   4.0701355944287088E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -8.1772851537615410E-01,  -4.0701355944287088E-01,   4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -8.1772851537615410E-01,   4.0701355944287088E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [   8.1772851537615410E-01,  -4.0701355944287088E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [  -8.1772851537615410E-01,  -4.0701355944287088E-01,  -4.0701355944287088E-01,   6.6419831635756137E-03],
            [   4.5366186262226382E-01,   4.5366186262226382E-01,   7.6706051182693302E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,   4.5366186262226382E-01,   7.6706051182693302E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,  -4.5366186262226382E-01,   7.6706051182693302E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,   4.5366186262226382E-01,  -7.6706051182693302E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,  -4.5366186262226382E-01,   7.6706051182693302E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,   4.5366186262226382E-01,  -7.6706051182693302E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,  -4.5366186262226382E-01,  -7.6706051182693302E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,  -4.5366186262226382E-01,  -7.6706051182693302E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,   7.6706051182693302E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,  -7.6706051182693302E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,   7.6706051182693302E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,  -7.6706051182693302E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,   7.6706051182693302E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,  -7.6706051182693302E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -4.5366186262226382E-01,  -7.6706051182693302E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [   4.5366186262226382E-01,   7.6706051182693302E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [   7.6706051182693302E-01,   4.5366186262226382E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -7.6706051182693302E-01,   4.5366186262226382E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [   7.6706051182693302E-01,  -4.5366186262226382E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [   7.6706051182693302E-01,   4.5366186262226382E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -7.6706051182693302E-01,  -4.5366186262226382E-01,   4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -7.6706051182693302E-01,   4.5366186262226382E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [   7.6706051182693302E-01,  -4.5366186262226382E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [  -7.6706051182693302E-01,  -4.5366186262226382E-01,  -4.5366186262226382E-01,   6.7315945073989324E-03],
            [   4.9791956864635772E-01,   4.9791956864635772E-01,   7.1003676406088312E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,   4.9791956864635772E-01,   7.1003676406088312E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,  -4.9791956864635772E-01,   7.1003676406088312E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,   4.9791956864635772E-01,  -7.1003676406088312E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,  -4.9791956864635772E-01,   7.1003676406088312E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,   4.9791956864635772E-01,  -7.1003676406088312E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,  -4.9791956864635772E-01,  -7.1003676406088312E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,  -4.9791956864635772E-01,  -7.1003676406088312E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,   7.1003676406088312E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,  -7.1003676406088312E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,   7.1003676406088312E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,  -7.1003676406088312E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,   7.1003676406088312E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,  -7.1003676406088312E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -4.9791956864635772E-01,  -7.1003676406088312E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [   4.9791956864635772E-01,   7.1003676406088312E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [   7.1003676406088312E-01,   4.9791956864635772E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -7.1003676406088312E-01,   4.9791956864635772E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [   7.1003676406088312E-01,  -4.9791956864635772E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [   7.1003676406088312E-01,   4.9791956864635772E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -7.1003676406088312E-01,  -4.9791956864635772E-01,   4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -7.1003676406088312E-01,   4.9791956864635772E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [   7.1003676406088312E-01,  -4.9791956864635772E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [  -7.1003676406088312E-01,  -4.9791956864635772E-01,  -4.9791956864635772E-01,   6.7832197119488003E-03],
            [   5.3930751111269992E-01,   5.3930751111269992E-01,   6.4675715451384852E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,   5.3930751111269992E-01,   6.4675715451384852E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,  -5.3930751111269992E-01,   6.4675715451384852E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,   5.3930751111269992E-01,  -6.4675715451384852E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,  -5.3930751111269992E-01,   6.4675715451384852E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,   5.3930751111269992E-01,  -6.4675715451384852E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,  -5.3930751111269992E-01,  -6.4675715451384852E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,  -5.3930751111269992E-01,  -6.4675715451384852E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,   6.4675715451384852E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,  -6.4675715451384852E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,   6.4675715451384852E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,  -6.4675715451384852E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,   6.4675715451384852E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,  -6.4675715451384852E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -5.3930751111269992E-01,  -6.4675715451384852E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [   5.3930751111269992E-01,   6.4675715451384852E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [   6.4675715451384852E-01,   5.3930751111269992E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -6.4675715451384852E-01,   5.3930751111269992E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [   6.4675715451384852E-01,  -5.3930751111269992E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [   6.4675715451384852E-01,   5.3930751111269992E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -6.4675715451384852E-01,  -5.3930751111269992E-01,   5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -6.4675715451384852E-01,   5.3930751111269992E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [   6.4675715451384852E-01,  -5.3930751111269992E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [  -6.4675715451384852E-01,  -5.3930751111269992E-01,  -5.3930751111269992E-01,   6.8070765963859966E-03],
            [   6.1156176768439163E-01,   6.1156176768439163E-01,   5.0198048628754921E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,   6.1156176768439163E-01,   5.0198048628754921E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,  -6.1156176768439163E-01,   5.0198048628754921E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,   6.1156176768439163E-01,  -5.0198048628754921E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,  -6.1156176768439163E-01,   5.0198048628754921E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,   6.1156176768439163E-01,  -5.0198048628754921E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,  -6.1156176768439163E-01,  -5.0198048628754921E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,  -6.1156176768439163E-01,  -5.0198048628754921E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,   5.0198048628754921E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,  -5.0198048628754921E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,   5.0198048628754921E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,  -5.0198048628754921E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,   5.0198048628754921E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,  -5.0198048628754921E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -6.1156176768439163E-01,  -5.0198048628754921E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [   6.1156176768439163E-01,   5.0198048628754921E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [   5.0198048628754921E-01,   6.1156176768439163E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -5.0198048628754921E-01,   6.1156176768439163E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [   5.0198048628754921E-01,  -6.1156176768439163E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [   5.0198048628754921E-01,   6.1156176768439163E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -5.0198048628754921E-01,  -6.1156176768439163E-01,   6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -5.0198048628754921E-01,   6.1156176768439163E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [   5.0198048628754921E-01,  -6.1156176768439163E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [  -5.0198048628754921E-01,  -6.1156176768439163E-01,  -6.1156176768439163E-01,   6.8101038794137281E-03],
            [   6.4143084351601587E-01,   6.4143084351601587E-01,   4.2087165023634548E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,   6.4143084351601587E-01,   4.2087165023634548E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,  -6.4143084351601587E-01,   4.2087165023634548E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,   6.4143084351601587E-01,  -4.2087165023634548E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,  -6.4143084351601587E-01,   4.2087165023634548E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,   6.4143084351601587E-01,  -4.2087165023634548E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,  -6.4143084351601587E-01,  -4.2087165023634548E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,  -6.4143084351601587E-01,  -4.2087165023634548E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,   4.2087165023634548E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,  -4.2087165023634548E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,   4.2087165023634548E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,  -4.2087165023634548E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,   4.2087165023634548E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,  -4.2087165023634548E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -6.4143084351601587E-01,  -4.2087165023634548E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [   6.4143084351601587E-01,   4.2087165023634548E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [   4.2087165023634548E-01,   6.4143084351601587E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -4.2087165023634548E-01,   6.4143084351601587E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [   4.2087165023634548E-01,  -6.4143084351601587E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [   4.2087165023634548E-01,   6.4143084351601587E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -4.2087165023634548E-01,  -6.4143084351601587E-01,   6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -4.2087165023634548E-01,   6.4143084351601587E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [   4.2087165023634548E-01,  -6.4143084351601587E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [  -4.2087165023634548E-01,  -6.4143084351601587E-01,  -6.4143084351601587E-01,   6.8071236705515093E-03],
            [   6.6640994127216069E-01,   6.6640994127216069E-01,   3.3435846085791021E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,   6.6640994127216069E-01,   3.3435846085791021E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,  -6.6640994127216069E-01,   3.3435846085791021E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,   6.6640994127216069E-01,  -3.3435846085791021E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,  -6.6640994127216069E-01,   3.3435846085791021E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,   6.6640994127216069E-01,  -3.3435846085791021E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,  -6.6640994127216069E-01,  -3.3435846085791021E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,  -6.6640994127216069E-01,  -3.3435846085791021E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,   3.3435846085791021E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,  -3.3435846085791021E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,   3.3435846085791021E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,  -3.3435846085791021E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,   3.3435846085791021E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,  -3.3435846085791021E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -6.6640994127216069E-01,  -3.3435846085791021E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [   6.6640994127216069E-01,   3.3435846085791021E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [   3.3435846085791021E-01,   6.6640994127216069E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -3.3435846085791021E-01,   6.6640994127216069E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [   3.3435846085791021E-01,  -6.6640994127216069E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [   3.3435846085791021E-01,   6.6640994127216069E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -3.3435846085791021E-01,  -6.6640994127216069E-01,   6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -3.3435846085791021E-01,   6.6640994127216069E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [   3.3435846085791021E-01,  -6.6640994127216069E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [  -3.3435846085791021E-01,  -6.6640994127216069E-01,  -6.6640994127216069E-01,   6.8104002721096051E-03],
            [   6.8591617712149133E-01,   6.8591617712149133E-01,   2.4297735681762167E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,   6.8591617712149133E-01,   2.4297735681762167E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,  -6.8591617712149133E-01,   2.4297735681762167E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,   6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,  -6.8591617712149133E-01,   2.4297735681762167E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,   6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,  -6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,  -6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,   2.4297735681762167E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,   2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,  -2.4297735681762167E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,   2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,  -2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -6.8591617712149133E-01,  -2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [   6.8591617712149133E-01,   2.4297735681762167E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [   2.4297735681762167E-01,   6.8591617712149133E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -2.4297735681762167E-01,   6.8591617712149133E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [   2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [   2.4297735681762167E-01,   6.8591617712149133E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -2.4297735681762167E-01,  -6.8591617712149133E-01,   6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -2.4297735681762167E-01,   6.8591617712149133E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [   2.4297735681762167E-01,  -6.8591617712149133E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [  -2.4297735681762167E-01,  -6.8591617712149133E-01,  -6.8591617712149133E-01,   6.8222620688523682E-03],
            [   6.9936255935038905E-01,   6.9936255935038905E-01,   1.4759410949542376E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,   6.9936255935038905E-01,   1.4759410949542376E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,  -6.9936255935038905E-01,   1.4759410949542376E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,   6.9936255935038905E-01,  -1.4759410949542376E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,  -6.9936255935038905E-01,   1.4759410949542376E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,   6.9936255935038905E-01,  -1.4759410949542376E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,  -6.9936255935038905E-01,  -1.4759410949542376E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,  -6.9936255935038905E-01,  -1.4759410949542376E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,   1.4759410949542376E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,  -1.4759410949542376E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,   1.4759410949542376E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,  -1.4759410949542376E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,   1.4759410949542376E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,  -1.4759410949542376E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -6.9936255935038905E-01,  -1.4759410949542376E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [   6.9936255935038905E-01,   1.4759410949542376E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [   1.4759410949542376E-01,   6.9936255935038905E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -1.4759410949542376E-01,   6.9936255935038905E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [   1.4759410949542376E-01,  -6.9936255935038905E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [   1.4759410949542376E-01,   6.9936255935038905E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -1.4759410949542376E-01,  -6.9936255935038905E-01,   6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -1.4759410949542376E-01,   6.9936255935038905E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [   1.4759410949542376E-01,  -6.9936255935038905E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [  -1.4759410949542376E-01,  -6.9936255935038905E-01,  -6.9936255935038905E-01,   6.8389789149757565E-03],
            [   7.0623933877193801E-01,   7.0623933877193801E-01,   4.9517600325051238E-02,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,   7.0623933877193801E-01,   4.9517600325051238E-02,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,  -7.0623933877193801E-01,   4.9517600325051238E-02,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,   7.0623933877193801E-01,  -4.9517600325051238E-02,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,  -7.0623933877193801E-01,   4.9517600325051238E-02,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,   7.0623933877193801E-01,  -4.9517600325051238E-02,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,  -7.0623933877193801E-01,  -4.9517600325051238E-02,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,  -7.0623933877193801E-01,  -4.9517600325051238E-02,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,   4.9517600325051238E-02,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,  -4.9517600325051238E-02,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,   4.9517600325051238E-02,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,  -4.9517600325051238E-02,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,   4.9517600325051238E-02,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,  -4.9517600325051238E-02,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -7.0623933877193801E-01,  -4.9517600325051238E-02,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [   7.0623933877193801E-01,   4.9517600325051238E-02,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [   4.9517600325051238E-02,   7.0623933877193801E-01,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -4.9517600325051238E-02,   7.0623933877193801E-01,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [   4.9517600325051238E-02,  -7.0623933877193801E-01,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [   4.9517600325051238E-02,   7.0623933877193801E-01,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -4.9517600325051238E-02,  -7.0623933877193801E-01,   7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -4.9517600325051238E-02,   7.0623933877193801E-01,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [   4.9517600325051238E-02,  -7.0623933877193801E-01,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [  -4.9517600325051238E-02,  -7.0623933877193801E-01,  -7.0623933877193801E-01,   6.8514998518257719E-03],
            [   7.4790281683497634E-02,   9.9719928488026055E-01,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [  -7.4790281683497634E-02,   9.9719928488026055E-01,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [   7.4790281683497634E-02,  -9.9719928488026055E-01,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [  -7.4790281683497634E-02,  -9.9719928488026055E-01,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [   9.9719928488026055E-01,   7.4790281683497634E-02,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [  -9.9719928488026055E-01,   7.4790281683497634E-02,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [   9.9719928488026055E-01,  -7.4790281683497634E-02,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [  -9.9719928488026055E-01,  -7.4790281683497634E-02,   0.0000000000000000E+00,   3.2270471125056760E-03],
            [   7.4790281683497634E-02,   0.0000000000000000E+00,   9.9719928488026055E-01,   3.2270471125056760E-03],
            [  -7.4790281683497634E-02,   0.0000000000000000E+00,   9.9719928488026055E-01,   3.2270471125056760E-03],
            [   7.4790281683497634E-02,   0.0000000000000000E+00,  -9.9719928488026055E-01,   3.2270471125056760E-03],
            [  -7.4790281683497634E-02,   0.0000000000000000E+00,  -9.9719928488026055E-01,   3.2270471125056760E-03],
            [   9.9719928488026055E-01,   0.0000000000000000E+00,   7.4790281683497634E-02,   3.2270471125056760E-03],
            [  -9.9719928488026055E-01,   0.0000000000000000E+00,   7.4790281683497634E-02,   3.2270471125056760E-03],
            [   9.9719928488026055E-01,   0.0000000000000000E+00,  -7.4790281683497634E-02,   3.2270471125056760E-03],
            [  -9.9719928488026055E-01,   0.0000000000000000E+00,  -7.4790281683497634E-02,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,   7.4790281683497634E-02,   9.9719928488026055E-01,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,  -7.4790281683497634E-02,   9.9719928488026055E-01,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,   7.4790281683497634E-02,  -9.9719928488026055E-01,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,  -7.4790281683497634E-02,  -9.9719928488026055E-01,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,   9.9719928488026055E-01,   7.4790281683497634E-02,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,  -9.9719928488026055E-01,   7.4790281683497634E-02,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,   9.9719928488026055E-01,  -7.4790281683497634E-02,   3.2270471125056760E-03],
            [   0.0000000000000000E+00,  -9.9719928488026055E-01,  -7.4790281683497634E-02,   3.2270471125056760E-03],
            [   1.8489511539693659E-01,   9.8275825934069538E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [  -1.8489511539693659E-01,   9.8275825934069538E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [   1.8489511539693659E-01,  -9.8275825934069538E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [  -1.8489511539693659E-01,  -9.8275825934069538E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [   9.8275825934069538E-01,   1.8489511539693659E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [  -9.8275825934069538E-01,   1.8489511539693659E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [   9.8275825934069538E-01,  -1.8489511539693659E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [  -9.8275825934069538E-01,  -1.8489511539693659E-01,   0.0000000000000000E+00,   4.8094160645482812E-03],
            [   1.8489511539693659E-01,   0.0000000000000000E+00,   9.8275825934069538E-01,   4.8094160645482812E-03],
            [  -1.8489511539693659E-01,   0.0000000000000000E+00,   9.8275825934069538E-01,   4.8094160645482812E-03],
            [   1.8489511539693659E-01,   0.0000000000000000E+00,  -9.8275825934069538E-01,   4.8094160645482812E-03],
            [  -1.8489511539693659E-01,   0.0000000000000000E+00,  -9.8275825934069538E-01,   4.8094160645482812E-03],
            [   9.8275825934069538E-01,   0.0000000000000000E+00,   1.8489511539693659E-01,   4.8094160645482812E-03],
            [  -9.8275825934069538E-01,   0.0000000000000000E+00,   1.8489511539693659E-01,   4.8094160645482812E-03],
            [   9.8275825934069538E-01,   0.0000000000000000E+00,  -1.8489511539693659E-01,   4.8094160645482812E-03],
            [  -9.8275825934069538E-01,   0.0000000000000000E+00,  -1.8489511539693659E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,   1.8489511539693659E-01,   9.8275825934069538E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,  -1.8489511539693659E-01,   9.8275825934069538E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,   1.8489511539693659E-01,  -9.8275825934069538E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,  -1.8489511539693659E-01,  -9.8275825934069538E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,   9.8275825934069538E-01,   1.8489511539693659E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,  -9.8275825934069538E-01,   1.8489511539693659E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,   9.8275825934069538E-01,  -1.8489511539693659E-01,   4.8094160645482812E-03],
            [   0.0000000000000000E+00,  -9.8275825934069538E-01,  -1.8489511539693659E-01,   4.8094160645482812E-03],
            [   3.0595290665813052E-01,   9.5204664744299228E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [  -3.0595290665813052E-01,   9.5204664744299228E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [   3.0595290665813052E-01,  -9.5204664744299228E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [  -3.0595290665813052E-01,  -9.5204664744299228E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [   9.5204664744299228E-01,   3.0595290665813052E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [  -9.5204664744299228E-01,   3.0595290665813052E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [   9.5204664744299228E-01,  -3.0595290665813052E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [  -9.5204664744299228E-01,  -3.0595290665813052E-01,   0.0000000000000000E+00,   5.7547588192389931E-03],
            [   3.0595290665813052E-01,   0.0000000000000000E+00,   9.5204664744299228E-01,   5.7547588192389931E-03],
            [  -3.0595290665813052E-01,   0.0000000000000000E+00,   9.5204664744299228E-01,   5.7547588192389931E-03],
            [   3.0595290665813052E-01,   0.0000000000000000E+00,  -9.5204664744299228E-01,   5.7547588192389931E-03],
            [  -3.0595290665813052E-01,   0.0000000000000000E+00,  -9.5204664744299228E-01,   5.7547588192389931E-03],
            [   9.5204664744299228E-01,   0.0000000000000000E+00,   3.0595290665813052E-01,   5.7547588192389931E-03],
            [  -9.5204664744299228E-01,   0.0000000000000000E+00,   3.0595290665813052E-01,   5.7547588192389931E-03],
            [   9.5204664744299228E-01,   0.0000000000000000E+00,  -3.0595290665813052E-01,   5.7547588192389931E-03],
            [  -9.5204664744299228E-01,   0.0000000000000000E+00,  -3.0595290665813052E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,   3.0595290665813052E-01,   9.5204664744299228E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,  -3.0595290665813052E-01,   9.5204664744299228E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,   3.0595290665813052E-01,  -9.5204664744299228E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,  -3.0595290665813052E-01,  -9.5204664744299228E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,   9.5204664744299228E-01,   3.0595290665813052E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,  -9.5204664744299228E-01,   3.0595290665813052E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,   9.5204664744299228E-01,  -3.0595290665813052E-01,   5.7547588192389931E-03],
            [   0.0000000000000000E+00,  -9.5204664744299228E-01,  -3.0595290665813052E-01,   5.7547588192389931E-03],
            [   4.2855561010213622E-01,   9.0351540609443171E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [  -4.2855561010213622E-01,   9.0351540609443171E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [   4.2855561010213622E-01,  -9.0351540609443171E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [  -4.2855561010213622E-01,  -9.0351540609443171E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [   9.0351540609443171E-01,   4.2855561010213622E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [  -9.0351540609443171E-01,   4.2855561010213622E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [   9.0351540609443171E-01,  -4.2855561010213622E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [  -9.0351540609443171E-01,  -4.2855561010213622E-01,   0.0000000000000000E+00,   6.3359690514574142E-03],
            [   4.2855561010213622E-01,   0.0000000000000000E+00,   9.0351540609443171E-01,   6.3359690514574142E-03],
            [  -4.2855561010213622E-01,   0.0000000000000000E+00,   9.0351540609443171E-01,   6.3359690514574142E-03],
            [   4.2855561010213622E-01,   0.0000000000000000E+00,  -9.0351540609443171E-01,   6.3359690514574142E-03],
            [  -4.2855561010213622E-01,   0.0000000000000000E+00,  -9.0351540609443171E-01,   6.3359690514574142E-03],
            [   9.0351540609443171E-01,   0.0000000000000000E+00,   4.2855561010213622E-01,   6.3359690514574142E-03],
            [  -9.0351540609443171E-01,   0.0000000000000000E+00,   4.2855561010213622E-01,   6.3359690514574142E-03],
            [   9.0351540609443171E-01,   0.0000000000000000E+00,  -4.2855561010213622E-01,   6.3359690514574142E-03],
            [  -9.0351540609443171E-01,   0.0000000000000000E+00,  -4.2855561010213622E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,   4.2855561010213622E-01,   9.0351540609443171E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,  -4.2855561010213622E-01,   9.0351540609443171E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,   4.2855561010213622E-01,  -9.0351540609443171E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,  -4.2855561010213622E-01,  -9.0351540609443171E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,   9.0351540609443171E-01,   4.2855561010213622E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,  -9.0351540609443171E-01,   4.2855561010213622E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,   9.0351540609443171E-01,  -4.2855561010213622E-01,   6.3359690514574142E-03],
            [   0.0000000000000000E+00,  -9.0351540609443171E-01,  -4.2855561010213622E-01,   6.3359690514574142E-03],
            [   5.4687586534965260E-01,   8.3721370503478298E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [  -5.4687586534965260E-01,   8.3721370503478298E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [   5.4687586534965260E-01,  -8.3721370503478298E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [  -5.4687586534965260E-01,  -8.3721370503478298E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [   8.3721370503478298E-01,   5.4687586534965260E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [  -8.3721370503478298E-01,   5.4687586534965260E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [   8.3721370503478298E-01,  -5.4687586534965260E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [  -8.3721370503478298E-01,  -5.4687586534965260E-01,   0.0000000000000000E+00,   6.6761468877639448E-03],
            [   5.4687586534965260E-01,   0.0000000000000000E+00,   8.3721370503478298E-01,   6.6761468877639448E-03],
            [  -5.4687586534965260E-01,   0.0000000000000000E+00,   8.3721370503478298E-01,   6.6761468877639448E-03],
            [   5.4687586534965260E-01,   0.0000000000000000E+00,  -8.3721370503478298E-01,   6.6761468877639448E-03],
            [  -5.4687586534965260E-01,   0.0000000000000000E+00,  -8.3721370503478298E-01,   6.6761468877639448E-03],
            [   8.3721370503478298E-01,   0.0000000000000000E+00,   5.4687586534965260E-01,   6.6761468877639448E-03],
            [  -8.3721370503478298E-01,   0.0000000000000000E+00,   5.4687586534965260E-01,   6.6761468877639448E-03],
            [   8.3721370503478298E-01,   0.0000000000000000E+00,  -5.4687586534965260E-01,   6.6761468877639448E-03],
            [  -8.3721370503478298E-01,   0.0000000000000000E+00,  -5.4687586534965260E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,   5.4687586534965260E-01,   8.3721370503478298E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,  -5.4687586534965260E-01,   8.3721370503478298E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,   5.4687586534965260E-01,  -8.3721370503478298E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,  -5.4687586534965260E-01,  -8.3721370503478298E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,   8.3721370503478298E-01,   5.4687586534965260E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,  -8.3721370503478298E-01,   5.4687586534965260E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,   8.3721370503478298E-01,  -5.4687586534965260E-01,   6.6761468877639448E-03],
            [   0.0000000000000000E+00,  -8.3721370503478298E-01,  -5.4687586534965260E-01,   6.6761468877639448E-03],
            [   6.5658219783434391E-01,   7.5425447793634115E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [  -6.5658219783434391E-01,   7.5425447793634115E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [   6.5658219783434391E-01,  -7.5425447793634115E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [  -6.5658219783434391E-01,  -7.5425447793634115E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [   7.5425447793634115E-01,   6.5658219783434391E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [  -7.5425447793634115E-01,   6.5658219783434391E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [   7.5425447793634115E-01,  -6.5658219783434391E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [  -7.5425447793634115E-01,  -6.5658219783434391E-01,   0.0000000000000000E+00,   6.8340972452322875E-03],
            [   6.5658219783434391E-01,   0.0000000000000000E+00,   7.5425447793634115E-01,   6.8340972452322875E-03],
            [  -6.5658219783434391E-01,   0.0000000000000000E+00,   7.5425447793634115E-01,   6.8340972452322875E-03],
            [   6.5658219783434391E-01,   0.0000000000000000E+00,  -7.5425447793634115E-01,   6.8340972452322875E-03],
            [  -6.5658219783434391E-01,   0.0000000000000000E+00,  -7.5425447793634115E-01,   6.8340972452322875E-03],
            [   7.5425447793634115E-01,   0.0000000000000000E+00,   6.5658219783434391E-01,   6.8340972452322875E-03],
            [  -7.5425447793634115E-01,   0.0000000000000000E+00,   6.5658219783434391E-01,   6.8340972452322875E-03],
            [   7.5425447793634115E-01,   0.0000000000000000E+00,  -6.5658219783434391E-01,   6.8340972452322875E-03],
            [  -7.5425447793634115E-01,   0.0000000000000000E+00,  -6.5658219783434391E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,   6.5658219783434391E-01,   7.5425447793634115E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,  -6.5658219783434391E-01,   7.5425447793634115E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,   6.5658219783434391E-01,  -7.5425447793634115E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,  -6.5658219783434391E-01,  -7.5425447793634115E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,   7.5425447793634115E-01,   6.5658219783434391E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,  -7.5425447793634115E-01,   6.5658219783434391E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,   7.5425447793634115E-01,  -6.5658219783434391E-01,   6.8340972452322875E-03],
            [   0.0000000000000000E+00,  -7.5425447793634115E-01,  -6.5658219783434391E-01,   6.8340972452322875E-03],
            [   1.2539015723671171E-01,   3.6819172264396412E-02,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,   3.6819172264396412E-02,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,  -3.6819172264396412E-02,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,   3.6819172264396412E-02,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,  -3.6819172264396412E-02,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,  -3.6819172264396412E-02,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,   3.6819172264396412E-02,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,  -3.6819172264396412E-02,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,   1.2539015723671171E-01,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,   1.2539015723671171E-01,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,  -1.2539015723671171E-01,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,   1.2539015723671171E-01,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,  -1.2539015723671171E-01,   9.9142405509545584E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,  -1.2539015723671171E-01,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,   1.2539015723671171E-01,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,  -1.2539015723671171E-01,  -9.9142405509545584E-01,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,   1.2539015723671171E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,   1.2539015723671171E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,  -1.2539015723671171E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,   1.2539015723671171E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,  -1.2539015723671171E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,  -1.2539015723671171E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,   1.2539015723671171E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,  -1.2539015723671171E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,   3.6819172264396412E-02,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,   3.6819172264396412E-02,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,  -3.6819172264396412E-02,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,   3.6819172264396412E-02,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,  -3.6819172264396412E-02,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   9.9142405509545584E-01,  -3.6819172264396412E-02,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,   3.6819172264396412E-02,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -9.9142405509545584E-01,  -3.6819172264396412E-02,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,   9.9142405509545584E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,   9.9142405509545584E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,  -9.9142405509545584E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,   9.9142405509545584E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,  -9.9142405509545584E-01,   3.6819172264396412E-02,   4.1670611151331648E-03],
            [   1.2539015723671171E-01,  -9.9142405509545584E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,   9.9142405509545584E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [  -1.2539015723671171E-01,  -9.9142405509545584E-01,  -3.6819172264396412E-02,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,   9.9142405509545584E-01,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,   9.9142405509545584E-01,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,  -9.9142405509545584E-01,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,   9.9142405509545584E-01,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,  -9.9142405509545584E-01,   1.2539015723671171E-01,   4.1670611151331648E-03],
            [   3.6819172264396412E-02,  -9.9142405509545584E-01,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,   9.9142405509545584E-01,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [  -3.6819172264396412E-02,  -9.9142405509545584E-01,  -1.2539015723671171E-01,   4.1670611151331648E-03],
            [   1.7757215103839410E-01,   7.9824876072133011E-02,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,   7.9824876072133011E-02,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,  -7.9824876072133011E-02,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,   7.9824876072133011E-02,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,  -7.9824876072133011E-02,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,  -7.9824876072133011E-02,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,   7.9824876072133011E-02,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,  -7.9824876072133011E-02,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,   1.7757215103839410E-01,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,   1.7757215103839410E-01,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,  -1.7757215103839410E-01,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,   1.7757215103839410E-01,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,  -1.7757215103839410E-01,   9.8086498578329639E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,  -1.7757215103839410E-01,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,   1.7757215103839410E-01,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,  -1.7757215103839410E-01,  -9.8086498578329639E-01,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,   1.7757215103839410E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,   1.7757215103839410E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,  -1.7757215103839410E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,   1.7757215103839410E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,  -1.7757215103839410E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,  -1.7757215103839410E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,   1.7757215103839410E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,  -1.7757215103839410E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,   7.9824876072133011E-02,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,   7.9824876072133011E-02,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,  -7.9824876072133011E-02,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,   7.9824876072133011E-02,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,  -7.9824876072133011E-02,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   9.8086498578329639E-01,  -7.9824876072133011E-02,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,   7.9824876072133011E-02,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -9.8086498578329639E-01,  -7.9824876072133011E-02,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,   9.8086498578329639E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,   9.8086498578329639E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,  -9.8086498578329639E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,   9.8086498578329639E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,  -9.8086498578329639E-01,   7.9824876072133011E-02,   4.8997706152330324E-03],
            [   1.7757215103839410E-01,  -9.8086498578329639E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,   9.8086498578329639E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [  -1.7757215103839410E-01,  -9.8086498578329639E-01,  -7.9824876072133011E-02,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,   9.8086498578329639E-01,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,   9.8086498578329639E-01,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,  -9.8086498578329639E-01,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,   9.8086498578329639E-01,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,  -9.8086498578329639E-01,   1.7757215103839410E-01,   4.8997706152330324E-03],
            [   7.9824876072133011E-02,  -9.8086498578329639E-01,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,   9.8086498578329639E-01,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [  -7.9824876072133011E-02,  -9.8086498578329639E-01,  -1.7757215103839410E-01,   4.8997706152330324E-03],
            [   2.3056933582161140E-01,   1.2646409665923350E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,   1.2646409665923350E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,  -1.2646409665923350E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,   1.2646409665923350E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,  -1.2646409665923350E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,  -1.2646409665923350E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,   1.2646409665923350E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,  -1.2646409665923350E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,   2.3056933582161140E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,   2.3056933582161140E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,  -2.3056933582161140E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,   2.3056933582161140E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,  -2.3056933582161140E-01,   9.6480288848808127E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,  -2.3056933582161140E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,   2.3056933582161140E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,  -2.3056933582161140E-01,  -9.6480288848808127E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,   2.3056933582161140E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,   2.3056933582161140E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,  -2.3056933582161140E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,   2.3056933582161140E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,  -2.3056933582161140E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,  -2.3056933582161140E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,   2.3056933582161140E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,  -2.3056933582161140E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,   1.2646409665923350E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,   1.2646409665923350E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,  -1.2646409665923350E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,   1.2646409665923350E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,  -1.2646409665923350E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   9.6480288848808127E-01,  -1.2646409665923350E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,   1.2646409665923350E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -9.6480288848808127E-01,  -1.2646409665923350E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,   9.6480288848808127E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,   9.6480288848808127E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,  -9.6480288848808127E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,   9.6480288848808127E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,  -9.6480288848808127E-01,   1.2646409665923350E-01,   5.4580061955015521E-03],
            [   2.3056933582161140E-01,  -9.6480288848808127E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,   9.6480288848808127E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [  -2.3056933582161140E-01,  -9.6480288848808127E-01,  -1.2646409665923350E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,   9.6480288848808127E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,   9.6480288848808127E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,  -9.6480288848808127E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,   9.6480288848808127E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,  -9.6480288848808127E-01,   2.3056933582161140E-01,   5.4580061955015521E-03],
            [   1.2646409665923350E-01,  -9.6480288848808127E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,   9.6480288848808127E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [  -1.2646409665923350E-01,  -9.6480288848808127E-01,  -2.3056933582161140E-01,   5.4580061955015521E-03],
            [   2.8365028459920633E-01,   1.7515856834189569E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,   1.7515856834189569E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,  -1.7515856834189569E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,   1.7515856834189569E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,  -1.7515856834189569E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,  -1.7515856834189569E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,   1.7515856834189569E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,  -1.7515856834189569E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,   2.8365028459920633E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,   2.8365028459920633E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,  -2.8365028459920633E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,   2.8365028459920633E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,  -2.8365028459920633E-01,   9.4279477723585570E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,  -2.8365028459920633E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,   2.8365028459920633E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,  -2.8365028459920633E-01,  -9.4279477723585570E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,   2.8365028459920633E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,   2.8365028459920633E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,  -2.8365028459920633E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,   2.8365028459920633E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,  -2.8365028459920633E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,  -2.8365028459920633E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,   2.8365028459920633E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,  -2.8365028459920633E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,   1.7515856834189569E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,   1.7515856834189569E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,  -1.7515856834189569E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,   1.7515856834189569E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,  -1.7515856834189569E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   9.4279477723585570E-01,  -1.7515856834189569E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,   1.7515856834189569E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -9.4279477723585570E-01,  -1.7515856834189569E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,   9.4279477723585570E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,   9.4279477723585570E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,  -9.4279477723585570E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,   9.4279477723585570E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,  -9.4279477723585570E-01,   1.7515856834189569E-01,   5.8803266444788288E-03],
            [   2.8365028459920633E-01,  -9.4279477723585570E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,   9.4279477723585570E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [  -2.8365028459920633E-01,  -9.4279477723585570E-01,  -1.7515856834189569E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,   9.4279477723585570E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,   9.4279477723585570E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,  -9.4279477723585570E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,   9.4279477723585570E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,  -9.4279477723585570E-01,   2.8365028459920633E-01,   5.8803266444788288E-03],
            [   1.7515856834189569E-01,  -9.4279477723585570E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,   9.4279477723585570E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [  -1.7515856834189569E-01,  -9.4279477723585570E-01,  -2.8365028459920633E-01,   5.8803266444788288E-03],
            [   3.3617947462325898E-01,   2.2479959076326700E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,   2.2479959076326700E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,  -2.2479959076326700E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,   2.2479959076326700E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,  -2.2479959076326700E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,  -2.2479959076326700E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,   2.2479959076326700E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,  -2.2479959076326700E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,   3.3617947462325898E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,   3.3617947462325898E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,  -3.3617947462325898E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,   3.3617947462325898E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,  -3.3617947462325898E-01,   9.1457558727242294E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,  -3.3617947462325898E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,   3.3617947462325898E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,  -3.3617947462325898E-01,  -9.1457558727242294E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,   3.3617947462325898E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,   3.3617947462325898E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,  -3.3617947462325898E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,   3.3617947462325898E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,  -3.3617947462325898E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,  -3.3617947462325898E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,   3.3617947462325898E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,  -3.3617947462325898E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,   2.2479959076326700E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,   2.2479959076326700E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,  -2.2479959076326700E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,   2.2479959076326700E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,  -2.2479959076326700E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   9.1457558727242294E-01,  -2.2479959076326700E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,   2.2479959076326700E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -9.1457558727242294E-01,  -2.2479959076326700E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,   9.1457558727242294E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,   9.1457558727242294E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,  -9.1457558727242294E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,   9.1457558727242294E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,  -9.1457558727242294E-01,   2.2479959076326700E-01,   6.1962863180240425E-03],
            [   3.3617947462325898E-01,  -9.1457558727242294E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,   9.1457558727242294E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [  -3.3617947462325898E-01,  -9.1457558727242294E-01,  -2.2479959076326700E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,   9.1457558727242294E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,   9.1457558727242294E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,  -9.1457558727242294E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,   9.1457558727242294E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,  -9.1457558727242294E-01,   3.3617947462325898E-01,   6.1962863180240425E-03],
            [   2.2479959076326700E-01,  -9.1457558727242294E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,   9.1457558727242294E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [  -2.2479959076326700E-01,  -9.1457558727242294E-01,  -3.3617947462325898E-01,   6.1962863180240425E-03],
            [   3.8759791722648240E-01,   2.7452992574222462E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,   2.7452992574222462E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,  -2.7452992574222462E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,   2.7452992574222462E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,  -2.7452992574222462E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,  -2.7452992574222462E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,   2.7452992574222462E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,  -2.7452992574222462E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,   3.8759791722648240E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,   3.8759791722648240E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,  -3.8759791722648240E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,   3.8759791722648240E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,  -3.8759791722648240E-01,   8.8000066729160009E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,  -3.8759791722648240E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,   3.8759791722648240E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,  -3.8759791722648240E-01,  -8.8000066729160009E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,   3.8759791722648240E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,   3.8759791722648240E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,  -3.8759791722648240E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,   3.8759791722648240E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,  -3.8759791722648240E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,  -3.8759791722648240E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,   3.8759791722648240E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,  -3.8759791722648240E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,   2.7452992574222462E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,   2.7452992574222462E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,  -2.7452992574222462E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,   2.7452992574222462E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,  -2.7452992574222462E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   8.8000066729160009E-01,  -2.7452992574222462E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,   2.7452992574222462E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -8.8000066729160009E-01,  -2.7452992574222462E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,   8.8000066729160009E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,   8.8000066729160009E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,  -8.8000066729160009E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,   8.8000066729160009E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,  -8.8000066729160009E-01,   2.7452992574222462E-01,   6.4277386151766524E-03],
            [   3.8759791722648240E-01,  -8.8000066729160009E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,   8.8000066729160009E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [  -3.8759791722648240E-01,  -8.8000066729160009E-01,  -2.7452992574222462E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,   8.8000066729160009E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,   8.8000066729160009E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,  -8.8000066729160009E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,   8.8000066729160009E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,  -8.8000066729160009E-01,   3.8759791722648240E-01,   6.4277386151766524E-03],
            [   2.7452992574222462E-01,  -8.8000066729160009E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,   8.8000066729160009E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [  -2.7452992574222462E-01,  -8.8000066729160009E-01,  -3.8759791722648240E-01,   6.4277386151766524E-03],
            [   4.3740193169990738E-01,   3.2363734824411178E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,   3.2363734824411178E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,  -3.2363734824411178E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,   3.2363734824411178E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,  -3.2363734824411178E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,  -3.2363734824411178E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,   3.2363734824411178E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,  -3.2363734824411178E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,   4.3740193169990738E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,   4.3740193169990738E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,  -4.3740193169990738E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,   4.3740193169990738E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,  -4.3740193169990738E-01,   8.3901037953454971E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,  -4.3740193169990738E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,   4.3740193169990738E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,  -4.3740193169990738E-01,  -8.3901037953454971E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,   4.3740193169990738E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,   4.3740193169990738E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,  -4.3740193169990738E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,   4.3740193169990738E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,  -4.3740193169990738E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,  -4.3740193169990738E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,   4.3740193169990738E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,  -4.3740193169990738E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,   3.2363734824411178E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,   3.2363734824411178E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,  -3.2363734824411178E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,   3.2363734824411178E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,  -3.2363734824411178E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   8.3901037953454971E-01,  -3.2363734824411178E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,   3.2363734824411178E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -8.3901037953454971E-01,  -3.2363734824411178E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,   8.3901037953454971E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,   8.3901037953454971E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,  -8.3901037953454971E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,   8.3901037953454971E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,  -8.3901037953454971E-01,   3.2363734824411178E-01,   6.5913342640307468E-03],
            [   4.3740193169990738E-01,  -8.3901037953454971E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,   8.3901037953454971E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [  -4.3740193169990738E-01,  -8.3901037953454971E-01,  -3.2363734824411178E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,   8.3901037953454971E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,   8.3901037953454971E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,  -8.3901037953454971E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,   8.3901037953454971E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,  -8.3901037953454971E-01,   4.3740193169990738E-01,   6.5913342640307468E-03],
            [   3.2363734824411178E-01,  -8.3901037953454971E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,   8.3901037953454971E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [  -3.2363734824411178E-01,  -8.3901037953454971E-01,  -4.3740193169990738E-01,   6.5913342640307468E-03],
            [   4.8512758433400222E-01,   3.7149678594367408E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,   3.7149678594367408E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,  -3.7149678594367408E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,   3.7149678594367408E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,  -3.7149678594367408E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,  -3.7149678594367408E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,   3.7149678594367408E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,  -3.7149678594367408E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,   4.8512758433400222E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,   4.8512758433400222E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,  -4.8512758433400222E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,   4.8512758433400222E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,  -4.8512758433400222E-01,   7.9160682472536548E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,  -4.8512758433400222E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,   4.8512758433400222E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,  -4.8512758433400222E-01,  -7.9160682472536548E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,   4.8512758433400222E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,   4.8512758433400222E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,  -4.8512758433400222E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,   4.8512758433400222E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,  -4.8512758433400222E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,  -4.8512758433400222E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,   4.8512758433400222E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,  -4.8512758433400222E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,   3.7149678594367408E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,   3.7149678594367408E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,  -3.7149678594367408E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,   3.7149678594367408E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,  -3.7149678594367408E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   7.9160682472536548E-01,  -3.7149678594367408E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,   3.7149678594367408E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -7.9160682472536548E-01,  -3.7149678594367408E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,   7.9160682472536548E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,   7.9160682472536548E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,  -7.9160682472536548E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,   7.9160682472536548E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,  -7.9160682472536548E-01,   3.7149678594367408E-01,   6.7004409618828167E-03],
            [   4.8512758433400222E-01,  -7.9160682472536548E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,   7.9160682472536548E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [  -4.8512758433400222E-01,  -7.9160682472536548E-01,  -3.7149678594367408E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,   7.9160682472536548E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,   7.9160682472536548E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,  -7.9160682472536548E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,   7.9160682472536548E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,  -7.9160682472536548E-01,   4.8512758433400222E-01,   6.7004409618828167E-03],
            [   3.7149678594367408E-01,  -7.9160682472536548E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,   7.9160682472536548E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [  -3.7149678594367408E-01,  -7.9160682472536548E-01,  -4.8512758433400222E-01,   6.7004409618828167E-03],
            [   5.3033918038068684E-01,   4.1753536463217450E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,   4.1753536463217450E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,  -4.1753536463217450E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,   4.1753536463217450E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,  -4.1753536463217450E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,  -4.1753536463217450E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,   4.1753536463217450E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,  -4.1753536463217450E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,   5.3033918038068684E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,   5.3033918038068684E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,  -5.3033918038068684E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,   5.3033918038068684E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,  -5.3033918038068684E-01,   7.3783776877753993E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,  -5.3033918038068684E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,   5.3033918038068684E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,  -5.3033918038068684E-01,  -7.3783776877753993E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,   5.3033918038068684E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,   5.3033918038068684E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,  -5.3033918038068684E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,   5.3033918038068684E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,  -5.3033918038068684E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,  -5.3033918038068684E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,   5.3033918038068684E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,  -5.3033918038068684E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,   4.1753536463217450E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,   4.1753536463217450E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,  -4.1753536463217450E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,   4.1753536463217450E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,  -4.1753536463217450E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   7.3783776877753993E-01,  -4.1753536463217450E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,   4.1753536463217450E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -7.3783776877753993E-01,  -4.1753536463217450E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,   7.3783776877753993E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,   7.3783776877753993E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,  -7.3783776877753993E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,   7.3783776877753993E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,  -7.3783776877753993E-01,   4.1753536463217450E-01,   6.7664667165411368E-03],
            [   5.3033918038068684E-01,  -7.3783776877753993E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,   7.3783776877753993E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [  -5.3033918038068684E-01,  -7.3783776877753993E-01,  -4.1753536463217450E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,   7.3783776877753993E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,   7.3783776877753993E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,  -7.3783776877753993E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,   7.3783776877753993E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,  -7.3783776877753993E-01,   5.3033918038068684E-01,   6.7664667165411368E-03],
            [   4.1753536463217450E-01,  -7.3783776877753993E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,   7.3783776877753993E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [  -4.1753536463217450E-01,  -7.3783776877753993E-01,  -5.3033918038068684E-01,   6.7664667165411368E-03],
            [   5.7261973805962874E-01,   4.6120844063554611E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,   4.6120844063554611E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,   4.6120844063554611E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,  -4.6120844063554611E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,   4.6120844063554611E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,  -4.6120844063554611E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,   5.7261973805962874E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,   5.7261973805962874E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,   5.7261973805962874E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7778566661670425E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,  -5.7261973805962874E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,   5.7261973805962874E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,  -5.7261973805962874E-01,  -6.7778566661670425E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,   5.7261973805962874E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,   5.7261973805962874E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,  -5.7261973805962874E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,   5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,  -5.7261973805962874E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,  -5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,   5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,  -5.7261973805962874E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,   4.6120844063554611E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,   4.6120844063554611E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,  -4.6120844063554611E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,   4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,  -4.6120844063554611E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   6.7778566661670425E-01,  -4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,   4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -6.7778566661670425E-01,  -4.6120844063554611E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,   6.7778566661670425E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,   6.7778566661670425E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,  -6.7778566661670425E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,   6.7778566661670425E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,  -6.7778566661670425E-01,   4.6120844063554611E-01,   6.7997475990105149E-03],
            [   5.7261973805962874E-01,  -6.7778566661670425E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,   6.7778566661670425E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [  -5.7261973805962874E-01,  -6.7778566661670425E-01,  -4.6120844063554611E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,   6.7778566661670425E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,   6.7778566661670425E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,  -6.7778566661670425E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,   6.7778566661670425E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,  -6.7778566661670425E-01,   5.7261973805962874E-01,   6.7997475990105149E-03],
            [   4.6120844063554611E-01,  -6.7778566661670425E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,   6.7778566661670425E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [  -4.6120844063554611E-01,  -6.7778566661670425E-01,  -5.7261973805962874E-01,   6.7997475990105149E-03],
            [   2.4315207325648630E-01,   4.2580401330439520E-02,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,   4.2580401330439520E-02,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,  -4.2580401330439520E-02,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,   4.2580401330439520E-02,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,  -4.2580401330439520E-02,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,  -4.2580401330439520E-02,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,   4.2580401330439520E-02,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,  -4.2580401330439520E-02,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,   2.4315207325648630E-01,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,   2.4315207325648630E-01,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,  -2.4315207325648630E-01,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,   2.4315207325648630E-01,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,  -2.4315207325648630E-01,   9.6905313512397817E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,  -2.4315207325648630E-01,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,   2.4315207325648630E-01,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,  -2.4315207325648630E-01,  -9.6905313512397817E-01,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,   2.4315207325648630E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,   2.4315207325648630E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,  -2.4315207325648630E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,   2.4315207325648630E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,  -2.4315207325648630E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,  -2.4315207325648630E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,   2.4315207325648630E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,  -2.4315207325648630E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,   4.2580401330439520E-02,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,   4.2580401330439520E-02,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,  -4.2580401330439520E-02,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,   4.2580401330439520E-02,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,  -4.2580401330439520E-02,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   9.6905313512397817E-01,  -4.2580401330439520E-02,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,   4.2580401330439520E-02,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -9.6905313512397817E-01,  -4.2580401330439520E-02,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,   9.6905313512397817E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,   9.6905313512397817E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,  -9.6905313512397817E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,   9.6905313512397817E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,  -9.6905313512397817E-01,   4.2580401330439520E-02,   5.3530192763276306E-03],
            [   2.4315207325648630E-01,  -9.6905313512397817E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,   9.6905313512397817E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [  -2.4315207325648630E-01,  -9.6905313512397817E-01,  -4.2580401330439520E-02,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,   9.6905313512397817E-01,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,   9.6905313512397817E-01,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,  -9.6905313512397817E-01,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,   9.6905313512397817E-01,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,  -9.6905313512397817E-01,   2.4315207325648630E-01,   5.3530192763276306E-03],
            [   4.2580401330439520E-02,  -9.6905313512397817E-01,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,   9.6905313512397817E-01,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [  -4.2580401330439520E-02,  -9.6905313512397817E-01,  -2.4315207325648630E-01,   5.3530192763276306E-03],
            [   3.0020968008958693E-01,   8.8694243067227216E-02,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,   8.8694243067227216E-02,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,  -8.8694243067227216E-02,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,   8.8694243067227216E-02,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,  -8.8694243067227216E-02,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,  -8.8694243067227216E-02,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,   8.8694243067227216E-02,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,  -8.8694243067227216E-02,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,   3.0020968008958693E-01,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,   3.0020968008958693E-01,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,  -3.0020968008958693E-01,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,   3.0020968008958693E-01,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,  -3.0020968008958693E-01,   9.4974074316480683E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,  -3.0020968008958693E-01,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,   3.0020968008958693E-01,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,  -3.0020968008958693E-01,  -9.4974074316480683E-01,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,   3.0020968008958693E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,   3.0020968008958693E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,  -3.0020968008958693E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,   3.0020968008958693E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,  -3.0020968008958693E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,  -3.0020968008958693E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,   3.0020968008958693E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,  -3.0020968008958693E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,   8.8694243067227216E-02,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,   8.8694243067227216E-02,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,  -8.8694243067227216E-02,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,   8.8694243067227216E-02,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,  -8.8694243067227216E-02,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   9.4974074316480683E-01,  -8.8694243067227216E-02,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,   8.8694243067227216E-02,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -9.4974074316480683E-01,  -8.8694243067227216E-02,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,   9.4974074316480683E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,   9.4974074316480683E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,  -9.4974074316480683E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,   9.4974074316480683E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,  -9.4974074316480683E-01,   8.8694243067227216E-02,   5.7867274229756781E-03],
            [   3.0020968008958693E-01,  -9.4974074316480683E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,   9.4974074316480683E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [  -3.0020968008958693E-01,  -9.4974074316480683E-01,  -8.8694243067227216E-02,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,   9.4974074316480683E-01,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,   9.4974074316480683E-01,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,  -9.4974074316480683E-01,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,   9.4974074316480683E-01,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,  -9.4974074316480683E-01,   3.0020968008958693E-01,   5.7867274229756781E-03],
            [   8.8694243067227216E-02,  -9.4974074316480683E-01,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,   9.4974074316480683E-01,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [  -8.8694243067227216E-02,  -9.4974074316480683E-01,  -3.0020968008958693E-01,   5.7867274229756781E-03],
            [   3.5585544574574318E-01,   1.3688117065106550E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,   1.3688117065106550E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,  -1.3688117065106550E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,   1.3688117065106550E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,  -1.3688117065106550E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,  -1.3688117065106550E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,   1.3688117065106550E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,  -1.3688117065106550E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,   3.5585544574574318E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,   3.5585544574574318E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,  -3.5585544574574318E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,   3.5585544574574318E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,  -3.5585544574574318E-01,   9.2446224739266247E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,  -3.5585544574574318E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,   3.5585544574574318E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,  -3.5585544574574318E-01,  -9.2446224739266247E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,   3.5585544574574318E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,   3.5585544574574318E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,  -3.5585544574574318E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,   3.5585544574574318E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,  -3.5585544574574318E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,  -3.5585544574574318E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,   3.5585544574574318E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,  -3.5585544574574318E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,   1.3688117065106550E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,   1.3688117065106550E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,  -1.3688117065106550E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,   1.3688117065106550E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,  -1.3688117065106550E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   9.2446224739266247E-01,  -1.3688117065106550E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,   1.3688117065106550E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -9.2446224739266247E-01,  -1.3688117065106550E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,   9.2446224739266247E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,   9.2446224739266247E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,  -9.2446224739266247E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,   9.2446224739266247E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,  -9.2446224739266247E-01,   1.3688117065106550E-01,   6.1221031324703978E-03],
            [   3.5585544574574318E-01,  -9.2446224739266247E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,   9.2446224739266247E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [  -3.5585544574574318E-01,  -9.2446224739266247E-01,  -1.3688117065106550E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,   9.2446224739266247E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,   9.2446224739266247E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,  -9.2446224739266247E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,   9.2446224739266247E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,  -9.2446224739266247E-01,   3.5585544574574318E-01,   6.1221031324703978E-03],
            [   1.3688117065106550E-01,  -9.2446224739266247E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,   9.2446224739266247E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [  -1.3688117065106550E-01,  -9.2446224739266247E-01,  -3.5585544574574318E-01,   6.1221031324703978E-03],
            [   4.0977825370488868E-01,   1.8607399850150330E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,   1.8607399850150330E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,  -1.8607399850150330E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,   1.8607399850150330E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,  -1.8607399850150330E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,  -1.8607399850150330E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,   1.8607399850150330E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,  -1.8607399850150330E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,   4.0977825370488868E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,   4.0977825370488868E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,  -4.0977825370488868E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,   4.0977825370488868E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,  -4.0977825370488868E-01,   8.9300517908477695E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,  -4.0977825370488868E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,   4.0977825370488868E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,  -4.0977825370488868E-01,  -8.9300517908477695E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,   4.0977825370488868E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,   4.0977825370488868E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,  -4.0977825370488868E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,   4.0977825370488868E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,  -4.0977825370488868E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,  -4.0977825370488868E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,   4.0977825370488868E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,  -4.0977825370488868E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,   1.8607399850150330E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,   1.8607399850150330E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,  -1.8607399850150330E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,   1.8607399850150330E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,  -1.8607399850150330E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   8.9300517908477695E-01,  -1.8607399850150330E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,   1.8607399850150330E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -8.9300517908477695E-01,  -1.8607399850150330E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,   8.9300517908477695E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,   8.9300517908477695E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,  -8.9300517908477695E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,   8.9300517908477695E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,  -8.9300517908477695E-01,   1.8607399850150330E-01,   6.3739684254056688E-03],
            [   4.0977825370488868E-01,  -8.9300517908477695E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,   8.9300517908477695E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [  -4.0977825370488868E-01,  -8.9300517908477695E-01,  -1.8607399850150330E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,   8.9300517908477695E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,   8.9300517908477695E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,  -8.9300517908477695E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,   8.9300517908477695E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,  -8.9300517908477695E-01,   4.0977825370488868E-01,   6.3739684254056688E-03],
            [   1.8607399850150330E-01,  -8.9300517908477695E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,   8.9300517908477695E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [  -1.8607399850150330E-01,  -8.9300517908477695E-01,  -4.0977825370488868E-01,   6.3739684254056688E-03],
            [   4.6163376660674582E-01,   2.3542350773958531E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,   2.3542350773958531E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,  -2.3542350773958531E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,   2.3542350773958531E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,  -2.3542350773958531E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,  -2.3542350773958531E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,   2.3542350773958531E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,  -2.3542350773958531E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,   4.6163376660674582E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,   4.6163376660674582E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,  -4.6163376660674582E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,   4.6163376660674582E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,  -4.6163376660674582E-01,   8.5526021626874349E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,  -4.6163376660674582E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,   4.6163376660674582E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,  -4.6163376660674582E-01,  -8.5526021626874349E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,   4.6163376660674582E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,   4.6163376660674582E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,  -4.6163376660674582E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,   4.6163376660674582E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,  -4.6163376660674582E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,  -4.6163376660674582E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,   4.6163376660674582E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,  -4.6163376660674582E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,   2.3542350773958531E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,   2.3542350773958531E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,  -2.3542350773958531E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,   2.3542350773958531E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,  -2.3542350773958531E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   8.5526021626874349E-01,  -2.3542350773958531E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,   2.3542350773958531E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -8.5526021626874349E-01,  -2.3542350773958531E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,   8.5526021626874349E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,   8.5526021626874349E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,  -8.5526021626874349E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,   8.5526021626874349E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,  -8.5526021626874349E-01,   2.3542350773958531E-01,   6.5559633196224862E-03],
            [   4.6163376660674582E-01,  -8.5526021626874349E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,   8.5526021626874349E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [  -4.6163376660674582E-01,  -8.5526021626874349E-01,  -2.3542350773958531E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,   8.5526021626874349E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,   8.5526021626874349E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,  -8.5526021626874349E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,   8.5526021626874349E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,  -8.5526021626874349E-01,   4.6163376660674582E-01,   6.5559633196224862E-03],
            [   2.3542350773958531E-01,  -8.5526021626874349E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,   8.5526021626874349E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [  -2.3542350773958531E-01,  -8.5526021626874349E-01,  -4.6163376660674582E-01,   6.5559633196224862E-03],
            [   5.1107070084178741E-01,   2.8420749213470109E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,   2.8420749213470109E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,  -2.8420749213470109E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,   2.8420749213470109E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,  -2.8420749213470109E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,  -2.8420749213470109E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,   2.8420749213470109E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,  -2.8420749213470109E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,   5.1107070084178741E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,   5.1107070084178741E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,  -5.1107070084178741E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,   5.1107070084178741E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,  -5.1107070084178741E-01,   8.1119223378653471E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,  -5.1107070084178741E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,   5.1107070084178741E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,  -5.1107070084178741E-01,  -8.1119223378653471E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,   5.1107070084178741E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,   5.1107070084178741E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,  -5.1107070084178741E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,   5.1107070084178741E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,  -5.1107070084178741E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,  -5.1107070084178741E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,   5.1107070084178741E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,  -5.1107070084178741E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,   2.8420749213470109E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,   2.8420749213470109E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,  -2.8420749213470109E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,   2.8420749213470109E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,  -2.8420749213470109E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   8.1119223378653471E-01,  -2.8420749213470109E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,   2.8420749213470109E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -8.1119223378653471E-01,  -2.8420749213470109E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,   8.1119223378653471E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,   8.1119223378653471E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,  -8.1119223378653471E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,   8.1119223378653471E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,  -8.1119223378653471E-01,   2.8420749213470109E-01,   6.6800136558887776E-03],
            [   5.1107070084178741E-01,  -8.1119223378653471E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,   8.1119223378653471E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [  -5.1107070084178741E-01,  -8.1119223378653471E-01,  -2.8420749213470109E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,   8.1119223378653471E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,   8.1119223378653471E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,  -8.1119223378653471E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,   8.1119223378653471E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,  -8.1119223378653471E-01,   5.1107070084178741E-01,   6.6800136558887776E-03],
            [   2.8420749213470109E-01,  -8.1119223378653471E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,   8.1119223378653471E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [  -2.8420749213470109E-01,  -8.1119223378653471E-01,  -5.1107070084178741E-01,   6.6800136558887776E-03],
            [   5.5774152861637949E-01,   3.3177844149841018E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,   3.3177844149841018E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,  -3.3177844149841018E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,   3.3177844149841018E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,  -3.3177844149841018E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,  -3.3177844149841018E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,   3.3177844149841018E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,  -3.3177844149841018E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,   5.5774152861637949E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,   5.5774152861637949E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,  -5.5774152861637949E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,   5.5774152861637949E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,  -5.5774152861637949E-01,   7.6082025013372923E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,  -5.5774152861637949E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,   5.5774152861637949E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,  -5.5774152861637949E-01,  -7.6082025013372923E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,   5.5774152861637949E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,   5.5774152861637949E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,  -5.5774152861637949E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,   5.5774152861637949E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,  -5.5774152861637949E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,  -5.5774152861637949E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,   5.5774152861637949E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,  -5.5774152861637949E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,   3.3177844149841018E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,   3.3177844149841018E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,  -3.3177844149841018E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,   3.3177844149841018E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,  -3.3177844149841018E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   7.6082025013372923E-01,  -3.3177844149841018E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,   3.3177844149841018E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -7.6082025013372923E-01,  -3.3177844149841018E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,   7.6082025013372923E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,   7.6082025013372923E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,  -7.6082025013372923E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,   7.6082025013372923E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,  -7.6082025013372923E-01,   3.3177844149841018E-01,   6.7567285116043752E-03],
            [   5.5774152861637949E-01,  -7.6082025013372923E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,   7.6082025013372923E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [  -5.5774152861637949E-01,  -7.6082025013372923E-01,  -3.3177844149841018E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,   7.6082025013372923E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,   7.6082025013372923E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,  -7.6082025013372923E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,   7.6082025013372923E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,  -7.6082025013372923E-01,   5.5774152861637949E-01,   6.7567285116043752E-03],
            [   3.3177844149841018E-01,  -7.6082025013372923E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,   7.6082025013372923E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [  -3.3177844149841018E-01,  -7.6082025013372923E-01,  -5.5774152861637949E-01,   6.7567285116043752E-03],
            [   6.0130604313669500E-01,   3.7752990020407001E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,   3.7752990020407001E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,  -3.7752990020407001E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,   3.7752990020407001E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,  -3.7752990020407001E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,  -3.7752990020407001E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,   3.7752990020407001E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,  -3.7752990020407001E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,   6.0130604313669500E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,   6.0130604313669500E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,  -6.0130604313669500E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,   6.0130604313669500E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,  -6.0130604313669500E-01,   7.0420324973632153E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,  -6.0130604313669500E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,   6.0130604313669500E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,  -6.0130604313669500E-01,  -7.0420324973632153E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,   6.0130604313669500E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,   6.0130604313669500E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,  -6.0130604313669500E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,   6.0130604313669500E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,  -6.0130604313669500E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,  -6.0130604313669500E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,   6.0130604313669500E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,  -6.0130604313669500E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,   3.7752990020407001E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,   3.7752990020407001E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,  -3.7752990020407001E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,   3.7752990020407001E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,  -3.7752990020407001E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   7.0420324973632153E-01,  -3.7752990020407001E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,   3.7752990020407001E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -7.0420324973632153E-01,  -3.7752990020407001E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,   7.0420324973632153E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,   7.0420324973632153E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,  -7.0420324973632153E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,   7.0420324973632153E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,  -7.0420324973632153E-01,   3.7752990020407001E-01,   6.7959335563293781E-03],
            [   6.0130604313669500E-01,  -7.0420324973632153E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,   7.0420324973632153E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [  -6.0130604313669500E-01,  -7.0420324973632153E-01,  -3.7752990020407001E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,   7.0420324973632153E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,   7.0420324973632153E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,  -7.0420324973632153E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,   7.0420324973632153E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,  -7.0420324973632153E-01,   6.0130604313669500E-01,   6.7959335563293781E-03],
            [   3.7752990020407001E-01,  -7.0420324973632153E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,   7.0420324973632153E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [  -3.7752990020407001E-01,  -7.0420324973632153E-01,  -6.0130604313669500E-01,   6.7959335563293781E-03],
            [   3.6615967672617811E-01,   4.5993678871645918E-02,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,   4.5993678871645918E-02,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,  -4.5993678871645918E-02,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,   4.5993678871645918E-02,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,  -4.5993678871645918E-02,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,  -4.5993678871645918E-02,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,   4.5993678871645918E-02,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,  -4.5993678871645918E-02,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,   3.6615967672617811E-01,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,   3.6615967672617811E-01,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,  -3.6615967672617811E-01,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,   3.6615967672617811E-01,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,  -3.6615967672617811E-01,   9.2941469358066031E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,  -3.6615967672617811E-01,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,   3.6615967672617811E-01,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,  -3.6615967672617811E-01,  -9.2941469358066031E-01,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,   3.6615967672617811E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,   3.6615967672617811E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,  -3.6615967672617811E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,   3.6615967672617811E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,  -3.6615967672617811E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,  -3.6615967672617811E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,   3.6615967672617811E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,  -3.6615967672617811E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,   4.5993678871645918E-02,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,   4.5993678871645918E-02,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,  -4.5993678871645918E-02,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,   4.5993678871645918E-02,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,  -4.5993678871645918E-02,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   9.2941469358066031E-01,  -4.5993678871645918E-02,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,   4.5993678871645918E-02,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -9.2941469358066031E-01,  -4.5993678871645918E-02,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,   9.2941469358066031E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,   9.2941469358066031E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,  -9.2941469358066031E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,   9.2941469358066031E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,  -9.2941469358066031E-01,   4.5993678871645918E-02,   6.0855727429196937E-03],
            [   3.6615967672617811E-01,  -9.2941469358066031E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,   9.2941469358066031E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [  -3.6615967672617811E-01,  -9.2941469358066031E-01,  -4.5993678871645918E-02,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,   9.2941469358066031E-01,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,   9.2941469358066031E-01,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,  -9.2941469358066031E-01,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,   9.2941469358066031E-01,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,  -9.2941469358066031E-01,   3.6615967672617811E-01,   6.0855727429196937E-03],
            [   4.5993678871645918E-02,  -9.2941469358066031E-01,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,   9.2941469358066031E-01,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [  -4.5993678871645918E-02,  -9.2941469358066031E-01,  -3.6615967672617811E-01,   6.0855727429196937E-03],
            [   4.2376331535065809E-01,   9.4048937736544214E-02,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,   9.4048937736544214E-02,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,  -9.4048937736544214E-02,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,   9.4048937736544214E-02,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,  -9.4048937736544214E-02,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,  -9.4048937736544214E-02,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,   9.4048937736544214E-02,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,  -9.4048937736544214E-02,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,   4.2376331535065809E-01,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,   4.2376331535065809E-01,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,  -4.2376331535065809E-01,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,   4.2376331535065809E-01,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,  -4.2376331535065809E-01,   9.0087704481446651E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,  -4.2376331535065809E-01,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,   4.2376331535065809E-01,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,  -4.2376331535065809E-01,  -9.0087704481446651E-01,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,   4.2376331535065809E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,   4.2376331535065809E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,  -4.2376331535065809E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,   4.2376331535065809E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,  -4.2376331535065809E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,  -4.2376331535065809E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,   4.2376331535065809E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,  -4.2376331535065809E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,   9.4048937736544214E-02,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,   9.4048937736544214E-02,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,  -9.4048937736544214E-02,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,   9.4048937736544214E-02,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,  -9.4048937736544214E-02,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.0087704481446651E-01,  -9.4048937736544214E-02,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,   9.4048937736544214E-02,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.0087704481446651E-01,  -9.4048937736544214E-02,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,   9.0087704481446651E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,   9.0087704481446651E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,  -9.0087704481446651E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,   9.0087704481446651E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,  -9.0087704481446651E-01,   9.4048937736544214E-02,   6.3446676277882268E-03],
            [   4.2376331535065809E-01,  -9.0087704481446651E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,   9.0087704481446651E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [  -4.2376331535065809E-01,  -9.0087704481446651E-01,  -9.4048937736544214E-02,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,   9.0087704481446651E-01,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,   9.0087704481446651E-01,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,  -9.0087704481446651E-01,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,   9.0087704481446651E-01,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,  -9.0087704481446651E-01,   4.2376331535065809E-01,   6.3446676277882268E-03],
            [   9.4048937736544214E-02,  -9.0087704481446651E-01,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,   9.0087704481446651E-01,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [  -9.4048937736544214E-02,  -9.0087704481446651E-01,  -4.2376331535065809E-01,   6.3446676277882268E-03],
            [   4.7863284546584522E-01,   1.4313771090919711E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,   1.4313771090919711E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,  -1.4313771090919711E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,   1.4313771090919711E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,  -1.4313771090919711E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,  -1.4313771090919711E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,   1.4313771090919711E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,  -1.4313771090919711E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,   4.7863284546584522E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,   4.7863284546584522E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,  -4.7863284546584522E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,   4.7863284546584522E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,  -4.7863284546584522E-01,   8.6626912386217680E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,  -4.7863284546584522E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,   4.7863284546584522E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,  -4.7863284546584522E-01,  -8.6626912386217680E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,   4.7863284546584522E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,   4.7863284546584522E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,  -4.7863284546584522E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,   4.7863284546584522E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,  -4.7863284546584522E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,  -4.7863284546584522E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,   4.7863284546584522E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,  -4.7863284546584522E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,   1.4313771090919711E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,   1.4313771090919711E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,  -1.4313771090919711E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,   1.4313771090919711E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,  -1.4313771090919711E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   8.6626912386217680E-01,  -1.4313771090919711E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,   1.4313771090919711E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -8.6626912386217680E-01,  -1.4313771090919711E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,   8.6626912386217680E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,   8.6626912386217680E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,  -8.6626912386217680E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,   8.6626912386217680E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,  -8.6626912386217680E-01,   1.4313771090919711E-01,   6.5377900043913943E-03],
            [   4.7863284546584522E-01,  -8.6626912386217680E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,   8.6626912386217680E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [  -4.7863284546584522E-01,  -8.6626912386217680E-01,  -1.4313771090919711E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,   8.6626912386217680E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,   8.6626912386217680E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,  -8.6626912386217680E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,   8.6626912386217680E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,  -8.6626912386217680E-01,   4.7863284546584522E-01,   6.5377900043913943E-03],
            [   1.4313771090919711E-01,  -8.6626912386217680E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,   8.6626912386217680E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [  -1.4313771090919711E-01,  -8.6626912386217680E-01,  -4.7863284546584522E-01,   6.5377900043913943E-03],
            [   5.3057020767897745E-01,   1.9241863888435701E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,   1.9241863888435701E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,  -1.9241863888435701E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,   1.9241863888435701E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,  -1.9241863888435701E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,  -1.9241863888435701E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,   1.9241863888435701E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,  -1.9241863888435701E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,   5.3057020767897745E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,   5.3057020767897745E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,  -5.3057020767897745E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,   5.3057020767897745E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,  -5.3057020767897745E-01,   8.2551215747157725E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,  -5.3057020767897745E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,   5.3057020767897745E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,  -5.3057020767897745E-01,  -8.2551215747157725E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,   5.3057020767897745E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,   5.3057020767897745E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,  -5.3057020767897745E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,   5.3057020767897745E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,  -5.3057020767897745E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,  -5.3057020767897745E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,   5.3057020767897745E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,  -5.3057020767897745E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,   1.9241863888435701E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,   1.9241863888435701E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,  -1.9241863888435701E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,   1.9241863888435701E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,  -1.9241863888435701E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   8.2551215747157725E-01,  -1.9241863888435701E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,   1.9241863888435701E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -8.2551215747157725E-01,  -1.9241863888435701E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,   8.2551215747157725E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,   8.2551215747157725E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,  -8.2551215747157725E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,   8.2551215747157725E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,  -8.2551215747157725E-01,   1.9241863888435701E-01,   6.6726578328890635E-03],
            [   5.3057020767897745E-01,  -8.2551215747157725E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,   8.2551215747157725E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [  -5.3057020767897745E-01,  -8.2551215747157725E-01,  -1.9241863888435701E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,   8.2551215747157725E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,   8.2551215747157725E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,  -8.2551215747157725E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,   8.2551215747157725E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,  -8.2551215747157725E-01,   5.3057020767897745E-01,   6.6726578328890635E-03],
            [   1.9241863888435701E-01,  -8.2551215747157725E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,   8.2551215747157725E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [  -1.9241863888435701E-01,  -8.2551215747157725E-01,  -5.3057020767897745E-01,   6.6726578328890635E-03],
            [   5.7934362242317883E-01,   2.4115909447751899E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,   2.4115909447751899E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,  -2.4115909447751899E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,   2.4115909447751899E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,  -2.4115909447751899E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,  -2.4115909447751899E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,   2.4115909447751899E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,  -2.4115909447751899E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,   5.7934362242317883E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,   5.7934362242317883E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,  -5.7934362242317883E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,   5.7934362242317883E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,  -5.7934362242317883E-01,   7.7859055883588280E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,  -5.7934362242317883E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,   5.7934362242317883E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,  -5.7934362242317883E-01,  -7.7859055883588280E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,   5.7934362242317883E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,   5.7934362242317883E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,  -5.7934362242317883E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,   5.7934362242317883E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,  -5.7934362242317883E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,  -5.7934362242317883E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,   5.7934362242317883E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,  -5.7934362242317883E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,   2.4115909447751899E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,   2.4115909447751899E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,  -2.4115909447751899E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,   2.4115909447751899E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,  -2.4115909447751899E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   7.7859055883588280E-01,  -2.4115909447751899E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,   2.4115909447751899E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -7.7859055883588280E-01,  -2.4115909447751899E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,   7.7859055883588280E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,   7.7859055883588280E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,  -7.7859055883588280E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,   7.7859055883588280E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,  -7.7859055883588280E-01,   2.4115909447751899E-01,   6.7574649790051577E-03],
            [   5.7934362242317883E-01,  -7.7859055883588280E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,   7.7859055883588280E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [  -5.7934362242317883E-01,  -7.7859055883588280E-01,  -2.4115909447751899E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,   7.7859055883588280E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,   7.7859055883588280E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,  -7.7859055883588280E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,   7.7859055883588280E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,  -7.7859055883588280E-01,   5.7934362242317883E-01,   6.7574649790051577E-03],
            [   2.4115909447751899E-01,  -7.7859055883588280E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,   7.7859055883588280E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [  -2.4115909447751899E-01,  -7.7859055883588280E-01,  -5.7934362242317883E-01,   6.7574649790051577E-03],
            [   6.2470690170947474E-01,   2.8868714915836052E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,   2.8868714915836052E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,  -2.8868714915836052E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,   2.8868714915836052E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,  -2.8868714915836052E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,  -2.8868714915836052E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,   2.8868714915836052E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,  -2.8868714915836052E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,   6.2470690170947474E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,   6.2470690170947474E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,  -6.2470690170947474E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,   6.2470690170947474E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,  -6.2470690170947474E-01,   7.2553498665975236E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,  -6.2470690170947474E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,   6.2470690170947474E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,  -6.2470690170947474E-01,  -7.2553498665975236E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,   6.2470690170947474E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,   6.2470690170947474E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,  -6.2470690170947474E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,   6.2470690170947474E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,  -6.2470690170947474E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,  -6.2470690170947474E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,   6.2470690170947474E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,  -6.2470690170947474E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,   2.8868714915836052E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,   2.8868714915836052E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,  -2.8868714915836052E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,   2.8868714915836052E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,  -2.8868714915836052E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   7.2553498665975236E-01,  -2.8868714915836052E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,   2.8868714915836052E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -7.2553498665975236E-01,  -2.8868714915836052E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,   7.2553498665975236E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,   7.2553498665975236E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,  -7.2553498665975236E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,   7.2553498665975236E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,  -7.2553498665975236E-01,   2.8868714915836052E-01,   6.8005381756230188E-03],
            [   6.2470690170947474E-01,  -7.2553498665975236E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,   7.2553498665975236E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [  -6.2470690170947474E-01,  -7.2553498665975236E-01,  -2.8868714915836052E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,   7.2553498665975236E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,   7.2553498665975236E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,  -7.2553498665975236E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,   7.2553498665975236E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,  -7.2553498665975236E-01,   6.2470690170947474E-01,   6.8005381756230188E-03],
            [   2.8868714915836052E-01,  -7.2553498665975236E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,   7.2553498665975236E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [  -2.8868714915836052E-01,  -7.2553498665975236E-01,  -6.2470690170947474E-01,   6.8005381756230188E-03],
            [   4.8743155525352039E-01,   4.8049787749532058E-02,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,   4.8049787749532058E-02,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,  -4.8049787749532058E-02,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,   4.8049787749532058E-02,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,  -4.8049787749532058E-02,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,  -4.8049787749532058E-02,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,   4.8049787749532058E-02,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,  -4.8049787749532058E-02,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,   4.8743155525352039E-01,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,   4.8743155525352039E-01,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,  -4.8743155525352039E-01,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,   4.8743155525352039E-01,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,  -4.8743155525352039E-01,   8.7183811389521115E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,  -4.8743155525352039E-01,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,   4.8743155525352039E-01,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,  -4.8743155525352039E-01,  -8.7183811389521115E-01,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,   4.8743155525352039E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,   4.8743155525352039E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,  -4.8743155525352039E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,   4.8743155525352039E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,  -4.8743155525352039E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,  -4.8743155525352039E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,   4.8743155525352039E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,  -4.8743155525352039E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,   4.8049787749532058E-02,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,   4.8049787749532058E-02,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,  -4.8049787749532058E-02,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,   4.8049787749532058E-02,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,  -4.8049787749532058E-02,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   8.7183811389521115E-01,  -4.8049787749532058E-02,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,   4.8049787749532058E-02,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -8.7183811389521115E-01,  -4.8049787749532058E-02,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,   8.7183811389521115E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,   8.7183811389521115E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,  -8.7183811389521115E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,   8.7183811389521115E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,  -8.7183811389521115E-01,   4.8049787749532058E-02,   6.5319947873452109E-03],
            [   4.8743155525352039E-01,  -8.7183811389521115E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,   8.7183811389521115E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [  -4.8743155525352039E-01,  -8.7183811389521115E-01,  -4.8049787749532058E-02,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,   8.7183811389521115E-01,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,   8.7183811389521115E-01,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,  -8.7183811389521115E-01,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,   8.7183811389521115E-01,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,  -8.7183811389521115E-01,   4.8743155525352039E-01,   6.5319947873452109E-03],
            [   4.8049787749532058E-02,  -8.7183811389521115E-01,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,   8.7183811389521115E-01,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [  -4.8049787749532058E-02,  -8.7183811389521115E-01,  -4.8743155525352039E-01,   6.5319947873452109E-03],
            [   5.4273373220590526E-01,   9.7168571993666644E-02,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,   9.7168571993666644E-02,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,  -9.7168571993666644E-02,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,   9.7168571993666644E-02,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,  -9.7168571993666644E-02,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,  -9.7168571993666644E-02,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,   9.7168571993666644E-02,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,  -9.7168571993666644E-02,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,   5.4273373220590526E-01,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,   5.4273373220590526E-01,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,  -5.4273373220590526E-01,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,   5.4273373220590526E-01,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,  -5.4273373220590526E-01,   8.3426516440671328E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,  -5.4273373220590526E-01,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,   5.4273373220590526E-01,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,  -5.4273373220590526E-01,  -8.3426516440671328E-01,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,   5.4273373220590526E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,   5.4273373220590526E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,  -5.4273373220590526E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,   5.4273373220590526E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,  -5.4273373220590526E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,  -5.4273373220590526E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,   5.4273373220590526E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,  -5.4273373220590526E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,   9.7168571993666644E-02,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,   9.7168571993666644E-02,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,  -9.7168571993666644E-02,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,   9.7168571993666644E-02,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,  -9.7168571993666644E-02,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   8.3426516440671328E-01,  -9.7168571993666644E-02,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,   9.7168571993666644E-02,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -8.3426516440671328E-01,  -9.7168571993666644E-02,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,   8.3426516440671328E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,   8.3426516440671328E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,  -8.3426516440671328E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,   8.3426516440671328E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,  -8.3426516440671328E-01,   9.7168571993666644E-02,   6.6741512810649271E-03],
            [   5.4273373220590526E-01,  -8.3426516440671328E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,   8.3426516440671328E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [  -5.4273373220590526E-01,  -8.3426516440671328E-01,  -9.7168571993666644E-02,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,   8.3426516440671328E-01,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,   8.3426516440671328E-01,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,  -8.3426516440671328E-01,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,   8.3426516440671328E-01,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,  -8.3426516440671328E-01,   5.4273373220590526E-01,   6.6741512810649271E-03],
            [   9.7168571993666644E-02,  -8.3426516440671328E-01,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,   8.3426516440671328E-01,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [  -9.7168571993666644E-02,  -8.3426516440671328E-01,  -5.4273373220590526E-01,   6.6741512810649271E-03],
            [   5.9434937472466998E-01,   1.4652058397950549E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,   1.4652058397950549E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,  -1.4652058397950549E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,   1.4652058397950549E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,  -1.4652058397950549E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,  -1.4652058397950549E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,   1.4652058397950549E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,  -1.4652058397950549E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,   5.9434937472466998E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,   5.9434937472466998E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,  -5.9434937472466998E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,   5.9434937472466998E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,  -5.9434937472466998E-01,   7.9074682372722715E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,  -5.9434937472466998E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,   5.9434937472466998E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,  -5.9434937472466998E-01,  -7.9074682372722715E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,   5.9434937472466998E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,   5.9434937472466998E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,  -5.9434937472466998E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,   5.9434937472466998E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,  -5.9434937472466998E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,  -5.9434937472466998E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,   5.9434937472466998E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,  -5.9434937472466998E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,   1.4652058397950549E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,   1.4652058397950549E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,  -1.4652058397950549E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,   1.4652058397950549E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,  -1.4652058397950549E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   7.9074682372722715E-01,  -1.4652058397950549E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,   1.4652058397950549E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -7.9074682372722715E-01,  -1.4652058397950549E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,   7.9074682372722715E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,   7.9074682372722715E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,  -7.9074682372722715E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,   7.9074682372722715E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,  -7.9074682372722715E-01,   1.4652058397950549E-01,   6.7661226416927253E-03],
            [   5.9434937472466998E-01,  -7.9074682372722715E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,   7.9074682372722715E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [  -5.9434937472466998E-01,  -7.9074682372722715E-01,  -1.4652058397950549E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,   7.9074682372722715E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,   7.9074682372722715E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,  -7.9074682372722715E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,   7.9074682372722715E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,  -7.9074682372722715E-01,   5.9434937472466998E-01,   6.7661226416927253E-03],
            [   1.4652058397950549E-01,  -7.9074682372722715E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,   7.9074682372722715E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [  -1.4652058397950549E-01,  -7.9074682372722715E-01,  -5.9434937472466998E-01,   6.7661226416927253E-03],
            [   6.4213140335649432E-01,   1.9535794498035741E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,   1.9535794498035741E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,  -1.9535794498035741E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,   1.9535794498035741E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,  -1.9535794498035741E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,  -1.9535794498035741E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,   1.9535794498035741E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,  -1.9535794498035741E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,   6.4213140335649432E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,   6.4213140335649432E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,  -6.4213140335649432E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,   6.4213140335649432E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,  -6.4213140335649432E-01,   7.4128438143297670E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,  -6.4213140335649432E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,   6.4213140335649432E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,  -6.4213140335649432E-01,  -7.4128438143297670E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,   6.4213140335649432E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,   6.4213140335649432E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,  -6.4213140335649432E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,   6.4213140335649432E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,  -6.4213140335649432E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,  -6.4213140335649432E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,   6.4213140335649432E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,  -6.4213140335649432E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,   1.9535794498035741E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,   1.9535794498035741E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,  -1.9535794498035741E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,   1.9535794498035741E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,  -1.9535794498035741E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   7.4128438143297670E-01,  -1.9535794498035741E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,   1.9535794498035741E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -7.4128438143297670E-01,  -1.9535794498035741E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,   7.4128438143297670E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,   7.4128438143297670E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,  -7.4128438143297670E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,   7.4128438143297670E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,  -7.4128438143297670E-01,   1.9535794498035741E-01,   6.8133095946901617E-03],
            [   6.4213140335649432E-01,  -7.4128438143297670E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,   7.4128438143297670E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [  -6.4213140335649432E-01,  -7.4128438143297670E-01,  -1.9535794498035741E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,   7.4128438143297670E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,   7.4128438143297670E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,  -7.4128438143297670E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,   7.4128438143297670E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,  -7.4128438143297670E-01,   6.4213140335649432E-01,   6.8133095946901617E-03],
            [   1.9535794498035741E-01,  -7.4128438143297670E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,   7.4128438143297670E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [  -1.9535794498035741E-01,  -7.4128438143297670E-01,  -6.4213140335649432E-01,   6.8133095946901617E-03],
            [   6.0206283747139799E-01,   4.9163750157381080E-02,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,   4.9163750157381080E-02,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,  -4.9163750157381080E-02,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,   4.9163750157381080E-02,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,  -4.9163750157381080E-02,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,  -4.9163750157381080E-02,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,   4.9163750157381080E-02,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,  -4.9163750157381080E-02,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,   6.0206283747139799E-01,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,   6.0206283747139799E-01,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,  -6.0206283747139799E-01,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,   6.0206283747139799E-01,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,  -6.0206283747139799E-01,   7.9693366437009783E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,  -6.0206283747139799E-01,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,   6.0206283747139799E-01,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,  -6.0206283747139799E-01,  -7.9693366437009783E-01,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,   6.0206283747139799E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,   6.0206283747139799E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,  -6.0206283747139799E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,   6.0206283747139799E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,  -6.0206283747139799E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,  -6.0206283747139799E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,   6.0206283747139799E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,  -6.0206283747139799E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,   4.9163750157381080E-02,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,   4.9163750157381080E-02,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,  -4.9163750157381080E-02,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,   4.9163750157381080E-02,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,  -4.9163750157381080E-02,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   7.9693366437009783E-01,  -4.9163750157381080E-02,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,   4.9163750157381080E-02,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -7.9693366437009783E-01,  -4.9163750157381080E-02,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,   7.9693366437009783E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,   7.9693366437009783E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,  -7.9693366437009783E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,   7.9693366437009783E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,  -7.9693366437009783E-01,   4.9163750157381080E-02,   6.7744654992381911E-03],
            [   6.0206283747139799E-01,  -7.9693366437009783E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,   7.9693366437009783E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [  -6.0206283747139799E-01,  -7.9693366437009783E-01,  -4.9163750157381080E-02,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,   7.9693366437009783E-01,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,   7.9693366437009783E-01,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,  -7.9693366437009783E-01,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,   7.9693366437009783E-01,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,  -7.9693366437009783E-01,   6.0206283747139799E-01,   6.7744654992381911E-03],
            [   4.9163750157381080E-02,  -7.9693366437009783E-01,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,   7.9693366437009783E-01,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [  -4.9163750157381080E-02,  -7.9693366437009783E-01,  -6.0206283747139799E-01,   6.7744654992381911E-03],
            [   6.5292225298568807E-01,   9.8616215401270052E-02,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,   9.8616215401270052E-02,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,  -9.8616215401270052E-02,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,   9.8616215401270052E-02,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,  -9.8616215401270052E-02,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,  -9.8616215401270052E-02,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,   9.8616215401270052E-02,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,  -9.8616215401270052E-02,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,   6.5292225298568807E-01,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,   6.5292225298568807E-01,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,  -6.5292225298568807E-01,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,   6.5292225298568807E-01,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,  -6.5292225298568807E-01,   7.5097761192729540E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,  -6.5292225298568807E-01,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,   6.5292225298568807E-01,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,  -6.5292225298568807E-01,  -7.5097761192729540E-01,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,   6.5292225298568807E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,   6.5292225298568807E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,  -6.5292225298568807E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,   6.5292225298568807E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,  -6.5292225298568807E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,  -6.5292225298568807E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,   6.5292225298568807E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,  -6.5292225298568807E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,   9.8616215401270052E-02,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,   9.8616215401270052E-02,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,  -9.8616215401270052E-02,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,   9.8616215401270052E-02,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,  -9.8616215401270052E-02,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   7.5097761192729540E-01,  -9.8616215401270052E-02,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,   9.8616215401270052E-02,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -7.5097761192729540E-01,  -9.8616215401270052E-02,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,   7.5097761192729540E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,   7.5097761192729540E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,  -7.5097761192729540E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,   7.5097761192729540E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,  -7.5097761192729540E-01,   9.8616215401270052E-02,   6.8277021115086258E-03],
            [   6.5292225298568807E-01,  -7.5097761192729540E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,   7.5097761192729540E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [  -6.5292225298568807E-01,  -7.5097761192729540E-01,  -9.8616215401270052E-02,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,   7.5097761192729540E-01,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,   7.5097761192729540E-01,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,  -7.5097761192729540E-01,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,   7.5097761192729540E-01,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,  -7.5097761192729540E-01,   6.5292225298568807E-01,   6.8277021115086258E-03],
            [   9.8616215401270052E-02,  -7.5097761192729540E-01,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,   7.5097761192729540E-01,  -6.5292225298568807E-01,   6.8277021115086258E-03],
            [  -9.8616215401270052E-02,  -7.5097761192729540E-01,  -6.5292225298568807E-01,   6.8277021115086258E-03],
        ])
  
        order = 77
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build2354():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   4.9293049835095494E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   4.9293049835095494E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   4.9293049835095494E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   4.9293049835095494E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   4.9293049835095494E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   4.9293049835095494E-04],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   5.9110093088826686E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   5.9110093088826686E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   5.9110093088826686E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   5.9110093088826686E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   5.9110093088826686E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   5.9110093088826686E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   5.9110093088826686E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   5.9110093088826686E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   5.9110093088826686E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   5.9110093088826686E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   5.9110093088826686E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   5.9110093088826686E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.8788030210044596E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.8788030210044596E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.8788030210044596E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.8788030210044596E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.8788030210044596E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.8788030210044596E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.8788030210044596E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.8788030210044596E-03],
            [   2.2900246465305890E-02,   2.2900246465305890E-02,   9.9947544113082465E-01,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,   2.2900246465305890E-02,   9.9947544113082465E-01,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,  -2.2900246465305890E-02,   9.9947544113082465E-01,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,   2.2900246465305890E-02,  -9.9947544113082465E-01,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,  -2.2900246465305890E-02,   9.9947544113082465E-01,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,   2.2900246465305890E-02,  -9.9947544113082465E-01,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,  -2.2900246465305890E-02,  -9.9947544113082465E-01,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,  -2.2900246465305890E-02,  -9.9947544113082465E-01,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,   9.9947544113082465E-01,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,  -9.9947544113082465E-01,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,   9.9947544113082465E-01,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,  -9.9947544113082465E-01,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,   9.9947544113082465E-01,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,  -9.9947544113082465E-01,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -2.2900246465305890E-02,  -9.9947544113082465E-01,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [   2.2900246465305890E-02,   9.9947544113082465E-01,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [   9.9947544113082465E-01,   2.2900246465305890E-02,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -9.9947544113082465E-01,   2.2900246465305890E-02,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [   9.9947544113082465E-01,  -2.2900246465305890E-02,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [   9.9947544113082465E-01,   2.2900246465305890E-02,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -9.9947544113082465E-01,  -2.2900246465305890E-02,   2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -9.9947544113082465E-01,   2.2900246465305890E-02,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [   9.9947544113082465E-01,  -2.2900246465305890E-02,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [  -9.9947544113082465E-01,  -2.2900246465305890E-02,  -2.2900246465305890E-02,   1.8068332670631564E-03],
            [   5.7790866522712842E-02,   5.7790866522712842E-02,   9.9665461996275717E-01,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,   5.7790866522712842E-02,   9.9665461996275717E-01,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,  -5.7790866522712842E-02,   9.9665461996275717E-01,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,   5.7790866522712842E-02,  -9.9665461996275717E-01,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,  -5.7790866522712842E-02,   9.9665461996275717E-01,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,   5.7790866522712842E-02,  -9.9665461996275717E-01,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,  -5.7790866522712842E-02,  -9.9665461996275717E-01,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,  -5.7790866522712842E-02,  -9.9665461996275717E-01,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,   9.9665461996275717E-01,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,  -9.9665461996275717E-01,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,   9.9665461996275717E-01,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,  -9.9665461996275717E-01,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,   9.9665461996275717E-01,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,  -9.9665461996275717E-01,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -5.7790866522712842E-02,  -9.9665461996275717E-01,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [   5.7790866522712842E-02,   9.9665461996275717E-01,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [   9.9665461996275717E-01,   5.7790866522712842E-02,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -9.9665461996275717E-01,   5.7790866522712842E-02,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [   9.9665461996275717E-01,  -5.7790866522712842E-02,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [   9.9665461996275717E-01,   5.7790866522712842E-02,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -9.9665461996275717E-01,  -5.7790866522712842E-02,   5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -9.9665461996275717E-01,   5.7790866522712842E-02,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [   9.9665461996275717E-01,  -5.7790866522712842E-02,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [  -9.9665461996275717E-01,  -5.7790866522712842E-02,  -5.7790866522712842E-02,   2.8947545691340188E-03],
            [   9.8631035763759839E-02,   9.8631035763759839E-02,   9.9022413501607598E-01,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,   9.8631035763759839E-02,   9.9022413501607598E-01,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,  -9.8631035763759839E-02,   9.9022413501607598E-01,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,   9.8631035763759839E-02,  -9.9022413501607598E-01,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,  -9.8631035763759839E-02,   9.9022413501607598E-01,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,   9.8631035763759839E-02,  -9.9022413501607598E-01,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,  -9.8631035763759839E-02,  -9.9022413501607598E-01,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,  -9.8631035763759839E-02,  -9.9022413501607598E-01,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,   9.9022413501607598E-01,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,  -9.9022413501607598E-01,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,   9.9022413501607598E-01,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,  -9.9022413501607598E-01,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,   9.9022413501607598E-01,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,  -9.9022413501607598E-01,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.8631035763759839E-02,  -9.9022413501607598E-01,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.8631035763759839E-02,   9.9022413501607598E-01,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.9022413501607598E-01,   9.8631035763759839E-02,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.9022413501607598E-01,   9.8631035763759839E-02,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.9022413501607598E-01,  -9.8631035763759839E-02,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.9022413501607598E-01,   9.8631035763759839E-02,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.9022413501607598E-01,  -9.8631035763759839E-02,   9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.9022413501607598E-01,   9.8631035763759839E-02,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [   9.9022413501607598E-01,  -9.8631035763759839E-02,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [  -9.9022413501607598E-01,  -9.8631035763759839E-02,  -9.8631035763759839E-02,   3.6858556768216608E-03],
            [   1.4281557929821850E-01,   1.4281557929821850E-01,   9.7939135212611950E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,   1.4281557929821850E-01,   9.7939135212611950E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,  -1.4281557929821850E-01,   9.7939135212611950E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,   1.4281557929821850E-01,  -9.7939135212611950E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,  -1.4281557929821850E-01,   9.7939135212611950E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,   1.4281557929821850E-01,  -9.7939135212611950E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,  -1.4281557929821850E-01,  -9.7939135212611950E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,  -1.4281557929821850E-01,  -9.7939135212611950E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,   9.7939135212611950E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,  -9.7939135212611950E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,   9.7939135212611950E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,  -9.7939135212611950E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,   9.7939135212611950E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,  -9.7939135212611950E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -1.4281557929821850E-01,  -9.7939135212611950E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [   1.4281557929821850E-01,   9.7939135212611950E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [   9.7939135212611950E-01,   1.4281557929821850E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -9.7939135212611950E-01,   1.4281557929821850E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [   9.7939135212611950E-01,  -1.4281557929821850E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [   9.7939135212611950E-01,   1.4281557929821850E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -9.7939135212611950E-01,  -1.4281557929821850E-01,   1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -9.7939135212611950E-01,   1.4281557929821850E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [   9.7939135212611950E-01,  -1.4281557929821850E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [  -9.7939135212611950E-01,  -1.4281557929821850E-01,  -1.4281557929821850E-01,   4.2762177941215633E-03],
            [   1.8889781166014630E-01,   1.8889781166014630E-01,   9.6365721784253544E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,   1.8889781166014630E-01,   9.6365721784253544E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,  -1.8889781166014630E-01,   9.6365721784253544E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,   1.8889781166014630E-01,  -9.6365721784253544E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,  -1.8889781166014630E-01,   9.6365721784253544E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,   1.8889781166014630E-01,  -9.6365721784253544E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,  -1.8889781166014630E-01,  -9.6365721784253544E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,  -1.8889781166014630E-01,  -9.6365721784253544E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,   9.6365721784253544E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,  -9.6365721784253544E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,   9.6365721784253544E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,  -9.6365721784253544E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,   9.6365721784253544E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,  -9.6365721784253544E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -1.8889781166014630E-01,  -9.6365721784253544E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [   1.8889781166014630E-01,   9.6365721784253544E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [   9.6365721784253544E-01,   1.8889781166014630E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -9.6365721784253544E-01,   1.8889781166014630E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [   9.6365721784253544E-01,  -1.8889781166014630E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [   9.6365721784253544E-01,   1.8889781166014630E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -9.6365721784253544E-01,  -1.8889781166014630E-01,   1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -9.6365721784253544E-01,   1.8889781166014630E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [   9.6365721784253544E-01,  -1.8889781166014630E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [  -9.6365721784253544E-01,  -1.8889781166014630E-01,  -1.8889781166014630E-01,   4.7238727165387030E-03],
            [   2.3590916829702099E-01,   2.3590916829702099E-01,   9.4270553654193401E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,   2.3590916829702099E-01,   9.4270553654193401E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,  -2.3590916829702099E-01,   9.4270553654193401E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,   2.3590916829702099E-01,  -9.4270553654193401E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,  -2.3590916829702099E-01,   9.4270553654193401E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,   2.3590916829702099E-01,  -9.4270553654193401E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,  -2.3590916829702099E-01,  -9.4270553654193401E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,  -2.3590916829702099E-01,  -9.4270553654193401E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,   9.4270553654193401E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,  -9.4270553654193401E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,   9.4270553654193401E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,  -9.4270553654193401E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,   9.4270553654193401E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,  -9.4270553654193401E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -2.3590916829702099E-01,  -9.4270553654193401E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [   2.3590916829702099E-01,   9.4270553654193401E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [   9.4270553654193401E-01,   2.3590916829702099E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -9.4270553654193401E-01,   2.3590916829702099E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [   9.4270553654193401E-01,  -2.3590916829702099E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [   9.4270553654193401E-01,   2.3590916829702099E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -9.4270553654193401E-01,  -2.3590916829702099E-01,   2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -9.4270553654193401E-01,   2.3590916829702099E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [   9.4270553654193401E-01,  -2.3590916829702099E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [  -9.4270553654193401E-01,  -2.3590916829702099E-01,  -2.3590916829702099E-01,   5.0650496548794288E-03],
            [   2.8312288337061708E-01,   2.8312288337061708E-01,   9.1634211178130187E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,   2.8312288337061708E-01,   9.1634211178130187E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,  -2.8312288337061708E-01,   9.1634211178130187E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,   2.8312288337061708E-01,  -9.1634211178130187E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,  -2.8312288337061708E-01,   9.1634211178130187E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,   2.8312288337061708E-01,  -9.1634211178130187E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,  -2.8312288337061708E-01,  -9.1634211178130187E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,  -2.8312288337061708E-01,  -9.1634211178130187E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,   9.1634211178130187E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,  -9.1634211178130187E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,   9.1634211178130187E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,  -9.1634211178130187E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,   9.1634211178130187E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,  -9.1634211178130187E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -2.8312288337061708E-01,  -9.1634211178130187E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [   2.8312288337061708E-01,   9.1634211178130187E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [   9.1634211178130187E-01,   2.8312288337061708E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -9.1634211178130187E-01,   2.8312288337061708E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [   9.1634211178130187E-01,  -2.8312288337061708E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [   9.1634211178130187E-01,   2.8312288337061708E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -9.1634211178130187E-01,  -2.8312288337061708E-01,   2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -9.1634211178130187E-01,   2.8312288337061708E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [   9.1634211178130187E-01,  -2.8312288337061708E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [  -9.1634211178130187E-01,  -2.8312288337061708E-01,  -2.8312288337061708E-01,   5.3238578079174365E-03],
            [   3.2994958579666928E-01,   3.2994958579666928E-01,   8.8445833235105698E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,   3.2994958579666928E-01,   8.8445833235105698E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,  -3.2994958579666928E-01,   8.8445833235105698E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,   3.2994958579666928E-01,  -8.8445833235105698E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,  -3.2994958579666928E-01,   8.8445833235105698E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,   3.2994958579666928E-01,  -8.8445833235105698E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,  -3.2994958579666928E-01,  -8.8445833235105698E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,  -3.2994958579666928E-01,  -8.8445833235105698E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,   8.8445833235105698E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,  -8.8445833235105698E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,   8.8445833235105698E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,  -8.8445833235105698E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,   8.8445833235105698E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,  -8.8445833235105698E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -3.2994958579666928E-01,  -8.8445833235105698E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [   3.2994958579666928E-01,   8.8445833235105698E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [   8.8445833235105698E-01,   3.2994958579666928E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -8.8445833235105698E-01,   3.2994958579666928E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [   8.8445833235105698E-01,  -3.2994958579666928E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [   8.8445833235105698E-01,   3.2994958579666928E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -8.8445833235105698E-01,  -3.2994958579666928E-01,   3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -8.8445833235105698E-01,   3.2994958579666928E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [   8.8445833235105698E-01,  -3.2994958579666928E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [  -8.8445833235105698E-01,  -3.2994958579666928E-01,  -3.2994958579666928E-01,   5.5172934897933746E-03],
            [   3.7588408026607961E-01,   3.7588408026607961E-01,   8.4700786088739866E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,   3.7588408026607961E-01,   8.4700786088739866E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,  -3.7588408026607961E-01,   8.4700786088739866E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,   3.7588408026607961E-01,  -8.4700786088739866E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,  -3.7588408026607961E-01,   8.4700786088739866E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,   3.7588408026607961E-01,  -8.4700786088739866E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,  -3.7588408026607961E-01,  -8.4700786088739866E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,  -3.7588408026607961E-01,  -8.4700786088739866E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,   8.4700786088739866E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,  -8.4700786088739866E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,   8.4700786088739866E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,  -8.4700786088739866E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,   8.4700786088739866E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,  -8.4700786088739866E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -3.7588408026607961E-01,  -8.4700786088739866E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [   3.7588408026607961E-01,   8.4700786088739866E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [   8.4700786088739866E-01,   3.7588408026607961E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -8.4700786088739866E-01,   3.7588408026607961E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [   8.4700786088739866E-01,  -3.7588408026607961E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [   8.4700786088739866E-01,   3.7588408026607961E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -8.4700786088739866E-01,  -3.7588408026607961E-01,   3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -8.4700786088739866E-01,   3.7588408026607961E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [   8.4700786088739866E-01,  -3.7588408026607961E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [  -8.4700786088739866E-01,  -3.7588408026607961E-01,  -3.7588408026607961E-01,   5.6580378581474666E-03],
            [   4.2047518310094800E-01,   4.2047518310094800E-01,   8.0399082133594557E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,   4.2047518310094800E-01,   8.0399082133594557E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,  -4.2047518310094800E-01,   8.0399082133594557E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,   4.2047518310094800E-01,  -8.0399082133594557E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,  -4.2047518310094800E-01,   8.0399082133594557E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,   4.2047518310094800E-01,  -8.0399082133594557E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,  -4.2047518310094800E-01,  -8.0399082133594557E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,  -4.2047518310094800E-01,  -8.0399082133594557E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,   8.0399082133594557E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,  -8.0399082133594557E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,   8.0399082133594557E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,  -8.0399082133594557E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,   8.0399082133594557E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,  -8.0399082133594557E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -4.2047518310094800E-01,  -8.0399082133594557E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [   4.2047518310094800E-01,   8.0399082133594557E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [   8.0399082133594557E-01,   4.2047518310094800E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -8.0399082133594557E-01,   4.2047518310094800E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [   8.0399082133594557E-01,  -4.2047518310094800E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [   8.0399082133594557E-01,   4.2047518310094800E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -8.0399082133594557E-01,  -4.2047518310094800E-01,   4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -8.0399082133594557E-01,   4.2047518310094800E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [   8.0399082133594557E-01,  -4.2047518310094800E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [  -8.0399082133594557E-01,  -4.2047518310094800E-01,  -4.2047518310094800E-01,   5.7561237355207200E-03],
            [   4.6330685187510512E-01,   4.6330685187510512E-01,   7.5544260007704023E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,   4.6330685187510512E-01,   7.5544260007704023E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,  -4.6330685187510512E-01,   7.5544260007704023E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,   4.6330685187510512E-01,  -7.5544260007704023E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,  -4.6330685187510512E-01,   7.5544260007704023E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,   4.6330685187510512E-01,  -7.5544260007704023E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,  -4.6330685187510512E-01,  -7.5544260007704023E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,  -4.6330685187510512E-01,  -7.5544260007704023E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,   7.5544260007704023E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,  -7.5544260007704023E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,   7.5544260007704023E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,  -7.5544260007704023E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,   7.5544260007704023E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,  -7.5544260007704023E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -4.6330685187510512E-01,  -7.5544260007704023E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [   4.6330685187510512E-01,   7.5544260007704023E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [   7.5544260007704023E-01,   4.6330685187510512E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -7.5544260007704023E-01,   4.6330685187510512E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [   7.5544260007704023E-01,  -4.6330685187510512E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [   7.5544260007704023E-01,   4.6330685187510512E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -7.5544260007704023E-01,  -4.6330685187510512E-01,   4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -7.5544260007704023E-01,   4.6330685187510512E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [   7.5544260007704023E-01,  -4.6330685187510512E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [  -7.5544260007704023E-01,  -4.6330685187510512E-01,  -4.6330685187510512E-01,   5.8199783514631450E-03],
            [   5.0398494745073130E-01,   5.0398494745073130E-01,   7.0142593727789049E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,   5.0398494745073130E-01,   7.0142593727789049E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,  -5.0398494745073130E-01,   7.0142593727789049E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,   5.0398494745073130E-01,  -7.0142593727789049E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,  -5.0398494745073130E-01,   7.0142593727789049E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,   5.0398494745073130E-01,  -7.0142593727789049E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,  -5.0398494745073130E-01,  -7.0142593727789049E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,  -5.0398494745073130E-01,  -7.0142593727789049E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,   7.0142593727789049E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,  -7.0142593727789049E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,   7.0142593727789049E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,  -7.0142593727789049E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,   7.0142593727789049E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,  -7.0142593727789049E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -5.0398494745073130E-01,  -7.0142593727789049E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [   5.0398494745073130E-01,   7.0142593727789049E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [   7.0142593727789049E-01,   5.0398494745073130E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -7.0142593727789049E-01,   5.0398494745073130E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [   7.0142593727789049E-01,  -5.0398494745073130E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [   7.0142593727789049E-01,   5.0398494745073130E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -7.0142593727789049E-01,  -5.0398494745073130E-01,   5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -7.0142593727789049E-01,   5.0398494745073130E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [   7.0142593727789049E-01,  -5.0398494745073130E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [  -7.0142593727789049E-01,  -5.0398494745073130E-01,  -5.0398494745073130E-01,   5.8570960639374881E-03],
            [   5.4212657934407471E-01,   5.4212657934407471E-01,   6.4202612403031178E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,   5.4212657934407471E-01,   6.4202612403031178E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,  -5.4212657934407471E-01,   6.4202612403031178E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,   5.4212657934407471E-01,  -6.4202612403031178E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,  -5.4212657934407471E-01,   6.4202612403031178E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,   5.4212657934407471E-01,  -6.4202612403031178E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,  -5.4212657934407471E-01,  -6.4202612403031178E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,  -5.4212657934407471E-01,  -6.4202612403031178E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,   6.4202612403031178E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,  -6.4202612403031178E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,   6.4202612403031178E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,  -6.4202612403031178E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,   6.4202612403031178E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,  -6.4202612403031178E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -5.4212657934407471E-01,  -6.4202612403031178E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [   5.4212657934407471E-01,   6.4202612403031178E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [   6.4202612403031178E-01,   5.4212657934407471E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -6.4202612403031178E-01,   5.4212657934407471E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [   6.4202612403031178E-01,  -5.4212657934407471E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [   6.4202612403031178E-01,   5.4212657934407471E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -6.4202612403031178E-01,  -5.4212657934407471E-01,   5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -6.4202612403031178E-01,   5.4212657934407471E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [   6.4202612403031178E-01,  -5.4212657934407471E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [  -6.4202612403031178E-01,  -5.4212657934407471E-01,  -5.4212657934407471E-01,   5.8744663748681340E-03],
            [   6.0926602305573097E-01,   6.0926602305573097E-01,   5.0753307902018274E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,   6.0926602305573097E-01,   5.0753307902018274E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,  -6.0926602305573097E-01,   5.0753307902018274E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,   6.0926602305573097E-01,  -5.0753307902018274E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,  -6.0926602305573097E-01,   5.0753307902018274E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,   6.0926602305573097E-01,  -5.0753307902018274E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,  -6.0926602305573097E-01,  -5.0753307902018274E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,  -6.0926602305573097E-01,  -5.0753307902018274E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,   5.0753307902018274E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,  -5.0753307902018274E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,   5.0753307902018274E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,  -5.0753307902018274E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,   5.0753307902018274E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,  -5.0753307902018274E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -6.0926602305573097E-01,  -5.0753307902018274E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [   6.0926602305573097E-01,   5.0753307902018274E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [   5.0753307902018274E-01,   6.0926602305573097E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -5.0753307902018274E-01,   6.0926602305573097E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [   5.0753307902018274E-01,  -6.0926602305573097E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [   5.0753307902018274E-01,   6.0926602305573097E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -5.0753307902018274E-01,  -6.0926602305573097E-01,   6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -5.0753307902018274E-01,   6.0926602305573097E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [   5.0753307902018274E-01,  -6.0926602305573097E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [  -5.0753307902018274E-01,  -6.0926602305573097E-01,  -6.0926602305573097E-01,   5.8765562829333918E-03],
            [   6.3746542049848687E-01,   6.3746542049848687E-01,   4.3275359656203283E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,   6.3746542049848687E-01,   4.3275359656203283E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,  -6.3746542049848687E-01,   4.3275359656203283E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,   6.3746542049848687E-01,  -4.3275359656203283E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,  -6.3746542049848687E-01,   4.3275359656203283E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,   6.3746542049848687E-01,  -4.3275359656203283E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,  -6.3746542049848687E-01,  -4.3275359656203283E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,  -6.3746542049848687E-01,  -4.3275359656203283E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,   4.3275359656203283E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,  -4.3275359656203283E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,   4.3275359656203283E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,  -4.3275359656203283E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,   4.3275359656203283E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,  -4.3275359656203283E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -6.3746542049848687E-01,  -4.3275359656203283E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [   6.3746542049848687E-01,   4.3275359656203283E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [   4.3275359656203283E-01,   6.3746542049848687E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -4.3275359656203283E-01,   6.3746542049848687E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [   4.3275359656203283E-01,  -6.3746542049848687E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [   4.3275359656203283E-01,   6.3746542049848687E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -4.3275359656203283E-01,  -6.3746542049848687E-01,   6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -4.3275359656203283E-01,   6.3746542049848687E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [   4.3275359656203283E-01,  -6.3746542049848687E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [  -4.3275359656203283E-01,  -6.3746542049848687E-01,  -6.3746542049848687E-01,   5.8736303146413411E-03],
            [   6.6151364726098916E-01,   6.6151364726098916E-01,   3.5326956983998392E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,   6.6151364726098916E-01,   3.5326956983998392E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,  -6.6151364726098916E-01,   3.5326956983998392E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,   6.6151364726098916E-01,  -3.5326956983998392E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,  -6.6151364726098916E-01,   3.5326956983998392E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,   6.6151364726098916E-01,  -3.5326956983998392E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,  -6.6151364726098916E-01,  -3.5326956983998392E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,  -6.6151364726098916E-01,  -3.5326956983998392E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,   3.5326956983998392E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,  -3.5326956983998392E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,   3.5326956983998392E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,  -3.5326956983998392E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,   3.5326956983998392E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,  -3.5326956983998392E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -6.6151364726098916E-01,  -3.5326956983998392E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [   6.6151364726098916E-01,   3.5326956983998392E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [   3.5326956983998392E-01,   6.6151364726098916E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -3.5326956983998392E-01,   6.6151364726098916E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [   3.5326956983998392E-01,  -6.6151364726098916E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [   3.5326956983998392E-01,   6.6151364726098916E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -3.5326956983998392E-01,  -6.6151364726098916E-01,   6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -3.5326956983998392E-01,   6.6151364726098916E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [   3.5326956983998392E-01,  -6.6151364726098916E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [  -3.5326956983998392E-01,  -6.6151364726098916E-01,  -6.6151364726098916E-01,   5.8746884622790816E-03],
            [   6.8094872859581268E-01,   6.8094872859581268E-01,   2.6947663729439059E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,   6.8094872859581268E-01,   2.6947663729439059E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,  -6.8094872859581268E-01,   2.6947663729439059E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,   6.8094872859581268E-01,  -2.6947663729439059E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,  -6.8094872859581268E-01,   2.6947663729439059E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,   6.8094872859581268E-01,  -2.6947663729439059E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,  -6.8094872859581268E-01,  -2.6947663729439059E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,  -6.8094872859581268E-01,  -2.6947663729439059E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,   2.6947663729439059E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,  -2.6947663729439059E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,   2.6947663729439059E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,  -2.6947663729439059E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,   2.6947663729439059E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,  -2.6947663729439059E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -6.8094872859581268E-01,  -2.6947663729439059E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [   6.8094872859581268E-01,   2.6947663729439059E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [   2.6947663729439059E-01,   6.8094872859581268E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -2.6947663729439059E-01,   6.8094872859581268E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [   2.6947663729439059E-01,  -6.8094872859581268E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [   2.6947663729439059E-01,   6.8094872859581268E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -2.6947663729439059E-01,  -6.8094872859581268E-01,   6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -2.6947663729439059E-01,   6.8094872859581268E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [   2.6947663729439059E-01,  -6.8094872859581268E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [  -2.6947663729439059E-01,  -6.8094872859581268E-01,  -6.8094872859581268E-01,   5.8820026431523446E-03],
            [   6.9529800216651960E-01,   6.9529800216651960E-01,   1.8199279207290886E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,   6.9529800216651960E-01,   1.8199279207290886E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,  -6.9529800216651960E-01,   1.8199279207290886E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,   6.9529800216651960E-01,  -1.8199279207290886E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,  -6.9529800216651960E-01,   1.8199279207290886E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,   6.9529800216651960E-01,  -1.8199279207290886E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,  -6.9529800216651960E-01,  -1.8199279207290886E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,  -6.9529800216651960E-01,  -1.8199279207290886E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,   1.8199279207290886E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,  -1.8199279207290886E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,   1.8199279207290886E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,  -1.8199279207290886E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,   1.8199279207290886E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,  -1.8199279207290886E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -6.9529800216651960E-01,  -1.8199279207290886E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [   6.9529800216651960E-01,   1.8199279207290886E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [   1.8199279207290886E-01,   6.9529800216651960E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -1.8199279207290886E-01,   6.9529800216651960E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [   1.8199279207290886E-01,  -6.9529800216651960E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [   1.8199279207290886E-01,   6.9529800216651960E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -1.8199279207290886E-01,  -6.9529800216651960E-01,   6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -1.8199279207290886E-01,   6.9529800216651960E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [   1.8199279207290886E-01,  -6.9529800216651960E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [  -1.8199279207290886E-01,  -6.9529800216651960E-01,  -6.9529800216651960E-01,   5.8941930615133906E-03],
            [   7.0412454976953998E-01,   7.0412454976953998E-01,   9.1745500291214421E-02,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,   7.0412454976953998E-01,   9.1745500291214421E-02,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,  -7.0412454976953998E-01,   9.1745500291214421E-02,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,   7.0412454976953998E-01,  -9.1745500291214421E-02,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,  -7.0412454976953998E-01,   9.1745500291214421E-02,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,   7.0412454976953998E-01,  -9.1745500291214421E-02,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,  -7.0412454976953998E-01,  -9.1745500291214421E-02,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,  -7.0412454976953998E-01,  -9.1745500291214421E-02,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,   9.1745500291214421E-02,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,  -9.1745500291214421E-02,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,   9.1745500291214421E-02,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,  -9.1745500291214421E-02,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,   9.1745500291214421E-02,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,  -9.1745500291214421E-02,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -7.0412454976953998E-01,  -9.1745500291214421E-02,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [   7.0412454976953998E-01,   9.1745500291214421E-02,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [   9.1745500291214421E-02,   7.0412454976953998E-01,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -9.1745500291214421E-02,   7.0412454976953998E-01,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [   9.1745500291214421E-02,  -7.0412454976953998E-01,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [   9.1745500291214421E-02,   7.0412454976953998E-01,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -9.1745500291214421E-02,  -7.0412454976953998E-01,   7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -9.1745500291214421E-02,   7.0412454976953998E-01,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [   9.1745500291214421E-02,  -7.0412454976953998E-01,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [  -9.1745500291214421E-02,  -7.0412454976953998E-01,  -7.0412454976953998E-01,   5.9060397177197700E-03],
            [   6.7440330883060645E-02,   9.9772330922474861E-01,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [  -6.7440330883060645E-02,   9.9772330922474861E-01,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [   6.7440330883060645E-02,  -9.9772330922474861E-01,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [  -6.7440330883060645E-02,  -9.9772330922474861E-01,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [   9.9772330922474861E-01,   6.7440330883060645E-02,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [  -9.9772330922474861E-01,   6.7440330883060645E-02,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [   9.9772330922474861E-01,  -6.7440330883060645E-02,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [  -9.9772330922474861E-01,  -6.7440330883060645E-02,   0.0000000000000000E+00,   2.6388652972678065E-03],
            [   6.7440330883060645E-02,   0.0000000000000000E+00,   9.9772330922474861E-01,   2.6388652972678065E-03],
            [  -6.7440330883060645E-02,   0.0000000000000000E+00,   9.9772330922474861E-01,   2.6388652972678065E-03],
            [   6.7440330883060645E-02,   0.0000000000000000E+00,  -9.9772330922474861E-01,   2.6388652972678065E-03],
            [  -6.7440330883060645E-02,   0.0000000000000000E+00,  -9.9772330922474861E-01,   2.6388652972678065E-03],
            [   9.9772330922474861E-01,   0.0000000000000000E+00,   6.7440330883060645E-02,   2.6388652972678065E-03],
            [  -9.9772330922474861E-01,   0.0000000000000000E+00,   6.7440330883060645E-02,   2.6388652972678065E-03],
            [   9.9772330922474861E-01,   0.0000000000000000E+00,  -6.7440330883060645E-02,   2.6388652972678065E-03],
            [  -9.9772330922474861E-01,   0.0000000000000000E+00,  -6.7440330883060645E-02,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,   6.7440330883060645E-02,   9.9772330922474861E-01,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,  -6.7440330883060645E-02,   9.9772330922474861E-01,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,   6.7440330883060645E-02,  -9.9772330922474861E-01,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,  -6.7440330883060645E-02,  -9.9772330922474861E-01,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,   9.9772330922474861E-01,   6.7440330883060645E-02,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,  -9.9772330922474861E-01,   6.7440330883060645E-02,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,   9.9772330922474861E-01,  -6.7440330883060645E-02,   2.6388652972678065E-03],
            [   0.0000000000000000E+00,  -9.9772330922474861E-01,  -6.7440330883060645E-02,   2.6388652972678065E-03],
            [   1.6786844853341659E-01,   9.8580940550746610E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [  -1.6786844853341659E-01,   9.8580940550746610E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [   1.6786844853341659E-01,  -9.8580940550746610E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [  -1.6786844853341659E-01,  -9.8580940550746610E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [   9.8580940550746610E-01,   1.6786844853341659E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [  -9.8580940550746610E-01,   1.6786844853341659E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [   9.8580940550746610E-01,  -1.6786844853341659E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [  -9.8580940550746610E-01,  -1.6786844853341659E-01,   0.0000000000000000E+00,   3.9863909836355509E-03],
            [   1.6786844853341659E-01,   0.0000000000000000E+00,   9.8580940550746610E-01,   3.9863909836355509E-03],
            [  -1.6786844853341659E-01,   0.0000000000000000E+00,   9.8580940550746610E-01,   3.9863909836355509E-03],
            [   1.6786844853341659E-01,   0.0000000000000000E+00,  -9.8580940550746610E-01,   3.9863909836355509E-03],
            [  -1.6786844853341659E-01,   0.0000000000000000E+00,  -9.8580940550746610E-01,   3.9863909836355509E-03],
            [   9.8580940550746610E-01,   0.0000000000000000E+00,   1.6786844853341659E-01,   3.9863909836355509E-03],
            [  -9.8580940550746610E-01,   0.0000000000000000E+00,   1.6786844853341659E-01,   3.9863909836355509E-03],
            [   9.8580940550746610E-01,   0.0000000000000000E+00,  -1.6786844853341659E-01,   3.9863909836355509E-03],
            [  -9.8580940550746610E-01,   0.0000000000000000E+00,  -1.6786844853341659E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,   1.6786844853341659E-01,   9.8580940550746610E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,  -1.6786844853341659E-01,   9.8580940550746610E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,   1.6786844853341659E-01,  -9.8580940550746610E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,  -1.6786844853341659E-01,  -9.8580940550746610E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,   9.8580940550746610E-01,   1.6786844853341659E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,  -9.8580940550746610E-01,   1.6786844853341659E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,   9.8580940550746610E-01,  -1.6786844853341659E-01,   3.9863909836355509E-03],
            [   0.0000000000000000E+00,  -9.8580940550746610E-01,  -1.6786844853341659E-01,   3.9863909836355509E-03],
            [   2.7935590495396129E-01,   9.6018762664770541E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [  -2.7935590495396129E-01,   9.6018762664770541E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [   2.7935590495396129E-01,  -9.6018762664770541E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [  -2.7935590495396129E-01,  -9.6018762664770541E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [   9.6018762664770541E-01,   2.7935590495396129E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [  -9.6018762664770541E-01,   2.7935590495396129E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [   9.6018762664770541E-01,  -2.7935590495396129E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [  -9.6018762664770541E-01,  -2.7935590495396129E-01,   0.0000000000000000E+00,   4.8154977584754172E-03],
            [   2.7935590495396129E-01,   0.0000000000000000E+00,   9.6018762664770541E-01,   4.8154977584754172E-03],
            [  -2.7935590495396129E-01,   0.0000000000000000E+00,   9.6018762664770541E-01,   4.8154977584754172E-03],
            [   2.7935590495396129E-01,   0.0000000000000000E+00,  -9.6018762664770541E-01,   4.8154977584754172E-03],
            [  -2.7935590495396129E-01,   0.0000000000000000E+00,  -9.6018762664770541E-01,   4.8154977584754172E-03],
            [   9.6018762664770541E-01,   0.0000000000000000E+00,   2.7935590495396129E-01,   4.8154977584754172E-03],
            [  -9.6018762664770541E-01,   0.0000000000000000E+00,   2.7935590495396129E-01,   4.8154977584754172E-03],
            [   9.6018762664770541E-01,   0.0000000000000000E+00,  -2.7935590495396129E-01,   4.8154977584754172E-03],
            [  -9.6018762664770541E-01,   0.0000000000000000E+00,  -2.7935590495396129E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,   2.7935590495396129E-01,   9.6018762664770541E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,  -2.7935590495396129E-01,   9.6018762664770541E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,   2.7935590495396129E-01,  -9.6018762664770541E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,  -2.7935590495396129E-01,  -9.6018762664770541E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,   9.6018762664770541E-01,   2.7935590495396129E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,  -9.6018762664770541E-01,   2.7935590495396129E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,   9.6018762664770541E-01,  -2.7935590495396129E-01,   4.8154977584754172E-03],
            [   0.0000000000000000E+00,  -9.6018762664770541E-01,  -2.7935590495396129E-01,   4.8154977584754172E-03],
            [   3.9352642180576392E-01,   9.1931330640905662E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [  -3.9352642180576392E-01,   9.1931330640905662E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [   3.9352642180576392E-01,  -9.1931330640905662E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [  -3.9352642180576392E-01,  -9.1931330640905662E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [   9.1931330640905662E-01,   3.9352642180576392E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [  -9.1931330640905662E-01,   3.9352642180576392E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [   9.1931330640905662E-01,  -3.9352642180576392E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [  -9.1931330640905662E-01,  -3.9352642180576392E-01,   0.0000000000000000E+00,   5.3434643442922007E-03],
            [   3.9352642180576392E-01,   0.0000000000000000E+00,   9.1931330640905662E-01,   5.3434643442922007E-03],
            [  -3.9352642180576392E-01,   0.0000000000000000E+00,   9.1931330640905662E-01,   5.3434643442922007E-03],
            [   3.9352642180576392E-01,   0.0000000000000000E+00,  -9.1931330640905662E-01,   5.3434643442922007E-03],
            [  -3.9352642180576392E-01,   0.0000000000000000E+00,  -9.1931330640905662E-01,   5.3434643442922007E-03],
            [   9.1931330640905662E-01,   0.0000000000000000E+00,   3.9352642180576392E-01,   5.3434643442922007E-03],
            [  -9.1931330640905662E-01,   0.0000000000000000E+00,   3.9352642180576392E-01,   5.3434643442922007E-03],
            [   9.1931330640905662E-01,   0.0000000000000000E+00,  -3.9352642180576392E-01,   5.3434643442922007E-03],
            [  -9.1931330640905662E-01,   0.0000000000000000E+00,  -3.9352642180576392E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,   3.9352642180576392E-01,   9.1931330640905662E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,  -3.9352642180576392E-01,   9.1931330640905662E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,   3.9352642180576392E-01,  -9.1931330640905662E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,  -3.9352642180576392E-01,  -9.1931330640905662E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,   9.1931330640905662E-01,   3.9352642180576392E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,  -9.1931330640905662E-01,   3.9352642180576392E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,   9.1931330640905662E-01,  -3.9352642180576392E-01,   5.3434643442922007E-03],
            [   0.0000000000000000E+00,  -9.1931330640905662E-01,  -3.9352642180576392E-01,   5.3434643442922007E-03],
            [   5.0526292682325580E-01,   8.6296545398874291E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [  -5.0526292682325580E-01,   8.6296545398874291E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [   5.0526292682325580E-01,  -8.6296545398874291E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [  -5.0526292682325580E-01,  -8.6296545398874291E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [   8.6296545398874291E-01,   5.0526292682325580E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [  -8.6296545398874291E-01,   5.0526292682325580E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [   8.6296545398874291E-01,  -5.0526292682325580E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [  -8.6296545398874291E-01,  -5.0526292682325580E-01,   0.0000000000000000E+00,   5.6722183754591244E-03],
            [   5.0526292682325580E-01,   0.0000000000000000E+00,   8.6296545398874291E-01,   5.6722183754591244E-03],
            [  -5.0526292682325580E-01,   0.0000000000000000E+00,   8.6296545398874291E-01,   5.6722183754591244E-03],
            [   5.0526292682325580E-01,   0.0000000000000000E+00,  -8.6296545398874291E-01,   5.6722183754591244E-03],
            [  -5.0526292682325580E-01,   0.0000000000000000E+00,  -8.6296545398874291E-01,   5.6722183754591244E-03],
            [   8.6296545398874291E-01,   0.0000000000000000E+00,   5.0526292682325580E-01,   5.6722183754591244E-03],
            [  -8.6296545398874291E-01,   0.0000000000000000E+00,   5.0526292682325580E-01,   5.6722183754591244E-03],
            [   8.6296545398874291E-01,   0.0000000000000000E+00,  -5.0526292682325580E-01,   5.6722183754591244E-03],
            [  -8.6296545398874291E-01,   0.0000000000000000E+00,  -5.0526292682325580E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,   5.0526292682325580E-01,   8.6296545398874291E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,  -5.0526292682325580E-01,   8.6296545398874291E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,   5.0526292682325580E-01,  -8.6296545398874291E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,  -5.0526292682325580E-01,  -8.6296545398874291E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,   8.6296545398874291E-01,   5.0526292682325580E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,  -8.6296545398874291E-01,   5.0526292682325580E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,   8.6296545398874291E-01,  -5.0526292682325580E-01,   5.6722183754591244E-03],
            [   0.0000000000000000E+00,  -8.6296545398874291E-01,  -5.0526292682325580E-01,   5.6722183754591244E-03],
            [   6.1079053154375307E-01,   7.9179222437234098E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [  -6.1079053154375307E-01,   7.9179222437234098E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [   6.1079053154375307E-01,  -7.9179222437234098E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [  -6.1079053154375307E-01,  -7.9179222437234098E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [   7.9179222437234098E-01,   6.1079053154375307E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [  -7.9179222437234098E-01,   6.1079053154375307E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [   7.9179222437234098E-01,  -6.1079053154375307E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [  -7.9179222437234098E-01,  -6.1079053154375307E-01,   0.0000000000000000E+00,   5.8531609243512930E-03],
            [   6.1079053154375307E-01,   0.0000000000000000E+00,   7.9179222437234098E-01,   5.8531609243512930E-03],
            [  -6.1079053154375307E-01,   0.0000000000000000E+00,   7.9179222437234098E-01,   5.8531609243512930E-03],
            [   6.1079053154375307E-01,   0.0000000000000000E+00,  -7.9179222437234098E-01,   5.8531609243512930E-03],
            [  -6.1079053154375307E-01,   0.0000000000000000E+00,  -7.9179222437234098E-01,   5.8531609243512930E-03],
            [   7.9179222437234098E-01,   0.0000000000000000E+00,   6.1079053154375307E-01,   5.8531609243512930E-03],
            [  -7.9179222437234098E-01,   0.0000000000000000E+00,   6.1079053154375307E-01,   5.8531609243512930E-03],
            [   7.9179222437234098E-01,   0.0000000000000000E+00,  -6.1079053154375307E-01,   5.8531609243512930E-03],
            [  -7.9179222437234098E-01,   0.0000000000000000E+00,  -6.1079053154375307E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,   6.1079053154375307E-01,   7.9179222437234098E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,  -6.1079053154375307E-01,   7.9179222437234098E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,   6.1079053154375307E-01,  -7.9179222437234098E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,  -6.1079053154375307E-01,  -7.9179222437234098E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,   7.9179222437234098E-01,   6.1079053154375307E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,  -7.9179222437234098E-01,   6.1079053154375307E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,   7.9179222437234098E-01,  -6.1079053154375307E-01,   5.8531609243512930E-03],
            [   0.0000000000000000E+00,  -7.9179222437234098E-01,  -6.1079053154375307E-01,   5.8531609243512930E-03],
            [   1.1350810398435240E-01,   3.3319548846625878E-02,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,   3.3319548846625878E-02,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,  -3.3319548846625878E-02,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,   3.3319548846625878E-02,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,  -3.3319548846625878E-02,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,  -3.3319548846625878E-02,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,   3.3319548846625878E-02,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,  -3.3319548846625878E-02,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,   1.1350810398435240E-01,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,   1.1350810398435240E-01,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,  -1.1350810398435240E-01,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,   1.1350810398435240E-01,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,  -1.1350810398435240E-01,   9.9297820620320498E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,  -1.1350810398435240E-01,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,   1.1350810398435240E-01,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,  -1.1350810398435240E-01,  -9.9297820620320498E-01,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,   1.1350810398435240E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,   1.1350810398435240E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,  -1.1350810398435240E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,   1.1350810398435240E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,  -1.1350810398435240E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,  -1.1350810398435240E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,   1.1350810398435240E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,  -1.1350810398435240E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,   3.3319548846625878E-02,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,   3.3319548846625878E-02,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,  -3.3319548846625878E-02,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,   3.3319548846625878E-02,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,  -3.3319548846625878E-02,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   9.9297820620320498E-01,  -3.3319548846625878E-02,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,   3.3319548846625878E-02,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -9.9297820620320498E-01,  -3.3319548846625878E-02,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,   9.9297820620320498E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,   9.9297820620320498E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,  -9.9297820620320498E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,   9.9297820620320498E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,  -9.9297820620320498E-01,   3.3319548846625878E-02,   3.4348449974872658E-03],
            [   1.1350810398435240E-01,  -9.9297820620320498E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,   9.9297820620320498E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [  -1.1350810398435240E-01,  -9.9297820620320498E-01,  -3.3319548846625878E-02,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,   9.9297820620320498E-01,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,   9.9297820620320498E-01,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,  -9.9297820620320498E-01,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,   9.9297820620320498E-01,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,  -9.9297820620320498E-01,   1.1350810398435240E-01,   3.4348449974872658E-03],
            [   3.3319548846625878E-02,  -9.9297820620320498E-01,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,   9.9297820620320498E-01,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [  -3.3319548846625878E-02,  -9.9297820620320498E-01,  -1.1350810398435240E-01,   3.4348449974872658E-03],
            [   1.6128666260993779E-01,   7.2471674654365381E-02,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,   7.2471674654365381E-02,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,  -7.2471674654365381E-02,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,   7.2471674654365381E-02,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,  -7.2471674654365381E-02,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,  -7.2471674654365381E-02,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,   7.2471674654365381E-02,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,  -7.2471674654365381E-02,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,   1.6128666260993779E-01,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,   1.6128666260993779E-01,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,  -1.6128666260993779E-01,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,   1.6128666260993779E-01,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,  -1.6128666260993779E-01,   9.8424309438112900E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,  -1.6128666260993779E-01,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,   1.6128666260993779E-01,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,  -1.6128666260993779E-01,  -9.8424309438112900E-01,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,   1.6128666260993779E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,   1.6128666260993779E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,  -1.6128666260993779E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,   1.6128666260993779E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,  -1.6128666260993779E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,  -1.6128666260993779E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,   1.6128666260993779E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,  -1.6128666260993779E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,   7.2471674654365381E-02,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,   7.2471674654365381E-02,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,  -7.2471674654365381E-02,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,   7.2471674654365381E-02,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,  -7.2471674654365381E-02,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   9.8424309438112900E-01,  -7.2471674654365381E-02,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,   7.2471674654365381E-02,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -9.8424309438112900E-01,  -7.2471674654365381E-02,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,   9.8424309438112900E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,   9.8424309438112900E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,  -9.8424309438112900E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,   9.8424309438112900E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,  -9.8424309438112900E-01,   7.2471674654365381E-02,   4.0658308257449528E-03],
            [   1.6128666260993779E-01,  -9.8424309438112900E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,   9.8424309438112900E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [  -1.6128666260993779E-01,  -9.8424309438112900E-01,  -7.2471674654365381E-02,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,   9.8424309438112900E-01,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,   9.8424309438112900E-01,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,  -9.8424309438112900E-01,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,   9.8424309438112900E-01,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,  -9.8424309438112900E-01,   1.6128666260993779E-01,   4.0658308257449528E-03],
            [   7.2471674654365381E-02,  -9.8424309438112900E-01,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,   9.8424309438112900E-01,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [  -7.2471674654365381E-02,  -9.8424309438112900E-01,  -1.6128666260993779E-01,   4.0658308257449528E-03],
            [   2.1007865501682049E-01,   1.1515391108497450E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,   1.1515391108497450E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,  -1.1515391108497450E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,   1.1515391108497450E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,  -1.1515391108497450E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,  -1.1515391108497450E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,   1.1515391108497450E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,  -1.1515391108497450E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,   2.1007865501682049E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,   2.1007865501682049E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,  -2.1007865501682049E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,   2.1007865501682049E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,  -2.1007865501682049E-01,   9.7087925895456106E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,  -2.1007865501682049E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,   2.1007865501682049E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,  -2.1007865501682049E-01,  -9.7087925895456106E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,   2.1007865501682049E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,   2.1007865501682049E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,  -2.1007865501682049E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,   2.1007865501682049E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,  -2.1007865501682049E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,  -2.1007865501682049E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,   2.1007865501682049E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,  -2.1007865501682049E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,   1.1515391108497450E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,   1.1515391108497450E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,  -1.1515391108497450E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,   1.1515391108497450E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,  -1.1515391108497450E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   9.7087925895456106E-01,  -1.1515391108497450E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,   1.1515391108497450E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -9.7087925895456106E-01,  -1.1515391108497450E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,   9.7087925895456106E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,   9.7087925895456106E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,  -9.7087925895456106E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,   9.7087925895456106E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,  -9.7087925895456106E-01,   1.1515391108497450E-01,   4.5551946494309598E-03],
            [   2.1007865501682049E-01,  -9.7087925895456106E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,   9.7087925895456106E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [  -2.1007865501682049E-01,  -9.7087925895456106E-01,  -1.1515391108497450E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,   9.7087925895456106E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,   9.7087925895456106E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,  -9.7087925895456106E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,   9.7087925895456106E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,  -9.7087925895456106E-01,   2.1007865501682049E-01,   4.5551946494309598E-03],
            [   1.1515391108497450E-01,  -9.7087925895456106E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,   9.7087925895456106E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [  -1.1515391108497450E-01,  -9.7087925895456106E-01,  -2.1007865501682049E-01,   4.5551946494309598E-03],
            [   2.5922820094599419E-01,   1.5994910971436771E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,   1.5994910971436771E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,  -1.5994910971436771E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,   1.5994910971436771E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,  -1.5994910971436771E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,  -1.5994910971436771E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,   1.5994910971436771E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,  -1.5994910971436771E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,   2.5922820094599419E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,   2.5922820094599419E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,  -2.5922820094599419E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,   2.5922820094599419E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,  -2.5922820094599419E-01,   9.5247940772275197E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,  -2.5922820094599419E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,   2.5922820094599419E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,  -2.5922820094599419E-01,  -9.5247940772275197E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,   2.5922820094599419E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,   2.5922820094599419E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,  -2.5922820094599419E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,   2.5922820094599419E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,  -2.5922820094599419E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,  -2.5922820094599419E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,   2.5922820094599419E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,  -2.5922820094599419E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,   1.5994910971436771E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,   1.5994910971436771E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,  -1.5994910971436771E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,   1.5994910971436771E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,  -1.5994910971436771E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   9.5247940772275197E-01,  -1.5994910971436771E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,   1.5994910971436771E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -9.5247940772275197E-01,  -1.5994910971436771E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,   9.5247940772275197E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,   9.5247940772275197E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,  -9.5247940772275197E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,   9.5247940772275197E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,  -9.5247940772275197E-01,   1.5994910971436771E-01,   4.9329791390095110E-03],
            [   2.5922820094599419E-01,  -9.5247940772275197E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,   9.5247940772275197E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [  -2.5922820094599419E-01,  -9.5247940772275197E-01,  -1.5994910971436771E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,   9.5247940772275197E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,   9.5247940772275197E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,  -9.5247940772275197E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,   9.5247940772275197E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,  -9.5247940772275197E-01,   2.5922820094599419E-01,   4.9329791390095110E-03],
            [   1.5994910971436771E-01,  -9.5247940772275197E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,   9.5247940772275197E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [  -1.5994910971436771E-01,  -9.5247940772275197E-01,  -2.5922820094599419E-01,   4.9329791390095110E-03],
            [   3.0817405613202031E-01,   2.0586999560280270E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,   2.0586999560280270E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,  -2.0586999560280270E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,   2.0586999560280270E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,  -2.0586999560280270E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,  -2.0586999560280270E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,   2.0586999560280270E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,  -2.0586999560280270E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,   3.0817405613202031E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,   3.0817405613202031E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,  -3.0817405613202031E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,   3.0817405613202031E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,  -3.0817405613202031E-01,   9.2878754084970394E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,  -3.0817405613202031E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,   3.0817405613202031E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,  -3.0817405613202031E-01,  -9.2878754084970394E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,   3.0817405613202031E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,   3.0817405613202031E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,  -3.0817405613202031E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,   3.0817405613202031E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,  -3.0817405613202031E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,  -3.0817405613202031E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,   3.0817405613202031E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,  -3.0817405613202031E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,   2.0586999560280270E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,   2.0586999560280270E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,  -2.0586999560280270E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,   2.0586999560280270E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,  -2.0586999560280270E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   9.2878754084970394E-01,  -2.0586999560280270E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,   2.0586999560280270E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -9.2878754084970394E-01,  -2.0586999560280270E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,   9.2878754084970394E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,   9.2878754084970394E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,  -9.2878754084970394E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,   9.2878754084970394E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,  -9.2878754084970394E-01,   2.0586999560280270E-01,   5.2227467150882069E-03],
            [   3.0817405613202031E-01,  -9.2878754084970394E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,   9.2878754084970394E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [  -3.0817405613202031E-01,  -9.2878754084970394E-01,  -2.0586999560280270E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,   9.2878754084970394E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,   9.2878754084970394E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,  -9.2878754084970394E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,   9.2878754084970394E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,  -9.2878754084970394E-01,   3.0817405613202031E-01,   5.2227467150882069E-03],
            [   2.0586999560280270E-01,  -9.2878754084970394E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,   9.2878754084970394E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [  -2.0586999560280270E-01,  -9.2878754084970394E-01,  -3.0817405613202031E-01,   5.2227467150882069E-03],
            [   3.5642897815781638E-01,   2.5216249535029112E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,   2.5216249535029112E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,  -2.5216249535029112E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,   2.5216249535029112E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,  -2.5216249535029112E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,  -2.5216249535029112E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,   2.5216249535029112E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,  -2.5216249535029112E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,   3.5642897815781638E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,   3.5642897815781638E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,  -3.5642897815781638E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,   3.5642897815781638E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,  -3.5642897815781638E-01,   8.9965129881976447E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,  -3.5642897815781638E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,   3.5642897815781638E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,  -3.5642897815781638E-01,  -8.9965129881976447E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,   3.5642897815781638E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,   3.5642897815781638E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,  -3.5642897815781638E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,   3.5642897815781638E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,  -3.5642897815781638E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,  -3.5642897815781638E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,   3.5642897815781638E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,  -3.5642897815781638E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,   2.5216249535029112E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,   2.5216249535029112E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,  -2.5216249535029112E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,   2.5216249535029112E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,  -2.5216249535029112E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   8.9965129881976447E-01,  -2.5216249535029112E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,   2.5216249535029112E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -8.9965129881976447E-01,  -2.5216249535029112E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,   8.9965129881976447E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,   8.9965129881976447E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,  -8.9965129881976447E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,   8.9965129881976447E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,  -8.9965129881976447E-01,   2.5216249535029112E-01,   5.4420489875991705E-03],
            [   3.5642897815781638E-01,  -8.9965129881976447E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,   8.9965129881976447E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [  -3.5642897815781638E-01,  -8.9965129881976447E-01,  -2.5216249535029112E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,   8.9965129881976447E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,   8.9965129881976447E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,  -8.9965129881976447E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,   8.9965129881976447E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,  -8.9965129881976447E-01,   3.5642897815781638E-01,   5.4420489875991705E-03],
            [   2.5216249535029112E-01,  -8.9965129881976447E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,   8.9965129881976447E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [  -2.5216249535029112E-01,  -8.9965129881976447E-01,  -3.5642897815781638E-01,   5.4420489875991705E-03],
            [   4.0355872882407029E-01,   2.9820907857976742E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,   2.9820907857976742E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,  -2.9820907857976742E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,   2.9820907857976742E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,  -2.9820907857976742E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,  -2.9820907857976742E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,   2.9820907857976742E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,  -2.9820907857976742E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,   4.0355872882407029E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,   4.0355872882407029E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,  -4.0355872882407029E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,   4.0355872882407029E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,  -4.0355872882407029E-01,   8.6499231085744721E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,  -4.0355872882407029E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,   4.0355872882407029E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,  -4.0355872882407029E-01,  -8.6499231085744721E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,   4.0355872882407029E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,   4.0355872882407029E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,  -4.0355872882407029E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,   4.0355872882407029E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,  -4.0355872882407029E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,  -4.0355872882407029E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,   4.0355872882407029E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,  -4.0355872882407029E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,   2.9820907857976742E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,   2.9820907857976742E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,  -2.9820907857976742E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,   2.9820907857976742E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,  -2.9820907857976742E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   8.6499231085744721E-01,  -2.9820907857976742E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,   2.9820907857976742E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -8.6499231085744721E-01,  -2.9820907857976742E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,   8.6499231085744721E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,   8.6499231085744721E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,  -8.6499231085744721E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,   8.6499231085744721E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,  -8.6499231085744721E-01,   2.9820907857976742E-01,   5.6041963124529711E-03],
            [   4.0355872882407029E-01,  -8.6499231085744721E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,   8.6499231085744721E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [  -4.0355872882407029E-01,  -8.6499231085744721E-01,  -2.9820907857976742E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,   8.6499231085744721E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,   8.6499231085744721E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,  -8.6499231085744721E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,   8.6499231085744721E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,  -8.6499231085744721E-01,   4.0355872882407029E-01,   5.6041963124529711E-03],
            [   2.9820907857976742E-01,  -8.6499231085744721E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,   8.6499231085744721E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [  -2.9820907857976742E-01,  -8.6499231085744721E-01,  -4.0355872882407029E-01,   5.6041963124529711E-03],
            [   4.4916711963739031E-01,   3.4347620872357332E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,   3.4347620872357332E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,  -3.4347620872357332E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,   3.4347620872357332E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,  -3.4347620872357332E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,  -3.4347620872357332E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,   3.4347620872357332E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,  -3.4347620872357332E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,   4.4916711963739031E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,   4.4916711963739031E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,  -4.4916711963739031E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,   4.4916711963739031E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,  -4.4916711963739031E-01,   8.2478663463803203E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,  -4.4916711963739031E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,   4.4916711963739031E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,  -4.4916711963739031E-01,  -8.2478663463803203E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,   4.4916711963739031E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,   4.4916711963739031E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,  -4.4916711963739031E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,   4.4916711963739031E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,  -4.4916711963739031E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,  -4.4916711963739031E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,   4.4916711963739031E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,  -4.4916711963739031E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,   3.4347620872357332E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,   3.4347620872357332E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,  -3.4347620872357332E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,   3.4347620872357332E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,  -3.4347620872357332E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   8.2478663463803203E-01,  -3.4347620872357332E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,   3.4347620872357332E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -8.2478663463803203E-01,  -3.4347620872357332E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,   8.2478663463803203E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,   8.2478663463803203E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,  -8.2478663463803203E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,   8.2478663463803203E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,  -8.2478663463803203E-01,   3.4347620872357332E-01,   5.7197004579728648E-03],
            [   4.4916711963739031E-01,  -8.2478663463803203E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,   8.2478663463803203E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [  -4.4916711963739031E-01,  -8.2478663463803203E-01,  -3.4347620872357332E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,   8.2478663463803203E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,   8.2478663463803203E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,  -8.2478663463803203E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,   8.2478663463803203E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,  -8.2478663463803203E-01,   4.4916711963739031E-01,   5.7197004579728648E-03],
            [   3.4347620872357332E-01,  -8.2478663463803203E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,   8.2478663463803203E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [  -3.4347620872357332E-01,  -8.2478663463803203E-01,  -4.4916711963739031E-01,   5.7197004579728648E-03],
            [   4.9288547829174889E-01,   3.8748313572034371E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,   3.8748313572034371E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,  -3.8748313572034371E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,   3.8748313572034371E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,  -3.8748313572034371E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,  -3.8748313572034371E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,   3.8748313572034371E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,  -3.8748313572034371E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,   4.9288547829174889E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,   4.9288547829174889E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,  -4.9288547829174889E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,   4.9288547829174889E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,  -4.9288547829174889E-01,   7.7905116957838116E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,  -4.9288547829174889E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,   4.9288547829174889E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,  -4.9288547829174889E-01,  -7.7905116957838116E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,   4.9288547829174889E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,   4.9288547829174889E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,  -4.9288547829174889E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,   4.9288547829174889E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,  -4.9288547829174889E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,  -4.9288547829174889E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,   4.9288547829174889E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,  -4.9288547829174889E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,   3.8748313572034371E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,   3.8748313572034371E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,  -3.8748313572034371E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,   3.8748313572034371E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,  -3.8748313572034371E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   7.7905116957838116E-01,  -3.8748313572034371E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,   3.8748313572034371E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -7.7905116957838116E-01,  -3.8748313572034371E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,   7.7905116957838116E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,   7.7905116957838116E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,  -7.7905116957838116E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,   7.7905116957838116E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,  -7.7905116957838116E-01,   3.8748313572034371E-01,   5.7972958591505329E-03],
            [   4.9288547829174889E-01,  -7.7905116957838116E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,   7.7905116957838116E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [  -4.9288547829174889E-01,  -7.7905116957838116E-01,  -3.8748313572034371E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,   7.7905116957838116E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,   7.7905116957838116E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,  -7.7905116957838116E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,   7.7905116957838116E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,  -7.7905116957838116E-01,   4.9288547829174889E-01,   5.7972958591505329E-03],
            [   3.8748313572034371E-01,  -7.7905116957838116E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,   7.7905116957838116E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [  -3.8748313572034371E-01,  -7.7905116957838116E-01,  -4.9288547829174889E-01,   5.7972958591505329E-03],
            [   5.3436467919589881E-01,   4.2978148217469259E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,   4.2978148217469259E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,  -4.2978148217469259E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,   4.2978148217469259E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,  -4.2978148217469259E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,  -4.2978148217469259E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,   4.2978148217469259E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,  -4.2978148217469259E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,   5.3436467919589881E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,   5.3436467919589881E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,  -5.3436467919589881E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,   5.3436467919589881E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,  -5.3436467919589881E-01,   7.2783395579458132E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,  -5.3436467919589881E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,   5.3436467919589881E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,  -5.3436467919589881E-01,  -7.2783395579458132E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,   5.3436467919589881E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,   5.3436467919589881E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,  -5.3436467919589881E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,   5.3436467919589881E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,  -5.3436467919589881E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,  -5.3436467919589881E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,   5.3436467919589881E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,  -5.3436467919589881E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,   4.2978148217469259E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,   4.2978148217469259E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,  -4.2978148217469259E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,   4.2978148217469259E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,  -4.2978148217469259E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   7.2783395579458132E-01,  -4.2978148217469259E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,   4.2978148217469259E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -7.2783395579458132E-01,  -4.2978148217469259E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,   7.2783395579458132E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,   7.2783395579458132E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,  -7.2783395579458132E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,   7.2783395579458132E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,  -7.2783395579458132E-01,   4.2978148217469259E-01,   5.8446436257833705E-03],
            [   5.3436467919589881E-01,  -7.2783395579458132E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,   7.2783395579458132E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [  -5.3436467919589881E-01,  -7.2783395579458132E-01,  -4.2978148217469259E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,   7.2783395579458132E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,   7.2783395579458132E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,  -7.2783395579458132E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,   7.2783395579458132E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,  -7.2783395579458132E-01,   5.3436467919589881E-01,   5.8446436257833705E-03],
            [   4.2978148217469259E-01,  -7.2783395579458132E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,   7.2783395579458132E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [  -4.2978148217469259E-01,  -7.2783395579458132E-01,  -5.3436467919589881E-01,   5.8446436257833705E-03],
            [   5.7326832165309904E-01,   4.6994022609435371E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,   4.6994022609435371E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,  -4.6994022609435371E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,   4.6994022609435371E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,  -4.6994022609435371E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,  -4.6994022609435371E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,   4.6994022609435371E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,  -4.6994022609435371E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,   5.7326832165309904E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,   5.7326832165309904E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,  -5.7326832165309904E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,   5.7326832165309904E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,  -5.7326832165309904E-01,   6.7120757987929980E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,  -5.7326832165309904E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,   5.7326832165309904E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,  -5.7326832165309904E-01,  -6.7120757987929980E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,   5.7326832165309904E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,   5.7326832165309904E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,  -5.7326832165309904E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,   5.7326832165309904E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,  -5.7326832165309904E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,  -5.7326832165309904E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,   5.7326832165309904E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,  -5.7326832165309904E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,   4.6994022609435371E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,   4.6994022609435371E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,  -4.6994022609435371E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,   4.6994022609435371E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,  -4.6994022609435371E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   6.7120757987929980E-01,  -4.6994022609435371E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,   4.6994022609435371E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -6.7120757987929980E-01,  -4.6994022609435371E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,   6.7120757987929980E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,   6.7120757987929980E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,  -6.7120757987929980E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,   6.7120757987929980E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,  -6.7120757987929980E-01,   4.6994022609435371E-01,   5.8688086532179455E-03],
            [   5.7326832165309904E-01,  -6.7120757987929980E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,   6.7120757987929980E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [  -5.7326832165309904E-01,  -6.7120757987929980E-01,  -4.6994022609435371E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,   6.7120757987929980E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,   6.7120757987929980E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,  -6.7120757987929980E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,   6.7120757987929980E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,  -6.7120757987929980E-01,   5.7326832165309904E-01,   5.8688086532179455E-03],
            [   4.6994022609435371E-01,  -6.7120757987929980E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,   6.7120757987929980E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [  -4.6994022609435371E-01,  -6.7120757987929980E-01,  -5.7326832165309904E-01,   5.8688086532179455E-03],
            [   2.2141315832189859E-01,   3.8736020406438948E-02,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,   3.8736020406438948E-02,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,  -3.8736020406438948E-02,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,   3.8736020406438948E-02,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,  -3.8736020406438948E-02,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,  -3.8736020406438948E-02,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,   3.8736020406438948E-02,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,  -3.8736020406438948E-02,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,   2.2141315832189859E-01,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,   2.2141315832189859E-01,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,  -2.2141315832189859E-01,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,   2.2141315832189859E-01,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,  -2.2141315832189859E-01,   9.7441045460575482E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,  -2.2141315832189859E-01,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,   2.2141315832189859E-01,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,  -2.2141315832189859E-01,  -9.7441045460575482E-01,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,   2.2141315832189859E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,   2.2141315832189859E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,  -2.2141315832189859E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,   2.2141315832189859E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,  -2.2141315832189859E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,  -2.2141315832189859E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,   2.2141315832189859E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,  -2.2141315832189859E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,   3.8736020406438948E-02,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,   3.8736020406438948E-02,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,  -3.8736020406438948E-02,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,   3.8736020406438948E-02,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,  -3.8736020406438948E-02,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   9.7441045460575482E-01,  -3.8736020406438948E-02,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,   3.8736020406438948E-02,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -9.7441045460575482E-01,  -3.8736020406438948E-02,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,   9.7441045460575482E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,   9.7441045460575482E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,  -9.7441045460575482E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,   9.7441045460575482E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,  -9.7441045460575482E-01,   3.8736020406438948E-02,   4.4605030889831813E-03],
            [   2.2141315832189859E-01,  -9.7441045460575482E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,   9.7441045460575482E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [  -2.2141315832189859E-01,  -9.7441045460575482E-01,  -3.8736020406438948E-02,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,   9.7441045460575482E-01,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,   9.7441045460575482E-01,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,  -9.7441045460575482E-01,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,   9.7441045460575482E-01,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,  -9.7441045460575482E-01,   2.2141315832189859E-01,   4.4605030889831813E-03],
            [   3.8736020406438948E-02,  -9.7441045460575482E-01,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,   9.7441045460575482E-01,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [  -3.8736020406438948E-02,  -9.7441045460575482E-01,  -2.2141315832189859E-01,   4.4605030889831813E-03],
            [   2.7417965047500709E-01,   8.0894962569020123E-02,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,   8.0894962569020123E-02,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,  -8.0894962569020123E-02,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,   8.0894962569020123E-02,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,  -8.0894962569020123E-02,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,  -8.0894962569020123E-02,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,   8.0894962569020123E-02,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,  -8.0894962569020123E-02,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,   2.7417965047500709E-01,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,   2.7417965047500709E-01,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,  -2.7417965047500709E-01,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,   2.7417965047500709E-01,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,  -2.7417965047500709E-01,   9.5827006855915087E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,  -2.7417965047500709E-01,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,   2.7417965047500709E-01,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,  -2.7417965047500709E-01,  -9.5827006855915087E-01,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,   2.7417965047500709E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,   2.7417965047500709E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,  -2.7417965047500709E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,   2.7417965047500709E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,  -2.7417965047500709E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,  -2.7417965047500709E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,   2.7417965047500709E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,  -2.7417965047500709E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,   8.0894962569020123E-02,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,   8.0894962569020123E-02,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,  -8.0894962569020123E-02,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,   8.0894962569020123E-02,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,  -8.0894962569020123E-02,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   9.5827006855915087E-01,  -8.0894962569020123E-02,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,   8.0894962569020123E-02,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -9.5827006855915087E-01,  -8.0894962569020123E-02,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,   9.5827006855915087E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,   9.5827006855915087E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,  -9.5827006855915087E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,   9.5827006855915087E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,  -9.5827006855915087E-01,   8.0894962569020123E-02,   4.8457285338885268E-03],
            [   2.7417965047500709E-01,  -9.5827006855915087E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,   9.5827006855915087E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [  -2.7417965047500709E-01,  -9.5827006855915087E-01,  -8.0894962569020123E-02,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,   9.5827006855915087E-01,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,   9.5827006855915087E-01,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,  -9.5827006855915087E-01,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,   9.5827006855915087E-01,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,  -9.5827006855915087E-01,   2.7417965047500709E-01,   4.8457285338885268E-03],
            [   8.0894962569020123E-02,  -9.5827006855915087E-01,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,   9.5827006855915087E-01,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [  -8.0894962569020123E-02,  -9.5827006855915087E-01,  -2.7417965047500709E-01,   4.8457285338885268E-03],
            [   3.2597974391494849E-01,   1.2517321776208720E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,   1.2517321776208720E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,  -1.2517321776208720E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,   1.2517321776208720E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,  -1.2517321776208720E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,  -1.2517321776208720E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,   1.2517321776208720E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,  -1.2517321776208720E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,   3.2597974391494849E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,   3.2597974391494849E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,  -3.2597974391494849E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,   3.2597974391494849E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,  -3.2597974391494849E-01,   9.3705329203425225E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,  -3.2597974391494849E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,   3.2597974391494849E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,  -3.2597974391494849E-01,  -9.3705329203425225E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,   3.2597974391494849E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,   3.2597974391494849E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,  -3.2597974391494849E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,   3.2597974391494849E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,  -3.2597974391494849E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,  -3.2597974391494849E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,   3.2597974391494849E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,  -3.2597974391494849E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,   1.2517321776208720E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,   1.2517321776208720E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,  -1.2517321776208720E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,   1.2517321776208720E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,  -1.2517321776208720E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   9.3705329203425225E-01,  -1.2517321776208720E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,   1.2517321776208720E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -9.3705329203425225E-01,  -1.2517321776208720E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,   9.3705329203425225E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,   9.3705329203425225E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,  -9.3705329203425225E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,   9.3705329203425225E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,  -9.3705329203425225E-01,   1.2517321776208720E-01,   5.1504813688260445E-03],
            [   3.2597974391494849E-01,  -9.3705329203425225E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,   9.3705329203425225E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [  -3.2597974391494849E-01,  -9.3705329203425225E-01,  -1.2517321776208720E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,   9.3705329203425225E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,   9.3705329203425225E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,  -9.3705329203425225E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,   9.3705329203425225E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,  -9.3705329203425225E-01,   3.2597974391494849E-01,   5.1504813688260445E-03],
            [   1.2517321776208720E-01,  -9.3705329203425225E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,   9.3705329203425225E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [  -1.2517321776208720E-01,  -9.3705329203425225E-01,  -3.2597974391494849E-01,   5.1504813688260445E-03],
            [   3.7654411488268907E-01,   1.7062602864031851E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,   1.7062602864031851E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,  -1.7062602864031851E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,   1.7062602864031851E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,  -1.7062602864031851E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,  -1.7062602864031851E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,   1.7062602864031851E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,  -1.7062602864031851E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,   3.7654411488268907E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,   3.7654411488268907E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,  -3.7654411488268907E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,   3.7654411488268907E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,  -3.7654411488268907E-01,   9.1054999198157460E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,  -3.7654411488268907E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,   3.7654411488268907E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,  -3.7654411488268907E-01,  -9.1054999198157460E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,   3.7654411488268907E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,   3.7654411488268907E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,  -3.7654411488268907E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,   3.7654411488268907E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,  -3.7654411488268907E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,  -3.7654411488268907E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,   3.7654411488268907E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,  -3.7654411488268907E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,   1.7062602864031851E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,   1.7062602864031851E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,  -1.7062602864031851E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,   1.7062602864031851E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,  -1.7062602864031851E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   9.1054999198157460E-01,  -1.7062602864031851E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,   1.7062602864031851E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -9.1054999198157460E-01,  -1.7062602864031851E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,   9.1054999198157460E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,   9.1054999198157460E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,  -9.1054999198157460E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,   9.1054999198157460E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,  -9.1054999198157460E-01,   1.7062602864031851E-01,   5.3863593816172502E-03],
            [   3.7654411488268907E-01,  -9.1054999198157460E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,   9.1054999198157460E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [  -3.7654411488268907E-01,  -9.1054999198157460E-01,  -1.7062602864031851E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,   9.1054999198157460E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,   9.1054999198157460E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,  -9.1054999198157460E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,   9.1054999198157460E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,  -9.1054999198157460E-01,   3.7654411488268907E-01,   5.3863593816172502E-03],
            [   1.7062602864031851E-01,  -9.1054999198157460E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,   9.1054999198157460E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [  -1.7062602864031851E-01,  -9.1054999198157460E-01,  -3.7654411488268907E-01,   5.3863593816172502E-03],
            [   4.2557735745305580E-01,   2.1651151473004079E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,   2.1651151473004079E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,  -2.1651151473004079E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,   2.1651151473004079E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,  -2.1651151473004079E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,  -2.1651151473004079E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,   2.1651151473004079E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,  -2.1651151473004079E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,   4.2557735745305580E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,   4.2557735745305580E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,  -4.2557735745305580E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,   4.2557735745305580E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,  -4.2557735745305580E-01,   8.7863910498712572E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,  -4.2557735745305580E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,   4.2557735745305580E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,  -4.2557735745305580E-01,  -8.7863910498712572E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,   4.2557735745305580E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,   4.2557735745305580E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,  -4.2557735745305580E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,   4.2557735745305580E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,  -4.2557735745305580E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,  -4.2557735745305580E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,   4.2557735745305580E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,  -4.2557735745305580E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,   2.1651151473004079E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,   2.1651151473004079E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,  -2.1651151473004079E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,   2.1651151473004079E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,  -2.1651151473004079E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   8.7863910498712572E-01,  -2.1651151473004079E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,   2.1651151473004079E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -8.7863910498712572E-01,  -2.1651151473004079E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,   8.7863910498712572E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,   8.7863910498712572E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,  -8.7863910498712572E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,   8.7863910498712572E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,  -8.7863910498712572E-01,   2.1651151473004079E-01,   5.5641403439632437E-03],
            [   4.2557735745305580E-01,  -8.7863910498712572E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,   8.7863910498712572E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [  -4.2557735745305580E-01,  -8.7863910498712572E-01,  -2.1651151473004079E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,   8.7863910498712572E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,   8.7863910498712572E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,  -8.7863910498712572E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,   8.7863910498712572E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,  -8.7863910498712572E-01,   4.2557735745305580E-01,   5.5641403439632437E-03],
            [   2.1651151473004079E-01,  -8.7863910498712572E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,   8.7863910498712572E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [  -2.1651151473004079E-01,  -8.7863910498712572E-01,  -4.2557735745305580E-01,   5.5641403439632437E-03],
            [   4.7277951170584298E-01,   2.6220898122252589E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,   2.6220898122252589E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,  -2.6220898122252589E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,   2.6220898122252589E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,  -2.6220898122252589E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,  -2.6220898122252589E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,   2.6220898122252589E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,  -2.6220898122252589E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,   4.7277951170584298E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,   4.7277951170584298E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,  -4.7277951170584298E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,   4.7277951170584298E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,  -4.7277951170584298E-01,   8.4126451457162377E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,  -4.7277951170584298E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,   4.7277951170584298E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,  -4.7277951170584298E-01,  -8.4126451457162377E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,   4.7277951170584298E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,   4.7277951170584298E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,  -4.7277951170584298E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,   4.7277951170584298E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,  -4.7277951170584298E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,  -4.7277951170584298E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,   4.7277951170584298E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,  -4.7277951170584298E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,   2.6220898122252589E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,   2.6220898122252589E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,  -2.6220898122252589E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,   2.6220898122252589E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,  -2.6220898122252589E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   8.4126451457162377E-01,  -2.6220898122252589E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,   2.6220898122252589E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -8.4126451457162377E-01,  -2.6220898122252589E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,   8.4126451457162377E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,   8.4126451457162377E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,  -8.4126451457162377E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,   8.4126451457162377E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,  -8.4126451457162377E-01,   2.6220898122252589E-01,   5.6931609203902458E-03],
            [   4.7277951170584298E-01,  -8.4126451457162377E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,   8.4126451457162377E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [  -4.7277951170584298E-01,  -8.4126451457162377E-01,  -2.6220898122252589E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,   8.4126451457162377E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,   8.4126451457162377E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,  -8.4126451457162377E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,   8.4126451457162377E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,  -8.4126451457162377E-01,   4.7277951170584298E-01,   5.6931609203902458E-03],
            [   2.6220898122252589E-01,  -8.4126451457162377E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,   8.4126451457162377E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [  -2.6220898122252589E-01,  -8.4126451457162377E-01,  -4.7277951170584298E-01,   5.6931609203902458E-03],
            [   5.1785468958190117E-01,   3.0717214312962010E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,   3.0717214312962010E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,  -3.0717214312962010E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,   3.0717214312962010E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,  -3.0717214312962010E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,  -3.0717214312962010E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,   3.0717214312962010E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,  -3.0717214312962010E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,   5.1785468958190117E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,   5.1785468958190117E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,  -5.1785468958190117E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,   5.1785468958190117E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,  -5.1785468958190117E-01,   7.9841830825901594E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,  -5.1785468958190117E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,   5.1785468958190117E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,  -5.1785468958190117E-01,  -7.9841830825901594E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,   5.1785468958190117E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,   5.1785468958190117E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,  -5.1785468958190117E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,   5.1785468958190117E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,  -5.1785468958190117E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,  -5.1785468958190117E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,   5.1785468958190117E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,  -5.1785468958190117E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,   3.0717214312962010E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,   3.0717214312962010E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,  -3.0717214312962010E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,   3.0717214312962010E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,  -3.0717214312962010E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   7.9841830825901594E-01,  -3.0717214312962010E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,   3.0717214312962010E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -7.9841830825901594E-01,  -3.0717214312962010E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,   7.9841830825901594E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,   7.9841830825901594E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,  -7.9841830825901594E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,   7.9841830825901594E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,  -7.9841830825901594E-01,   3.0717214312962010E-01,   5.7815426732258689E-03],
            [   5.1785468958190117E-01,  -7.9841830825901594E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,   7.9841830825901594E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [  -5.1785468958190117E-01,  -7.9841830825901594E-01,  -3.0717214312962010E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,   7.9841830825901594E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,   7.9841830825901594E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,  -7.9841830825901594E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,   7.9841830825901594E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,  -7.9841830825901594E-01,   5.1785468958190117E-01,   5.7815426732258689E-03],
            [   3.0717214312962010E-01,  -7.9841830825901594E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,   7.9841830825901594E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [  -3.0717214312962010E-01,  -7.9841830825901594E-01,  -5.1785468958190117E-01,   5.7815426732258689E-03],
            [   5.6051411920974603E-01,   3.5089989988011377E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,   3.5089989988011377E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,  -3.5089989988011377E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,   3.5089989988011377E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,  -3.5089989988011377E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,  -3.5089989988011377E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,   3.5089989988011377E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,  -3.5089989988011377E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,   5.6051411920974603E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,   5.6051411920974603E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,  -5.6051411920974603E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,   5.6051411920974603E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,  -5.6051411920974603E-01,   7.5012877723138227E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,  -5.6051411920974603E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,   5.6051411920974603E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,  -5.6051411920974603E-01,  -7.5012877723138227E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,   5.6051411920974603E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,   5.6051411920974603E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,  -5.6051411920974603E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,   5.6051411920974603E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,  -5.6051411920974603E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,  -5.6051411920974603E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,   5.6051411920974603E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,  -5.6051411920974603E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,   3.5089989988011377E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,   3.5089989988011377E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,  -3.5089989988011377E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,   3.5089989988011377E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,  -3.5089989988011377E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   7.5012877723138227E-01,  -3.5089989988011377E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,   3.5089989988011377E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -7.5012877723138227E-01,  -3.5089989988011377E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,   7.5012877723138227E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,   7.5012877723138227E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,  -7.5012877723138227E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,   7.5012877723138227E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,  -7.5012877723138227E-01,   3.5089989988011377E-01,   5.8365753142536657E-03],
            [   5.6051411920974603E-01,  -7.5012877723138227E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,   7.5012877723138227E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [  -5.6051411920974603E-01,  -7.5012877723138227E-01,  -3.5089989988011377E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,   7.5012877723138227E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,   7.5012877723138227E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,  -7.5012877723138227E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,   7.5012877723138227E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,  -7.5012877723138227E-01,   5.6051411920974603E-01,   5.8365753142536657E-03],
            [   3.5089989988011377E-01,  -7.5012877723138227E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,   7.5012877723138227E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [  -3.5089989988011377E-01,  -7.5012877723138227E-01,  -5.6051411920974603E-01,   5.8365753142536657E-03],
            [   6.0047633193525118E-01,   3.9291608761669311E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,   3.9291608761669311E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,  -3.9291608761669311E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,   3.9291608761669311E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,  -3.9291608761669311E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,  -3.9291608761669311E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,   3.9291608761669311E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,  -3.9291608761669311E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,   6.0047633193525118E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,   6.0047633193525118E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,  -6.0047633193525118E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,   6.0047633193525118E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,  -6.0047633193525118E-01,   6.9645180944382457E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,  -6.0047633193525118E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,   6.0047633193525118E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,  -6.0047633193525118E-01,  -6.9645180944382457E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,   6.0047633193525118E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,   6.0047633193525118E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,  -6.0047633193525118E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,   6.0047633193525118E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,  -6.0047633193525118E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,  -6.0047633193525118E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,   6.0047633193525118E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,  -6.0047633193525118E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,   3.9291608761669311E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,   3.9291608761669311E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,  -3.9291608761669311E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,   3.9291608761669311E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,  -3.9291608761669311E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   6.9645180944382457E-01,  -3.9291608761669311E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,   3.9291608761669311E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -6.9645180944382457E-01,  -3.9291608761669311E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,   6.9645180944382457E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,   6.9645180944382457E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,  -6.9645180944382457E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,   6.9645180944382457E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,  -6.9645180944382457E-01,   3.9291608761669311E-01,   5.8650700569414863E-03],
            [   6.0047633193525118E-01,  -6.9645180944382457E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,   6.9645180944382457E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [  -6.0047633193525118E-01,  -6.9645180944382457E-01,  -3.9291608761669311E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,   6.9645180944382457E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,   6.9645180944382457E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,  -6.9645180944382457E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,   6.9645180944382457E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,  -6.9645180944382457E-01,   6.0047633193525118E-01,   5.8650700569414863E-03],
            [   3.9291608761669311E-01,  -6.9645180944382457E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,   6.9645180944382457E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [  -3.9291608761669311E-01,  -6.9645180944382457E-01,  -6.0047633193525118E-01,   5.8650700569414863E-03],
            [   3.3528426349469492E-01,   4.2025634572880187E-02,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,   4.2025634572880187E-02,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,  -4.2025634572880187E-02,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,   4.2025634572880187E-02,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,  -4.2025634572880187E-02,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,  -4.2025634572880187E-02,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,   4.2025634572880187E-02,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,  -4.2025634572880187E-02,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,   3.3528426349469492E-01,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,   3.3528426349469492E-01,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,  -3.3528426349469492E-01,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,   3.3528426349469492E-01,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,  -3.3528426349469492E-01,   9.4117921178252062E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,  -3.3528426349469492E-01,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,   3.3528426349469492E-01,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,  -3.3528426349469492E-01,  -9.4117921178252062E-01,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,   3.3528426349469492E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,   3.3528426349469492E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,  -3.3528426349469492E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,   3.3528426349469492E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,  -3.3528426349469492E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,  -3.3528426349469492E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,   3.3528426349469492E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,  -3.3528426349469492E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,   4.2025634572880187E-02,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,   4.2025634572880187E-02,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,  -4.2025634572880187E-02,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,   4.2025634572880187E-02,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,  -4.2025634572880187E-02,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   9.4117921178252062E-01,  -4.2025634572880187E-02,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,   4.2025634572880187E-02,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -9.4117921178252062E-01,  -4.2025634572880187E-02,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,   9.4117921178252062E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,   9.4117921178252062E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,  -9.4117921178252062E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,   9.4117921178252062E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,  -9.4117921178252062E-01,   4.2025634572880187E-02,   5.1137092432884416E-03],
            [   3.3528426349469492E-01,  -9.4117921178252062E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,   9.4117921178252062E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [  -3.3528426349469492E-01,  -9.4117921178252062E-01,  -4.2025634572880187E-02,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,   9.4117921178252062E-01,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,   9.4117921178252062E-01,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,  -9.4117921178252062E-01,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,   9.4117921178252062E-01,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,  -9.4117921178252062E-01,   3.3528426349469492E-01,   5.1137092432884416E-03],
            [   4.2025634572880187E-02,  -9.4117921178252062E-01,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,   9.4117921178252062E-01,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [  -4.2025634572880187E-02,  -9.4117921178252062E-01,  -3.3528426349469492E-01,   5.1137092432884416E-03],
            [   3.8919716298146700E-01,   8.6143097588708500E-02,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,   8.6143097588708500E-02,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,  -8.6143097588708500E-02,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,   8.6143097588708500E-02,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,  -8.6143097588708500E-02,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,  -8.6143097588708500E-02,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,   8.6143097588708500E-02,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,  -8.6143097588708500E-02,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,   3.8919716298146700E-01,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,   3.8919716298146700E-01,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,  -3.8919716298146700E-01,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,   3.8919716298146700E-01,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,  -3.8919716298146700E-01,   9.1711773239044925E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,  -3.8919716298146700E-01,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,   3.8919716298146700E-01,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,  -3.8919716298146700E-01,  -9.1711773239044925E-01,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,   3.8919716298146700E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,   3.8919716298146700E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,  -3.8919716298146700E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,   3.8919716298146700E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,  -3.8919716298146700E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,  -3.8919716298146700E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,   3.8919716298146700E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,  -3.8919716298146700E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,   8.6143097588708500E-02,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,   8.6143097588708500E-02,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,  -8.6143097588708500E-02,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,   8.6143097588708500E-02,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,  -8.6143097588708500E-02,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   9.1711773239044925E-01,  -8.6143097588708500E-02,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,   8.6143097588708500E-02,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -9.1711773239044925E-01,  -8.6143097588708500E-02,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,   9.1711773239044925E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,   9.1711773239044925E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,  -9.1711773239044925E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,   9.1711773239044925E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,  -9.1711773239044925E-01,   8.6143097588708500E-02,   5.3538303456390100E-03],
            [   3.8919716298146700E-01,  -9.1711773239044925E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,   9.1711773239044925E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [  -3.8919716298146700E-01,  -9.1711773239044925E-01,  -8.6143097588708500E-02,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,   9.1711773239044925E-01,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,   9.1711773239044925E-01,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,  -9.1711773239044925E-01,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,   9.1711773239044925E-01,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,  -9.1711773239044925E-01,   3.8919716298146700E-01,   5.3538303456390100E-03],
            [   8.6143097588708500E-02,  -9.1711773239044925E-01,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,   9.1711773239044925E-01,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [  -8.6143097588708500E-02,  -9.1711773239044925E-01,  -3.8919716298146700E-01,   5.3538303456390100E-03],
            [   4.4098755655422811E-01,   1.3145008793800009E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,   1.3145008793800009E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,  -1.3145008793800009E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,   1.3145008793800009E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,  -1.3145008793800009E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,  -1.3145008793800009E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,   1.3145008793800009E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,  -1.3145008793800009E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,   4.4098755655422811E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,   4.4098755655422811E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,  -4.4098755655422811E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,   4.4098755655422811E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,  -4.4098755655422811E-01,   8.8783492235067185E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,  -4.4098755655422811E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,   4.4098755655422811E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,  -4.4098755655422811E-01,  -8.8783492235067185E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,   4.4098755655422811E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,   4.4098755655422811E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,  -4.4098755655422811E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,   4.4098755655422811E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,  -4.4098755655422811E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,  -4.4098755655422811E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,   4.4098755655422811E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,  -4.4098755655422811E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,   1.3145008793800009E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,   1.3145008793800009E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,  -1.3145008793800009E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,   1.3145008793800009E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,  -1.3145008793800009E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   8.8783492235067185E-01,  -1.3145008793800009E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,   1.3145008793800009E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -8.8783492235067185E-01,  -1.3145008793800009E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,   8.8783492235067185E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,   8.8783492235067185E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,  -8.8783492235067185E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,   8.8783492235067185E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,  -8.8783492235067185E-01,   1.3145008793800009E-01,   5.5401088051453256E-03],
            [   4.4098755655422811E-01,  -8.8783492235067185E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,   8.8783492235067185E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [  -4.4098755655422811E-01,  -8.8783492235067185E-01,  -1.3145008793800009E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,   8.8783492235067185E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,   8.8783492235067185E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,  -8.8783492235067185E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,   8.8783492235067185E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,  -8.8783492235067185E-01,   4.4098755655422811E-01,   5.5401088051453256E-03],
            [   1.3145008793800009E-01,  -8.8783492235067185E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,   8.8783492235067185E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [  -1.3145008793800009E-01,  -8.8783492235067185E-01,  -4.4098755655422811E-01,   5.5401088051453256E-03],
            [   4.9048930585924838E-01,   1.7721896573838589E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,   1.7721896573838589E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,  -1.7721896573838589E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,   1.7721896573838589E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,  -1.7721896573838589E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,  -1.7721896573838589E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,   1.7721896573838589E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,  -1.7721896573838589E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,   4.9048930585924838E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,   4.9048930585924838E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,  -4.9048930585924838E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,   4.9048930585924838E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,  -4.9048930585924838E-01,   8.5323717629996021E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,  -4.9048930585924838E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,   4.9048930585924838E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,  -4.9048930585924838E-01,  -8.5323717629996021E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,   4.9048930585924838E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,   4.9048930585924838E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,  -4.9048930585924838E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,   4.9048930585924838E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,  -4.9048930585924838E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,  -4.9048930585924838E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,   4.9048930585924838E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,  -4.9048930585924838E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,   1.7721896573838589E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,   1.7721896573838589E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,  -1.7721896573838589E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,   1.7721896573838589E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,  -1.7721896573838589E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   8.5323717629996021E-01,  -1.7721896573838589E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,   1.7721896573838589E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -8.5323717629996021E-01,  -1.7721896573838589E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,   8.5323717629996021E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,   8.5323717629996021E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,  -8.5323717629996021E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,   8.5323717629996021E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,  -8.5323717629996021E-01,   1.7721896573838589E-01,   5.6784263532920782E-03],
            [   4.9048930585924838E-01,  -8.5323717629996021E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,   8.5323717629996021E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [  -4.9048930585924838E-01,  -8.5323717629996021E-01,  -1.7721896573838589E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,   8.5323717629996021E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,   8.5323717629996021E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,  -8.5323717629996021E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,   8.5323717629996021E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,  -8.5323717629996021E-01,   4.9048930585924838E-01,   5.6784263532920782E-03],
            [   1.7721896573838589E-01,  -8.5323717629996021E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,   8.5323717629996021E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [  -1.7721896573838589E-01,  -8.5323717629996021E-01,  -4.9048930585924838E-01,   5.6784263532920782E-03],
            [   5.3750561387695495E-01,   2.2282771100502941E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,   2.2282771100502941E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,  -2.2282771100502941E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,   2.2282771100502941E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,  -2.2282771100502941E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,  -2.2282771100502941E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,   2.2282771100502941E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,  -2.2282771100502941E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,   5.3750561387695495E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,   5.3750561387695495E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,  -5.3750561387695495E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,   5.3750561387695495E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,  -5.3750561387695495E-01,   8.1328686590834409E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,  -5.3750561387695495E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,   5.3750561387695495E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,  -5.3750561387695495E-01,  -8.1328686590834409E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,   5.3750561387695495E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,   5.3750561387695495E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,  -5.3750561387695495E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,   5.3750561387695495E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,  -5.3750561387695495E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,  -5.3750561387695495E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,   5.3750561387695495E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,  -5.3750561387695495E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,   2.2282771100502941E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,   2.2282771100502941E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,  -2.2282771100502941E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,   2.2282771100502941E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,  -2.2282771100502941E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   8.1328686590834409E-01,  -2.2282771100502941E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,   2.2282771100502941E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -8.1328686590834409E-01,  -2.2282771100502941E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,   8.1328686590834409E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,   8.1328686590834409E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,  -8.1328686590834409E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,   8.1328686590834409E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,  -8.1328686590834409E-01,   2.2282771100502941E-01,   5.7749571406295035E-03],
            [   5.3750561387695495E-01,  -8.1328686590834409E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,   8.1328686590834409E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [  -5.3750561387695495E-01,  -8.1328686590834409E-01,  -2.2282771100502941E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,   8.1328686590834409E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,   8.1328686590834409E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,  -8.1328686590834409E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,   8.1328686590834409E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,  -8.1328686590834409E-01,   5.3750561387695495E-01,   5.7749571406295035E-03],
            [   2.2282771100502941E-01,  -8.1328686590834409E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,   8.1328686590834409E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [  -2.2282771100502941E-01,  -8.1328686590834409E-01,  -5.3750561387695495E-01,   5.7749571406295035E-03],
            [   5.8182557086699693E-01,   2.6771799350143860E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,   2.6771799350143860E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,  -2.6771799350143860E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,   2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,  -2.6771799350143860E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,  -2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,   2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,  -2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,   5.8182557086699693E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,   5.8182557086699693E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,  -5.8182557086699693E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,   5.8182557086699693E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,  -5.8182557086699693E-01,   7.6798833392236943E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,  -5.8182557086699693E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,   5.8182557086699693E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,  -5.8182557086699693E-01,  -7.6798833392236943E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,   5.8182557086699693E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,   5.8182557086699693E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,  -5.8182557086699693E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,   5.8182557086699693E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,  -5.8182557086699693E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,  -5.8182557086699693E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,   5.8182557086699693E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,  -5.8182557086699693E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,   2.6771799350143860E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,   2.6771799350143860E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,   2.6771799350143860E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   7.6798833392236943E-01,  -2.6771799350143860E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,   2.6771799350143860E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -7.6798833392236943E-01,  -2.6771799350143860E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,   7.6798833392236943E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,   7.6798833392236943E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,  -7.6798833392236943E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,   7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,  -7.6798833392236943E-01,   2.6771799350143860E-01,   5.8358084066976517E-03],
            [   5.8182557086699693E-01,  -7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,   7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [  -5.8182557086699693E-01,  -7.6798833392236943E-01,  -2.6771799350143860E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,   7.6798833392236943E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,   7.6798833392236943E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,   7.6798833392236943E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,  -7.6798833392236943E-01,   5.8182557086699693E-01,   5.8358084066976517E-03],
            [   2.6771799350143860E-01,  -7.6798833392236943E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,   7.6798833392236943E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [  -2.6771799350143860E-01,  -7.6798833392236943E-01,  -5.8182557086699693E-01,   5.8358084066976517E-03],
            [   6.2323348581449589E-01,   3.1136750355441650E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,   3.1136750355441650E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,  -3.1136750355441650E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,   3.1136750355441650E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,  -3.1136750355441650E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,  -3.1136750355441650E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,   3.1136750355441650E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,  -3.1136750355441650E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,   6.2323348581449589E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,   6.2323348581449589E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,  -6.2323348581449589E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,   6.2323348581449589E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,  -6.2323348581449589E-01,   7.1737737620432596E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,  -6.2323348581449589E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,   6.2323348581449589E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,  -6.2323348581449589E-01,  -7.1737737620432596E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,   6.2323348581449589E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,   6.2323348581449589E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,  -6.2323348581449589E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,   6.2323348581449589E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,  -6.2323348581449589E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,  -6.2323348581449589E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,   6.2323348581449589E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,  -6.2323348581449589E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,   3.1136750355441650E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,   3.1136750355441650E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,  -3.1136750355441650E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,   3.1136750355441650E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,  -3.1136750355441650E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   7.1737737620432596E-01,  -3.1136750355441650E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,   3.1136750355441650E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -7.1737737620432596E-01,  -3.1136750355441650E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,   7.1737737620432596E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,   7.1737737620432596E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,  -7.1737737620432596E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,   7.1737737620432596E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,  -7.1737737620432596E-01,   3.1136750355441650E-01,   5.8670216594544425E-03],
            [   6.2323348581449589E-01,  -7.1737737620432596E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,   7.1737737620432596E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [  -6.2323348581449589E-01,  -7.1737737620432596E-01,  -3.1136750355441650E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,   7.1737737620432596E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,   7.1737737620432596E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,  -7.1737737620432596E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,   7.1737737620432596E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,  -7.1737737620432596E-01,   6.2323348581449589E-01,   5.8670216594544425E-03],
            [   3.1136750355441650E-01,  -7.1737737620432596E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,   7.1737737620432596E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [  -3.1136750355441650E-01,  -7.1737737620432596E-01,  -6.2323348581449589E-01,   5.8670216594544425E-03],
            [   4.4894853544920582E-01,   4.4091623783681741E-02,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,   4.4091623783681741E-02,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,  -4.4091623783681741E-02,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,   4.4091623783681741E-02,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,  -4.4091623783681741E-02,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,  -4.4091623783681741E-02,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,   4.4091623783681741E-02,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,  -4.4091623783681741E-02,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,   4.4894853544920582E-01,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,   4.4894853544920582E-01,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,  -4.4894853544920582E-01,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,   4.4894853544920582E-01,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,  -4.4894853544920582E-01,   8.9246912620556873E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,  -4.4894853544920582E-01,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,   4.4894853544920582E-01,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,  -4.4894853544920582E-01,  -8.9246912620556873E-01,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,   4.4894853544920582E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,   4.4894853544920582E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,  -4.4894853544920582E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,   4.4894853544920582E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,  -4.4894853544920582E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,  -4.4894853544920582E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,   4.4894853544920582E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,  -4.4894853544920582E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,   4.4091623783681741E-02,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,   4.4091623783681741E-02,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,  -4.4091623783681741E-02,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,   4.4091623783681741E-02,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,  -4.4091623783681741E-02,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   8.9246912620556873E-01,  -4.4091623783681741E-02,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,   4.4091623783681741E-02,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -8.9246912620556873E-01,  -4.4091623783681741E-02,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,   8.9246912620556873E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,   8.9246912620556873E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,  -8.9246912620556873E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,   8.9246912620556873E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,  -8.9246912620556873E-01,   4.4091623783681741E-02,   5.5298839461129651E-03],
            [   4.4894853544920582E-01,  -8.9246912620556873E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,   8.9246912620556873E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [  -4.4894853544920582E-01,  -8.9246912620556873E-01,  -4.4091623783681741E-02,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,   8.9246912620556873E-01,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,   8.9246912620556873E-01,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,  -8.9246912620556873E-01,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,   8.9246912620556873E-01,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,  -8.9246912620556873E-01,   4.4894853544920582E-01,   5.5298839461129651E-03],
            [   4.4091623783681741E-02,  -8.9246912620556873E-01,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,   8.9246912620556873E-01,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [  -4.4091623783681741E-02,  -8.9246912620556873E-01,  -4.4894853544920582E-01,   5.5298839461129651E-03],
            [   5.0151368759331505E-01,   8.9390099177484889E-02,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,   8.9390099177484889E-02,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,  -8.9390099177484889E-02,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,   8.9390099177484889E-02,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,  -8.9390099177484889E-02,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,  -8.9390099177484889E-02,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,   8.9390099177484889E-02,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,  -8.9390099177484889E-02,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,   5.0151368759331505E-01,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,   5.0151368759331505E-01,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,  -5.0151368759331505E-01,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,   5.0151368759331505E-01,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,  -5.0151368759331505E-01,   8.6051928004292511E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,  -5.0151368759331505E-01,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,   5.0151368759331505E-01,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,  -5.0151368759331505E-01,  -8.6051928004292511E-01,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,   5.0151368759331505E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,   5.0151368759331505E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,  -5.0151368759331505E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,   5.0151368759331505E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,  -5.0151368759331505E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,  -5.0151368759331505E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,   5.0151368759331505E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,  -5.0151368759331505E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,   8.9390099177484889E-02,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,   8.9390099177484889E-02,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,  -8.9390099177484889E-02,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,   8.9390099177484889E-02,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,  -8.9390099177484889E-02,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.6051928004292511E-01,  -8.9390099177484889E-02,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,   8.9390099177484889E-02,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.6051928004292511E-01,  -8.9390099177484889E-02,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,   8.6051928004292511E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,   8.6051928004292511E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,  -8.6051928004292511E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,   8.6051928004292511E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,  -8.6051928004292511E-01,   8.9390099177484889E-02,   5.6731042121477022E-03],
            [   5.0151368759331505E-01,  -8.6051928004292511E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,   8.6051928004292511E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [  -5.0151368759331505E-01,  -8.6051928004292511E-01,  -8.9390099177484889E-02,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,   8.6051928004292511E-01,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,   8.6051928004292511E-01,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,  -8.6051928004292511E-01,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,   8.6051928004292511E-01,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,  -8.6051928004292511E-01,   5.0151368759331505E-01,   5.6731042121477022E-03],
            [   8.9390099177484889E-02,  -8.6051928004292511E-01,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,   8.6051928004292511E-01,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [  -8.9390099177484889E-02,  -8.6051928004292511E-01,  -5.0151368759331505E-01,   5.6731042121477022E-03],
            [   5.5113005505126234E-01,   1.3518060293833650E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,   1.3518060293833650E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,  -1.3518060293833650E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,   1.3518060293833650E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,  -1.3518060293833650E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,  -1.3518060293833650E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,   1.3518060293833650E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,  -1.3518060293833650E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,   5.5113005505126234E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,   5.5113005505126234E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,  -5.5113005505126234E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,   5.5113005505126234E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,  -5.5113005505126234E-01,   8.2339654299032639E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,  -5.5113005505126234E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,   5.5113005505126234E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,  -5.5113005505126234E-01,  -8.2339654299032639E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,   5.5113005505126234E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,   5.5113005505126234E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,  -5.5113005505126234E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,   5.5113005505126234E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,  -5.5113005505126234E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,  -5.5113005505126234E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,   5.5113005505126234E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,  -5.5113005505126234E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,   1.3518060293833650E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,   1.3518060293833650E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,  -1.3518060293833650E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,   1.3518060293833650E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,  -1.3518060293833650E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   8.2339654299032639E-01,  -1.3518060293833650E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,   1.3518060293833650E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -8.2339654299032639E-01,  -1.3518060293833650E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,   8.2339654299032639E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,   8.2339654299032639E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,  -8.2339654299032639E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,   8.2339654299032639E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,  -8.2339654299032639E-01,   1.3518060293833650E-01,   5.7757535368458211E-03],
            [   5.5113005505126234E-01,  -8.2339654299032639E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,   8.2339654299032639E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [  -5.5113005505126234E-01,  -8.2339654299032639E-01,  -1.3518060293833650E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,   8.2339654299032639E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,   8.2339654299032639E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,  -8.2339654299032639E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,   8.2339654299032639E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,  -8.2339654299032639E-01,   5.5113005505126234E-01,   5.7757535368458211E-03],
            [   1.3518060293833650E-01,  -8.2339654299032639E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,   8.2339654299032639E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [  -1.3518060293833650E-01,  -8.2339654299032639E-01,  -5.5113005505126234E-01,   5.7757535368458211E-03],
            [   5.9767204098579996E-01,   1.8083703550531960E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,   1.8083703550531960E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,  -1.8083703550531960E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,   1.8083703550531960E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,  -1.8083703550531960E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,  -1.8083703550531960E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,   1.8083703550531960E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,  -1.8083703550531960E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,   5.9767204098579996E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,   5.9767204098579996E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,  -5.9767204098579996E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,   5.9767204098579996E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,  -5.9767204098579996E-01,   7.8108008425097875E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,  -5.9767204098579996E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,   5.9767204098579996E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,  -5.9767204098579996E-01,  -7.8108008425097875E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,   5.9767204098579996E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,   5.9767204098579996E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,  -5.9767204098579996E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,   5.9767204098579996E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,  -5.9767204098579996E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,  -5.9767204098579996E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,   5.9767204098579996E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,  -5.9767204098579996E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,   1.8083703550531960E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,   1.8083703550531960E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,  -1.8083703550531960E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,   1.8083703550531960E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,  -1.8083703550531960E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   7.8108008425097875E-01,  -1.8083703550531960E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,   1.8083703550531960E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -7.8108008425097875E-01,  -1.8083703550531960E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,   7.8108008425097875E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,   7.8108008425097875E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,  -7.8108008425097875E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,   7.8108008425097875E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,  -7.8108008425097875E-01,   1.8083703550531960E-01,   5.8416772064913700E-03],
            [   5.9767204098579996E-01,  -7.8108008425097875E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,   7.8108008425097875E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [  -5.9767204098579996E-01,  -7.8108008425097875E-01,  -1.8083703550531960E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,   7.8108008425097875E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,   7.8108008425097875E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,  -7.8108008425097875E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,   7.8108008425097875E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,  -7.8108008425097875E-01,   5.9767204098579996E-01,   5.8416772064913700E-03],
            [   1.8083703550531960E-01,  -7.8108008425097875E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,   7.8108008425097875E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [  -1.8083703550531960E-01,  -7.8108008425097875E-01,  -5.9767204098579996E-01,   5.8416772064913700E-03],
            [   6.4099563789893543E-01,   2.2578521923016021E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,   2.2578521923016021E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,  -2.2578521923016021E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,   2.2578521923016021E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,  -2.2578521923016021E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,  -2.2578521923016021E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,   2.2578521923016021E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,  -2.2578521923016021E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,   6.4099563789893543E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,   6.4099563789893543E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,  -6.4099563789893543E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,   6.4099563789893543E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,  -6.4099563789893543E-01,   7.3358409672765212E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,  -6.4099563789893543E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,   6.4099563789893543E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,  -6.4099563789893543E-01,  -7.3358409672765212E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,   6.4099563789893543E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,   6.4099563789893543E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,  -6.4099563789893543E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,   6.4099563789893543E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,  -6.4099563789893543E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,  -6.4099563789893543E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,   6.4099563789893543E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,  -6.4099563789893543E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,   2.2578521923016021E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,   2.2578521923016021E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,  -2.2578521923016021E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,   2.2578521923016021E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,  -2.2578521923016021E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   7.3358409672765212E-01,  -2.2578521923016021E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,   2.2578521923016021E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -7.3358409672765212E-01,  -2.2578521923016021E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,   7.3358409672765212E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,   7.3358409672765212E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,  -7.3358409672765212E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,   7.3358409672765212E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,  -7.3358409672765212E-01,   2.2578521923016021E-01,   5.8754091155787218E-03],
            [   6.4099563789893543E-01,  -7.3358409672765212E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,   7.3358409672765212E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [  -6.4099563789893543E-01,  -7.3358409672765212E-01,  -2.2578521923016021E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,   7.3358409672765212E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,   7.3358409672765212E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,  -7.3358409672765212E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,   7.3358409672765212E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,  -7.3358409672765212E-01,   6.4099563789893543E-01,   5.8754091155787218E-03],
            [   2.2578521923016021E-01,  -7.3358409672765212E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,   7.3358409672765212E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [  -2.2578521923016021E-01,  -7.3358409672765212E-01,  -6.4099563789893543E-01,   5.8754091155787218E-03],
            [   5.5812223308275144E-01,   4.5321734216371597E-02,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,   4.5321734216371597E-02,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,  -4.5321734216371597E-02,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,   4.5321734216371597E-02,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,  -4.5321734216371597E-02,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,  -4.5321734216371597E-02,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,   4.5321734216371597E-02,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,  -4.5321734216371597E-02,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,   5.5812223308275144E-01,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,   5.5812223308275144E-01,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,  -5.5812223308275144E-01,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,   5.5812223308275144E-01,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,  -5.5812223308275144E-01,   8.2852007419636087E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,  -5.5812223308275144E-01,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,   5.5812223308275144E-01,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,  -5.5812223308275144E-01,  -8.2852007419636087E-01,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,   5.5812223308275144E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,   5.5812223308275144E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,  -5.5812223308275144E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,   5.5812223308275144E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,  -5.5812223308275144E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,  -5.5812223308275144E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,   5.5812223308275144E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,  -5.5812223308275144E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,   4.5321734216371597E-02,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,   4.5321734216371597E-02,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,  -4.5321734216371597E-02,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,   4.5321734216371597E-02,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,  -4.5321734216371597E-02,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   8.2852007419636087E-01,  -4.5321734216371597E-02,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,   4.5321734216371597E-02,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -8.2852007419636087E-01,  -4.5321734216371597E-02,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,   8.2852007419636087E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,   8.2852007419636087E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,  -8.2852007419636087E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,   8.2852007419636087E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,  -8.2852007419636087E-01,   4.5321734216371597E-02,   5.7786385859223653E-03],
            [   5.5812223308275144E-01,  -8.2852007419636087E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,   8.2852007419636087E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [  -5.5812223308275144E-01,  -8.2852007419636087E-01,  -4.5321734216371597E-02,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,   8.2852007419636087E-01,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,   8.2852007419636087E-01,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,  -8.2852007419636087E-01,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,   8.2852007419636087E-01,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,  -8.2852007419636087E-01,   5.5812223308275144E-01,   5.7786385859223653E-03],
            [   4.5321734216371597E-02,  -8.2852007419636087E-01,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,   8.2852007419636087E-01,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [  -4.5321734216371597E-02,  -8.2852007419636087E-01,  -5.5812223308275144E-01,   5.7786385859223653E-03],
            [   6.0747059841616946E-01,   9.1174880318403137E-02,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,   9.1174880318403137E-02,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,  -9.1174880318403137E-02,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,   9.1174880318403137E-02,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,  -9.1174880318403137E-02,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,  -9.1174880318403137E-02,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,   9.1174880318403137E-02,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,  -9.1174880318403137E-02,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,   6.0747059841616946E-01,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,   6.0747059841616946E-01,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,  -6.0747059841616946E-01,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,   6.0747059841616946E-01,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,  -6.0747059841616946E-01,   7.8909227170136809E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,  -6.0747059841616946E-01,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,   6.0747059841616946E-01,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,  -6.0747059841616946E-01,  -7.8909227170136809E-01,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,   6.0747059841616946E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,   6.0747059841616946E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,  -6.0747059841616946E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,   6.0747059841616946E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,  -6.0747059841616946E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,  -6.0747059841616946E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,   6.0747059841616946E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,  -6.0747059841616946E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,   9.1174880318403137E-02,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,   9.1174880318403137E-02,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,  -9.1174880318403137E-02,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,   9.1174880318403137E-02,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,  -9.1174880318403137E-02,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   7.8909227170136809E-01,  -9.1174880318403137E-02,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,   9.1174880318403137E-02,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -7.8909227170136809E-01,  -9.1174880318403137E-02,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,   7.8909227170136809E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,   7.8909227170136809E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,  -7.8909227170136809E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,   7.8909227170136809E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,  -7.8909227170136809E-01,   9.1174880318403137E-02,   5.8495411637504964E-03],
            [   6.0747059841616946E-01,  -7.8909227170136809E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,   7.8909227170136809E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [  -6.0747059841616946E-01,  -7.8909227170136809E-01,  -9.1174880318403137E-02,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,   7.8909227170136809E-01,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,   7.8909227170136809E-01,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,  -7.8909227170136809E-01,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,   7.8909227170136809E-01,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,  -7.8909227170136809E-01,   6.0747059841616946E-01,   5.8495411637504964E-03],
            [   9.1174880318403137E-02,  -7.8909227170136809E-01,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,   7.8909227170136809E-01,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [  -9.1174880318403137E-02,  -7.8909227170136809E-01,  -6.0747059841616946E-01,   5.8495411637504964E-03],
            [   6.5322725373790325E-01,   1.3692942131401550E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,   1.3692942131401550E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,  -1.3692942131401550E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,   1.3692942131401550E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,  -1.3692942131401550E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,  -1.3692942131401550E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,   1.3692942131401550E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,  -1.3692942131401550E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,   6.5322725373790325E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,   6.5322725373790325E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,  -6.5322725373790325E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,   6.5322725373790325E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,  -6.5322725373790325E-01,   7.4467743926658991E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,  -6.5322725373790325E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,   6.5322725373790325E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,  -6.5322725373790325E-01,  -7.4467743926658991E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,   6.5322725373790325E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,   6.5322725373790325E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,  -6.5322725373790325E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,   6.5322725373790325E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,  -6.5322725373790325E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,  -6.5322725373790325E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,   6.5322725373790325E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,  -6.5322725373790325E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,   1.3692942131401550E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,   1.3692942131401550E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,  -1.3692942131401550E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,   1.3692942131401550E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,  -1.3692942131401550E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   7.4467743926658991E-01,  -1.3692942131401550E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,   1.3692942131401550E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -7.4467743926658991E-01,  -1.3692942131401550E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,   7.4467743926658991E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,   7.4467743926658991E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,  -7.4467743926658991E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,   7.4467743926658991E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,  -7.4467743926658991E-01,   1.3692942131401550E-01,   5.8869799309974394E-03],
            [   6.5322725373790325E-01,  -7.4467743926658991E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,   7.4467743926658991E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [  -6.5322725373790325E-01,  -7.4467743926658991E-01,  -1.3692942131401550E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,   7.4467743926658991E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,   7.4467743926658991E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,  -7.4467743926658991E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,   7.4467743926658991E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,  -7.4467743926658991E-01,   6.5322725373790325E-01,   5.8869799309974394E-03],
            [   1.3692942131401550E-01,  -7.4467743926658991E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,   7.4467743926658991E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [  -1.3692942131401550E-01,  -7.4467743926658991E-01,  -6.5322725373790325E-01,   5.8869799309974394E-03],
            [   6.5947614945004873E-01,   4.5899014872755828E-02,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,   4.5899014872755828E-02,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,  -4.5899014872755828E-02,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,   4.5899014872755828E-02,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,  -4.5899014872755828E-02,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,  -4.5899014872755828E-02,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,   4.5899014872755828E-02,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,  -4.5899014872755828E-02,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,   6.5947614945004873E-01,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,   6.5947614945004873E-01,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,  -6.5947614945004873E-01,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,   6.5947614945004873E-01,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,  -6.5947614945004873E-01,   7.5032292297400016E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,  -6.5947614945004873E-01,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,   6.5947614945004873E-01,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,  -6.5947614945004873E-01,  -7.5032292297400016E-01,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,   6.5947614945004873E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,   6.5947614945004873E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,  -6.5947614945004873E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,   6.5947614945004873E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,  -6.5947614945004873E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,  -6.5947614945004873E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,   6.5947614945004873E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,  -6.5947614945004873E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,   4.5899014872755828E-02,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,   4.5899014872755828E-02,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,  -4.5899014872755828E-02,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,   4.5899014872755828E-02,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,  -4.5899014872755828E-02,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   7.5032292297400016E-01,  -4.5899014872755828E-02,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,   4.5899014872755828E-02,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -7.5032292297400016E-01,  -4.5899014872755828E-02,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,   7.5032292297400016E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,   7.5032292297400016E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,  -7.5032292297400016E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,   7.5032292297400016E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,  -7.5032292297400016E-01,   4.5899014872755828E-02,   5.8954443361500459E-03],
            [   6.5947614945004873E-01,  -7.5032292297400016E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,   7.5032292297400016E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [  -6.5947614945004873E-01,  -7.5032292297400016E-01,  -4.5899014872755828E-02,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,   7.5032292297400016E-01,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,   7.5032292297400016E-01,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,  -7.5032292297400016E-01,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,   7.5032292297400016E-01,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,  -7.5032292297400016E-01,   6.5947614945004873E-01,   5.8954443361500459E-03],
            [   4.5899014872755828E-02,  -7.5032292297400016E-01,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,   7.5032292297400016E-01,  -6.5947614945004873E-01,   5.8954443361500459E-03],
            [  -4.5899014872755828E-02,  -7.5032292297400016E-01,  -6.5947614945004873E-01,   5.8954443361500459E-03],
        ])
  
        order = 83
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build2702():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.7682463285563676E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.7682463285563676E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   3.7682463285563676E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   3.7682463285563676E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   3.7682463285563676E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   3.7682463285563676E-04],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.1243906727305565E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   5.1243906727305565E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.1243906727305565E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.1243906727305565E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.1243906727305565E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.1243906727305565E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.1243906727305565E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.1243906727305565E-03],
            [   2.0655625388187032E-02,   2.0655625388187032E-02,   9.9957325408378439E-01,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,   2.0655625388187032E-02,   9.9957325408378439E-01,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,  -2.0655625388187032E-02,   9.9957325408378439E-01,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,   2.0655625388187032E-02,  -9.9957325408378439E-01,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,  -2.0655625388187032E-02,   9.9957325408378439E-01,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,   2.0655625388187032E-02,  -9.9957325408378439E-01,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,  -2.0655625388187032E-02,  -9.9957325408378439E-01,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,  -2.0655625388187032E-02,  -9.9957325408378439E-01,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,   9.9957325408378439E-01,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,  -9.9957325408378439E-01,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,   9.9957325408378439E-01,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,  -9.9957325408378439E-01,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,   9.9957325408378439E-01,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,  -9.9957325408378439E-01,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -2.0655625388187032E-02,  -9.9957325408378439E-01,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [   2.0655625388187032E-02,   9.9957325408378439E-01,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [   9.9957325408378439E-01,   2.0655625388187032E-02,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -9.9957325408378439E-01,   2.0655625388187032E-02,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [   9.9957325408378439E-01,  -2.0655625388187032E-02,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [   9.9957325408378439E-01,   2.0655625388187032E-02,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -9.9957325408378439E-01,  -2.0655625388187032E-02,   2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -9.9957325408378439E-01,   2.0655625388187032E-02,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [   9.9957325408378439E-01,  -2.0655625388187032E-02,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [  -9.9957325408378439E-01,  -2.0655625388187032E-02,  -2.0655625388187032E-02,   1.4895537260646084E-03],
            [   5.2509181730223793E-02,   5.2509181730223793E-02,   9.9723897420229457E-01,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,   5.2509181730223793E-02,   9.9723897420229457E-01,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,  -5.2509181730223793E-02,   9.9723897420229457E-01,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,   5.2509181730223793E-02,  -9.9723897420229457E-01,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,  -5.2509181730223793E-02,   9.9723897420229457E-01,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,   5.2509181730223793E-02,  -9.9723897420229457E-01,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,  -5.2509181730223793E-02,  -9.9723897420229457E-01,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,  -5.2509181730223793E-02,  -9.9723897420229457E-01,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,   9.9723897420229457E-01,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,  -9.9723897420229457E-01,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,   9.9723897420229457E-01,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,  -9.9723897420229457E-01,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,   9.9723897420229457E-01,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,  -9.9723897420229457E-01,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -5.2509181730223793E-02,  -9.9723897420229457E-01,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [   5.2509181730223793E-02,   9.9723897420229457E-01,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [   9.9723897420229457E-01,   5.2509181730223793E-02,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -9.9723897420229457E-01,   5.2509181730223793E-02,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [   9.9723897420229457E-01,  -5.2509181730223793E-02,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [   9.9723897420229457E-01,   5.2509181730223793E-02,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -9.9723897420229457E-01,  -5.2509181730223793E-02,   5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -9.9723897420229457E-01,   5.2509181730223793E-02,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [   9.9723897420229457E-01,  -5.2509181730223793E-02,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [  -9.9723897420229457E-01,  -5.2509181730223793E-02,  -5.2509181730223793E-02,   2.4044602150006204E-03],
            [   8.9934800820383756E-02,   8.9934800820383756E-02,   9.9187875428541961E-01,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,   8.9934800820383756E-02,   9.9187875428541961E-01,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,  -8.9934800820383756E-02,   9.9187875428541961E-01,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,   8.9934800820383756E-02,  -9.9187875428541961E-01,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,  -8.9934800820383756E-02,   9.9187875428541961E-01,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,   8.9934800820383756E-02,  -9.9187875428541961E-01,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,  -8.9934800820383756E-02,  -9.9187875428541961E-01,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,  -8.9934800820383756E-02,  -9.9187875428541961E-01,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,   9.9187875428541961E-01,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,  -9.9187875428541961E-01,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,   9.9187875428541961E-01,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,  -9.9187875428541961E-01,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,   9.9187875428541961E-01,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,  -9.9187875428541961E-01,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -8.9934800820383756E-02,  -9.9187875428541961E-01,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [   8.9934800820383756E-02,   9.9187875428541961E-01,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [   9.9187875428541961E-01,   8.9934800820383756E-02,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -9.9187875428541961E-01,   8.9934800820383756E-02,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [   9.9187875428541961E-01,  -8.9934800820383756E-02,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [   9.9187875428541961E-01,   8.9934800820383756E-02,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -9.9187875428541961E-01,  -8.9934800820383756E-02,   8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -9.9187875428541961E-01,   8.9934800820383756E-02,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [   9.9187875428541961E-01,  -8.9934800820383756E-02,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [  -9.9187875428541961E-01,  -8.9934800820383756E-02,  -8.9934800820383756E-02,   3.0823881804206499E-03],
            [   1.3060239244360189E-01,   1.3060239244360189E-01,   9.8279500923438501E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,   1.3060239244360189E-01,   9.8279500923438501E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,  -1.3060239244360189E-01,   9.8279500923438501E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,   1.3060239244360189E-01,  -9.8279500923438501E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,  -1.3060239244360189E-01,   9.8279500923438501E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,   1.3060239244360189E-01,  -9.8279500923438501E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,  -1.3060239244360189E-01,  -9.8279500923438501E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,  -1.3060239244360189E-01,  -9.8279500923438501E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,   9.8279500923438501E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,  -9.8279500923438501E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,   9.8279500923438501E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,  -9.8279500923438501E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,   9.8279500923438501E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,  -9.8279500923438501E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -1.3060239244360189E-01,  -9.8279500923438501E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [   1.3060239244360189E-01,   9.8279500923438501E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [   9.8279500923438501E-01,   1.3060239244360189E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -9.8279500923438501E-01,   1.3060239244360189E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [   9.8279500923438501E-01,  -1.3060239244360189E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [   9.8279500923438501E-01,   1.3060239244360189E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -9.8279500923438501E-01,  -1.3060239244360189E-01,   1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -9.8279500923438501E-01,   1.3060239244360189E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [   9.8279500923438501E-01,  -1.3060239244360189E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [  -9.8279500923438501E-01,  -1.3060239244360189E-01,  -1.3060239244360189E-01,   3.5970082080780371E-03],
            [   1.7320603885314181E-01,   1.7320603885314181E-01,   9.6953562915944858E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,   1.7320603885314181E-01,   9.6953562915944858E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,  -1.7320603885314181E-01,   9.6953562915944858E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,   1.7320603885314181E-01,  -9.6953562915944858E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,  -1.7320603885314181E-01,   9.6953562915944858E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,   1.7320603885314181E-01,  -9.6953562915944858E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,  -1.7320603885314181E-01,  -9.6953562915944858E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,  -1.7320603885314181E-01,  -9.6953562915944858E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,   9.6953562915944858E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,  -9.6953562915944858E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,   9.6953562915944858E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,  -9.6953562915944858E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,   9.6953562915944858E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,  -9.6953562915944858E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -1.7320603885314181E-01,  -9.6953562915944858E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [   1.7320603885314181E-01,   9.6953562915944858E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [   9.6953562915944858E-01,   1.7320603885314181E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -9.6953562915944858E-01,   1.7320603885314181E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [   9.6953562915944858E-01,  -1.7320603885314181E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [   9.6953562915944858E-01,   1.7320603885314181E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -9.6953562915944858E-01,  -1.7320603885314181E-01,   1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -9.6953562915944858E-01,   1.7320603885314181E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [   9.6953562915944858E-01,  -1.7320603885314181E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [  -9.6953562915944858E-01,  -1.7320603885314181E-01,  -1.7320603885314181E-01,   3.9936331181650766E-03],
            [   2.1687270848202489E-01,   2.1687270848202489E-01,   9.5180484167256751E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,   2.1687270848202489E-01,   9.5180484167256751E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,  -2.1687270848202489E-01,   9.5180484167256751E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,   2.1687270848202489E-01,  -9.5180484167256751E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,  -2.1687270848202489E-01,   9.5180484167256751E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,   2.1687270848202489E-01,  -9.5180484167256751E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,  -2.1687270848202489E-01,  -9.5180484167256751E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,  -2.1687270848202489E-01,  -9.5180484167256751E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,   9.5180484167256751E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,  -9.5180484167256751E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,   9.5180484167256751E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,  -9.5180484167256751E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,   9.5180484167256751E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,  -9.5180484167256751E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -2.1687270848202489E-01,  -9.5180484167256751E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [   2.1687270848202489E-01,   9.5180484167256751E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [   9.5180484167256751E-01,   2.1687270848202489E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -9.5180484167256751E-01,   2.1687270848202489E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [   9.5180484167256751E-01,  -2.1687270848202489E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [   9.5180484167256751E-01,   2.1687270848202489E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -9.5180484167256751E-01,  -2.1687270848202489E-01,   2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -9.5180484167256751E-01,   2.1687270848202489E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [   9.5180484167256751E-01,  -2.1687270848202489E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [  -9.5180484167256751E-01,  -2.1687270848202489E-01,  -2.1687270848202489E-01,   4.3014003852300045E-03],
            [   2.6095283091735860E-01,   2.6095283091735860E-01,   9.2941230897402738E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,   2.6095283091735860E-01,   9.2941230897402738E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,  -2.6095283091735860E-01,   9.2941230897402738E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,   2.6095283091735860E-01,  -9.2941230897402738E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,  -2.6095283091735860E-01,   9.2941230897402738E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,   2.6095283091735860E-01,  -9.2941230897402738E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,  -2.6095283091735860E-01,  -9.2941230897402738E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,  -2.6095283091735860E-01,  -9.2941230897402738E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,   9.2941230897402738E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,  -9.2941230897402738E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,   9.2941230897402738E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,  -9.2941230897402738E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,   9.2941230897402738E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,  -9.2941230897402738E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -2.6095283091735860E-01,  -9.2941230897402738E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [   2.6095283091735860E-01,   9.2941230897402738E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [   9.2941230897402738E-01,   2.6095283091735860E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -9.2941230897402738E-01,   2.6095283091735860E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [   9.2941230897402738E-01,  -2.6095283091735860E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [   9.2941230897402738E-01,   2.6095283091735860E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -9.2941230897402738E-01,  -2.6095283091735860E-01,   2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -9.2941230897402738E-01,   2.6095283091735860E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [   9.2941230897402738E-01,  -2.6095283091735860E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [  -9.2941230897402738E-01,  -2.6095283091735860E-01,  -2.6095283091735860E-01,   4.5399664629328079E-03],
            [   3.0492529279389519E-01,   3.0492529279389519E-01,   9.0224227989443873E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,   3.0492529279389519E-01,   9.0224227989443873E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,  -3.0492529279389519E-01,   9.0224227989443873E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,   3.0492529279389519E-01,  -9.0224227989443873E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,  -3.0492529279389519E-01,   9.0224227989443873E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,   3.0492529279389519E-01,  -9.0224227989443873E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,  -3.0492529279389519E-01,  -9.0224227989443873E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,  -3.0492529279389519E-01,  -9.0224227989443873E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,   9.0224227989443873E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,  -9.0224227989443873E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,   9.0224227989443873E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,  -9.0224227989443873E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,   9.0224227989443873E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,  -9.0224227989443873E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -3.0492529279389519E-01,  -9.0224227989443873E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [   3.0492529279389519E-01,   9.0224227989443873E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [   9.0224227989443873E-01,   3.0492529279389519E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -9.0224227989443873E-01,   3.0492529279389519E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [   9.0224227989443873E-01,  -3.0492529279389519E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [   9.0224227989443873E-01,   3.0492529279389519E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -9.0224227989443873E-01,  -3.0492529279389519E-01,   3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -9.0224227989443873E-01,   3.0492529279389519E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [   9.0224227989443873E-01,  -3.0492529279389519E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [  -9.0224227989443873E-01,  -3.0492529279389519E-01,  -3.0492529279389519E-01,   4.7232441001198435E-03],
            [   3.4834841380844039E-01,   3.4834841380844039E-01,   8.7023374170063472E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,   3.4834841380844039E-01,   8.7023374170063472E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,  -3.4834841380844039E-01,   8.7023374170063472E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,   3.4834841380844039E-01,  -8.7023374170063472E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,  -3.4834841380844039E-01,   8.7023374170063472E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,   3.4834841380844039E-01,  -8.7023374170063472E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,  -3.4834841380844039E-01,  -8.7023374170063472E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,  -3.4834841380844039E-01,  -8.7023374170063472E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,   8.7023374170063472E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,  -8.7023374170063472E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,   8.7023374170063472E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,  -8.7023374170063472E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,   8.7023374170063472E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,  -8.7023374170063472E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -3.4834841380844039E-01,  -8.7023374170063472E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [   3.4834841380844039E-01,   8.7023374170063472E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [   8.7023374170063472E-01,   3.4834841380844039E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -8.7023374170063472E-01,   3.4834841380844039E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [   8.7023374170063472E-01,  -3.4834841380844039E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [   8.7023374170063472E-01,   3.4834841380844039E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -8.7023374170063472E-01,  -3.4834841380844039E-01,   3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -8.7023374170063472E-01,   3.4834841380844039E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [   8.7023374170063472E-01,  -3.4834841380844039E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [  -8.7023374170063472E-01,  -3.4834841380844039E-01,  -3.4834841380844039E-01,   4.8615666264618333E-03],
            [   3.9083215491064061E-01,   3.9083215491064061E-01,   8.3336693801458794E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,   3.9083215491064061E-01,   8.3336693801458794E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,  -3.9083215491064061E-01,   8.3336693801458794E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,   3.9083215491064061E-01,  -8.3336693801458794E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,  -3.9083215491064061E-01,   8.3336693801458794E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,   3.9083215491064061E-01,  -8.3336693801458794E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,  -3.9083215491064061E-01,  -8.3336693801458794E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,  -3.9083215491064061E-01,  -8.3336693801458794E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,   8.3336693801458794E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,  -8.3336693801458794E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,   8.3336693801458794E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,  -8.3336693801458794E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,   8.3336693801458794E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,  -8.3336693801458794E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -3.9083215491064061E-01,  -8.3336693801458794E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [   3.9083215491064061E-01,   8.3336693801458794E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [   8.3336693801458794E-01,   3.9083215491064061E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -8.3336693801458794E-01,   3.9083215491064061E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [   8.3336693801458794E-01,  -3.9083215491064061E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [   8.3336693801458794E-01,   3.9083215491064061E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -8.3336693801458794E-01,  -3.9083215491064061E-01,   3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -8.3336693801458794E-01,   3.9083215491064061E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [   8.3336693801458794E-01,  -3.9083215491064061E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [  -8.3336693801458794E-01,  -3.9083215491064061E-01,  -3.9083215491064061E-01,   4.9630000255908545E-03],
            [   4.3202100718948139E-01,   4.3202100718948139E-01,   7.9165377450876351E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,   4.3202100718948139E-01,   7.9165377450876351E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,  -4.3202100718948139E-01,   7.9165377450876351E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,   4.3202100718948139E-01,  -7.9165377450876351E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,  -4.3202100718948139E-01,   7.9165377450876351E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,   4.3202100718948139E-01,  -7.9165377450876351E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,  -4.3202100718948139E-01,  -7.9165377450876351E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,  -4.3202100718948139E-01,  -7.9165377450876351E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,   7.9165377450876351E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,  -7.9165377450876351E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,   7.9165377450876351E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,  -7.9165377450876351E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,   7.9165377450876351E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,  -7.9165377450876351E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -4.3202100718948139E-01,  -7.9165377450876351E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [   4.3202100718948139E-01,   7.9165377450876351E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [   7.9165377450876351E-01,   4.3202100718948139E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -7.9165377450876351E-01,   4.3202100718948139E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [   7.9165377450876351E-01,  -4.3202100718948139E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [   7.9165377450876351E-01,   4.3202100718948139E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -7.9165377450876351E-01,  -4.3202100718948139E-01,   4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -7.9165377450876351E-01,   4.3202100718948139E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [   7.9165377450876351E-01,  -4.3202100718948139E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [  -7.9165377450876351E-01,  -4.3202100718948139E-01,  -4.3202100718948139E-01,   5.0341736545726646E-03],
            [   4.7158247958900529E-01,   4.7158247958900529E-01,   7.4513081394435077E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,   4.7158247958900529E-01,   7.4513081394435077E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,  -4.7158247958900529E-01,   7.4513081394435077E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,   4.7158247958900529E-01,  -7.4513081394435077E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,  -4.7158247958900529E-01,   7.4513081394435077E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,   4.7158247958900529E-01,  -7.4513081394435077E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,  -4.7158247958900529E-01,  -7.4513081394435077E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,  -4.7158247958900529E-01,  -7.4513081394435077E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,   7.4513081394435077E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,  -7.4513081394435077E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,   7.4513081394435077E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,  -7.4513081394435077E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,   7.4513081394435077E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,  -7.4513081394435077E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -4.7158247958900529E-01,  -7.4513081394435077E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [   4.7158247958900529E-01,   7.4513081394435077E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [   7.4513081394435077E-01,   4.7158247958900529E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -7.4513081394435077E-01,   4.7158247958900529E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [   7.4513081394435077E-01,  -4.7158247958900529E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [   7.4513081394435077E-01,   4.7158247958900529E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -7.4513081394435077E-01,  -4.7158247958900529E-01,   4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -7.4513081394435077E-01,   4.7158247958900529E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [   7.4513081394435077E-01,  -4.7158247958900529E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [  -7.4513081394435077E-01,  -4.7158247958900529E-01,  -4.7158247958900529E-01,   5.0808251017854999E-03],
            [   5.0919847940784535E-01,   5.0919847940784535E-01,   6.9385431982331580E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,   5.0919847940784535E-01,   6.9385431982331580E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,  -5.0919847940784535E-01,   6.9385431982331580E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,   5.0919847940784535E-01,  -6.9385431982331580E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,  -5.0919847940784535E-01,   6.9385431982331580E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,   5.0919847940784535E-01,  -6.9385431982331580E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,  -5.0919847940784535E-01,  -6.9385431982331580E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,  -5.0919847940784535E-01,  -6.9385431982331580E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,   6.9385431982331580E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,  -6.9385431982331580E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,   6.9385431982331580E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,  -6.9385431982331580E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,   6.9385431982331580E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,  -6.9385431982331580E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -5.0919847940784535E-01,  -6.9385431982331580E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [   5.0919847940784535E-01,   6.9385431982331580E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [   6.9385431982331580E-01,   5.0919847940784535E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -6.9385431982331580E-01,   5.0919847940784535E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [   6.9385431982331580E-01,  -5.0919847940784535E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [   6.9385431982331580E-01,   5.0919847940784535E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -6.9385431982331580E-01,  -5.0919847940784535E-01,   5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -6.9385431982331580E-01,   5.0919847940784535E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [   6.9385431982331580E-01,  -5.0919847940784535E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [  -6.9385431982331580E-01,  -5.0919847940784535E-01,  -5.0919847940784535E-01,   5.1081636760235537E-03],
            [   5.4455801456508035E-01,   5.4455801456508035E-01,   6.3789743497358209E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,   5.4455801456508035E-01,   6.3789743497358209E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,  -5.4455801456508035E-01,   6.3789743497358209E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,   5.4455801456508035E-01,  -6.3789743497358209E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,  -5.4455801456508035E-01,   6.3789743497358209E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,   5.4455801456508035E-01,  -6.3789743497358209E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,  -5.4455801456508035E-01,  -6.3789743497358209E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,  -5.4455801456508035E-01,  -6.3789743497358209E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,   6.3789743497358209E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,  -6.3789743497358209E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,   6.3789743497358209E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,  -6.3789743497358209E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,   6.3789743497358209E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,  -6.3789743497358209E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -5.4455801456508035E-01,  -6.3789743497358209E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [   5.4455801456508035E-01,   6.3789743497358209E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [   6.3789743497358209E-01,   5.4455801456508035E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -6.3789743497358209E-01,   5.4455801456508035E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [   6.3789743497358209E-01,  -5.4455801456508035E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [   6.3789743497358209E-01,   5.4455801456508035E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -6.3789743497358209E-01,  -5.4455801456508035E-01,   5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -6.3789743497358209E-01,   5.4455801456508035E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [   6.3789743497358209E-01,  -5.4455801456508035E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [  -6.3789743497358209E-01,  -5.4455801456508035E-01,  -5.4455801456508035E-01,   5.1211046803115922E-03],
            [   6.0725757968417682E-01,   6.0725757968417682E-01,   5.1232456883525634E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,   6.0725757968417682E-01,   5.1232456883525634E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1232456883525634E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,   6.0725757968417682E-01,  -5.1232456883525634E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1232456883525634E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,   6.0725757968417682E-01,  -5.1232456883525634E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,  -6.0725757968417682E-01,  -5.1232456883525634E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,  -6.0725757968417682E-01,  -5.1232456883525634E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,   5.1232456883525634E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,  -5.1232456883525634E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,   5.1232456883525634E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,  -5.1232456883525634E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,   5.1232456883525634E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,  -5.1232456883525634E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -6.0725757968417682E-01,  -5.1232456883525634E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [   6.0725757968417682E-01,   5.1232456883525634E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [   5.1232456883525634E-01,   6.0725757968417682E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -5.1232456883525634E-01,   6.0725757968417682E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [   5.1232456883525634E-01,  -6.0725757968417682E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [   5.1232456883525634E-01,   6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -5.1232456883525634E-01,  -6.0725757968417682E-01,   6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -5.1232456883525634E-01,   6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [   5.1232456883525634E-01,  -6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [  -5.1232456883525634E-01,  -6.0725757968417682E-01,  -6.0725757968417682E-01,   5.1225848995966874E-03],
            [   6.3394845057558025E-01,   6.3394845057558025E-01,   4.4296582715333949E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,   6.3394845057558025E-01,   4.4296582715333949E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,  -6.3394845057558025E-01,   4.4296582715333949E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,   6.3394845057558025E-01,  -4.4296582715333949E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,  -6.3394845057558025E-01,   4.4296582715333949E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,   6.3394845057558025E-01,  -4.4296582715333949E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,  -6.3394845057558025E-01,  -4.4296582715333949E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,  -6.3394845057558025E-01,  -4.4296582715333949E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,   4.4296582715333949E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,  -4.4296582715333949E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,   4.4296582715333949E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,  -4.4296582715333949E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,   4.4296582715333949E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,  -4.4296582715333949E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -6.3394845057558025E-01,  -4.4296582715333949E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [   6.3394845057558025E-01,   4.4296582715333949E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [   4.4296582715333949E-01,   6.3394845057558025E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -4.4296582715333949E-01,   6.3394845057558025E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [   4.4296582715333949E-01,  -6.3394845057558025E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [   4.4296582715333949E-01,   6.3394845057558025E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -4.4296582715333949E-01,  -6.3394845057558025E-01,   6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -4.4296582715333949E-01,   6.3394845057558025E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [   4.4296582715333949E-01,  -6.3394845057558025E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [  -4.4296582715333949E-01,  -6.3394845057558025E-01,  -6.3394845057558025E-01,   5.1198923302043890E-03],
            [   6.5707182574869583E-01,   6.5707182574869583E-01,   3.6947697034395932E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,   6.5707182574869583E-01,   3.6947697034395932E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,  -6.5707182574869583E-01,   3.6947697034395932E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,   6.5707182574869583E-01,  -3.6947697034395932E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,  -6.5707182574869583E-01,   3.6947697034395932E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,   6.5707182574869583E-01,  -3.6947697034395932E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,  -6.5707182574869583E-01,  -3.6947697034395932E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,  -6.5707182574869583E-01,  -3.6947697034395932E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,   3.6947697034395932E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,  -3.6947697034395932E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,   3.6947697034395932E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,  -3.6947697034395932E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,   3.6947697034395932E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,  -3.6947697034395932E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -6.5707182574869583E-01,  -3.6947697034395932E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [   6.5707182574869583E-01,   3.6947697034395932E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [   3.6947697034395932E-01,   6.5707182574869583E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -3.6947697034395932E-01,   6.5707182574869583E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [   3.6947697034395932E-01,  -6.5707182574869583E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [   3.6947697034395932E-01,   6.5707182574869583E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -3.6947697034395932E-01,  -6.5707182574869583E-01,   6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -3.6947697034395932E-01,   6.5707182574869583E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [   3.6947697034395932E-01,  -6.5707182574869583E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [  -3.6947697034395932E-01,  -6.5707182574869583E-01,  -6.5707182574869583E-01,   5.1197451701639456E-03],
            [   6.7625573300907094E-01,   6.7625573300907094E-01,   2.9215812010746578E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,   6.7625573300907094E-01,   2.9215812010746578E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,  -6.7625573300907094E-01,   2.9215812010746578E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,   6.7625573300907094E-01,  -2.9215812010746578E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,  -6.7625573300907094E-01,   2.9215812010746578E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,   6.7625573300907094E-01,  -2.9215812010746578E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,  -6.7625573300907094E-01,  -2.9215812010746578E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,  -6.7625573300907094E-01,  -2.9215812010746578E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,   2.9215812010746578E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,  -2.9215812010746578E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,   2.9215812010746578E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,  -2.9215812010746578E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,   2.9215812010746578E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,  -2.9215812010746578E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -6.7625573300907094E-01,  -2.9215812010746578E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [   6.7625573300907094E-01,   2.9215812010746578E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [   2.9215812010746578E-01,   6.7625573300907094E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -2.9215812010746578E-01,   6.7625573300907094E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [   2.9215812010746578E-01,  -6.7625573300907094E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [   2.9215812010746578E-01,   6.7625573300907094E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -2.9215812010746578E-01,  -6.7625573300907094E-01,   6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -2.9215812010746578E-01,   6.7625573300907094E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [   2.9215812010746578E-01,  -6.7625573300907094E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [  -2.9215812010746578E-01,  -6.7625573300907094E-01,  -6.7625573300907094E-01,   5.1241233427689777E-03],
            [   6.9111616969237899E-01,   6.9111616969237899E-01,   2.1146366113228440E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,   6.9111616969237899E-01,   2.1146366113228440E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,  -6.9111616969237899E-01,   2.1146366113228440E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,   6.9111616969237899E-01,  -2.1146366113228440E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,  -6.9111616969237899E-01,   2.1146366113228440E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,   6.9111616969237899E-01,  -2.1146366113228440E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,  -6.9111616969237899E-01,  -2.1146366113228440E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,  -6.9111616969237899E-01,  -2.1146366113228440E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,   2.1146366113228440E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,  -2.1146366113228440E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,   2.1146366113228440E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,  -2.1146366113228440E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,   2.1146366113228440E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,  -2.1146366113228440E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -6.9111616969237899E-01,  -2.1146366113228440E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [   6.9111616969237899E-01,   2.1146366113228440E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [   2.1146366113228440E-01,   6.9111616969237899E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -2.1146366113228440E-01,   6.9111616969237899E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [   2.1146366113228440E-01,  -6.9111616969237899E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [   2.1146366113228440E-01,   6.9111616969237899E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -2.1146366113228440E-01,  -6.9111616969237899E-01,   6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -2.1146366113228440E-01,   6.9111616969237899E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [   2.1146366113228440E-01,  -6.9111616969237899E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [  -2.1146366113228440E-01,  -6.9111616969237899E-01,  -6.9111616969237899E-01,   5.1327561349120629E-03],
            [   7.0128419116599605E-01,   7.0128419116599605E-01,   1.2806625801244212E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,   7.0128419116599605E-01,   1.2806625801244212E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,  -7.0128419116599605E-01,   1.2806625801244212E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,   7.0128419116599605E-01,  -1.2806625801244212E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,  -7.0128419116599605E-01,   1.2806625801244212E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,   7.0128419116599605E-01,  -1.2806625801244212E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,  -7.0128419116599605E-01,  -1.2806625801244212E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,  -7.0128419116599605E-01,  -1.2806625801244212E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,   1.2806625801244212E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,  -1.2806625801244212E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,   1.2806625801244212E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,  -1.2806625801244212E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,   1.2806625801244212E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,  -1.2806625801244212E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -7.0128419116599605E-01,  -1.2806625801244212E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [   7.0128419116599605E-01,   1.2806625801244212E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [   1.2806625801244212E-01,   7.0128419116599605E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -1.2806625801244212E-01,   7.0128419116599605E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [   1.2806625801244212E-01,  -7.0128419116599605E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [   1.2806625801244212E-01,   7.0128419116599605E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -1.2806625801244212E-01,  -7.0128419116599605E-01,   7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -1.2806625801244212E-01,   7.0128419116599605E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [   1.2806625801244212E-01,  -7.0128419116599605E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [  -1.2806625801244212E-01,  -7.0128419116599605E-01,  -7.0128419116599605E-01,   5.1427475386184888E-03],
            [   7.0645592724100204E-01,   7.0645592724100204E-01,   4.2895754243421923E-02,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,   7.0645592724100204E-01,   4.2895754243421923E-02,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,  -7.0645592724100204E-01,   4.2895754243421923E-02,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,   7.0645592724100204E-01,  -4.2895754243421923E-02,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,  -7.0645592724100204E-01,   4.2895754243421923E-02,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,   7.0645592724100204E-01,  -4.2895754243421923E-02,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,  -7.0645592724100204E-01,  -4.2895754243421923E-02,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,  -7.0645592724100204E-01,  -4.2895754243421923E-02,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,   4.2895754243421923E-02,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,  -4.2895754243421923E-02,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,   4.2895754243421923E-02,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,  -4.2895754243421923E-02,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,   4.2895754243421923E-02,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,  -4.2895754243421923E-02,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -7.0645592724100204E-01,  -4.2895754243421923E-02,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [   7.0645592724100204E-01,   4.2895754243421923E-02,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [   4.2895754243421923E-02,   7.0645592724100204E-01,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -4.2895754243421923E-02,   7.0645592724100204E-01,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [   4.2895754243421923E-02,  -7.0645592724100204E-01,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [   4.2895754243421923E-02,   7.0645592724100204E-01,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -4.2895754243421923E-02,  -7.0645592724100204E-01,   7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -4.2895754243421923E-02,   7.0645592724100204E-01,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [   4.2895754243421923E-02,  -7.0645592724100204E-01,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [  -4.2895754243421923E-02,  -7.0645592724100204E-01,  -7.0645592724100204E-01,   5.1495386918329177E-03],
            [   6.1235549898947653E-02,   9.9812334279315074E-01,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [  -6.1235549898947653E-02,   9.9812334279315074E-01,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [   6.1235549898947653E-02,  -9.9812334279315074E-01,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [  -6.1235549898947653E-02,  -9.9812334279315074E-01,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [   9.9812334279315074E-01,   6.1235549898947653E-02,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [  -9.9812334279315074E-01,   6.1235549898947653E-02,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [   9.9812334279315074E-01,  -6.1235549898947653E-02,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [  -9.9812334279315074E-01,  -6.1235549898947653E-02,   0.0000000000000000E+00,   2.1852752769870869E-03],
            [   6.1235549898947653E-02,   0.0000000000000000E+00,   9.9812334279315074E-01,   2.1852752769870869E-03],
            [  -6.1235549898947653E-02,   0.0000000000000000E+00,   9.9812334279315074E-01,   2.1852752769870869E-03],
            [   6.1235549898947653E-02,   0.0000000000000000E+00,  -9.9812334279315074E-01,   2.1852752769870869E-03],
            [  -6.1235549898947653E-02,   0.0000000000000000E+00,  -9.9812334279315074E-01,   2.1852752769870869E-03],
            [   9.9812334279315074E-01,   0.0000000000000000E+00,   6.1235549898947653E-02,   2.1852752769870869E-03],
            [  -9.9812334279315074E-01,   0.0000000000000000E+00,   6.1235549898947653E-02,   2.1852752769870869E-03],
            [   9.9812334279315074E-01,   0.0000000000000000E+00,  -6.1235549898947653E-02,   2.1852752769870869E-03],
            [  -9.9812334279315074E-01,   0.0000000000000000E+00,  -6.1235549898947653E-02,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,   6.1235549898947653E-02,   9.9812334279315074E-01,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,  -6.1235549898947653E-02,   9.9812334279315074E-01,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,   6.1235549898947653E-02,  -9.9812334279315074E-01,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,  -6.1235549898947653E-02,  -9.9812334279315074E-01,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,   9.9812334279315074E-01,   6.1235549898947653E-02,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,  -9.9812334279315074E-01,   6.1235549898947653E-02,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,   9.9812334279315074E-01,  -6.1235549898947653E-02,   2.1852752769870869E-03],
            [   0.0000000000000000E+00,  -9.9812334279315074E-01,  -6.1235549898947653E-02,   2.1852752769870869E-03],
            [   1.5330703483123931E-01,   9.8817860383194556E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [  -1.5330703483123931E-01,   9.8817860383194556E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [   1.5330703483123931E-01,  -9.8817860383194556E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [  -1.5330703483123931E-01,  -9.8817860383194556E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [   9.8817860383194556E-01,   1.5330703483123931E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [  -9.8817860383194556E-01,   1.5330703483123931E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [   9.8817860383194556E-01,  -1.5330703483123931E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [  -9.8817860383194556E-01,  -1.5330703483123931E-01,   0.0000000000000000E+00,   3.3421720916887148E-03],
            [   1.5330703483123931E-01,   0.0000000000000000E+00,   9.8817860383194556E-01,   3.3421720916887148E-03],
            [  -1.5330703483123931E-01,   0.0000000000000000E+00,   9.8817860383194556E-01,   3.3421720916887148E-03],
            [   1.5330703483123931E-01,   0.0000000000000000E+00,  -9.8817860383194556E-01,   3.3421720916887148E-03],
            [  -1.5330703483123931E-01,   0.0000000000000000E+00,  -9.8817860383194556E-01,   3.3421720916887148E-03],
            [   9.8817860383194556E-01,   0.0000000000000000E+00,   1.5330703483123931E-01,   3.3421720916887148E-03],
            [  -9.8817860383194556E-01,   0.0000000000000000E+00,   1.5330703483123931E-01,   3.3421720916887148E-03],
            [   9.8817860383194556E-01,   0.0000000000000000E+00,  -1.5330703483123931E-01,   3.3421720916887148E-03],
            [  -9.8817860383194556E-01,   0.0000000000000000E+00,  -1.5330703483123931E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,   1.5330703483123931E-01,   9.8817860383194556E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,  -1.5330703483123931E-01,   9.8817860383194556E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,   1.5330703483123931E-01,  -9.8817860383194556E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,  -1.5330703483123931E-01,  -9.8817860383194556E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,   9.8817860383194556E-01,   1.5330703483123931E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,  -9.8817860383194556E-01,   1.5330703483123931E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,   9.8817860383194556E-01,  -1.5330703483123931E-01,   3.3421720916887148E-03],
            [   0.0000000000000000E+00,  -9.8817860383194556E-01,  -1.5330703483123931E-01,   3.3421720916887148E-03],
            [   2.5639026052442060E-01,   9.6657334657449545E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [  -2.5639026052442060E-01,   9.6657334657449545E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [   2.5639026052442060E-01,  -9.6657334657449545E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [  -2.5639026052442060E-01,  -9.6657334657449545E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [   9.6657334657449545E-01,   2.5639026052442060E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [  -9.6657334657449545E-01,   2.5639026052442060E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [   9.6657334657449545E-01,  -2.5639026052442060E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [  -9.6657334657449545E-01,  -2.5639026052442060E-01,   0.0000000000000000E+00,   4.0722530450096389E-03],
            [   2.5639026052442060E-01,   0.0000000000000000E+00,   9.6657334657449545E-01,   4.0722530450096389E-03],
            [  -2.5639026052442060E-01,   0.0000000000000000E+00,   9.6657334657449545E-01,   4.0722530450096389E-03],
            [   2.5639026052442060E-01,   0.0000000000000000E+00,  -9.6657334657449545E-01,   4.0722530450096389E-03],
            [  -2.5639026052442060E-01,   0.0000000000000000E+00,  -9.6657334657449545E-01,   4.0722530450096389E-03],
            [   9.6657334657449545E-01,   0.0000000000000000E+00,   2.5639026052442060E-01,   4.0722530450096389E-03],
            [  -9.6657334657449545E-01,   0.0000000000000000E+00,   2.5639026052442060E-01,   4.0722530450096389E-03],
            [   9.6657334657449545E-01,   0.0000000000000000E+00,  -2.5639026052442060E-01,   4.0722530450096389E-03],
            [  -9.6657334657449545E-01,   0.0000000000000000E+00,  -2.5639026052442060E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,   2.5639026052442060E-01,   9.6657334657449545E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,  -2.5639026052442060E-01,   9.6657334657449545E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,   2.5639026052442060E-01,  -9.6657334657449545E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,  -2.5639026052442060E-01,  -9.6657334657449545E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,   9.6657334657449545E-01,   2.5639026052442060E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,  -9.6657334657449545E-01,   2.5639026052442060E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,   9.6657334657449545E-01,  -2.5639026052442060E-01,   4.0722530450096389E-03],
            [   0.0000000000000000E+00,  -9.6657334657449545E-01,  -2.5639026052442060E-01,   4.0722530450096389E-03],
            [   3.6293469916633608E-01,   9.3181457605096585E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [  -3.6293469916633608E-01,   9.3181457605096585E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [   3.6293469916633608E-01,  -9.3181457605096585E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [  -3.6293469916633608E-01,  -9.3181457605096585E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [   9.3181457605096585E-01,   3.6293469916633608E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [  -9.3181457605096585E-01,   3.6293469916633608E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [   9.3181457605096585E-01,  -3.6293469916633608E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [  -9.3181457605096585E-01,  -3.6293469916633608E-01,   0.0000000000000000E+00,   4.5505290556286165E-03],
            [   3.6293469916633608E-01,   0.0000000000000000E+00,   9.3181457605096585E-01,   4.5505290556286165E-03],
            [  -3.6293469916633608E-01,   0.0000000000000000E+00,   9.3181457605096585E-01,   4.5505290556286165E-03],
            [   3.6293469916633608E-01,   0.0000000000000000E+00,  -9.3181457605096585E-01,   4.5505290556286165E-03],
            [  -3.6293469916633608E-01,   0.0000000000000000E+00,  -9.3181457605096585E-01,   4.5505290556286165E-03],
            [   9.3181457605096585E-01,   0.0000000000000000E+00,   3.6293469916633608E-01,   4.5505290556286165E-03],
            [  -9.3181457605096585E-01,   0.0000000000000000E+00,   3.6293469916633608E-01,   4.5505290556286165E-03],
            [   9.3181457605096585E-01,   0.0000000000000000E+00,  -3.6293469916633608E-01,   4.5505290556286165E-03],
            [  -9.3181457605096585E-01,   0.0000000000000000E+00,  -3.6293469916633608E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,   3.6293469916633608E-01,   9.3181457605096585E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,  -3.6293469916633608E-01,   9.3181457605096585E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,   3.6293469916633608E-01,  -9.3181457605096585E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,  -3.6293469916633608E-01,  -9.3181457605096585E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,   9.3181457605096585E-01,   3.6293469916633608E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,  -9.3181457605096585E-01,   3.6293469916633608E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,   9.3181457605096585E-01,  -3.6293469916633608E-01,   4.5505290556286165E-03],
            [   0.0000000000000000E+00,  -9.3181457605096585E-01,  -3.6293469916633608E-01,   4.5505290556286165E-03],
            [   4.6839499689875380E-01,   8.8351917176720984E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [  -4.6839499689875380E-01,   8.8351917176720984E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [   4.6839499689875380E-01,  -8.8351917176720984E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [  -4.6839499689875380E-01,  -8.8351917176720984E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [   8.8351917176720984E-01,   4.6839499689875380E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [  -8.8351917176720984E-01,   4.6839499689875380E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [   8.8351917176720984E-01,  -4.6839499689875380E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [  -8.8351917176720984E-01,  -4.6839499689875380E-01,   0.0000000000000000E+00,   4.8617256311375631E-03],
            [   4.6839499689875380E-01,   0.0000000000000000E+00,   8.8351917176720984E-01,   4.8617256311375631E-03],
            [  -4.6839499689875380E-01,   0.0000000000000000E+00,   8.8351917176720984E-01,   4.8617256311375631E-03],
            [   4.6839499689875380E-01,   0.0000000000000000E+00,  -8.8351917176720984E-01,   4.8617256311375631E-03],
            [  -4.6839499689875380E-01,   0.0000000000000000E+00,  -8.8351917176720984E-01,   4.8617256311375631E-03],
            [   8.8351917176720984E-01,   0.0000000000000000E+00,   4.6839499689875380E-01,   4.8617256311375631E-03],
            [  -8.8351917176720984E-01,   0.0000000000000000E+00,   4.6839499689875380E-01,   4.8617256311375631E-03],
            [   8.8351917176720984E-01,   0.0000000000000000E+00,  -4.6839499689875380E-01,   4.8617256311375631E-03],
            [  -8.8351917176720984E-01,   0.0000000000000000E+00,  -4.6839499689875380E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,   4.6839499689875380E-01,   8.8351917176720984E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,  -4.6839499689875380E-01,   8.8351917176720984E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,   4.6839499689875380E-01,  -8.8351917176720984E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,  -4.6839499689875380E-01,  -8.8351917176720984E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,   8.8351917176720984E-01,   4.6839499689875380E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,  -8.8351917176720984E-01,   4.6839499689875380E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,   8.8351917176720984E-01,  -4.6839499689875380E-01,   4.8617256311375631E-03],
            [   0.0000000000000000E+00,  -8.8351917176720984E-01,  -4.6839499689875380E-01,   4.8617256311375631E-03],
            [   5.6944792406579525E-01,   8.2202740938313990E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [  -5.6944792406579525E-01,   8.2202740938313990E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [   5.6944792406579525E-01,  -8.2202740938313990E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [  -5.6944792406579525E-01,  -8.2202740938313990E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [   8.2202740938313990E-01,   5.6944792406579525E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [  -8.2202740938313990E-01,   5.6944792406579525E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [   8.2202740938313990E-01,  -5.6944792406579525E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [  -8.2202740938313990E-01,  -5.6944792406579525E-01,   0.0000000000000000E+00,   5.0503131786143896E-03],
            [   5.6944792406579525E-01,   0.0000000000000000E+00,   8.2202740938313990E-01,   5.0503131786143896E-03],
            [  -5.6944792406579525E-01,   0.0000000000000000E+00,   8.2202740938313990E-01,   5.0503131786143896E-03],
            [   5.6944792406579525E-01,   0.0000000000000000E+00,  -8.2202740938313990E-01,   5.0503131786143896E-03],
            [  -5.6944792406579525E-01,   0.0000000000000000E+00,  -8.2202740938313990E-01,   5.0503131786143896E-03],
            [   8.2202740938313990E-01,   0.0000000000000000E+00,   5.6944792406579525E-01,   5.0503131786143896E-03],
            [  -8.2202740938313990E-01,   0.0000000000000000E+00,   5.6944792406579525E-01,   5.0503131786143896E-03],
            [   8.2202740938313990E-01,   0.0000000000000000E+00,  -5.6944792406579525E-01,   5.0503131786143896E-03],
            [  -8.2202740938313990E-01,   0.0000000000000000E+00,  -5.6944792406579525E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,   5.6944792406579525E-01,   8.2202740938313990E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,  -5.6944792406579525E-01,   8.2202740938313990E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,   5.6944792406579525E-01,  -8.2202740938313990E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,  -5.6944792406579525E-01,  -8.2202740938313990E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,   8.2202740938313990E-01,   5.6944792406579525E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,  -8.2202740938313990E-01,   5.6944792406579525E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,   8.2202740938313990E-01,  -5.6944792406579525E-01,   5.0503131786143896E-03],
            [   0.0000000000000000E+00,  -8.2202740938313990E-01,  -5.6944792406579525E-01,   5.0503131786143896E-03],
            [   6.6344654309939555E-01,   7.4822368610560697E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [  -6.6344654309939555E-01,   7.4822368610560697E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [   6.6344654309939555E-01,  -7.4822368610560697E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [  -6.6344654309939555E-01,  -7.4822368610560697E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [   7.4822368610560697E-01,   6.6344654309939555E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [  -7.4822368610560697E-01,   6.6344654309939555E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [   7.4822368610560697E-01,  -6.6344654309939555E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [  -7.4822368610560697E-01,  -6.6344654309939555E-01,   0.0000000000000000E+00,   5.1395569041443410E-03],
            [   6.6344654309939555E-01,   0.0000000000000000E+00,   7.4822368610560697E-01,   5.1395569041443410E-03],
            [  -6.6344654309939555E-01,   0.0000000000000000E+00,   7.4822368610560697E-01,   5.1395569041443410E-03],
            [   6.6344654309939555E-01,   0.0000000000000000E+00,  -7.4822368610560697E-01,   5.1395569041443410E-03],
            [  -6.6344654309939555E-01,   0.0000000000000000E+00,  -7.4822368610560697E-01,   5.1395569041443410E-03],
            [   7.4822368610560697E-01,   0.0000000000000000E+00,   6.6344654309939555E-01,   5.1395569041443410E-03],
            [  -7.4822368610560697E-01,   0.0000000000000000E+00,   6.6344654309939555E-01,   5.1395569041443410E-03],
            [   7.4822368610560697E-01,   0.0000000000000000E+00,  -6.6344654309939555E-01,   5.1395569041443410E-03],
            [  -7.4822368610560697E-01,   0.0000000000000000E+00,  -6.6344654309939555E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,   6.6344654309939555E-01,   7.4822368610560697E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,  -6.6344654309939555E-01,   7.4822368610560697E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,   6.6344654309939555E-01,  -7.4822368610560697E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,  -6.6344654309939555E-01,  -7.4822368610560697E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,   7.4822368610560697E-01,   6.6344654309939555E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,  -7.4822368610560697E-01,   6.6344654309939555E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,   7.4822368610560697E-01,  -6.6344654309939555E-01,   5.1395569041443410E-03],
            [   0.0000000000000000E+00,  -7.4822368610560697E-01,  -6.6344654309939555E-01,   5.1395569041443410E-03],
            [   1.0339585735523051E-01,   3.0345440090635840E-02,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,   3.0345440090635840E-02,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,  -3.0345440090635840E-02,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,   3.0345440090635840E-02,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,  -3.0345440090635840E-02,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,  -3.0345440090635840E-02,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,   3.0345440090635840E-02,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,  -3.0345440090635840E-02,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,   1.0339585735523051E-01,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,   1.0339585735523051E-01,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,  -1.0339585735523051E-01,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,   1.0339585735523051E-01,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,  -1.0339585735523051E-01,   9.9417727340121909E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,  -1.0339585735523051E-01,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,   1.0339585735523051E-01,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,  -1.0339585735523051E-01,  -9.9417727340121909E-01,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,   1.0339585735523051E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,   1.0339585735523051E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,  -1.0339585735523051E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,   1.0339585735523051E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,  -1.0339585735523051E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,  -1.0339585735523051E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,   1.0339585735523051E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,  -1.0339585735523051E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,   3.0345440090635840E-02,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,   3.0345440090635840E-02,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,  -3.0345440090635840E-02,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,   3.0345440090635840E-02,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,  -3.0345440090635840E-02,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   9.9417727340121909E-01,  -3.0345440090635840E-02,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,   3.0345440090635840E-02,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -9.9417727340121909E-01,  -3.0345440090635840E-02,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,   9.9417727340121909E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,   9.9417727340121909E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,  -9.9417727340121909E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,   9.9417727340121909E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,  -9.9417727340121909E-01,   3.0345440090635840E-02,   2.8650162959626088E-03],
            [   1.0339585735523051E-01,  -9.9417727340121909E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,   9.9417727340121909E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [  -1.0339585735523051E-01,  -9.9417727340121909E-01,  -3.0345440090635840E-02,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,   9.9417727340121909E-01,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,   9.9417727340121909E-01,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,  -9.9417727340121909E-01,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,   9.9417727340121909E-01,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,  -9.9417727340121909E-01,   1.0339585735523051E-01,   2.8650162959626088E-03],
            [   3.0345440090635840E-02,  -9.9417727340121909E-01,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,   9.9417727340121909E-01,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [  -3.0345440090635840E-02,  -9.9417727340121909E-01,  -1.0339585735523051E-01,   2.8650162959626088E-03],
            [   1.4735214124143950E-01,   6.6188030442471346E-02,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,   6.6188030442471346E-02,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,  -6.6188030442471346E-02,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,   6.6188030442471346E-02,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,  -6.6188030442471346E-02,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,  -6.6188030442471346E-02,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,   6.6188030442471346E-02,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,  -6.6188030442471346E-02,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,   1.4735214124143950E-01,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,   1.4735214124143950E-01,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,  -1.4735214124143950E-01,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,   1.4735214124143950E-01,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,  -1.4735214124143950E-01,   9.8686700780688252E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,  -1.4735214124143950E-01,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,   1.4735214124143950E-01,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,  -1.4735214124143950E-01,  -9.8686700780688252E-01,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,   1.4735214124143950E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,   1.4735214124143950E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,  -1.4735214124143950E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,   1.4735214124143950E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,  -1.4735214124143950E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,  -1.4735214124143950E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,   1.4735214124143950E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,  -1.4735214124143950E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,   6.6188030442471346E-02,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,   6.6188030442471346E-02,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,  -6.6188030442471346E-02,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,   6.6188030442471346E-02,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,  -6.6188030442471346E-02,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   9.8686700780688252E-01,  -6.6188030442471346E-02,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,   6.6188030442471346E-02,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -9.8686700780688252E-01,  -6.6188030442471346E-02,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,   9.8686700780688252E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,   9.8686700780688252E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,  -9.8686700780688252E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,   9.8686700780688252E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,  -9.8686700780688252E-01,   6.6188030442471346E-02,   3.4120278488757329E-03],
            [   1.4735214124143950E-01,  -9.8686700780688252E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,   9.8686700780688252E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [  -1.4735214124143950E-01,  -9.8686700780688252E-01,  -6.6188030442471346E-02,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,   9.8686700780688252E-01,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,   9.8686700780688252E-01,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,  -9.8686700780688252E-01,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,   9.8686700780688252E-01,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,  -9.8686700780688252E-01,   1.4735214124143950E-01,   3.4120278488757329E-03],
            [   6.6188030442471346E-02,  -9.8686700780688252E-01,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,   9.8686700780688252E-01,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [  -6.6188030442471346E-02,  -9.8686700780688252E-01,  -1.4735214124143950E-01,   3.4120278488757329E-03],
            [   1.9245521587059669E-01,   1.0544311289877149E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,   1.0544311289877149E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,  -1.0544311289877149E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,   1.0544311289877149E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,  -1.0544311289877149E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,  -1.0544311289877149E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,   1.0544311289877149E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,  -1.0544311289877149E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,   1.9245521587059669E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,   1.9245521587059669E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,  -1.9245521587059669E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,   1.9245521587059669E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,  -1.9245521587059669E-01,   9.7562428210168017E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,  -1.9245521587059669E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,   1.9245521587059669E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,  -1.9245521587059669E-01,  -9.7562428210168017E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,   1.9245521587059669E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,   1.9245521587059669E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,  -1.9245521587059669E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,   1.9245521587059669E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,  -1.9245521587059669E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,  -1.9245521587059669E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,   1.9245521587059669E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,  -1.9245521587059669E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,   1.0544311289877149E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,   1.0544311289877149E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,  -1.0544311289877149E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,   1.0544311289877149E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,  -1.0544311289877149E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   9.7562428210168017E-01,  -1.0544311289877149E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,   1.0544311289877149E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -9.7562428210168017E-01,  -1.0544311289877149E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,   9.7562428210168017E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,   9.7562428210168017E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,  -9.7562428210168017E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,   9.7562428210168017E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,  -9.7562428210168017E-01,   1.0544311289877149E-01,   3.8426929598263855E-03],
            [   1.9245521587059669E-01,  -9.7562428210168017E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,   9.7562428210168017E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [  -1.9245521587059669E-01,  -9.7562428210168017E-01,  -1.0544311289877149E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,   9.7562428210168017E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,   9.7562428210168017E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,  -9.7562428210168017E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,   9.7562428210168017E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,  -9.7562428210168017E-01,   1.9245521587059669E-01,   3.8426929598263855E-03],
            [   1.0544311289877149E-01,  -9.7562428210168017E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,   9.7562428210168017E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [  -1.0544311289877149E-01,  -9.7562428210168017E-01,  -1.9245521587059669E-01,   3.8426929598263855E-03],
            [   2.3810943628903281E-01,   1.4682635512388581E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,   1.4682635512388581E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,  -1.4682635512388581E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,   1.4682635512388581E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,  -1.4682635512388581E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,  -1.4682635512388581E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,   1.4682635512388581E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,  -1.4682635512388581E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,   2.3810943628903281E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,   2.3810943628903281E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,  -2.3810943628903281E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,   2.3810943628903281E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,  -2.3810943628903281E-01,   9.6007599584155501E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,  -2.3810943628903281E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,   2.3810943628903281E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,  -2.3810943628903281E-01,  -9.6007599584155501E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,   2.3810943628903281E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,   2.3810943628903281E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,  -2.3810943628903281E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,   2.3810943628903281E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,  -2.3810943628903281E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,  -2.3810943628903281E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,   2.3810943628903281E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,  -2.3810943628903281E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,   1.4682635512388581E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,   1.4682635512388581E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,  -1.4682635512388581E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,   1.4682635512388581E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,  -1.4682635512388581E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   9.6007599584155501E-01,  -1.4682635512388581E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,   1.4682635512388581E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -9.6007599584155501E-01,  -1.4682635512388581E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,   9.6007599584155501E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,   9.6007599584155501E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,  -9.6007599584155501E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,   9.6007599584155501E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,  -9.6007599584155501E-01,   1.4682635512388581E-01,   4.1807222418867758E-03],
            [   2.3810943628903281E-01,  -9.6007599584155501E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,   9.6007599584155501E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [  -2.3810943628903281E-01,  -9.6007599584155501E-01,  -1.4682635512388581E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,   9.6007599584155501E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,   9.6007599584155501E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,  -9.6007599584155501E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,   9.6007599584155501E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,  -9.6007599584155501E-01,   2.3810943628903281E-01,   4.1807222418867758E-03],
            [   1.4682635512388581E-01,  -9.6007599584155501E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,   9.6007599584155501E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [  -1.4682635512388581E-01,  -9.6007599584155501E-01,  -2.3810943628903281E-01,   4.1807222418867758E-03],
            [   2.8381217079367599E-01,   1.8944861081878861E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,   1.8944861081878861E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,  -1.8944861081878861E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,   1.8944861081878861E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,  -1.8944861081878861E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,  -1.8944861081878861E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,   1.8944861081878861E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,  -1.8944861081878861E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,   2.8381217079367599E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,   2.8381217079367599E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,  -2.8381217079367599E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,   2.8381217079367599E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,  -2.8381217079367599E-01,   9.3997865697483385E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,  -2.8381217079367599E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,   2.8381217079367599E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,  -2.8381217079367599E-01,  -9.3997865697483385E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,   2.8381217079367599E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,   2.8381217079367599E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,  -2.8381217079367599E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,   2.8381217079367599E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,  -2.8381217079367599E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,  -2.8381217079367599E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,   2.8381217079367599E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,  -2.8381217079367599E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,   1.8944861081878861E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,   1.8944861081878861E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,  -1.8944861081878861E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,   1.8944861081878861E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,  -1.8944861081878861E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   9.3997865697483385E-01,  -1.8944861081878861E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,   1.8944861081878861E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -9.3997865697483385E-01,  -1.8944861081878861E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,   9.3997865697483385E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,   9.3997865697483385E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,  -9.3997865697483385E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,   9.3997865697483385E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,  -9.3997865697483385E-01,   1.8944861081878861E-01,   4.4451458976647630E-03],
            [   2.8381217079367599E-01,  -9.3997865697483385E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,   9.3997865697483385E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [  -2.8381217079367599E-01,  -9.3997865697483385E-01,  -1.8944861081878861E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,   9.3997865697483385E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,   9.3997865697483385E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,  -9.3997865697483385E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,   9.3997865697483385E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,  -9.3997865697483385E-01,   2.8381217079367599E-01,   4.4451458976647630E-03],
            [   1.8944861081878861E-01,  -9.3997865697483385E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,   9.3997865697483385E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [  -1.8944861081878861E-01,  -9.3997865697483385E-01,  -2.8381217079367599E-01,   4.4451458976647630E-03],
            [   3.2913231333734150E-01,   2.3263742387615791E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,   2.3263742387615791E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,  -2.3263742387615791E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,   2.3263742387615791E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,  -2.3263742387615791E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,  -2.3263742387615791E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,   2.3263742387615791E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,  -2.3263742387615791E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,   3.2913231333734150E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,   3.2913231333734150E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,  -3.2913231333734150E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,   3.2913231333734150E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,  -3.2913231333734150E-01,   9.1517853412843708E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,  -3.2913231333734150E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,   3.2913231333734150E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,  -3.2913231333734150E-01,  -9.1517853412843708E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,   3.2913231333734150E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,   3.2913231333734150E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,  -3.2913231333734150E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,   3.2913231333734150E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,  -3.2913231333734150E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,  -3.2913231333734150E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,   3.2913231333734150E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,  -3.2913231333734150E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,   2.3263742387615791E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,   2.3263742387615791E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,  -2.3263742387615791E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,   2.3263742387615791E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,  -2.3263742387615791E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   9.1517853412843708E-01,  -2.3263742387615791E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,   2.3263742387615791E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -9.1517853412843708E-01,  -2.3263742387615791E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,   9.1517853412843708E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,   9.1517853412843708E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,  -9.1517853412843708E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,   9.1517853412843708E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,  -9.1517853412843708E-01,   2.3263742387615791E-01,   4.6502702698293678E-03],
            [   3.2913231333734150E-01,  -9.1517853412843708E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,   9.1517853412843708E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [  -3.2913231333734150E-01,  -9.1517853412843708E-01,  -2.3263742387615791E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,   9.1517853412843708E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,   9.1517853412843708E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,  -9.1517853412843708E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,   9.1517853412843708E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,  -9.1517853412843708E-01,   3.2913231333734150E-01,   4.6502702698293678E-03],
            [   2.3263742387615791E-01,  -9.1517853412843708E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,   9.1517853412843708E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [  -2.3263742387615791E-01,  -9.1517853412843708E-01,  -3.2913231333734150E-01,   4.6502702698293678E-03],
            [   3.7368969787414602E-01,   2.7584858084857677E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,   2.7584858084857677E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,  -2.7584858084857677E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,   2.7584858084857677E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,  -2.7584858084857677E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,  -2.7584858084857677E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,   2.7584858084857677E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,  -2.7584858084857677E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,   3.7368969787414602E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,   3.7368969787414602E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,  -3.7368969787414602E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,   3.7368969787414602E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,  -3.7368969787414602E-01,   8.8558656840907179E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,  -3.7368969787414602E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,   3.7368969787414602E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,  -3.7368969787414602E-01,  -8.8558656840907179E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,   3.7368969787414602E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,   3.7368969787414602E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,  -3.7368969787414602E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,   3.7368969787414602E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,  -3.7368969787414602E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,  -3.7368969787414602E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,   3.7368969787414602E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,  -3.7368969787414602E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,   2.7584858084857677E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,   2.7584858084857677E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,  -2.7584858084857677E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,   2.7584858084857677E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,  -2.7584858084857677E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   8.8558656840907179E-01,  -2.7584858084857677E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,   2.7584858084857677E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -8.8558656840907179E-01,  -2.7584858084857677E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,   8.8558656840907179E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,   8.8558656840907179E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,  -8.8558656840907179E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,   8.8558656840907179E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,  -8.8558656840907179E-01,   2.7584858084857677E-01,   4.8069451042817343E-03],
            [   3.7368969787414602E-01,  -8.8558656840907179E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,   8.8558656840907179E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [  -3.7368969787414602E-01,  -8.8558656840907179E-01,  -2.7584858084857677E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,   8.8558656840907179E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,   8.8558656840907179E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,  -8.8558656840907179E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,   8.8558656840907179E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,  -8.8558656840907179E-01,   3.7368969787414602E-01,   4.8069451042817343E-03],
            [   2.7584858084857677E-01,  -8.8558656840907179E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,   8.8558656840907179E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [  -2.7584858084857677E-01,  -8.8558656840907179E-01,  -3.7368969787414602E-01,   4.8069451042817343E-03],
            [   4.1714060407600129E-01,   3.1861793319969212E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,   3.1861793319969212E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,  -3.1861793319969212E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,   3.1861793319969212E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,  -3.1861793319969212E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,  -3.1861793319969212E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,   3.1861793319969212E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,  -3.1861793319969212E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,   4.1714060407600129E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,   4.1714060407600129E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,  -4.1714060407600129E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,   4.1714060407600129E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,  -4.1714060407600129E-01,   8.5116175259151849E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,  -4.1714060407600129E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,   4.1714060407600129E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,  -4.1714060407600129E-01,  -8.5116175259151849E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,   4.1714060407600129E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,   4.1714060407600129E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,  -4.1714060407600129E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,   4.1714060407600129E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,  -4.1714060407600129E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,  -4.1714060407600129E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,   4.1714060407600129E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,  -4.1714060407600129E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,   3.1861793319969212E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,   3.1861793319969212E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,  -3.1861793319969212E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,   3.1861793319969212E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,  -3.1861793319969212E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   8.5116175259151849E-01,  -3.1861793319969212E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,   3.1861793319969212E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -8.5116175259151849E-01,  -3.1861793319969212E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,   8.5116175259151849E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,   8.5116175259151849E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,  -8.5116175259151849E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,   8.5116175259151849E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,  -8.5116175259151849E-01,   3.1861793319969212E-01,   4.9236613018748508E-03],
            [   4.1714060407600129E-01,  -8.5116175259151849E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,   8.5116175259151849E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [  -4.1714060407600129E-01,  -8.5116175259151849E-01,  -3.1861793319969212E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,   8.5116175259151849E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,   8.5116175259151849E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,  -8.5116175259151849E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,   8.5116175259151849E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,  -8.5116175259151849E-01,   4.1714060407600129E-01,   4.9236613018748508E-03],
            [   3.1861793319969212E-01,  -8.5116175259151849E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,   8.5116175259151849E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [  -3.1861793319969212E-01,  -8.5116175259151849E-01,  -4.1714060407600129E-01,   4.9236613018748508E-03],
            [   4.5916779852569151E-01,   3.6053297963037939E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,   3.6053297963037939E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,  -3.6053297963037939E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,   3.6053297963037939E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,  -3.6053297963037939E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,  -3.6053297963037939E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,   3.6053297963037939E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,  -3.6053297963037939E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,   4.5916779852569151E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,   4.5916779852569151E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,  -4.5916779852569151E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,   4.5916779852569151E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,  -4.5916779852569151E-01,   8.1189956484525250E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,  -4.5916779852569151E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,   4.5916779852569151E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,  -4.5916779852569151E-01,  -8.1189956484525250E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,   4.5916779852569151E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,   4.5916779852569151E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,  -4.5916779852569151E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,   4.5916779852569151E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,  -4.5916779852569151E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,  -4.5916779852569151E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,   4.5916779852569151E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,  -4.5916779852569151E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,   3.6053297963037939E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,   3.6053297963037939E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,  -3.6053297963037939E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,   3.6053297963037939E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,  -3.6053297963037939E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   8.1189956484525250E-01,  -3.6053297963037939E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,   3.6053297963037939E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -8.1189956484525250E-01,  -3.6053297963037939E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,   8.1189956484525250E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,   8.1189956484525250E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,  -8.1189956484525250E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,   8.1189956484525250E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,  -8.1189956484525250E-01,   3.6053297963037939E-01,   5.0073473591540534E-03],
            [   4.5916779852569151E-01,  -8.1189956484525250E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,   8.1189956484525250E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [  -4.5916779852569151E-01,  -8.1189956484525250E-01,  -3.6053297963037939E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,   8.1189956484525250E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,   8.1189956484525250E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,  -8.1189956484525250E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,   8.1189956484525250E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,  -8.1189956484525250E-01,   4.5916779852569151E-01,   5.0073473591540534E-03],
            [   3.6053297963037939E-01,  -8.1189956484525250E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,   8.1189956484525250E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [  -3.6053297963037939E-01,  -8.1189956484525250E-01,  -4.5916779852569151E-01,   5.0073473591540534E-03],
            [   4.9947338317184181E-01,   4.0121472535865088E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,   4.0121472535865088E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,  -4.0121472535865088E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,   4.0121472535865088E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,  -4.0121472535865088E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,  -4.0121472535865088E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,   4.0121472535865088E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,  -4.0121472535865088E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,   4.9947338317184181E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,   4.9947338317184181E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,  -4.9947338317184181E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,   4.9947338317184181E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,  -4.9947338317184181E-01,   7.6782360191534671E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,  -4.9947338317184181E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,   4.9947338317184181E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,  -4.9947338317184181E-01,  -7.6782360191534671E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,   4.9947338317184181E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,   4.9947338317184181E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,  -4.9947338317184181E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,   4.9947338317184181E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,  -4.9947338317184181E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,  -4.9947338317184181E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,   4.9947338317184181E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,  -4.9947338317184181E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,   4.0121472535865088E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,   4.0121472535865088E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,  -4.0121472535865088E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,   4.0121472535865088E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,  -4.0121472535865088E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   7.6782360191534671E-01,  -4.0121472535865088E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,   4.0121472535865088E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -7.6782360191534671E-01,  -4.0121472535865088E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,   7.6782360191534671E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,   7.6782360191534671E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,  -7.6782360191534671E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,   7.6782360191534671E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,  -7.6782360191534671E-01,   4.0121472535865088E-01,   5.0639281759680610E-03],
            [   4.9947338317184181E-01,  -7.6782360191534671E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,   7.6782360191534671E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [  -4.9947338317184181E-01,  -7.6782360191534671E-01,  -4.0121472535865088E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,   7.6782360191534671E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,   7.6782360191534671E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,  -7.6782360191534671E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,   7.6782360191534671E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,  -7.6782360191534671E-01,   4.9947338317184181E-01,   5.0639281759680610E-03],
            [   4.0121472535865088E-01,  -7.6782360191534671E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,   7.6782360191534671E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [  -4.0121472535865088E-01,  -7.6782360191534671E-01,  -4.9947338317184181E-01,   5.0639281759680610E-03],
            [   5.3777318304450961E-01,   4.4030500255706922E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,   4.4030500255706922E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,  -4.4030500255706922E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,   4.4030500255706922E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,  -4.4030500255706922E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,  -4.4030500255706922E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,   4.4030500255706922E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,  -4.4030500255706922E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,   5.3777318304450961E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,   5.3777318304450961E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,  -5.3777318304450961E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,   5.3777318304450961E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,  -5.3777318304450961E-01,   7.1897949089066204E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,  -5.3777318304450961E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,   5.3777318304450961E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,  -5.3777318304450961E-01,  -7.1897949089066204E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,   5.3777318304450961E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,   5.3777318304450961E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,  -5.3777318304450961E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,   5.3777318304450961E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,  -5.3777318304450961E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,  -5.3777318304450961E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,   5.3777318304450961E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,  -5.3777318304450961E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,   4.4030500255706922E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,   4.4030500255706922E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,  -4.4030500255706922E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,   4.4030500255706922E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,  -4.4030500255706922E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   7.1897949089066204E-01,  -4.4030500255706922E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,   4.4030500255706922E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -7.1897949089066204E-01,  -4.4030500255706922E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,   7.1897949089066204E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,   7.1897949089066204E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,  -7.1897949089066204E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,   7.1897949089066204E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,  -7.1897949089066204E-01,   4.4030500255706922E-01,   5.0987151932992570E-03],
            [   5.3777318304450961E-01,  -7.1897949089066204E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,   7.1897949089066204E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [  -5.3777318304450961E-01,  -7.1897949089066204E-01,  -4.4030500255706922E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,   7.1897949089066204E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,   7.1897949089066204E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,  -7.1897949089066204E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,   7.1897949089066204E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,  -7.1897949089066204E-01,   5.3777318304450961E-01,   5.0987151932992570E-03],
            [   4.4030500255706922E-01,  -7.1897949089066204E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,   7.1897949089066204E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [  -4.4030500255706922E-01,  -7.1897949089066204E-01,  -5.3777318304450961E-01,   5.0987151932992570E-03],
            [   5.7379178300013312E-01,   4.7745659042774830E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,   4.7745659042774830E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,  -4.7745659042774830E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,   4.7745659042774830E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,  -4.7745659042774830E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,  -4.7745659042774830E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,   4.7745659042774830E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,  -4.7745659042774830E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,   5.7379178300013312E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,   5.7379178300013312E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,  -5.7379178300013312E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,   5.7379178300013312E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,  -5.7379178300013312E-01,   6.6543083338438536E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,  -5.7379178300013312E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,   5.7379178300013312E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,  -5.7379178300013312E-01,  -6.6543083338438536E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,   5.7379178300013312E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,   5.7379178300013312E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,  -5.7379178300013312E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,   5.7379178300013312E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,  -5.7379178300013312E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,  -5.7379178300013312E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,   5.7379178300013312E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,  -5.7379178300013312E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,   4.7745659042774830E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,   4.7745659042774830E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,  -4.7745659042774830E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,   4.7745659042774830E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,  -4.7745659042774830E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   6.6543083338438536E-01,  -4.7745659042774830E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,   4.7745659042774830E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -6.6543083338438536E-01,  -4.7745659042774830E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,   6.6543083338438536E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,   6.6543083338438536E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,  -6.6543083338438536E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,   6.6543083338438536E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,  -6.6543083338438536E-01,   4.7745659042774830E-01,   5.1166733436156806E-03],
            [   5.7379178300013312E-01,  -6.6543083338438536E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,   6.6543083338438536E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [  -5.7379178300013312E-01,  -6.6543083338438536E-01,  -4.7745659042774830E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,   6.6543083338438536E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,   6.6543083338438536E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,  -6.6543083338438536E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,   6.6543083338438536E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,  -6.6543083338438536E-01,   5.7379178300013312E-01,   5.1166733436156806E-03],
            [   4.7745659042774830E-01,  -6.6543083338438536E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,   6.6543083338438536E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [  -4.7745659042774830E-01,  -6.6543083338438536E-01,  -5.7379178300013312E-01,   5.1166733436156806E-03],
            [   2.0273235862713890E-01,   3.5441225049761473E-02,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,   3.5441225049761473E-02,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,  -3.5441225049761473E-02,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,   3.5441225049761473E-02,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,  -3.5441225049761473E-02,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,  -3.5441225049761473E-02,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,   3.5441225049761473E-02,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,  -3.5441225049761473E-02,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,   2.0273235862713890E-01,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,   2.0273235862713890E-01,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,  -2.0273235862713890E-01,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,   2.0273235862713890E-01,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,  -2.0273235862713890E-01,   9.7859261714589352E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,  -2.0273235862713890E-01,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,   2.0273235862713890E-01,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,  -2.0273235862713890E-01,  -9.7859261714589352E-01,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,   2.0273235862713890E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,   2.0273235862713890E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,  -2.0273235862713890E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,   2.0273235862713890E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,  -2.0273235862713890E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,  -2.0273235862713890E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,   2.0273235862713890E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,  -2.0273235862713890E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,   3.5441225049761473E-02,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,   3.5441225049761473E-02,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,  -3.5441225049761473E-02,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,   3.5441225049761473E-02,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,  -3.5441225049761473E-02,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   9.7859261714589352E-01,  -3.5441225049761473E-02,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,   3.5441225049761473E-02,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -9.7859261714589352E-01,  -3.5441225049761473E-02,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,   9.7859261714589352E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,   9.7859261714589352E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,  -9.7859261714589352E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,   9.7859261714589352E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,  -9.7859261714589352E-01,   3.5441225049761473E-02,   3.7576425746796566E-03],
            [   2.0273235862713890E-01,  -9.7859261714589352E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,   9.7859261714589352E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [  -2.0273235862713890E-01,  -9.7859261714589352E-01,  -3.5441225049761473E-02,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,   9.7859261714589352E-01,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,   9.7859261714589352E-01,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,  -9.7859261714589352E-01,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,   9.7859261714589352E-01,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,  -9.7859261714589352E-01,   2.0273235862713890E-01,   3.7576425746796566E-03],
            [   3.5441225049761473E-02,  -9.7859261714589352E-01,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,   9.7859261714589352E-01,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [  -3.5441225049761473E-02,  -9.7859261714589352E-01,  -2.0273235862713890E-01,   3.7576425746796566E-03],
            [   2.5169423751872733E-01,   7.4183043886463282E-02,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,   7.4183043886463282E-02,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,  -7.4183043886463282E-02,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,   7.4183043886463282E-02,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,  -7.4183043886463282E-02,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,  -7.4183043886463282E-02,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,   7.4183043886463282E-02,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,  -7.4183043886463282E-02,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,   2.5169423751872733E-01,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,   2.5169423751872733E-01,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,  -2.5169423751872733E-01,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,   2.5169423751872733E-01,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,  -2.5169423751872733E-01,   9.6495952599039381E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,  -2.5169423751872733E-01,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,   2.5169423751872733E-01,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,  -2.5169423751872733E-01,  -9.6495952599039381E-01,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,   2.5169423751872733E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,   2.5169423751872733E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,  -2.5169423751872733E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,   2.5169423751872733E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,  -2.5169423751872733E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,  -2.5169423751872733E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,   2.5169423751872733E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,  -2.5169423751872733E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,   7.4183043886463282E-02,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,   7.4183043886463282E-02,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,  -7.4183043886463282E-02,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,   7.4183043886463282E-02,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,  -7.4183043886463282E-02,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   9.6495952599039381E-01,  -7.4183043886463282E-02,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,   7.4183043886463282E-02,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -9.6495952599039381E-01,  -7.4183043886463282E-02,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,   9.6495952599039381E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,   9.6495952599039381E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,  -9.6495952599039381E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,   9.6495952599039381E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,  -9.6495952599039381E-01,   7.4183043886463282E-02,   4.1003460788885011E-03],
            [   2.5169423751872733E-01,  -9.6495952599039381E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,   9.6495952599039381E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [  -2.5169423751872733E-01,  -9.6495952599039381E-01,  -7.4183043886463282E-02,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,   9.6495952599039381E-01,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,   9.6495952599039381E-01,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,  -9.6495952599039381E-01,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,   9.6495952599039381E-01,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,  -9.6495952599039381E-01,   2.5169423751872733E-01,   4.1003460788885011E-03],
            [   7.4183043886463282E-02,  -9.6495952599039381E-01,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,   9.6495952599039381E-01,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [  -7.4183043886463282E-02,  -9.6495952599039381E-01,  -2.5169423751872733E-01,   4.1003460788885011E-03],
            [   3.0002279952571809E-01,   1.1505027457271860E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,   1.1505027457271860E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,  -1.1505027457271860E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,   1.1505027457271860E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,  -1.1505027457271860E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,  -1.1505027457271860E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,   1.1505027457271860E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,  -1.1505027457271860E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,   3.0002279952571809E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,   3.0002279952571809E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,  -3.0002279952571809E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,   3.0002279952571809E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,  -3.0002279952571809E-01,   9.4696871864148335E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,  -3.0002279952571809E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,   3.0002279952571809E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,  -3.0002279952571809E-01,  -9.4696871864148335E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,   3.0002279952571809E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,   3.0002279952571809E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,  -3.0002279952571809E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,   3.0002279952571809E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,  -3.0002279952571809E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,  -3.0002279952571809E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,   3.0002279952571809E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,  -3.0002279952571809E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,   1.1505027457271860E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,   1.1505027457271860E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,  -1.1505027457271860E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,   1.1505027457271860E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,  -1.1505027457271860E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   9.4696871864148335E-01,  -1.1505027457271860E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,   1.1505027457271860E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -9.4696871864148335E-01,  -1.1505027457271860E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,   9.4696871864148335E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,   9.4696871864148335E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,  -9.4696871864148335E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,   9.4696871864148335E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,  -9.4696871864148335E-01,   1.1505027457271860E-01,   4.3764077201567725E-03],
            [   3.0002279952571809E-01,  -9.4696871864148335E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,   9.4696871864148335E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [  -3.0002279952571809E-01,  -9.4696871864148335E-01,  -1.1505027457271860E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,   9.4696871864148335E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,   9.4696871864148335E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,  -9.4696871864148335E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,   9.4696871864148335E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,  -9.4696871864148335E-01,   3.0002279952571809E-01,   4.3764077201567725E-03],
            [   1.1505027457271860E-01,  -9.4696871864148335E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,   9.4696871864148335E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [  -1.1505027457271860E-01,  -9.4696871864148335E-01,  -3.0002279952571809E-01,   4.3764077201567725E-03],
            [   3.4748066910463421E-01,   1.5719633712093639E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,   1.5719633712093639E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,  -1.5719633712093639E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,   1.5719633712093639E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,  -1.5719633712093639E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,  -1.5719633712093639E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,   1.5719633712093639E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,  -1.5719633712093639E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,   3.4748066910463421E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,   3.4748066910463421E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,  -3.4748066910463421E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,   3.4748066910463421E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,  -3.4748066910463421E-01,   9.2441684114600409E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,  -3.4748066910463421E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,   3.4748066910463421E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,  -3.4748066910463421E-01,  -9.2441684114600409E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,   3.4748066910463421E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,   3.4748066910463421E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,  -3.4748066910463421E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,   3.4748066910463421E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,  -3.4748066910463421E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,  -3.4748066910463421E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,   3.4748066910463421E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,  -3.4748066910463421E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,   1.5719633712093639E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,   1.5719633712093639E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,  -1.5719633712093639E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,   1.5719633712093639E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,  -1.5719633712093639E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   9.2441684114600409E-01,  -1.5719633712093639E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,   1.5719633712093639E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -9.2441684114600409E-01,  -1.5719633712093639E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,   9.2441684114600409E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,   9.2441684114600409E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,  -9.2441684114600409E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,   9.2441684114600409E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,  -9.2441684114600409E-01,   1.5719633712093639E-01,   4.5950149089489349E-03],
            [   3.4748066910463421E-01,  -9.2441684114600409E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,   9.2441684114600409E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [  -3.4748066910463421E-01,  -9.2441684114600409E-01,  -1.5719633712093639E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,   9.2441684114600409E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,   9.2441684114600409E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,  -9.2441684114600409E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,   9.2441684114600409E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,  -9.2441684114600409E-01,   3.4748066910463421E-01,   4.5950149089489349E-03],
            [   1.5719633712093639E-01,  -9.2441684114600409E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,   9.2441684114600409E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [  -1.5719633712093639E-01,  -9.2441684114600409E-01,  -3.4748066910463421E-01,   4.5950149089489349E-03],
            [   3.9381031803592093E-01,   1.9996318772471000E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,   1.9996318772471000E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,  -1.9996318772471000E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,   1.9996318772471000E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,  -1.9996318772471000E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,  -1.9996318772471000E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,   1.9996318772471000E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,  -1.9996318772471000E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,   3.9381031803592093E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,   3.9381031803592093E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,  -3.9381031803592093E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,   3.9381031803592093E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,  -3.9381031803592093E-01,   8.9717788479399074E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,  -3.9381031803592093E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,   3.9381031803592093E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,  -3.9381031803592093E-01,  -8.9717788479399074E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,   3.9381031803592093E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,   3.9381031803592093E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,  -3.9381031803592093E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,   3.9381031803592093E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,  -3.9381031803592093E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,  -3.9381031803592093E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,   3.9381031803592093E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,  -3.9381031803592093E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,   1.9996318772471000E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,   1.9996318772471000E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,  -1.9996318772471000E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,   1.9996318772471000E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,  -1.9996318772471000E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   8.9717788479399074E-01,  -1.9996318772471000E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,   1.9996318772471000E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -8.9717788479399074E-01,  -1.9996318772471000E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,   8.9717788479399074E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,   8.9717788479399074E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,  -8.9717788479399074E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,   8.9717788479399074E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,  -8.9717788479399074E-01,   1.9996318772471000E-01,   4.7648415991765761E-03],
            [   3.9381031803592093E-01,  -8.9717788479399074E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,   8.9717788479399074E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [  -3.9381031803592093E-01,  -8.9717788479399074E-01,  -1.9996318772471000E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,   8.9717788479399074E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,   8.9717788479399074E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,  -8.9717788479399074E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,   8.9717788479399074E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,  -8.9717788479399074E-01,   3.9381031803592093E-01,   4.7648415991765761E-03],
            [   1.9996318772471000E-01,  -8.9717788479399074E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,   8.9717788479399074E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [  -1.9996318772471000E-01,  -8.9717788479399074E-01,  -3.9381031803592093E-01,   4.7648415991765761E-03],
            [   4.3875195904557029E-01,   2.4280734578465349E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,   2.4280734578465349E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,  -2.4280734578465349E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,   2.4280734578465349E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,  -2.4280734578465349E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,  -2.4280734578465349E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,   2.4280734578465349E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,  -2.4280734578465349E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,   4.3875195904557029E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,   4.3875195904557029E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,  -4.3875195904557029E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,   4.3875195904557029E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,  -4.3875195904557029E-01,   8.6518281956282850E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,  -4.3875195904557029E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,   4.3875195904557029E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,  -4.3875195904557029E-01,  -8.6518281956282850E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,   4.3875195904557029E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,   4.3875195904557029E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,  -4.3875195904557029E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,   4.3875195904557029E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,  -4.3875195904557029E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,  -4.3875195904557029E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,   4.3875195904557029E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,  -4.3875195904557029E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,   2.4280734578465349E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,   2.4280734578465349E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,  -2.4280734578465349E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,   2.4280734578465349E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,  -2.4280734578465349E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   8.6518281956282850E-01,  -2.4280734578465349E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,   2.4280734578465349E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -8.6518281956282850E-01,  -2.4280734578465349E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,   8.6518281956282850E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,   8.6518281956282850E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,  -8.6518281956282850E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,   8.6518281956282850E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,  -8.6518281956282850E-01,   2.4280734578465349E-01,   4.8933880085754011E-03],
            [   4.3875195904557029E-01,  -8.6518281956282850E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,   8.6518281956282850E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [  -4.3875195904557029E-01,  -8.6518281956282850E-01,  -2.4280734578465349E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,   8.6518281956282850E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,   8.6518281956282850E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,  -8.6518281956282850E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,   8.6518281956282850E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,  -8.6518281956282850E-01,   4.3875195904557029E-01,   4.8933880085754011E-03],
            [   2.4280734578465349E-01,  -8.6518281956282850E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,   8.6518281956282850E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [  -2.4280734578465349E-01,  -8.6518281956282850E-01,  -4.3875195904557029E-01,   4.8933880085754011E-03],
            [   4.8205039600777871E-01,   2.8525751329061549E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,   2.8525751329061549E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,  -2.8525751329061549E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,   2.8525751329061549E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,  -2.8525751329061549E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,  -2.8525751329061549E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,   2.8525751329061549E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,  -2.8525751329061549E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,   4.8205039600777871E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,   4.8205039600777871E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,  -4.8205039600777871E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,   4.8205039600777871E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,  -4.8205039600777871E-01,   8.2840543625690799E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,  -4.8205039600777871E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,   4.8205039600777871E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,  -4.8205039600777871E-01,  -8.2840543625690799E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,   4.8205039600777871E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,   4.8205039600777871E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,  -4.8205039600777871E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,   4.8205039600777871E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,  -4.8205039600777871E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,  -4.8205039600777871E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,   4.8205039600777871E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,  -4.8205039600777871E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,   2.8525751329061549E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,   2.8525751329061549E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,  -2.8525751329061549E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,   2.8525751329061549E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,  -2.8525751329061549E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   8.2840543625690799E-01,  -2.8525751329061549E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,   2.8525751329061549E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -8.2840543625690799E-01,  -2.8525751329061549E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,   8.2840543625690799E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,   8.2840543625690799E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,  -8.2840543625690799E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,   8.2840543625690799E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,  -8.2840543625690799E-01,   2.8525751329061549E-01,   4.9870901505294990E-03],
            [   4.8205039600777871E-01,  -8.2840543625690799E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,   8.2840543625690799E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [  -4.8205039600777871E-01,  -8.2840543625690799E-01,  -2.8525751329061549E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,   8.2840543625690799E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,   8.2840543625690799E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,  -8.2840543625690799E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,   8.2840543625690799E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,  -8.2840543625690799E-01,   4.8205039600777871E-01,   4.9870901505294990E-03],
            [   2.8525751329061549E-01,  -8.2840543625690799E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,   8.2840543625690799E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [  -2.8525751329061549E-01,  -8.2840543625690799E-01,  -4.8205039600777871E-01,   4.9870901505294990E-03],
            [   5.2345737784751012E-01,   3.2688842086746389E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,   3.2688842086746389E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,  -3.2688842086746389E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,   3.2688842086746389E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,  -3.2688842086746389E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,  -3.2688842086746389E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,   3.2688842086746389E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,  -3.2688842086746389E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,   5.2345737784751012E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,   5.2345737784751012E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,  -5.2345737784751012E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,   5.2345737784751012E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,  -5.2345737784751012E-01,   7.8685216774168254E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,  -5.2345737784751012E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,   5.2345737784751012E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,  -5.2345737784751012E-01,  -7.8685216774168254E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,   5.2345737784751012E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,   5.2345737784751012E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,  -5.2345737784751012E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,   5.2345737784751012E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,  -5.2345737784751012E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,  -5.2345737784751012E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,   5.2345737784751012E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,  -5.2345737784751012E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,   3.2688842086746389E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,   3.2688842086746389E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,  -3.2688842086746389E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,   3.2688842086746389E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,  -3.2688842086746389E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   7.8685216774168254E-01,  -3.2688842086746389E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,   3.2688842086746389E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -7.8685216774168254E-01,  -3.2688842086746389E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,   7.8685216774168254E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,   7.8685216774168254E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,  -7.8685216774168254E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,   7.8685216774168254E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,  -7.8685216774168254E-01,   3.2688842086746389E-01,   5.0515947206226071E-03],
            [   5.2345737784751012E-01,  -7.8685216774168254E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,   7.8685216774168254E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [  -5.2345737784751012E-01,  -7.8685216774168254E-01,  -3.2688842086746389E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,   7.8685216774168254E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,   7.8685216774168254E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,  -7.8685216774168254E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,   7.8685216774168254E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,  -7.8685216774168254E-01,   5.2345737784751012E-01,   5.0515947206226071E-03],
            [   3.2688842086746389E-01,  -7.8685216774168254E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,   7.8685216774168254E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [  -3.2688842086746389E-01,  -7.8685216774168254E-01,  -5.2345737784751012E-01,   5.0515947206226071E-03],
            [   5.6273186472352821E-01,   3.6730333216759392E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,   3.6730333216759392E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,  -3.6730333216759392E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,   3.6730333216759392E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,  -3.6730333216759392E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,  -3.6730333216759392E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,   3.6730333216759392E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,  -3.6730333216759392E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,   5.6273186472352821E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,   5.6273186472352821E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,  -5.6273186472352821E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,   5.6273186472352821E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,  -5.6273186472352821E-01,   7.4055459663914236E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,  -5.6273186472352821E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,   5.6273186472352821E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,  -5.6273186472352821E-01,  -7.4055459663914236E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,   5.6273186472352821E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,   5.6273186472352821E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,  -5.6273186472352821E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,   5.6273186472352821E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,  -5.6273186472352821E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,  -5.6273186472352821E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,   5.6273186472352821E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,  -5.6273186472352821E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,   3.6730333216759392E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,   3.6730333216759392E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,  -3.6730333216759392E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,   3.6730333216759392E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,  -3.6730333216759392E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   7.4055459663914236E-01,  -3.6730333216759392E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,   3.6730333216759392E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -7.4055459663914236E-01,  -3.6730333216759392E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,   7.4055459663914236E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,   7.4055459663914236E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,  -7.4055459663914236E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,   7.4055459663914236E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,  -7.4055459663914236E-01,   3.6730333216759392E-01,   5.0920300966573557E-03],
            [   5.6273186472352821E-01,  -7.4055459663914236E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,   7.4055459663914236E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [  -5.6273186472352821E-01,  -7.4055459663914236E-01,  -3.6730333216759392E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,   7.4055459663914236E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,   7.4055459663914236E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,  -7.4055459663914236E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,   7.4055459663914236E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,  -7.4055459663914236E-01,   5.6273186472352821E-01,   5.0920300966573557E-03],
            [   3.6730333216759392E-01,  -7.4055459663914236E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,   7.4055459663914236E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [  -3.6730333216759392E-01,  -7.4055459663914236E-01,  -5.6273186472352821E-01,   5.0920300966573557E-03],
            [   5.9963906071569539E-01,   4.0612115518302899E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,   4.0612115518302899E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,  -4.0612115518302899E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,   4.0612115518302899E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,  -4.0612115518302899E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,  -4.0612115518302899E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,   4.0612115518302899E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,  -4.0612115518302899E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,   5.9963906071569539E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,   5.9963906071569539E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,  -5.9963906071569539E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,   5.9963906071569539E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,  -5.9963906071569539E-01,   6.8956406821759553E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,  -5.9963906071569539E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,   5.9963906071569539E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,  -5.9963906071569539E-01,  -6.8956406821759553E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,   5.9963906071569539E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,   5.9963906071569539E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,  -5.9963906071569539E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,   5.9963906071569539E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,  -5.9963906071569539E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,  -5.9963906071569539E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,   5.9963906071569539E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,  -5.9963906071569539E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,   4.0612115518302899E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,   4.0612115518302899E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,  -4.0612115518302899E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,   4.0612115518302899E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,  -4.0612115518302899E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   6.8956406821759553E-01,  -4.0612115518302899E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,   4.0612115518302899E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -6.8956406821759553E-01,  -4.0612115518302899E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,   6.8956406821759553E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,   6.8956406821759553E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,  -6.8956406821759553E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,   6.8956406821759553E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,  -6.8956406821759553E-01,   4.0612115518302899E-01,   5.1132293284683267E-03],
            [   5.9963906071569539E-01,  -6.8956406821759553E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,   6.8956406821759553E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [  -5.9963906071569539E-01,  -6.8956406821759553E-01,  -4.0612115518302899E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,   6.8956406821759553E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,   6.8956406821759553E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,  -6.8956406821759553E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,   6.8956406821759553E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,  -6.8956406821759553E-01,   5.9963906071569539E-01,   5.1132293284683267E-03],
            [   4.0612115518302899E-01,  -6.8956406821759553E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,   6.8956406821759553E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [  -4.0612115518302899E-01,  -6.8956406821759553E-01,  -5.9963906071569539E-01,   5.1132293284683267E-03],
            [   3.0847807537919469E-01,   3.8601255231000588E-02,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,   3.8601255231000588E-02,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,  -3.8601255231000588E-02,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,   3.8601255231000588E-02,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,  -3.8601255231000588E-02,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,  -3.8601255231000588E-02,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,   3.8601255231000588E-02,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,  -3.8601255231000588E-02,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,   3.0847807537919469E-01,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,   3.0847807537919469E-01,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,  -3.0847807537919469E-01,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,   3.0847807537919469E-01,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,  -3.0847807537919469E-01,   9.5044790499266141E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,  -3.0847807537919469E-01,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,   3.0847807537919469E-01,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,  -3.0847807537919469E-01,  -9.5044790499266141E-01,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,   3.0847807537919469E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,   3.0847807537919469E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,  -3.0847807537919469E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,   3.0847807537919469E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,  -3.0847807537919469E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,  -3.0847807537919469E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,   3.0847807537919469E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,  -3.0847807537919469E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,   3.8601255231000588E-02,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,   3.8601255231000588E-02,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,  -3.8601255231000588E-02,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,   3.8601255231000588E-02,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,  -3.8601255231000588E-02,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   9.5044790499266141E-01,  -3.8601255231000588E-02,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,   3.8601255231000588E-02,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -9.5044790499266141E-01,  -3.8601255231000588E-02,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,   9.5044790499266141E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,   9.5044790499266141E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,  -9.5044790499266141E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,   9.5044790499266141E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,  -9.5044790499266141E-01,   3.8601255231000588E-02,   4.3407704268729136E-03],
            [   3.0847807537919469E-01,  -9.5044790499266141E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,   9.5044790499266141E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [  -3.0847807537919469E-01,  -9.5044790499266141E-01,  -3.8601255231000588E-02,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,   9.5044790499266141E-01,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,   9.5044790499266141E-01,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,  -9.5044790499266141E-01,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,   9.5044790499266141E-01,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,  -9.5044790499266141E-01,   3.0847807537919469E-01,   4.3407704268729136E-03],
            [   3.8601255231000588E-02,  -9.5044790499266141E-01,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,   9.5044790499266141E-01,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [  -3.8601255231000588E-02,  -9.5044790499266141E-01,  -3.0847807537919469E-01,   4.3407704268729136E-03],
            [   3.5899882759202228E-01,   7.9289389871048666E-02,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,   7.9289389871048666E-02,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,  -7.9289389871048666E-02,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,   7.9289389871048666E-02,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,  -7.9289389871048666E-02,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,  -7.9289389871048666E-02,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,   7.9289389871048666E-02,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,  -7.9289389871048666E-02,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,   3.5899882759202228E-01,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,   3.5899882759202228E-01,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,  -3.5899882759202228E-01,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,   3.5899882759202228E-01,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,  -3.5899882759202228E-01,   9.2996399631460480E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,  -3.5899882759202228E-01,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,   3.5899882759202228E-01,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,  -3.5899882759202228E-01,  -9.2996399631460480E-01,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,   3.5899882759202228E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,   3.5899882759202228E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,  -3.5899882759202228E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,   3.5899882759202228E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,  -3.5899882759202228E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,  -3.5899882759202228E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,   3.5899882759202228E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,  -3.5899882759202228E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,   7.9289389871048666E-02,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,   7.9289389871048666E-02,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,  -7.9289389871048666E-02,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,   7.9289389871048666E-02,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,  -7.9289389871048666E-02,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   9.2996399631460480E-01,  -7.9289389871048666E-02,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,   7.9289389871048666E-02,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -9.2996399631460480E-01,  -7.9289389871048666E-02,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,   9.2996399631460480E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,   9.2996399631460480E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,  -9.2996399631460480E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,   9.2996399631460480E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,  -9.2996399631460480E-01,   7.9289389871048666E-02,   4.5615467122651606E-03],
            [   3.5899882759202228E-01,  -9.2996399631460480E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,   9.2996399631460480E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [  -3.5899882759202228E-01,  -9.2996399631460480E-01,  -7.9289389871048666E-02,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,   9.2996399631460480E-01,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,   9.2996399631460480E-01,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,  -9.2996399631460480E-01,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,   9.2996399631460480E-01,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,  -9.2996399631460480E-01,   3.5899882759202228E-01,   4.5615467122651606E-03],
            [   7.9289389871048666E-02,  -9.2996399631460480E-01,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,   9.2996399631460480E-01,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [  -7.9289389871048666E-02,  -9.2996399631460480E-01,  -3.5899882759202228E-01,   4.5615467122651606E-03],
            [   4.0786284158819730E-01,   1.2126146430300870E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,   1.2126146430300870E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,  -1.2126146430300870E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,   1.2126146430300870E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,  -1.2126146430300870E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,  -1.2126146430300870E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,   1.2126146430300870E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,  -1.2126146430300870E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,   4.0786284158819730E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,   4.0786284158819730E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,  -4.0786284158819730E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,   4.0786284158819730E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,  -4.0786284158819730E-01,   9.0495500425528963E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,  -4.0786284158819730E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,   4.0786284158819730E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,  -4.0786284158819730E-01,  -9.0495500425528963E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,   4.0786284158819730E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,   4.0786284158819730E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,  -4.0786284158819730E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,   4.0786284158819730E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,  -4.0786284158819730E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,  -4.0786284158819730E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,   4.0786284158819730E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,  -4.0786284158819730E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,   1.2126146430300870E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,   1.2126146430300870E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,  -1.2126146430300870E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,   1.2126146430300870E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,  -1.2126146430300870E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   9.0495500425528963E-01,  -1.2126146430300870E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,   1.2126146430300870E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -9.0495500425528963E-01,  -1.2126146430300870E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,   9.0495500425528963E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,   9.0495500425528963E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,  -9.0495500425528963E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,   9.0495500425528963E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,  -9.0495500425528963E-01,   1.2126146430300870E-01,   4.7377570066585795E-03],
            [   4.0786284158819730E-01,  -9.0495500425528963E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,   9.0495500425528963E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [  -4.0786284158819730E-01,  -9.0495500425528963E-01,  -1.2126146430300870E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,   9.0495500425528963E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,   9.0495500425528963E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,  -9.0495500425528963E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,   9.0495500425528963E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,  -9.0495500425528963E-01,   4.0786284158819730E-01,   4.7377570066585795E-03],
            [   1.2126146430300870E-01,  -9.0495500425528963E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,   9.0495500425528963E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [  -1.2126146430300870E-01,  -9.0495500425528963E-01,  -4.0786284158819730E-01,   4.7377570066585795E-03],
            [   4.5492872588897348E-01,   1.6387708273826929E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,   1.6387708273826929E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,  -1.6387708273826929E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,   1.6387708273826929E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,  -1.6387708273826929E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,  -1.6387708273826929E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,   1.6387708273826929E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,  -1.6387708273826929E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,   4.5492872588897348E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,   4.5492872588897348E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,  -4.5492872588897348E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,   4.5492872588897348E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,  -4.5492872588897348E-01,   8.7531945946278933E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,  -4.5492872588897348E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,   4.5492872588897348E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,  -4.5492872588897348E-01,  -8.7531945946278933E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,   4.5492872588897348E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,   4.5492872588897348E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,  -4.5492872588897348E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,   4.5492872588897348E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,  -4.5492872588897348E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,  -4.5492872588897348E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,   4.5492872588897348E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,  -4.5492872588897348E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,   1.6387708273826929E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,   1.6387708273826929E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,  -1.6387708273826929E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,   1.6387708273826929E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,  -1.6387708273826929E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   8.7531945946278933E-01,  -1.6387708273826929E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,   1.6387708273826929E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -8.7531945946278933E-01,  -1.6387708273826929E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,   8.7531945946278933E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,   8.7531945946278933E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,  -8.7531945946278933E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,   8.7531945946278933E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,  -8.7531945946278933E-01,   1.6387708273826929E-01,   4.8740033307729403E-03],
            [   4.5492872588897348E-01,  -8.7531945946278933E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,   8.7531945946278933E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [  -4.5492872588897348E-01,  -8.7531945946278933E-01,  -1.6387708273826929E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,   8.7531945946278933E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,   8.7531945946278933E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,  -8.7531945946278933E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,   8.7531945946278933E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,  -8.7531945946278933E-01,   4.5492872588897348E-01,   4.8740033307729403E-03],
            [   1.6387708273826929E-01,  -8.7531945946278933E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,   8.7531945946278933E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [  -1.6387708273826929E-01,  -8.7531945946278933E-01,  -4.5492872588897348E-01,   4.8740033307729403E-03],
            [   5.0002785129572791E-01,   2.0659657982601759E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,   2.0659657982601759E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,  -2.0659657982601759E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,   2.0659657982601759E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,  -2.0659657982601759E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,  -2.0659657982601759E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,   2.0659657982601759E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,  -2.0659657982601759E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,   5.0002785129572791E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,   5.0002785129572791E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,  -5.0002785129572791E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,   5.0002785129572791E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,  -5.0002785129572791E-01,   8.4100535142932908E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,  -5.0002785129572791E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,   5.0002785129572791E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,  -5.0002785129572791E-01,  -8.4100535142932908E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,   5.0002785129572791E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,   5.0002785129572791E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,  -5.0002785129572791E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,   5.0002785129572791E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,  -5.0002785129572791E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,  -5.0002785129572791E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,   5.0002785129572791E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,  -5.0002785129572791E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,   2.0659657982601759E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,   2.0659657982601759E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,  -2.0659657982601759E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,   2.0659657982601759E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,  -2.0659657982601759E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   8.4100535142932908E-01,  -2.0659657982601759E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,   2.0659657982601759E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -8.4100535142932908E-01,  -2.0659657982601759E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,   8.4100535142932908E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,   8.4100535142932908E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,  -8.4100535142932908E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,   8.4100535142932908E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,  -8.4100535142932908E-01,   2.0659657982601759E-01,   4.9751081472038574E-03],
            [   5.0002785129572791E-01,  -8.4100535142932908E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,   8.4100535142932908E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [  -5.0002785129572791E-01,  -8.4100535142932908E-01,  -2.0659657982601759E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,   8.4100535142932908E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,   8.4100535142932908E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,  -8.4100535142932908E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,   8.4100535142932908E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,  -8.4100535142932908E-01,   5.0002785129572791E-01,   4.9751081472038574E-03],
            [   2.0659657982601759E-01,  -8.4100535142932908E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,   8.4100535142932908E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [  -2.0659657982601759E-01,  -8.4100535142932908E-01,  -5.0002785129572791E-01,   4.9751081472038574E-03],
            [   5.4297850449281992E-01,   2.4894363788522350E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,   2.4894363788522350E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,  -2.4894363788522350E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,   2.4894363788522350E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,  -2.4894363788522350E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,  -2.4894363788522350E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,   2.4894363788522350E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,  -2.4894363788522350E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,   5.4297850449281992E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,   5.4297850449281992E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,  -5.4297850449281992E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,   5.4297850449281992E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,  -5.4297850449281992E-01,   8.0199838454650985E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,  -5.4297850449281992E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,   5.4297850449281992E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,  -5.4297850449281992E-01,  -8.0199838454650985E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,   5.4297850449281992E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,   5.4297850449281992E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,  -5.4297850449281992E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,   5.4297850449281992E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,  -5.4297850449281992E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,  -5.4297850449281992E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,   5.4297850449281992E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,  -5.4297850449281992E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,   2.4894363788522350E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,   2.4894363788522350E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,  -2.4894363788522350E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,   2.4894363788522350E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,  -2.4894363788522350E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   8.0199838454650985E-01,  -2.4894363788522350E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,   2.4894363788522350E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -8.0199838454650985E-01,  -2.4894363788522350E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,   8.0199838454650985E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,   8.0199838454650985E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,  -8.0199838454650985E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,   8.0199838454650985E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,  -8.0199838454650985E-01,   2.4894363788522350E-01,   5.0457584256684528E-03],
            [   5.4297850449281992E-01,  -8.0199838454650985E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,   8.0199838454650985E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [  -5.4297850449281992E-01,  -8.0199838454650985E-01,  -2.4894363788522350E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,   8.0199838454650985E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,   8.0199838454650985E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,  -8.0199838454650985E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,   8.0199838454650985E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,  -8.0199838454650985E-01,   5.4297850449281992E-01,   5.0457584256684528E-03],
            [   2.4894363788522350E-01,  -8.0199838454650985E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,   8.0199838454650985E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [  -2.4894363788522350E-01,  -8.0199838454650985E-01,  -5.4297850449281992E-01,   5.0457584256684528E-03],
            [   5.8359398504917115E-01,   2.9048113689468907E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,   2.9048113689468907E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,  -2.9048113689468907E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,   2.9048113689468907E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,  -2.9048113689468907E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,  -2.9048113689468907E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,   2.9048113689468907E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,  -2.9048113689468907E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,   5.8359398504917115E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,   5.8359398504917115E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,  -5.8359398504917115E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,   5.8359398504917115E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,  -5.8359398504917115E-01,   7.5831310797242368E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,  -5.8359398504917115E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,   5.8359398504917115E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,  -5.8359398504917115E-01,  -7.5831310797242368E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,   5.8359398504917115E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,   5.8359398504917115E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,  -5.8359398504917115E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,   5.8359398504917115E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,  -5.8359398504917115E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,  -5.8359398504917115E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,   5.8359398504917115E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,  -5.8359398504917115E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,   2.9048113689468907E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,   2.9048113689468907E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,  -2.9048113689468907E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,   2.9048113689468907E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,  -2.9048113689468907E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   7.5831310797242368E-01,  -2.9048113689468907E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,   2.9048113689468907E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -7.5831310797242368E-01,  -2.9048113689468907E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,   7.5831310797242368E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,   7.5831310797242368E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,  -7.5831310797242368E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,   7.5831310797242368E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,  -7.5831310797242368E-01,   2.9048113689468907E-01,   5.0904693337432373E-03],
            [   5.8359398504917115E-01,  -7.5831310797242368E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,   7.5831310797242368E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [  -5.8359398504917115E-01,  -7.5831310797242368E-01,  -2.9048113689468907E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,   7.5831310797242368E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,   7.5831310797242368E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,  -7.5831310797242368E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,   7.5831310797242368E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,  -7.5831310797242368E-01,   5.8359398504917115E-01,   5.0904693337432373E-03],
            [   2.9048113689468907E-01,  -7.5831310797242368E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,   7.5831310797242368E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [  -2.9048113689468907E-01,  -7.5831310797242368E-01,  -5.8359398504917115E-01,   5.0904693337432373E-03],
            [   6.2168703534448555E-01,   3.3079419576666091E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,   3.3079419576666091E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,  -3.3079419576666091E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,   3.3079419576666091E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,  -3.3079419576666091E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,  -3.3079419576666091E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,   3.3079419576666091E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,  -3.3079419576666091E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,   6.2168703534448555E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,   6.2168703534448555E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,  -6.2168703534448555E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,   6.2168703534448555E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,  -6.2168703534448555E-01,   7.0998621826882835E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,  -6.2168703534448555E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,   6.2168703534448555E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,  -6.2168703534448555E-01,  -7.0998621826882835E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,   6.2168703534448555E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,   6.2168703534448555E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,  -6.2168703534448555E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,   6.2168703534448555E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,  -6.2168703534448555E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,  -6.2168703534448555E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,   6.2168703534448555E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,  -6.2168703534448555E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,   3.3079419576666091E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,   3.3079419576666091E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,  -3.3079419576666091E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,   3.3079419576666091E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,  -3.3079419576666091E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   7.0998621826882835E-01,  -3.3079419576666091E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,   3.3079419576666091E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -7.0998621826882835E-01,  -3.3079419576666091E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,   7.0998621826882835E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,   7.0998621826882835E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,  -7.0998621826882835E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,   7.0998621826882835E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,  -7.0998621826882835E-01,   3.3079419576666091E-01,   5.1136585593854990E-03],
            [   6.2168703534448555E-01,  -7.0998621826882835E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,   7.0998621826882835E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [  -6.2168703534448555E-01,  -7.0998621826882835E-01,  -3.3079419576666091E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,   7.0998621826882835E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,   7.0998621826882835E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,  -7.0998621826882835E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,   7.0998621826882835E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,  -7.0998621826882835E-01,   6.2168703534448555E-01,   5.1136585593854990E-03],
            [   3.3079419576666091E-01,  -7.0998621826882835E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,   7.0998621826882835E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [  -3.3079419576666091E-01,  -7.0998621826882835E-01,  -6.2168703534448555E-01,   5.1136585593854990E-03],
            [   4.1511046627090908E-01,   4.0648291460525537E-02,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,   4.0648291460525537E-02,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,  -4.0648291460525537E-02,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,   4.0648291460525537E-02,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,  -4.0648291460525537E-02,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,  -4.0648291460525537E-02,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,   4.0648291460525537E-02,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,  -4.0648291460525537E-02,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,   4.1511046627090908E-01,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,   4.1511046627090908E-01,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,  -4.1511046627090908E-01,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,   4.1511046627090908E-01,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,  -4.1511046627090908E-01,   9.0886248530439884E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,  -4.1511046627090908E-01,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,   4.1511046627090908E-01,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,  -4.1511046627090908E-01,  -9.0886248530439884E-01,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,   4.1511046627090908E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,   4.1511046627090908E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,  -4.1511046627090908E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,   4.1511046627090908E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,  -4.1511046627090908E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,  -4.1511046627090908E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,   4.1511046627090908E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,  -4.1511046627090908E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,   4.0648291460525537E-02,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,   4.0648291460525537E-02,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,  -4.0648291460525537E-02,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,   4.0648291460525537E-02,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,  -4.0648291460525537E-02,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   9.0886248530439884E-01,  -4.0648291460525537E-02,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,   4.0648291460525537E-02,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -9.0886248530439884E-01,  -4.0648291460525537E-02,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,   9.0886248530439884E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,   9.0886248530439884E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,  -9.0886248530439884E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,   9.0886248530439884E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,  -9.0886248530439884E-01,   4.0648291460525537E-02,   4.7251073589234189E-03],
            [   4.1511046627090908E-01,  -9.0886248530439884E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,   9.0886248530439884E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [  -4.1511046627090908E-01,  -9.0886248530439884E-01,  -4.0648291460525537E-02,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,   9.0886248530439884E-01,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,   9.0886248530439884E-01,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,  -9.0886248530439884E-01,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,   9.0886248530439884E-01,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,  -9.0886248530439884E-01,   4.1511046627090908E-01,   4.7251073589234189E-03],
            [   4.0648291460525537E-02,  -9.0886248530439884E-01,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,   9.0886248530439884E-01,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [  -4.0648291460525537E-02,  -9.0886248530439884E-01,  -4.1511046627090908E-01,   4.7251073589234189E-03],
            [   4.6498042750092178E-01,   8.2584245472947557E-02,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,   8.2584245472947557E-02,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,  -8.2584245472947557E-02,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,   8.2584245472947557E-02,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,  -8.2584245472947557E-02,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,  -8.2584245472947557E-02,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,   8.2584245472947557E-02,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,  -8.2584245472947557E-02,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,   4.6498042750092178E-01,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,   4.6498042750092178E-01,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,  -4.6498042750092178E-01,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,   4.6498042750092178E-01,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,  -4.6498042750092178E-01,   8.8146074469639546E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,  -4.6498042750092178E-01,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,   4.6498042750092178E-01,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,  -4.6498042750092178E-01,  -8.8146074469639546E-01,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,   4.6498042750092178E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,   4.6498042750092178E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,  -4.6498042750092178E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,   4.6498042750092178E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,  -4.6498042750092178E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,  -4.6498042750092178E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,   4.6498042750092178E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,  -4.6498042750092178E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,   8.2584245472947557E-02,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,   8.2584245472947557E-02,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,  -8.2584245472947557E-02,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,   8.2584245472947557E-02,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,  -8.2584245472947557E-02,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.8146074469639546E-01,  -8.2584245472947557E-02,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,   8.2584245472947557E-02,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.8146074469639546E-01,  -8.2584245472947557E-02,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,   8.8146074469639546E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,   8.8146074469639546E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,  -8.8146074469639546E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,   8.8146074469639546E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,  -8.8146074469639546E-01,   8.2584245472947557E-02,   4.8644038183381887E-03],
            [   4.6498042750092178E-01,  -8.8146074469639546E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,   8.8146074469639546E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [  -4.6498042750092178E-01,  -8.8146074469639546E-01,  -8.2584245472947557E-02,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,   8.8146074469639546E-01,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,   8.8146074469639546E-01,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,  -8.8146074469639546E-01,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,   8.8146074469639546E-01,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,  -8.8146074469639546E-01,   4.6498042750092178E-01,   4.8644038183381887E-03],
            [   8.2584245472947557E-02,  -8.8146074469639546E-01,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,   8.8146074469639546E-01,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [  -8.2584245472947557E-02,  -8.8146074469639546E-01,  -4.6498042750092178E-01,   4.8644038183381887E-03],
            [   5.1246957570096618E-01,   1.2518419620272889E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,   1.2518419620272889E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,  -1.2518419620272889E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,   1.2518419620272889E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,  -1.2518419620272889E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,  -1.2518419620272889E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,   1.2518419620272889E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,  -1.2518419620272889E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,   5.1246957570096618E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,   5.1246957570096618E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,  -5.1246957570096618E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,   5.1246957570096618E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,  -5.1246957570096618E-01,   8.4953154797332187E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,  -5.1246957570096618E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,   5.1246957570096618E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,  -5.1246957570096618E-01,  -8.4953154797332187E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,   5.1246957570096618E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,   5.1246957570096618E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,  -5.1246957570096618E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,   5.1246957570096618E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,  -5.1246957570096618E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,  -5.1246957570096618E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,   5.1246957570096618E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,  -5.1246957570096618E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,   1.2518419620272889E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,   1.2518419620272889E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,  -1.2518419620272889E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,   1.2518419620272889E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,  -1.2518419620272889E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   8.4953154797332187E-01,  -1.2518419620272889E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,   1.2518419620272889E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -8.4953154797332187E-01,  -1.2518419620272889E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,   8.4953154797332187E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,   8.4953154797332187E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,  -8.4953154797332187E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,   8.4953154797332187E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,  -8.4953154797332187E-01,   1.2518419620272889E-01,   4.9703612262300767E-03],
            [   5.1246957570096618E-01,  -8.4953154797332187E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,   8.4953154797332187E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [  -5.1246957570096618E-01,  -8.4953154797332187E-01,  -1.2518419620272889E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,   8.4953154797332187E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,   8.4953154797332187E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,  -8.4953154797332187E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,   8.4953154797332187E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,  -8.4953154797332187E-01,   5.1246957570096618E-01,   4.9703612262300767E-03],
            [   1.2518419620272889E-01,  -8.4953154797332187E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,   8.4953154797332187E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [  -1.2518419620272889E-01,  -8.4953154797332187E-01,  -5.1246957570096618E-01,   4.9703612262300767E-03],
            [   5.5747111006062244E-01,   1.6791075059763311E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,   1.6791075059763311E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,  -1.6791075059763311E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,   1.6791075059763311E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,  -1.6791075059763311E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,  -1.6791075059763311E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,   1.6791075059763311E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,  -1.6791075059763311E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,   5.5747111006062244E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,   5.5747111006062244E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,  -5.5747111006062244E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,   5.5747111006062244E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,  -5.5747111006062244E-01,   8.1303870835373937E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,  -5.5747111006062244E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,   5.5747111006062244E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,  -5.5747111006062244E-01,  -8.1303870835373937E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,   5.5747111006062244E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,   5.5747111006062244E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,  -5.5747111006062244E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,   5.5747111006062244E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,  -5.5747111006062244E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,  -5.5747111006062244E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,   5.5747111006062244E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,  -5.5747111006062244E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,   1.6791075059763311E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,   1.6791075059763311E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,  -1.6791075059763311E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,   1.6791075059763311E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,  -1.6791075059763311E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   8.1303870835373937E-01,  -1.6791075059763311E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,   1.6791075059763311E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -8.1303870835373937E-01,  -1.6791075059763311E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,   8.1303870835373937E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,   8.1303870835373937E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,  -8.1303870835373937E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,   8.1303870835373937E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,  -8.1303870835373937E-01,   1.6791075059763311E-01,   5.0458525928210925E-03],
            [   5.5747111006062244E-01,  -8.1303870835373937E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,   8.1303870835373937E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [  -5.5747111006062244E-01,  -8.1303870835373937E-01,  -1.6791075059763311E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,   8.1303870835373937E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,   8.1303870835373937E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,  -8.1303870835373937E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,   8.1303870835373937E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,  -8.1303870835373937E-01,   5.5747111006062244E-01,   5.0458525928210925E-03],
            [   1.6791075059763311E-01,  -8.1303870835373937E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,   8.1303870835373937E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [  -1.6791075059763311E-01,  -8.1303870835373937E-01,  -5.5747111006062244E-01,   5.0458525928210925E-03],
            [   5.9985973332872267E-01,   2.1028050573587151E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,   2.1028050573587151E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,  -2.1028050573587151E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,   2.1028050573587151E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,  -2.1028050573587151E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,  -2.1028050573587151E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,   2.1028050573587151E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,  -2.1028050573587151E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,   5.9985973332872267E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,   5.9985973332872267E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,  -5.9985973332872267E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,   5.9985973332872267E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,  -5.9985973332872267E-01,   7.7197824401874160E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,  -5.9985973332872267E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,   5.9985973332872267E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,  -5.9985973332872267E-01,  -7.7197824401874160E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,   5.9985973332872267E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,   5.9985973332872267E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,  -5.9985973332872267E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,   5.9985973332872267E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,  -5.9985973332872267E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,  -5.9985973332872267E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,   5.9985973332872267E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,  -5.9985973332872267E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,   2.1028050573587151E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,   2.1028050573587151E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,  -2.1028050573587151E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,   2.1028050573587151E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,  -2.1028050573587151E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   7.7197824401874160E-01,  -2.1028050573587151E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,   2.1028050573587151E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -7.7197824401874160E-01,  -2.1028050573587151E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,   7.7197824401874160E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,   7.7197824401874160E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,  -7.7197824401874160E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,   7.7197824401874160E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,  -7.7197824401874160E-01,   2.1028050573587151E-01,   5.0942017985314862E-03],
            [   5.9985973332872267E-01,  -7.7197824401874160E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,   7.7197824401874160E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [  -5.9985973332872267E-01,  -7.7197824401874160E-01,  -2.1028050573587151E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,   7.7197824401874160E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,   7.7197824401874160E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,  -7.7197824401874160E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,   7.7197824401874160E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,  -7.7197824401874160E-01,   5.9985973332872267E-01,   5.0942017985314862E-03],
            [   2.1028050573587151E-01,  -7.7197824401874160E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,   7.7197824401874160E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [  -2.1028050573587151E-01,  -7.7197824401874160E-01,  -5.9985973332872267E-01,   5.0942017985314862E-03],
            [   6.3950071485166005E-01,   2.5184180877741069E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,   2.5184180877741069E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,  -2.5184180877741069E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,   2.5184180877741069E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,  -2.5184180877741069E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,  -2.5184180877741069E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,   2.5184180877741069E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,  -2.5184180877741069E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,   6.3950071485166005E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,   6.3950071485166005E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,  -6.3950071485166005E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,   6.3950071485166005E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,  -6.3950071485166005E-01,   7.2637079997473597E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,  -6.3950071485166005E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,   6.3950071485166005E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,  -6.3950071485166005E-01,  -7.2637079997473597E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,   6.3950071485166005E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,   6.3950071485166005E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,  -6.3950071485166005E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,   6.3950071485166005E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,  -6.3950071485166005E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,  -6.3950071485166005E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,   6.3950071485166005E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,  -6.3950071485166005E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,   2.5184180877741069E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,   2.5184180877741069E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,  -2.5184180877741069E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,   2.5184180877741069E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,  -2.5184180877741069E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   7.2637079997473597E-01,  -2.5184180877741069E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,   2.5184180877741069E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -7.2637079997473597E-01,  -2.5184180877741069E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,   7.2637079997473597E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,   7.2637079997473597E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,  -7.2637079997473597E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,   7.2637079997473597E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,  -7.2637079997473597E-01,   2.5184180877741069E-01,   5.1190099335426242E-03],
            [   6.3950071485166005E-01,  -7.2637079997473597E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,   7.2637079997473597E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [  -6.3950071485166005E-01,  -7.2637079997473597E-01,  -2.5184180877741069E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,   7.2637079997473597E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,   7.2637079997473597E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,  -7.2637079997473597E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,   7.2637079997473597E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,  -7.2637079997473597E-01,   6.3950071485166005E-01,   5.1190099335426242E-03],
            [   2.5184180877741069E-01,  -7.2637079997473597E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,   7.2637079997473597E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [  -2.5184180877741069E-01,  -7.2637079997473597E-01,  -6.3950071485166005E-01,   5.1190099335426242E-03],
            [   5.1884562247462518E-01,   4.1943216760775177E-02,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,   4.1943216760775177E-02,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,  -4.1943216760775177E-02,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,   4.1943216760775177E-02,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,  -4.1943216760775177E-02,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,  -4.1943216760775177E-02,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,   4.1943216760775177E-02,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,  -4.1943216760775177E-02,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,   5.1884562247462518E-01,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,   5.1884562247462518E-01,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,  -5.1884562247462518E-01,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,   5.1884562247462518E-01,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,  -5.1884562247462518E-01,   8.5383838436010673E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,  -5.1884562247462518E-01,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,   5.1884562247462518E-01,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,  -5.1884562247462518E-01,  -8.5383838436010673E-01,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,   5.1884562247462518E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,   5.1884562247462518E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,  -5.1884562247462518E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,   5.1884562247462518E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,  -5.1884562247462518E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,  -5.1884562247462518E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,   5.1884562247462518E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,  -5.1884562247462518E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,   4.1943216760775177E-02,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,   4.1943216760775177E-02,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,  -4.1943216760775177E-02,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,   4.1943216760775177E-02,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,  -4.1943216760775177E-02,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   8.5383838436010673E-01,  -4.1943216760775177E-02,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,   4.1943216760775177E-02,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -8.5383838436010673E-01,  -4.1943216760775177E-02,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,   8.5383838436010673E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,   8.5383838436010673E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,  -8.5383838436010673E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,   8.5383838436010673E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,  -8.5383838436010673E-01,   4.1943216760775177E-02,   4.9695325855484383E-03],
            [   5.1884562247462518E-01,  -8.5383838436010673E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,   8.5383838436010673E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [  -5.1884562247462518E-01,  -8.5383838436010673E-01,  -4.1943216760775177E-02,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,   8.5383838436010673E-01,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,   8.5383838436010673E-01,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,  -8.5383838436010673E-01,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,   8.5383838436010673E-01,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,  -8.5383838436010673E-01,   5.1884562247462518E-01,   4.9695325855484383E-03],
            [   4.1943216760775177E-02,  -8.5383838436010673E-01,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,   8.5383838436010673E-01,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [  -4.1943216760775177E-02,  -8.5383838436010673E-01,  -5.1884562247462518E-01,   4.9695325855484383E-03],
            [   5.6641907079427778E-01,   8.4576615519214984E-02,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,   8.4576615519214984E-02,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,  -8.4576615519214984E-02,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,   8.4576615519214984E-02,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,  -8.4576615519214984E-02,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,  -8.4576615519214984E-02,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,   8.4576615519214984E-02,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,  -8.4576615519214984E-02,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,   5.6641907079427778E-01,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,   5.6641907079427778E-01,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,  -5.6641907079427778E-01,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,   5.6641907079427778E-01,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,  -5.6641907079427778E-01,   8.1976596193539397E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,  -5.6641907079427778E-01,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,   5.6641907079427778E-01,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,  -5.6641907079427778E-01,  -8.1976596193539397E-01,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,   5.6641907079427778E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,   5.6641907079427778E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,  -5.6641907079427778E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,   5.6641907079427778E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,  -5.6641907079427778E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,  -5.6641907079427778E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,   5.6641907079427778E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,  -5.6641907079427778E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,   8.4576615519214984E-02,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,   8.4576615519214984E-02,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,  -8.4576615519214984E-02,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,   8.4576615519214984E-02,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,  -8.4576615519214984E-02,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.1976596193539397E-01,  -8.4576615519214984E-02,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,   8.4576615519214984E-02,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.1976596193539397E-01,  -8.4576615519214984E-02,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,   8.1976596193539397E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,   8.1976596193539397E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,  -8.1976596193539397E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,   8.1976596193539397E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,  -8.1976596193539397E-01,   8.4576615519214984E-02,   5.0487222461293706E-03],
            [   5.6641907079427778E-01,  -8.1976596193539397E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,   8.1976596193539397E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [  -5.6641907079427778E-01,  -8.1976596193539397E-01,  -8.4576615519214984E-02,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,   8.1976596193539397E-01,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,   8.1976596193539397E-01,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,  -8.1976596193539397E-01,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,   8.1976596193539397E-01,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,  -8.1976596193539397E-01,   5.6641907079427778E-01,   5.0487222461293706E-03],
            [   8.4576615519214984E-02,  -8.1976596193539397E-01,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,   8.1976596193539397E-01,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [  -8.4576615519214984E-02,  -8.1976596193539397E-01,  -5.6641907079427778E-01,   5.0487222461293706E-03],
            [   6.1104643532831526E-01,   1.2736529325193960E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,   1.2736529325193960E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,  -1.2736529325193960E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,   1.2736529325193960E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,  -1.2736529325193960E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,  -1.2736529325193960E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,   1.2736529325193960E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,  -1.2736529325193960E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,   6.1104643532831526E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,   6.1104643532831526E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,  -6.1104643532831526E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,   6.1104643532831526E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,  -6.1104643532831526E-01,   7.8128121438276399E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,  -6.1104643532831526E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,   6.1104643532831526E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,  -6.1104643532831526E-01,  -7.8128121438276399E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,   6.1104643532831526E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,   6.1104643532831526E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,  -6.1104643532831526E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,   6.1104643532831526E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,  -6.1104643532831526E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,  -6.1104643532831526E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,   6.1104643532831526E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,  -6.1104643532831526E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,   1.2736529325193960E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,   1.2736529325193960E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,  -1.2736529325193960E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,   1.2736529325193960E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,  -1.2736529325193960E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   7.8128121438276399E-01,  -1.2736529325193960E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,   1.2736529325193960E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -7.8128121438276399E-01,  -1.2736529325193960E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,   7.8128121438276399E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,   7.8128121438276399E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,  -7.8128121438276399E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,   7.8128121438276399E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,  -7.8128121438276399E-01,   1.2736529325193960E-01,   5.1007279696083669E-03],
            [   6.1104643532831526E-01,  -7.8128121438276399E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,   7.8128121438276399E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [  -6.1104643532831526E-01,  -7.8128121438276399E-01,  -1.2736529325193960E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,   7.8128121438276399E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,   7.8128121438276399E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,  -7.8128121438276399E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,   7.8128121438276399E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,  -7.8128121438276399E-01,   6.1104643532831526E-01,   5.1007279696083669E-03],
            [   1.2736529325193960E-01,  -7.8128121438276399E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,   7.8128121438276399E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [  -1.2736529325193960E-01,  -7.8128121438276399E-01,  -6.1104643532831526E-01,   5.1007279696083669E-03],
            [   6.5264303020515635E-01,   1.6981732390763540E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,   1.6981732390763540E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,  -1.6981732390763540E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,   1.6981732390763540E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,  -1.6981732390763540E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,  -1.6981732390763540E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,   1.6981732390763540E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,  -1.6981732390763540E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,   6.5264303020515635E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,   6.5264303020515635E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,  -6.5264303020515635E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,   6.5264303020515635E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,  -6.5264303020515635E-01,   7.3838956630323582E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,  -6.5264303020515635E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,   6.5264303020515635E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,  -6.5264303020515635E-01,  -7.3838956630323582E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,   6.5264303020515635E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,   6.5264303020515635E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,  -6.5264303020515635E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,   6.5264303020515635E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,  -6.5264303020515635E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,  -6.5264303020515635E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,   6.5264303020515635E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,  -6.5264303020515635E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,   1.6981732390763540E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,   1.6981732390763540E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,  -1.6981732390763540E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,   1.6981732390763540E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,  -1.6981732390763540E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   7.3838956630323582E-01,  -1.6981732390763540E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,   1.6981732390763540E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -7.3838956630323582E-01,  -1.6981732390763540E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,   7.3838956630323582E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,   7.3838956630323582E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,  -7.3838956630323582E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,   7.3838956630323582E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,  -7.3838956630323582E-01,   1.6981732390763540E-01,   5.1277902278269545E-03],
            [   6.5264303020515635E-01,  -7.3838956630323582E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,   7.3838956630323582E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [  -6.5264303020515635E-01,  -7.3838956630323582E-01,  -1.6981732390763540E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,   7.3838956630323582E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,   7.3838956630323582E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,  -7.3838956630323582E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,   7.3838956630323582E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,  -7.3838956630323582E-01,   6.5264303020515635E-01,   5.1277902278269545E-03],
            [   1.6981732390763540E-01,  -7.3838956630323582E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,   7.3838956630323582E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [  -1.6981732390763540E-01,  -7.3838956630323582E-01,  -6.5264303020515635E-01,   5.1277902278269545E-03],
            [   6.1675518803775475E-01,   4.2663988515488638E-02,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,   4.2663988515488638E-02,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,  -4.2663988515488638E-02,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,   4.2663988515488638E-02,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,  -4.2663988515488638E-02,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,  -4.2663988515488638E-02,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,   4.2663988515488638E-02,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,  -4.2663988515488638E-02,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,   6.1675518803775475E-01,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,   6.1675518803775475E-01,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,  -6.1675518803775475E-01,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,   6.1675518803775475E-01,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,  -6.1675518803775475E-01,   7.8599797844044361E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,  -6.1675518803775475E-01,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,   6.1675518803775475E-01,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,  -6.1675518803775475E-01,  -7.8599797844044361E-01,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,   6.1675518803775475E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,   6.1675518803775475E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,  -6.1675518803775475E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,   6.1675518803775475E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,  -6.1675518803775475E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,  -6.1675518803775475E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,   6.1675518803775475E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,  -6.1675518803775475E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,   4.2663988515488638E-02,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,   4.2663988515488638E-02,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,  -4.2663988515488638E-02,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,   4.2663988515488638E-02,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,  -4.2663988515488638E-02,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   7.8599797844044361E-01,  -4.2663988515488638E-02,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,   4.2663988515488638E-02,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -7.8599797844044361E-01,  -4.2663988515488638E-02,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,   7.8599797844044361E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,   7.8599797844044361E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,  -7.8599797844044361E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,   7.8599797844044361E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,  -7.8599797844044361E-01,   4.2663988515488638E-02,   5.1057399471641698E-03],
            [   6.1675518803775475E-01,  -7.8599797844044361E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,   7.8599797844044361E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [  -6.1675518803775475E-01,  -7.8599797844044361E-01,  -4.2663988515488638E-02,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,   7.8599797844044361E-01,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,   7.8599797844044361E-01,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,  -7.8599797844044361E-01,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,   7.8599797844044361E-01,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,  -7.8599797844044361E-01,   6.1675518803775475E-01,   5.1057399471641698E-03],
            [   4.2663988515488638E-02,  -7.8599797844044361E-01,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,   7.8599797844044361E-01,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [  -4.2663988515488638E-02,  -7.8599797844044361E-01,  -6.1675518803775475E-01,   5.1057399471641698E-03],
            [   6.6071954183553827E-01,   8.5519258142383495E-02,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,   8.5519258142383495E-02,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,  -8.5519258142383495E-02,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,   8.5519258142383495E-02,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,  -8.5519258142383495E-02,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,  -8.5519258142383495E-02,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,   8.5519258142383495E-02,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,  -8.5519258142383495E-02,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,   6.6071954183553827E-01,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,   6.6071954183553827E-01,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,  -6.6071954183553827E-01,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,   6.6071954183553827E-01,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,  -6.6071954183553827E-01,   7.4574536104719602E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,  -6.6071954183553827E-01,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,   6.6071954183553827E-01,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,  -6.6071954183553827E-01,  -7.4574536104719602E-01,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,   6.6071954183553827E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,   6.6071954183553827E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,  -6.6071954183553827E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,   6.6071954183553827E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,  -6.6071954183553827E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,  -6.6071954183553827E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,   6.6071954183553827E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,  -6.6071954183553827E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,   8.5519258142383495E-02,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,   8.5519258142383495E-02,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,  -8.5519258142383495E-02,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,   8.5519258142383495E-02,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,  -8.5519258142383495E-02,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   7.4574536104719602E-01,  -8.5519258142383495E-02,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,   8.5519258142383495E-02,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -7.4574536104719602E-01,  -8.5519258142383495E-02,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,   7.4574536104719602E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,   7.4574536104719602E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,  -7.4574536104719602E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,   7.4574536104719602E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,  -7.4574536104719602E-01,   8.5519258142383495E-02,   5.1361160557102459E-03],
            [   6.6071954183553827E-01,  -7.4574536104719602E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,   7.4574536104719602E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [  -6.6071954183553827E-01,  -7.4574536104719602E-01,  -8.5519258142383495E-02,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,   7.4574536104719602E-01,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,   7.4574536104719602E-01,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,  -7.4574536104719602E-01,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,   7.4574536104719602E-01,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,  -7.4574536104719602E-01,   6.6071954183553827E-01,   5.1361160557102459E-03],
            [   8.5519258142383495E-02,  -7.4574536104719602E-01,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,   7.4574536104719602E-01,  -6.6071954183553827E-01,   5.1361160557102459E-03],
            [  -8.5519258142383495E-02,  -7.4574536104719602E-01,  -6.6071954183553827E-01,   5.1361160557102459E-03],
        ])
  
        order = 89
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build3074():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.2661203017163315E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   3.2661203017163315E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   3.2661203017163315E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   3.2661203017163315E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   3.2661203017163315E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   3.2661203017163315E-04],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   4.5278318344245307E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   4.5278318344245307E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   4.5278318344245307E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   4.5278318344245307E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   4.5278318344245307E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   4.5278318344245307E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   4.5278318344245307E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   4.5278318344245307E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   4.5278318344245307E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   4.5278318344245307E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   4.5278318344245307E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   4.5278318344245307E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.5063859214751097E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   4.5063859214751097E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.5063859214751097E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5063859214751097E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   4.5063859214751097E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5063859214751097E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5063859214751097E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   4.5063859214751097E-03],
            [   1.8861085187233919E-02,   1.8861085187233919E-02,   9.9964419616737621E-01,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,   1.8861085187233919E-02,   9.9964419616737621E-01,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,  -1.8861085187233919E-02,   9.9964419616737621E-01,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,   1.8861085187233919E-02,  -9.9964419616737621E-01,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,  -1.8861085187233919E-02,   9.9964419616737621E-01,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,   1.8861085187233919E-02,  -9.9964419616737621E-01,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,  -1.8861085187233919E-02,  -9.9964419616737621E-01,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,  -1.8861085187233919E-02,  -9.9964419616737621E-01,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,   9.9964419616737621E-01,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,  -9.9964419616737621E-01,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,   9.9964419616737621E-01,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,  -9.9964419616737621E-01,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,   9.9964419616737621E-01,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,  -9.9964419616737621E-01,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -1.8861085187233919E-02,  -9.9964419616737621E-01,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [   1.8861085187233919E-02,   9.9964419616737621E-01,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [   9.9964419616737621E-01,   1.8861085187233919E-02,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -9.9964419616737621E-01,   1.8861085187233919E-02,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [   9.9964419616737621E-01,  -1.8861085187233919E-02,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [   9.9964419616737621E-01,   1.8861085187233919E-02,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -9.9964419616737621E-01,  -1.8861085187233919E-02,   1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -9.9964419616737621E-01,   1.8861085187233919E-02,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [   9.9964419616737621E-01,  -1.8861085187233919E-02,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [  -9.9964419616737621E-01,  -1.8861085187233919E-02,  -1.8861085187233919E-02,   1.2354663051475819E-03],
            [   4.8002172446253030E-02,   4.8002172446253030E-02,   9.9769313061726572E-01,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,   4.8002172446253030E-02,   9.9769313061726572E-01,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,  -4.8002172446253030E-02,   9.9769313061726572E-01,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,   4.8002172446253030E-02,  -9.9769313061726572E-01,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,  -4.8002172446253030E-02,   9.9769313061726572E-01,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,   4.8002172446253030E-02,  -9.9769313061726572E-01,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,  -4.8002172446253030E-02,  -9.9769313061726572E-01,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,  -4.8002172446253030E-02,  -9.9769313061726572E-01,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,   9.9769313061726572E-01,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,  -9.9769313061726572E-01,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,   9.9769313061726572E-01,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,  -9.9769313061726572E-01,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,   9.9769313061726572E-01,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,  -9.9769313061726572E-01,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -4.8002172446253030E-02,  -9.9769313061726572E-01,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [   4.8002172446253030E-02,   9.9769313061726572E-01,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [   9.9769313061726572E-01,   4.8002172446253030E-02,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -9.9769313061726572E-01,   4.8002172446253030E-02,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [   9.9769313061726572E-01,  -4.8002172446253030E-02,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [   9.9769313061726572E-01,   4.8002172446253030E-02,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -9.9769313061726572E-01,  -4.8002172446253030E-02,   4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -9.9769313061726572E-01,   4.8002172446253030E-02,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [   9.9769313061726572E-01,  -4.8002172446253030E-02,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [  -9.9769313061726572E-01,  -4.8002172446253030E-02,  -4.8002172446253030E-02,   2.0169315219166228E-03],
            [   8.2449220583972416E-02,   8.2449220583972416E-02,   9.9317886206372263E-01,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,   8.2449220583972416E-02,   9.9317886206372263E-01,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,  -8.2449220583972416E-02,   9.9317886206372263E-01,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,   8.2449220583972416E-02,  -9.9317886206372263E-01,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,  -8.2449220583972416E-02,   9.9317886206372263E-01,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,   8.2449220583972416E-02,  -9.9317886206372263E-01,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,  -8.2449220583972416E-02,  -9.9317886206372263E-01,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,  -8.2449220583972416E-02,  -9.9317886206372263E-01,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,   9.9317886206372263E-01,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,  -9.9317886206372263E-01,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,   9.9317886206372263E-01,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,  -9.9317886206372263E-01,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,   9.9317886206372263E-01,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,  -9.9317886206372263E-01,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -8.2449220583972416E-02,  -9.9317886206372263E-01,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [   8.2449220583972416E-02,   9.9317886206372263E-01,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [   9.9317886206372263E-01,   8.2449220583972416E-02,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -9.9317886206372263E-01,   8.2449220583972416E-02,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [   9.9317886206372263E-01,  -8.2449220583972416E-02,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [   9.9317886206372263E-01,   8.2449220583972416E-02,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -9.9317886206372263E-01,  -8.2449220583972416E-02,   8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -9.9317886206372263E-01,   8.2449220583972416E-02,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [   9.9317886206372263E-01,  -8.2449220583972416E-02,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [  -9.9317886206372263E-01,  -8.2449220583972416E-02,  -8.2449220583972416E-02,   2.6040034839101668E-03],
            [   1.2004083624840230E-01,   1.2004083624840230E-01,   9.8548485288489773E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,   1.2004083624840230E-01,   9.8548485288489773E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,  -1.2004083624840230E-01,   9.8548485288489773E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,   1.2004083624840230E-01,  -9.8548485288489773E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,  -1.2004083624840230E-01,   9.8548485288489773E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,   1.2004083624840230E-01,  -9.8548485288489773E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,  -1.2004083624840230E-01,  -9.8548485288489773E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,  -1.2004083624840230E-01,  -9.8548485288489773E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,   9.8548485288489773E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,  -9.8548485288489773E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,   9.8548485288489773E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,  -9.8548485288489773E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,   9.8548485288489773E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,  -9.8548485288489773E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -1.2004083624840230E-01,  -9.8548485288489773E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [   1.2004083624840230E-01,   9.8548485288489773E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [   9.8548485288489773E-01,   1.2004083624840230E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -9.8548485288489773E-01,   1.2004083624840230E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [   9.8548485288489773E-01,  -1.2004083624840230E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [   9.8548485288489773E-01,   1.2004083624840230E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -9.8548485288489773E-01,  -1.2004083624840230E-01,   1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -9.8548485288489773E-01,   1.2004083624840230E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [   9.8548485288489773E-01,  -1.2004083624840230E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [  -9.8548485288489773E-01,  -1.2004083624840230E-01,  -1.2004083624840230E-01,   3.0552586951828027E-03],
            [   1.5957735308099649E-01,   1.5957735308099649E-01,   9.7420230792547702E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,   1.5957735308099649E-01,   9.7420230792547702E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,  -1.5957735308099649E-01,   9.7420230792547702E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,   1.5957735308099649E-01,  -9.7420230792547702E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,  -1.5957735308099649E-01,   9.7420230792547702E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,   1.5957735308099649E-01,  -9.7420230792547702E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,  -1.5957735308099649E-01,  -9.7420230792547702E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,  -1.5957735308099649E-01,  -9.7420230792547702E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,   9.7420230792547702E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,  -9.7420230792547702E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,   9.7420230792547702E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,  -9.7420230792547702E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,   9.7420230792547702E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,  -9.7420230792547702E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -1.5957735308099649E-01,  -9.7420230792547702E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [   1.5957735308099649E-01,   9.7420230792547702E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [   9.7420230792547702E-01,   1.5957735308099649E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -9.7420230792547702E-01,   1.5957735308099649E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [   9.7420230792547702E-01,  -1.5957735308099649E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [   9.7420230792547702E-01,   1.5957735308099649E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -9.7420230792547702E-01,  -1.5957735308099649E-01,   1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -9.7420230792547702E-01,   1.5957735308099649E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [   9.7420230792547702E-01,  -1.5957735308099649E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [  -9.7420230792547702E-01,  -1.5957735308099649E-01,  -1.5957735308099649E-01,   3.4077723403550400E-03],
            [   2.0026359734340640E-01,   2.0026359734340640E-01,   9.5905629822141092E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,   2.0026359734340640E-01,   9.5905629822141092E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,  -2.0026359734340640E-01,   9.5905629822141092E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,   2.0026359734340640E-01,  -9.5905629822141092E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,  -2.0026359734340640E-01,   9.5905629822141092E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,   2.0026359734340640E-01,  -9.5905629822141092E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,  -2.0026359734340640E-01,  -9.5905629822141092E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,  -2.0026359734340640E-01,  -9.5905629822141092E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,   9.5905629822141092E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,  -9.5905629822141092E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,   9.5905629822141092E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,  -9.5905629822141092E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,   9.5905629822141092E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,  -9.5905629822141092E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -2.0026359734340640E-01,  -9.5905629822141092E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [   2.0026359734340640E-01,   9.5905629822141092E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [   9.5905629822141092E-01,   2.0026359734340640E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -9.5905629822141092E-01,   2.0026359734340640E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [   9.5905629822141092E-01,  -2.0026359734340640E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [   9.5905629822141092E-01,   2.0026359734340640E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -9.5905629822141092E-01,  -2.0026359734340640E-01,   2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -9.5905629822141092E-01,   2.0026359734340640E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [   9.5905629822141092E-01,  -2.0026359734340640E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [  -9.5905629822141092E-01,  -2.0026359734340640E-01,  -2.0026359734340640E-01,   3.6854174697266580E-03],
            [   2.4151275901399821E-01,   2.4151275901399821E-01,   9.3986338074578313E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,   2.4151275901399821E-01,   9.3986338074578313E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,  -2.4151275901399821E-01,   9.3986338074578313E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,   2.4151275901399821E-01,  -9.3986338074578313E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,  -2.4151275901399821E-01,   9.3986338074578313E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,   2.4151275901399821E-01,  -9.3986338074578313E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,  -2.4151275901399821E-01,  -9.3986338074578313E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,  -2.4151275901399821E-01,  -9.3986338074578313E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,   9.3986338074578313E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,  -9.3986338074578313E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,   9.3986338074578313E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,  -9.3986338074578313E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,   9.3986338074578313E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,  -9.3986338074578313E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -2.4151275901399821E-01,  -9.3986338074578313E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [   2.4151275901399821E-01,   9.3986338074578313E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [   9.3986338074578313E-01,   2.4151275901399821E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -9.3986338074578313E-01,   2.4151275901399821E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [   9.3986338074578313E-01,  -2.4151275901399821E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [   9.3986338074578313E-01,   2.4151275901399821E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -9.3986338074578313E-01,  -2.4151275901399821E-01,   2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -9.3986338074578313E-01,   2.4151275901399821E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [   9.3986338074578313E-01,  -2.4151275901399821E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [  -9.3986338074578313E-01,  -2.4151275901399821E-01,  -2.4151275901399821E-01,   3.9044122084268304E-03],
            [   2.8285841584584770E-01,   2.8285841584584770E-01,   9.1650544633971220E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,   2.8285841584584770E-01,   9.1650544633971220E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,  -2.8285841584584770E-01,   9.1650544633971220E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,   2.8285841584584770E-01,  -9.1650544633971220E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,  -2.8285841584584770E-01,   9.1650544633971220E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,   2.8285841584584770E-01,  -9.1650544633971220E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,  -2.8285841584584770E-01,  -9.1650544633971220E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,  -2.8285841584584770E-01,  -9.1650544633971220E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,   9.1650544633971220E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,  -9.1650544633971220E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,   9.1650544633971220E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,  -9.1650544633971220E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,   9.1650544633971220E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,  -9.1650544633971220E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -2.8285841584584770E-01,  -9.1650544633971220E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [   2.8285841584584770E-01,   9.1650544633971220E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [   9.1650544633971220E-01,   2.8285841584584770E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -9.1650544633971220E-01,   2.8285841584584770E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [   9.1650544633971220E-01,  -2.8285841584584770E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [   9.1650544633971220E-01,   2.8285841584584770E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -9.1650544633971220E-01,  -2.8285841584584770E-01,   2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -9.1650544633971220E-01,   2.8285841584584770E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [   9.1650544633971220E-01,  -2.8285841584584770E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [  -9.1650544633971220E-01,  -2.8285841584584770E-01,  -2.8285841584584770E-01,   4.0762894270249001E-03],
            [   3.2390910153381380E-01,   3.2390910153381380E-01,   8.8891269981203158E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,   3.2390910153381380E-01,   8.8891269981203158E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,  -3.2390910153381380E-01,   8.8891269981203158E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,   3.2390910153381380E-01,  -8.8891269981203158E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,  -3.2390910153381380E-01,   8.8891269981203158E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,   3.2390910153381380E-01,  -8.8891269981203158E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,  -3.2390910153381380E-01,  -8.8891269981203158E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,  -3.2390910153381380E-01,  -8.8891269981203158E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,   8.8891269981203158E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,  -8.8891269981203158E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,   8.8891269981203158E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,  -8.8891269981203158E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,   8.8891269981203158E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,  -8.8891269981203158E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -3.2390910153381380E-01,  -8.8891269981203158E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [   3.2390910153381380E-01,   8.8891269981203158E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [   8.8891269981203158E-01,   3.2390910153381380E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -8.8891269981203158E-01,   3.2390910153381380E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [   8.8891269981203158E-01,  -3.2390910153381380E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [   8.8891269981203158E-01,   3.2390910153381380E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -8.8891269981203158E-01,  -3.2390910153381380E-01,   3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -8.8891269981203158E-01,   3.2390910153381380E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [   8.8891269981203158E-01,  -3.2390910153381380E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [  -8.8891269981203158E-01,  -3.2390910153381380E-01,  -3.2390910153381380E-01,   4.2096073502911101E-03],
            [   3.6432250979621938E-01,   3.6432250979621938E-01,   8.5705205075979329E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,   3.6432250979621938E-01,   8.5705205075979329E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,  -3.6432250979621938E-01,   8.5705205075979329E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,   3.6432250979621938E-01,  -8.5705205075979329E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,  -3.6432250979621938E-01,   8.5705205075979329E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,   3.6432250979621938E-01,  -8.5705205075979329E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,  -3.6432250979621938E-01,  -8.5705205075979329E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,  -3.6432250979621938E-01,  -8.5705205075979329E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,   8.5705205075979329E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,  -8.5705205075979329E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,   8.5705205075979329E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,  -8.5705205075979329E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,   8.5705205075979329E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,  -8.5705205075979329E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -3.6432250979621938E-01,  -8.5705205075979329E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [   3.6432250979621938E-01,   8.5705205075979329E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [   8.5705205075979329E-01,   3.6432250979621938E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -8.5705205075979329E-01,   3.6432250979621938E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [   8.5705205075979329E-01,  -3.6432250979621938E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [   8.5705205075979329E-01,   3.6432250979621938E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -8.5705205075979329E-01,  -3.6432250979621938E-01,   3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -8.5705205075979329E-01,   3.6432250979621938E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [   8.5705205075979329E-01,  -3.6432250979621938E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [  -8.5705205075979329E-01,  -3.6432250979621938E-01,  -3.6432250979621938E-01,   4.3109948354220027E-03],
            [   4.0378970836918021E-01,   4.0378970836918021E-01,   8.2091884058673226E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,   4.0378970836918021E-01,   8.2091884058673226E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,  -4.0378970836918021E-01,   8.2091884058673226E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,   4.0378970836918021E-01,  -8.2091884058673226E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,  -4.0378970836918021E-01,   8.2091884058673226E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,   4.0378970836918021E-01,  -8.2091884058673226E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,  -4.0378970836918021E-01,  -8.2091884058673226E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,  -4.0378970836918021E-01,  -8.2091884058673226E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,   8.2091884058673226E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,  -8.2091884058673226E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,   8.2091884058673226E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,  -8.2091884058673226E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,   8.2091884058673226E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,  -8.2091884058673226E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -4.0378970836918021E-01,  -8.2091884058673226E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [   4.0378970836918021E-01,   8.2091884058673226E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [   8.2091884058673226E-01,   4.0378970836918021E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -8.2091884058673226E-01,   4.0378970836918021E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [   8.2091884058673226E-01,  -4.0378970836918021E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [   8.2091884058673226E-01,   4.0378970836918021E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -8.2091884058673226E-01,  -4.0378970836918021E-01,   4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -8.2091884058673226E-01,   4.0378970836918021E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [   8.2091884058673226E-01,  -4.0378970836918021E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [  -8.2091884058673226E-01,  -4.0378970836918021E-01,  -4.0378970836918021E-01,   4.3858193047452646E-03],
            [   4.4202475151941267E-01,   4.4202475151941267E-01,   7.8053074128339306E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,   4.4202475151941267E-01,   7.8053074128339306E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,  -4.4202475151941267E-01,   7.8053074128339306E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,   4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,  -4.4202475151941267E-01,   7.8053074128339306E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,   4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,  -4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,  -4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,   7.8053074128339306E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,   7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,  -7.8053074128339306E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,   7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,  -7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -4.4202475151941267E-01,  -7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [   4.4202475151941267E-01,   7.8053074128339306E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [   7.8053074128339306E-01,   4.4202475151941267E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -7.8053074128339306E-01,   4.4202475151941267E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [   7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [   7.8053074128339306E-01,   4.4202475151941267E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -7.8053074128339306E-01,  -4.4202475151941267E-01,   4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -7.8053074128339306E-01,   4.4202475151941267E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [   7.8053074128339306E-01,  -4.4202475151941267E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [  -7.8053074128339306E-01,  -4.4202475151941267E-01,  -4.4202475151941267E-01,   4.4386292752748606E-03],
            [   4.7875725384649381E-01,   4.7875725384649381E-01,   7.3592321867075772E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,   4.7875725384649381E-01,   7.3592321867075772E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,  -4.7875725384649381E-01,   7.3592321867075772E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,   4.7875725384649381E-01,  -7.3592321867075772E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,  -4.7875725384649381E-01,   7.3592321867075772E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,   4.7875725384649381E-01,  -7.3592321867075772E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,  -4.7875725384649381E-01,  -7.3592321867075772E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,  -4.7875725384649381E-01,  -7.3592321867075772E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,   7.3592321867075772E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,  -7.3592321867075772E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,   7.3592321867075772E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,  -7.3592321867075772E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,   7.3592321867075772E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,  -7.3592321867075772E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -4.7875725384649381E-01,  -7.3592321867075772E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [   4.7875725384649381E-01,   7.3592321867075772E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [   7.3592321867075772E-01,   4.7875725384649381E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -7.3592321867075772E-01,   4.7875725384649381E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [   7.3592321867075772E-01,  -4.7875725384649381E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [   7.3592321867075772E-01,   4.7875725384649381E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -7.3592321867075772E-01,  -4.7875725384649381E-01,   4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -7.3592321867075772E-01,   4.7875725384649381E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [   7.3592321867075772E-01,  -4.7875725384649381E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [  -7.3592321867075772E-01,  -4.7875725384649381E-01,  -4.7875725384649381E-01,   4.4734553635665392E-03],
            [   5.1372652512752337E-01,   5.1372652512752337E-01,   6.8714635614314379E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,   5.1372652512752337E-01,   6.8714635614314379E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,  -5.1372652512752337E-01,   6.8714635614314379E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,   5.1372652512752337E-01,  -6.8714635614314379E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,  -5.1372652512752337E-01,   6.8714635614314379E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,   5.1372652512752337E-01,  -6.8714635614314379E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,  -5.1372652512752337E-01,  -6.8714635614314379E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,  -5.1372652512752337E-01,  -6.8714635614314379E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,   6.8714635614314379E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,  -6.8714635614314379E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,   6.8714635614314379E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,  -6.8714635614314379E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,   6.8714635614314379E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,  -6.8714635614314379E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -5.1372652512752337E-01,  -6.8714635614314379E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [   5.1372652512752337E-01,   6.8714635614314379E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [   6.8714635614314379E-01,   5.1372652512752337E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -6.8714635614314379E-01,   5.1372652512752337E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [   6.8714635614314379E-01,  -5.1372652512752337E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [   6.8714635614314379E-01,   5.1372652512752337E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -6.8714635614314379E-01,  -5.1372652512752337E-01,   5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -6.8714635614314379E-01,   5.1372652512752337E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [   6.8714635614314379E-01,  -5.1372652512752337E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [  -6.8714635614314379E-01,  -5.1372652512752337E-01,  -5.1372652512752337E-01,   4.4940160174434737E-03],
            [   5.4667640566546105E-01,   5.4667640566546105E-01,   6.3426320638784062E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,   5.4667640566546105E-01,   6.3426320638784062E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,  -5.4667640566546105E-01,   6.3426320638784062E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,   5.4667640566546105E-01,  -6.3426320638784062E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,  -5.4667640566546105E-01,   6.3426320638784062E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,   5.4667640566546105E-01,  -6.3426320638784062E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,  -5.4667640566546105E-01,  -6.3426320638784062E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,  -5.4667640566546105E-01,  -6.3426320638784062E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,   6.3426320638784062E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,  -6.3426320638784062E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,   6.3426320638784062E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,  -6.3426320638784062E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,   6.3426320638784062E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,  -6.3426320638784062E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -5.4667640566546105E-01,  -6.3426320638784062E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [   5.4667640566546105E-01,   6.3426320638784062E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [   6.3426320638784062E-01,   5.4667640566546105E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -6.3426320638784062E-01,   5.4667640566546105E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [   6.3426320638784062E-01,  -5.4667640566546105E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [   6.3426320638784062E-01,   5.4667640566546105E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -6.3426320638784062E-01,  -5.4667640566546105E-01,   5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -6.3426320638784062E-01,   5.4667640566546105E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [   6.3426320638784062E-01,  -5.4667640566546105E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [  -6.3426320638784062E-01,  -5.4667640566546105E-01,  -5.4667640566546105E-01,   4.5038507299351195E-03],
            [   6.0548594208135353E-01,   6.0548594208135353E-01,   5.1650125642026423E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,   6.0548594208135353E-01,   5.1650125642026423E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,  -6.0548594208135353E-01,   5.1650125642026423E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,   6.0548594208135353E-01,  -5.1650125642026423E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,  -6.0548594208135353E-01,   5.1650125642026423E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,   6.0548594208135353E-01,  -5.1650125642026423E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,  -6.0548594208135353E-01,  -5.1650125642026423E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,  -6.0548594208135353E-01,  -5.1650125642026423E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,   5.1650125642026423E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,  -5.1650125642026423E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,   5.1650125642026423E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,  -5.1650125642026423E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,   5.1650125642026423E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,  -5.1650125642026423E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -6.0548594208135353E-01,  -5.1650125642026423E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [   6.0548594208135353E-01,   5.1650125642026423E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [   5.1650125642026423E-01,   6.0548594208135353E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -5.1650125642026423E-01,   6.0548594208135353E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [   5.1650125642026423E-01,  -6.0548594208135353E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [   5.1650125642026423E-01,   6.0548594208135353E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -5.1650125642026423E-01,  -6.0548594208135353E-01,   6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -5.1650125642026423E-01,   6.0548594208135353E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [   5.1650125642026423E-01,  -6.0548594208135353E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [  -5.1650125642026423E-01,  -6.0548594208135353E-01,  -6.0548594208135353E-01,   4.5049227020279442E-03],
            [   6.3081067017645620E-01,   6.3081067017645620E-01,   4.5183602864652173E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,   6.3081067017645620E-01,   4.5183602864652173E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5183602864652173E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,   6.3081067017645620E-01,  -4.5183602864652173E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5183602864652173E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,   6.3081067017645620E-01,  -4.5183602864652173E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,  -6.3081067017645620E-01,  -4.5183602864652173E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,  -6.3081067017645620E-01,  -4.5183602864652173E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,   4.5183602864652173E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,  -4.5183602864652173E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,   4.5183602864652173E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,  -4.5183602864652173E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,   4.5183602864652173E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,  -4.5183602864652173E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -6.3081067017645620E-01,  -4.5183602864652173E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [   6.3081067017645620E-01,   4.5183602864652173E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [   4.5183602864652173E-01,   6.3081067017645620E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -4.5183602864652173E-01,   6.3081067017645620E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [   4.5183602864652173E-01,  -6.3081067017645620E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [   4.5183602864652173E-01,   6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -4.5183602864652173E-01,  -6.3081067017645620E-01,   6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -4.5183602864652173E-01,   6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [   4.5183602864652173E-01,  -6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [  -4.5183602864652173E-01,  -6.3081067017645620E-01,  -6.3081067017645620E-01,   4.5025203860263171E-03],
            [   6.5303692301795835E-01,   6.5303692301795835E-01,   3.8351734556663059E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,   6.5303692301795835E-01,   3.8351734556663059E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,  -6.5303692301795835E-01,   3.8351734556663059E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,   6.5303692301795835E-01,  -3.8351734556663059E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,  -6.5303692301795835E-01,   3.8351734556663059E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,   6.5303692301795835E-01,  -3.8351734556663059E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,  -6.5303692301795835E-01,  -3.8351734556663059E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,  -6.5303692301795835E-01,  -3.8351734556663059E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,   3.8351734556663059E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,  -3.8351734556663059E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,   3.8351734556663059E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,  -3.8351734556663059E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,   3.8351734556663059E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,  -3.8351734556663059E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -6.5303692301795835E-01,  -3.8351734556663059E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [   6.5303692301795835E-01,   3.8351734556663059E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [   3.8351734556663059E-01,   6.5303692301795835E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -3.8351734556663059E-01,   6.5303692301795835E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [   3.8351734556663059E-01,  -6.5303692301795835E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [   3.8351734556663059E-01,   6.5303692301795835E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -3.8351734556663059E-01,  -6.5303692301795835E-01,   6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -3.8351734556663059E-01,   6.5303692301795835E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [   3.8351734556663059E-01,  -6.5303692301795835E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [  -3.8351734556663059E-01,  -6.5303692301795835E-01,  -6.5303692301795835E-01,   4.5017404026146774E-03],
            [   6.7186095246111577E-01,   6.7186095246111577E-01,   3.1177832047158877E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,   6.7186095246111577E-01,   3.1177832047158877E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,  -6.7186095246111577E-01,   3.1177832047158877E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,   6.7186095246111577E-01,  -3.1177832047158877E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,  -6.7186095246111577E-01,   3.1177832047158877E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,   6.7186095246111577E-01,  -3.1177832047158877E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,  -6.7186095246111577E-01,  -3.1177832047158877E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,  -6.7186095246111577E-01,  -3.1177832047158877E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,   3.1177832047158877E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,  -3.1177832047158877E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,   3.1177832047158877E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,  -3.1177832047158877E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,   3.1177832047158877E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,  -3.1177832047158877E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -6.7186095246111577E-01,  -3.1177832047158877E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [   6.7186095246111577E-01,   3.1177832047158877E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [   3.1177832047158877E-01,   6.7186095246111577E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -3.1177832047158877E-01,   6.7186095246111577E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [   3.1177832047158877E-01,  -6.7186095246111577E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [   3.1177832047158877E-01,   6.7186095246111577E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -3.1177832047158877E-01,  -6.7186095246111577E-01,   6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -3.1177832047158877E-01,   6.7186095246111577E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [   3.1177832047158877E-01,  -6.7186095246111577E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [  -3.1177832047158877E-01,  -6.7186095246111577E-01,  -6.7186095246111577E-01,   4.5042316141607492E-03],
            [   6.8696764998940130E-01,   6.8696764998940130E-01,   2.3696180227217825E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,   6.8696764998940130E-01,   2.3696180227217825E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,  -6.8696764998940130E-01,   2.3696180227217825E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,   6.8696764998940130E-01,  -2.3696180227217825E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,  -6.8696764998940130E-01,   2.3696180227217825E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,   6.8696764998940130E-01,  -2.3696180227217825E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,  -6.8696764998940130E-01,  -2.3696180227217825E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,  -6.8696764998940130E-01,  -2.3696180227217825E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,   2.3696180227217825E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,  -2.3696180227217825E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,   2.3696180227217825E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,  -2.3696180227217825E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,   2.3696180227217825E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,  -2.3696180227217825E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -6.8696764998940130E-01,  -2.3696180227217825E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [   6.8696764998940130E-01,   2.3696180227217825E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [   2.3696180227217825E-01,   6.8696764998940130E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -2.3696180227217825E-01,   6.8696764998940130E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [   2.3696180227217825E-01,  -6.8696764998940130E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [   2.3696180227217825E-01,   6.8696764998940130E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -2.3696180227217825E-01,  -6.8696764998940130E-01,   6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -2.3696180227217825E-01,   6.8696764998940130E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [   2.3696180227217825E-01,  -6.8696764998940130E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [  -2.3696180227217825E-01,  -6.8696764998940130E-01,  -6.8696764998940130E-01,   4.5102214191932990E-03],
            [   6.9804670772407484E-01,   6.9804670772407484E-01,   1.5956687523154681E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,   6.9804670772407484E-01,   1.5956687523154681E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,  -6.9804670772407484E-01,   1.5956687523154681E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,   6.9804670772407484E-01,  -1.5956687523154681E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,  -6.9804670772407484E-01,   1.5956687523154681E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,   6.9804670772407484E-01,  -1.5956687523154681E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,  -6.9804670772407484E-01,  -1.5956687523154681E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,  -6.9804670772407484E-01,  -1.5956687523154681E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,   1.5956687523154681E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,  -1.5956687523154681E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,   1.5956687523154681E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,  -1.5956687523154681E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,   1.5956687523154681E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,  -1.5956687523154681E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -6.9804670772407484E-01,  -1.5956687523154681E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [   6.9804670772407484E-01,   1.5956687523154681E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [   1.5956687523154681E-01,   6.9804670772407484E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -1.5956687523154681E-01,   6.9804670772407484E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [   1.5956687523154681E-01,  -6.9804670772407484E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [   1.5956687523154681E-01,   6.9804670772407484E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -1.5956687523154681E-01,  -6.9804670772407484E-01,   6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -1.5956687523154681E-01,   6.9804670772407484E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [   1.5956687523154681E-01,  -6.9804670772407484E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [  -1.5956687523154681E-01,  -6.9804670772407484E-01,  -6.9804670772407484E-01,   4.5181703246949820E-03],
            [   7.0482417212505222E-01,   7.0482417212505222E-01,   8.0285570163445411E-02,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,   7.0482417212505222E-01,   8.0285570163445411E-02,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,  -7.0482417212505222E-01,   8.0285570163445411E-02,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,   7.0482417212505222E-01,  -8.0285570163445411E-02,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,  -7.0482417212505222E-01,   8.0285570163445411E-02,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,   7.0482417212505222E-01,  -8.0285570163445411E-02,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,  -7.0482417212505222E-01,  -8.0285570163445411E-02,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,  -7.0482417212505222E-01,  -8.0285570163445411E-02,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,   8.0285570163445411E-02,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,  -8.0285570163445411E-02,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,   8.0285570163445411E-02,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,  -8.0285570163445411E-02,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,   8.0285570163445411E-02,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,  -8.0285570163445411E-02,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -7.0482417212505222E-01,  -8.0285570163445411E-02,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [   7.0482417212505222E-01,   8.0285570163445411E-02,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [   8.0285570163445411E-02,   7.0482417212505222E-01,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -8.0285570163445411E-02,   7.0482417212505222E-01,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [   8.0285570163445411E-02,  -7.0482417212505222E-01,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [   8.0285570163445411E-02,   7.0482417212505222E-01,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -8.0285570163445411E-02,  -7.0482417212505222E-01,   7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -8.0285570163445411E-02,   7.0482417212505222E-01,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [   8.0285570163445411E-02,  -7.0482417212505222E-01,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [  -8.0285570163445411E-02,  -7.0482417212505222E-01,  -7.0482417212505222E-01,   4.5250791300046594E-03],
            [   5.5911052220582319E-02,   9.9843575368652904E-01,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [  -5.5911052220582319E-02,   9.9843575368652904E-01,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [   5.5911052220582319E-02,  -9.9843575368652904E-01,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [  -5.5911052220582319E-02,  -9.9843575368652904E-01,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [   9.9843575368652904E-01,   5.5911052220582319E-02,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [  -9.9843575368652904E-01,   5.5911052220582319E-02,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [   9.9843575368652904E-01,  -5.5911052220582319E-02,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [  -9.9843575368652904E-01,  -5.5911052220582319E-02,   0.0000000000000000E+00,   1.8302253997867890E-03],
            [   5.5911052220582319E-02,   0.0000000000000000E+00,   9.9843575368652904E-01,   1.8302253997867890E-03],
            [  -5.5911052220582319E-02,   0.0000000000000000E+00,   9.9843575368652904E-01,   1.8302253997867890E-03],
            [   5.5911052220582319E-02,   0.0000000000000000E+00,  -9.9843575368652904E-01,   1.8302253997867890E-03],
            [  -5.5911052220582319E-02,   0.0000000000000000E+00,  -9.9843575368652904E-01,   1.8302253997867890E-03],
            [   9.9843575368652904E-01,   0.0000000000000000E+00,   5.5911052220582319E-02,   1.8302253997867890E-03],
            [  -9.9843575368652904E-01,   0.0000000000000000E+00,   5.5911052220582319E-02,   1.8302253997867890E-03],
            [   9.9843575368652904E-01,   0.0000000000000000E+00,  -5.5911052220582319E-02,   1.8302253997867890E-03],
            [  -9.9843575368652904E-01,   0.0000000000000000E+00,  -5.5911052220582319E-02,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,   5.5911052220582319E-02,   9.9843575368652904E-01,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,  -5.5911052220582319E-02,   9.9843575368652904E-01,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,   5.5911052220582319E-02,  -9.9843575368652904E-01,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,  -5.5911052220582319E-02,  -9.9843575368652904E-01,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,   9.9843575368652904E-01,   5.5911052220582319E-02,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,  -9.9843575368652904E-01,   5.5911052220582319E-02,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,   9.9843575368652904E-01,  -5.5911052220582319E-02,   1.8302253997867890E-03],
            [   0.0000000000000000E+00,  -9.9843575368652904E-01,  -5.5911052220582319E-02,   1.8302253997867890E-03],
            [   1.4073840785139161E-01,   9.9004681735534883E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [  -1.4073840785139161E-01,   9.9004681735534883E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [   1.4073840785139161E-01,  -9.9004681735534883E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [  -1.4073840785139161E-01,  -9.9004681735534883E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [   9.9004681735534883E-01,   1.4073840785139161E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [  -9.9004681735534883E-01,   1.4073840785139161E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [   9.9004681735534883E-01,  -1.4073840785139161E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [  -9.9004681735534883E-01,  -1.4073840785139161E-01,   0.0000000000000000E+00,   2.8304118546707956E-03],
            [   1.4073840785139161E-01,   0.0000000000000000E+00,   9.9004681735534883E-01,   2.8304118546707956E-03],
            [  -1.4073840785139161E-01,   0.0000000000000000E+00,   9.9004681735534883E-01,   2.8304118546707956E-03],
            [   1.4073840785139161E-01,   0.0000000000000000E+00,  -9.9004681735534883E-01,   2.8304118546707956E-03],
            [  -1.4073840785139161E-01,   0.0000000000000000E+00,  -9.9004681735534883E-01,   2.8304118546707956E-03],
            [   9.9004681735534883E-01,   0.0000000000000000E+00,   1.4073840785139161E-01,   2.8304118546707956E-03],
            [  -9.9004681735534883E-01,   0.0000000000000000E+00,   1.4073840785139161E-01,   2.8304118546707956E-03],
            [   9.9004681735534883E-01,   0.0000000000000000E+00,  -1.4073840785139161E-01,   2.8304118546707956E-03],
            [  -9.9004681735534883E-01,   0.0000000000000000E+00,  -1.4073840785139161E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,   1.4073840785139161E-01,   9.9004681735534883E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,  -1.4073840785139161E-01,   9.9004681735534883E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,   1.4073840785139161E-01,  -9.9004681735534883E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,  -1.4073840785139161E-01,  -9.9004681735534883E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,   9.9004681735534883E-01,   1.4073840785139161E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,  -9.9004681735534883E-01,   1.4073840785139161E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,   9.9004681735534883E-01,  -1.4073840785139161E-01,   2.8304118546707956E-03],
            [   0.0000000000000000E+00,  -9.9004681735534883E-01,  -1.4073840785139161E-01,   2.8304118546707956E-03],
            [   2.3640354389763091E-01,   9.7165496161582010E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [  -2.3640354389763091E-01,   9.7165496161582010E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [   2.3640354389763091E-01,  -9.7165496161582010E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [  -2.3640354389763091E-01,  -9.7165496161582010E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [   9.7165496161582010E-01,   2.3640354389763091E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [  -9.7165496161582010E-01,   2.3640354389763091E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [   9.7165496161582010E-01,  -2.3640354389763091E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [  -9.7165496161582010E-01,  -2.3640354389763091E-01,   0.0000000000000000E+00,   3.4760283152220324E-03],
            [   2.3640354389763091E-01,   0.0000000000000000E+00,   9.7165496161582010E-01,   3.4760283152220324E-03],
            [  -2.3640354389763091E-01,   0.0000000000000000E+00,   9.7165496161582010E-01,   3.4760283152220324E-03],
            [   2.3640354389763091E-01,   0.0000000000000000E+00,  -9.7165496161582010E-01,   3.4760283152220324E-03],
            [  -2.3640354389763091E-01,   0.0000000000000000E+00,  -9.7165496161582010E-01,   3.4760283152220324E-03],
            [   9.7165496161582010E-01,   0.0000000000000000E+00,   2.3640354389763091E-01,   3.4760283152220324E-03],
            [  -9.7165496161582010E-01,   0.0000000000000000E+00,   2.3640354389763091E-01,   3.4760283152220324E-03],
            [   9.7165496161582010E-01,   0.0000000000000000E+00,  -2.3640354389763091E-01,   3.4760283152220324E-03],
            [  -9.7165496161582010E-01,   0.0000000000000000E+00,  -2.3640354389763091E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,   2.3640354389763091E-01,   9.7165496161582010E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,  -2.3640354389763091E-01,   9.7165496161582010E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,   2.3640354389763091E-01,  -9.7165496161582010E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,  -2.3640354389763091E-01,  -9.7165496161582010E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,   9.7165496161582010E-01,   2.3640354389763091E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,  -9.7165496161582010E-01,   2.3640354389763091E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,   9.7165496161582010E-01,  -2.3640354389763091E-01,   3.4760283152220324E-03],
            [   0.0000000000000000E+00,  -9.7165496161582010E-01,  -2.3640354389763091E-01,   3.4760283152220324E-03],
            [   3.3606027378181702E-01,   9.4184048139039456E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [  -3.3606027378181702E-01,   9.4184048139039456E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [   3.3606027378181702E-01,  -9.4184048139039456E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [  -3.3606027378181702E-01,  -9.4184048139039456E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [   9.4184048139039456E-01,   3.3606027378181702E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [  -9.4184048139039456E-01,   3.3606027378181702E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [   9.4184048139039456E-01,  -3.3606027378181702E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [  -9.4184048139039456E-01,  -3.3606027378181702E-01,   0.0000000000000000E+00,   3.9090579671216749E-03],
            [   3.3606027378181702E-01,   0.0000000000000000E+00,   9.4184048139039456E-01,   3.9090579671216749E-03],
            [  -3.3606027378181702E-01,   0.0000000000000000E+00,   9.4184048139039456E-01,   3.9090579671216749E-03],
            [   3.3606027378181702E-01,   0.0000000000000000E+00,  -9.4184048139039456E-01,   3.9090579671216749E-03],
            [  -3.3606027378181702E-01,   0.0000000000000000E+00,  -9.4184048139039456E-01,   3.9090579671216749E-03],
            [   9.4184048139039456E-01,   0.0000000000000000E+00,   3.3606027378181702E-01,   3.9090579671216749E-03],
            [  -9.4184048139039456E-01,   0.0000000000000000E+00,   3.3606027378181702E-01,   3.9090579671216749E-03],
            [   9.4184048139039456E-01,   0.0000000000000000E+00,  -3.3606027378181702E-01,   3.9090579671216749E-03],
            [  -9.4184048139039456E-01,   0.0000000000000000E+00,  -3.3606027378181702E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,   3.3606027378181702E-01,   9.4184048139039456E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,  -3.3606027378181702E-01,   9.4184048139039456E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,   3.3606027378181702E-01,  -9.4184048139039456E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,  -3.3606027378181702E-01,  -9.4184048139039456E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,   9.4184048139039456E-01,   3.3606027378181702E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,  -9.4184048139039456E-01,   3.3606027378181702E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,   9.4184048139039456E-01,  -3.3606027378181702E-01,   3.9090579671216749E-03],
            [   0.0000000000000000E+00,  -9.4184048139039456E-01,  -3.3606027378181702E-01,   3.9090579671216749E-03],
            [   4.3562926300546650E-01,   9.0012618293954438E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [  -4.3562926300546650E-01,   9.0012618293954438E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [   4.3562926300546650E-01,  -9.0012618293954438E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [  -4.3562926300546650E-01,  -9.0012618293954438E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [   9.0012618293954438E-01,   4.3562926300546650E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [  -9.0012618293954438E-01,   4.3562926300546650E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [   9.0012618293954438E-01,  -4.3562926300546650E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [  -9.0012618293954438E-01,  -4.3562926300546650E-01,   0.0000000000000000E+00,   4.2003178127787621E-03],
            [   4.3562926300546650E-01,   0.0000000000000000E+00,   9.0012618293954438E-01,   4.2003178127787621E-03],
            [  -4.3562926300546650E-01,   0.0000000000000000E+00,   9.0012618293954438E-01,   4.2003178127787621E-03],
            [   4.3562926300546650E-01,   0.0000000000000000E+00,  -9.0012618293954438E-01,   4.2003178127787621E-03],
            [  -4.3562926300546650E-01,   0.0000000000000000E+00,  -9.0012618293954438E-01,   4.2003178127787621E-03],
            [   9.0012618293954438E-01,   0.0000000000000000E+00,   4.3562926300546650E-01,   4.2003178127787621E-03],
            [  -9.0012618293954438E-01,   0.0000000000000000E+00,   4.3562926300546650E-01,   4.2003178127787621E-03],
            [   9.0012618293954438E-01,   0.0000000000000000E+00,  -4.3562926300546650E-01,   4.2003178127787621E-03],
            [  -9.0012618293954438E-01,   0.0000000000000000E+00,  -4.3562926300546650E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,   4.3562926300546650E-01,   9.0012618293954438E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,  -4.3562926300546650E-01,   9.0012618293954438E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,   4.3562926300546650E-01,  -9.0012618293954438E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,  -4.3562926300546650E-01,  -9.0012618293954438E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,   9.0012618293954438E-01,   4.3562926300546650E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,  -9.0012618293954438E-01,   4.3562926300546650E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,   9.0012618293954438E-01,  -4.3562926300546650E-01,   4.2003178127787621E-03],
            [   0.0000000000000000E+00,  -9.0012618293954438E-01,  -4.3562926300546650E-01,   4.2003178127787621E-03],
            [   5.3215694152561743E-01,   8.4664572849929420E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [  -5.3215694152561743E-01,   8.4664572849929420E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [   5.3215694152561743E-01,  -8.4664572849929420E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [  -5.3215694152561743E-01,  -8.4664572849929420E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [   8.4664572849929420E-01,   5.3215694152561743E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [  -8.4664572849929420E-01,   5.3215694152561743E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [   8.4664572849929420E-01,  -5.3215694152561743E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [  -8.4664572849929420E-01,  -5.3215694152561743E-01,   0.0000000000000000E+00,   4.3881537904991181E-03],
            [   5.3215694152561743E-01,   0.0000000000000000E+00,   8.4664572849929420E-01,   4.3881537904991181E-03],
            [  -5.3215694152561743E-01,   0.0000000000000000E+00,   8.4664572849929420E-01,   4.3881537904991181E-03],
            [   5.3215694152561743E-01,   0.0000000000000000E+00,  -8.4664572849929420E-01,   4.3881537904991181E-03],
            [  -5.3215694152561743E-01,   0.0000000000000000E+00,  -8.4664572849929420E-01,   4.3881537904991181E-03],
            [   8.4664572849929420E-01,   0.0000000000000000E+00,   5.3215694152561743E-01,   4.3881537904991181E-03],
            [  -8.4664572849929420E-01,   0.0000000000000000E+00,   5.3215694152561743E-01,   4.3881537904991181E-03],
            [   8.4664572849929420E-01,   0.0000000000000000E+00,  -5.3215694152561743E-01,   4.3881537904991181E-03],
            [  -8.4664572849929420E-01,   0.0000000000000000E+00,  -5.3215694152561743E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,   5.3215694152561743E-01,   8.4664572849929420E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,  -5.3215694152561743E-01,   8.4664572849929420E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,   5.3215694152561743E-01,  -8.4664572849929420E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,  -5.3215694152561743E-01,  -8.4664572849929420E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,   8.4664572849929420E-01,   5.3215694152561743E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,  -8.4664572849929420E-01,   5.3215694152561743E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,   8.4664572849929420E-01,  -5.3215694152561743E-01,   4.3881537904991181E-03],
            [   0.0000000000000000E+00,  -8.4664572849929420E-01,  -5.3215694152561743E-01,   4.3881537904991181E-03],
            [   6.2329563050405545E-01,   7.8198628951827032E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [  -6.2329563050405545E-01,   7.8198628951827032E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [   6.2329563050405545E-01,  -7.8198628951827032E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [  -6.2329563050405545E-01,  -7.8198628951827032E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [   7.8198628951827032E-01,   6.2329563050405545E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [  -7.8198628951827032E-01,   6.2329563050405545E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [   7.8198628951827032E-01,  -6.2329563050405545E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [  -7.8198628951827032E-01,  -6.2329563050405545E-01,   0.0000000000000000E+00,   4.4937386610532908E-03],
            [   6.2329563050405545E-01,   0.0000000000000000E+00,   7.8198628951827032E-01,   4.4937386610532908E-03],
            [  -6.2329563050405545E-01,   0.0000000000000000E+00,   7.8198628951827032E-01,   4.4937386610532908E-03],
            [   6.2329563050405545E-01,   0.0000000000000000E+00,  -7.8198628951827032E-01,   4.4937386610532908E-03],
            [  -6.2329563050405545E-01,   0.0000000000000000E+00,  -7.8198628951827032E-01,   4.4937386610532908E-03],
            [   7.8198628951827032E-01,   0.0000000000000000E+00,   6.2329563050405545E-01,   4.4937386610532908E-03],
            [  -7.8198628951827032E-01,   0.0000000000000000E+00,   6.2329563050405545E-01,   4.4937386610532908E-03],
            [   7.8198628951827032E-01,   0.0000000000000000E+00,  -6.2329563050405545E-01,   4.4937386610532908E-03],
            [  -7.8198628951827032E-01,   0.0000000000000000E+00,  -6.2329563050405545E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,   6.2329563050405545E-01,   7.8198628951827032E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,  -6.2329563050405545E-01,   7.8198628951827032E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,   6.2329563050405545E-01,  -7.8198628951827032E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,  -6.2329563050405545E-01,  -7.8198628951827032E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,   7.8198628951827032E-01,   6.2329563050405545E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,  -7.8198628951827032E-01,   6.2329563050405545E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,   7.8198628951827032E-01,  -6.2329563050405545E-01,   4.4937386610532908E-03],
            [   0.0000000000000000E+00,  -7.8198628951827032E-01,  -6.2329563050405545E-01,   4.4937386610532908E-03],
            [   9.4698700868384694E-02,   2.7787483873094699E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,   2.7787483873094699E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,  -2.7787483873094699E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,   2.7787483873094699E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,  -2.7787483873094699E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,  -2.7787483873094699E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,   2.7787483873094699E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,  -2.7787483873094699E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,   9.4698700868384694E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,   9.4698700868384694E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,  -9.4698700868384694E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,   9.4698700868384694E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,  -9.4698700868384694E-02,   9.9511808937122770E-01,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,  -9.4698700868384694E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,   9.4698700868384694E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,  -9.4698700868384694E-02,  -9.9511808937122770E-01,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,   9.4698700868384694E-02,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,   9.4698700868384694E-02,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,  -9.4698700868384694E-02,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,   9.4698700868384694E-02,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,  -9.4698700868384694E-02,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,  -9.4698700868384694E-02,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,   9.4698700868384694E-02,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,  -9.4698700868384694E-02,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,   2.7787483873094699E-02,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,   2.7787483873094699E-02,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,  -2.7787483873094699E-02,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,   2.7787483873094699E-02,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,  -2.7787483873094699E-02,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   9.9511808937122770E-01,  -2.7787483873094699E-02,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,   2.7787483873094699E-02,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -9.9511808937122770E-01,  -2.7787483873094699E-02,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,   9.9511808937122770E-01,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,   9.9511808937122770E-01,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,  -9.9511808937122770E-01,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,   9.9511808937122770E-01,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,  -9.9511808937122770E-01,   2.7787483873094699E-02,   2.4151575420172221E-03],
            [   9.4698700868384694E-02,  -9.9511808937122770E-01,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,   9.9511808937122770E-01,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [  -9.4698700868384694E-02,  -9.9511808937122770E-01,  -2.7787483873094699E-02,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,   9.9511808937122770E-01,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,   9.9511808937122770E-01,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,  -9.9511808937122770E-01,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,   9.9511808937122770E-01,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,  -9.9511808937122770E-01,   9.4698700868384694E-02,   2.4151575420172221E-03],
            [   2.7787483873094699E-02,  -9.9511808937122770E-01,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,   9.9511808937122770E-01,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [  -2.7787483873094699E-02,  -9.9511808937122770E-01,  -9.4698700868384694E-02,   2.4151575420172221E-03],
            [   1.3531703005681411E-01,   6.0765698786283642E-02,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,   6.0765698786283642E-02,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,  -6.0765698786283642E-02,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,   6.0765698786283642E-02,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,  -6.0765698786283642E-02,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,  -6.0765698786283642E-02,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,   6.0765698786283642E-02,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,  -6.0765698786283642E-02,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,   1.3531703005681411E-01,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,   1.3531703005681411E-01,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,  -1.3531703005681411E-01,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,   1.3531703005681411E-01,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,  -1.3531703005681411E-01,   9.8893722309741072E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,  -1.3531703005681411E-01,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,   1.3531703005681411E-01,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,  -1.3531703005681411E-01,  -9.8893722309741072E-01,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,   1.3531703005681411E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,   1.3531703005681411E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,  -1.3531703005681411E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,   1.3531703005681411E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,  -1.3531703005681411E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,  -1.3531703005681411E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,   1.3531703005681411E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,  -1.3531703005681411E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,   6.0765698786283642E-02,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,   6.0765698786283642E-02,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,  -6.0765698786283642E-02,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,   6.0765698786283642E-02,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,  -6.0765698786283642E-02,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   9.8893722309741072E-01,  -6.0765698786283642E-02,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,   6.0765698786283642E-02,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -9.8893722309741072E-01,  -6.0765698786283642E-02,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,   9.8893722309741072E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,   9.8893722309741072E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,  -9.8893722309741072E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,   9.8893722309741072E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,  -9.8893722309741072E-01,   6.0765698786283642E-02,   2.8920976901946182E-03],
            [   1.3531703005681411E-01,  -9.8893722309741072E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,   9.8893722309741072E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [  -1.3531703005681411E-01,  -9.8893722309741072E-01,  -6.0765698786283642E-02,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,   9.8893722309741072E-01,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,   9.8893722309741072E-01,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,  -9.8893722309741072E-01,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,   9.8893722309741072E-01,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,  -9.8893722309741072E-01,   1.3531703005681411E-01,   2.8920976901946182E-03],
            [   6.0765698786283642E-02,  -9.8893722309741072E-01,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,   9.8893722309741072E-01,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [  -6.0765698786283642E-02,  -9.8893722309741072E-01,  -1.3531703005681411E-01,   2.8920976901946182E-03],
            [   1.7716794817260770E-01,   9.7030727627110402E-02,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,   9.7030727627110402E-02,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,  -9.7030727627110402E-02,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,   9.7030727627110402E-02,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,  -9.7030727627110402E-02,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,  -9.7030727627110402E-02,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,   9.7030727627110402E-02,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,  -9.7030727627110402E-02,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,   1.7716794817260770E-01,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,   1.7716794817260770E-01,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,  -1.7716794817260770E-01,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,   1.7716794817260770E-01,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,  -1.7716794817260770E-01,   9.7938580551101606E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,  -1.7716794817260770E-01,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,   1.7716794817260770E-01,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,  -1.7716794817260770E-01,  -9.7938580551101606E-01,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,   1.7716794817260770E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,   1.7716794817260770E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,  -1.7716794817260770E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,   1.7716794817260770E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,  -1.7716794817260770E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,  -1.7716794817260770E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,   1.7716794817260770E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,  -1.7716794817260770E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,   9.7030727627110402E-02,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,   9.7030727627110402E-02,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,  -9.7030727627110402E-02,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,   9.7030727627110402E-02,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,  -9.7030727627110402E-02,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7938580551101606E-01,  -9.7030727627110402E-02,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,   9.7030727627110402E-02,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7938580551101606E-01,  -9.7030727627110402E-02,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,   9.7938580551101606E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,   9.7938580551101606E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,  -9.7938580551101606E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,   9.7938580551101606E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,  -9.7938580551101606E-01,   9.7030727627110402E-02,   3.2725952445211981E-03],
            [   1.7716794817260770E-01,  -9.7938580551101606E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,   9.7938580551101606E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [  -1.7716794817260770E-01,  -9.7938580551101606E-01,  -9.7030727627110402E-02,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,   9.7938580551101606E-01,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,   9.7938580551101606E-01,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,  -9.7938580551101606E-01,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,   9.7938580551101606E-01,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,  -9.7938580551101606E-01,   1.7716794817260770E-01,   3.2725952445211981E-03],
            [   9.7030727627110402E-02,  -9.7938580551101606E-01,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,   9.7938580551101606E-01,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [  -9.7030727627110402E-02,  -9.7938580551101606E-01,  -1.7716794817260770E-01,   3.2725952445211981E-03],
            [   2.1970666642317510E-01,   1.3541124585247619E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,   1.3541124585247619E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,  -1.3541124585247619E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,   1.3541124585247619E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,  -1.3541124585247619E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,  -1.3541124585247619E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,   1.3541124585247619E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,  -1.3541124585247619E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,   2.1970666642317510E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,   2.1970666642317510E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,  -2.1970666642317510E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,   2.1970666642317510E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,  -2.1970666642317510E-01,   9.6612254669161712E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,  -2.1970666642317510E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,   2.1970666642317510E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,  -2.1970666642317510E-01,  -9.6612254669161712E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,   2.1970666642317510E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,   2.1970666642317510E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,  -2.1970666642317510E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,   2.1970666642317510E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,  -2.1970666642317510E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,  -2.1970666642317510E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,   2.1970666642317510E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,  -2.1970666642317510E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,   1.3541124585247619E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,   1.3541124585247619E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,  -1.3541124585247619E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,   1.3541124585247619E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,  -1.3541124585247619E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   9.6612254669161712E-01,  -1.3541124585247619E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,   1.3541124585247619E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -9.6612254669161712E-01,  -1.3541124585247619E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,   9.6612254669161712E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,   9.6612254669161712E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,  -9.6612254669161712E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,   9.6612254669161712E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,  -9.6612254669161712E-01,   1.3541124585247619E-01,   3.5754785501419806E-03],
            [   2.1970666642317510E-01,  -9.6612254669161712E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,   9.6612254669161712E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [  -2.1970666642317510E-01,  -9.6612254669161712E-01,  -1.3541124585247619E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,   9.6612254669161712E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,   9.6612254669161712E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,  -9.6612254669161712E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,   9.6612254669161712E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,  -9.6612254669161712E-01,   2.1970666642317510E-01,   3.5754785501419806E-03],
            [   1.3541124585247619E-01,  -9.6612254669161712E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,   9.6612254669161712E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [  -1.3541124585247619E-01,  -9.6612254669161712E-01,  -2.1970666642317510E-01,   3.5754785501419806E-03],
            [   2.6247835573749267E-01,   1.7509964797440999E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,   1.7509964797440999E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,  -1.7509964797440999E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,   1.7509964797440999E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,  -1.7509964797440999E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,  -1.7509964797440999E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,   1.7509964797440999E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,  -1.7509964797440999E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,   2.6247835573749267E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,   2.6247835573749267E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,  -2.6247835573749267E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,   2.6247835573749267E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,  -2.6247835573749267E-01,   9.4891792376821504E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,  -2.6247835573749267E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,   2.6247835573749267E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,  -2.6247835573749267E-01,  -9.4891792376821504E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,   2.6247835573749267E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,   2.6247835573749267E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,  -2.6247835573749267E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,   2.6247835573749267E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,  -2.6247835573749267E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,  -2.6247835573749267E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,   2.6247835573749267E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,  -2.6247835573749267E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,   1.7509964797440999E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,   1.7509964797440999E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,  -1.7509964797440999E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,   1.7509964797440999E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,  -1.7509964797440999E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   9.4891792376821504E-01,  -1.7509964797440999E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,   1.7509964797440999E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -9.4891792376821504E-01,  -1.7509964797440999E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,   9.4891792376821504E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,   9.4891792376821504E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,  -9.4891792376821504E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,   9.4891792376821504E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,  -9.4891792376821504E-01,   1.7509964797440999E-01,   3.8162445211913578E-03],
            [   2.6247835573749267E-01,  -9.4891792376821504E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,   9.4891792376821504E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [  -2.6247835573749267E-01,  -9.4891792376821504E-01,  -1.7509964797440999E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,   9.4891792376821504E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,   9.4891792376821504E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,  -9.4891792376821504E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,   9.4891792376821504E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,  -9.4891792376821504E-01,   2.6247835573749267E-01,   3.8162445211913578E-03],
            [   1.7509964797440999E-01,  -9.4891792376821504E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,   9.4891792376821504E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [  -1.7509964797440999E-01,  -9.4891792376821504E-01,  -2.6247835573749267E-01,   3.8162445211913578E-03],
            [   3.0509695212144422E-01,   2.1548969074498020E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,   2.1548969074498020E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,  -2.1548969074498020E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,   2.1548969074498020E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,  -2.1548969074498020E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,  -2.1548969074498020E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,   2.1548969074498020E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,  -2.1548969074498020E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,   3.0509695212144422E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,   3.0509695212144422E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,  -3.0509695212144422E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,   3.0509695212144422E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,  -3.0509695212144422E-01,   9.2762063527545457E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,  -3.0509695212144422E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,   3.0509695212144422E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,  -3.0509695212144422E-01,  -9.2762063527545457E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,   3.0509695212144422E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,   3.0509695212144422E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,  -3.0509695212144422E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,   3.0509695212144422E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,  -3.0509695212144422E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,  -3.0509695212144422E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,   3.0509695212144422E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,  -3.0509695212144422E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,   2.1548969074498020E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,   2.1548969074498020E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,  -2.1548969074498020E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,   2.1548969074498020E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,  -2.1548969074498020E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   9.2762063527545457E-01,  -2.1548969074498020E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,   2.1548969074498020E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -9.2762063527545457E-01,  -2.1548969074498020E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,   9.2762063527545457E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,   9.2762063527545457E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,  -9.2762063527545457E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,   9.2762063527545457E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,  -9.2762063527545457E-01,   2.1548969074498020E-01,   4.0066802454977344E-03],
            [   3.0509695212144422E-01,  -9.2762063527545457E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,   9.2762063527545457E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [  -3.0509695212144422E-01,  -9.2762063527545457E-01,  -2.1548969074498020E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,   9.2762063527545457E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,   9.2762063527545457E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,  -9.2762063527545457E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,   9.2762063527545457E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,  -9.2762063527545457E-01,   3.0509695212144422E-01,   4.0066802454977344E-03],
            [   2.1548969074498020E-01,  -9.2762063527545457E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,   9.2762063527545457E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [  -2.1548969074498020E-01,  -9.2762063527545457E-01,  -3.0509695212144422E-01,   4.0066802454977344E-03],
            [   3.4722526371960211E-01,   2.5609546257401522E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,   2.5609546257401522E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,  -2.5609546257401522E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,   2.5609546257401522E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,  -2.5609546257401522E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,  -2.5609546257401522E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,   2.5609546257401522E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,  -2.5609546257401522E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,   3.4722526371960211E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,   3.4722526371960211E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,  -3.4722526371960211E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,   3.4722526371960211E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,  -3.4722526371960211E-01,   9.0213620384277560E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,  -3.4722526371960211E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,   3.4722526371960211E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,  -3.4722526371960211E-01,  -9.0213620384277560E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,   3.4722526371960211E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,   3.4722526371960211E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,  -3.4722526371960211E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,   3.4722526371960211E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,  -3.4722526371960211E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,  -3.4722526371960211E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,   3.4722526371960211E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,  -3.4722526371960211E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,   2.5609546257401522E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,   2.5609546257401522E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,  -2.5609546257401522E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,   2.5609546257401522E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,  -2.5609546257401522E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   9.0213620384277560E-01,  -2.5609546257401522E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,   2.5609546257401522E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -9.0213620384277560E-01,  -2.5609546257401522E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,   9.0213620384277560E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,   9.0213620384277560E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,  -9.0213620384277560E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,   9.0213620384277560E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,  -9.0213620384277560E-01,   2.5609546257401522E-01,   4.1557570886285519E-03],
            [   3.4722526371960211E-01,  -9.0213620384277560E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,   9.0213620384277560E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [  -3.4722526371960211E-01,  -9.0213620384277560E-01,  -2.5609546257401522E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,   9.0213620384277560E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,   9.0213620384277560E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,  -9.0213620384277560E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,   9.0213620384277560E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,  -9.0213620384277560E-01,   3.4722526371960211E-01,   4.1557570886285519E-03],
            [   2.5609546257401522E-01,  -9.0213620384277560E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,   9.0213620384277560E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [  -2.5609546257401522E-01,  -9.0213620384277560E-01,  -3.4722526371960211E-01,   4.1557570886285519E-03],
            [   3.8856102190263597E-01,   2.9650700506240962E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,   2.9650700506240962E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,  -2.9650700506240962E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,   2.9650700506240962E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,  -2.9650700506240962E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,  -2.9650700506240962E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,   2.9650700506240962E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,  -2.9650700506240962E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,   3.8856102190263597E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,   3.8856102190263597E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,  -3.8856102190263597E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,   3.8856102190263597E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,  -3.8856102190263597E-01,   8.7241270520717396E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,  -3.8856102190263597E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,   3.8856102190263597E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,  -3.8856102190263597E-01,  -8.7241270520717396E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,   3.8856102190263597E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,   3.8856102190263597E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,  -3.8856102190263597E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,   3.8856102190263597E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,  -3.8856102190263597E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,  -3.8856102190263597E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,   3.8856102190263597E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,  -3.8856102190263597E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,   2.9650700506240962E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,   2.9650700506240962E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,  -2.9650700506240962E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,   2.9650700506240962E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,  -2.9650700506240962E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   8.7241270520717396E-01,  -2.9650700506240962E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,   2.9650700506240962E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -8.7241270520717396E-01,  -2.9650700506240962E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,   8.7241270520717396E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,   8.7241270520717396E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,  -8.7241270520717396E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,   8.7241270520717396E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,  -8.7241270520717396E-01,   2.9650700506240962E-01,   4.2704686427102413E-03],
            [   3.8856102190263597E-01,  -8.7241270520717396E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,   8.7241270520717396E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [  -3.8856102190263597E-01,  -8.7241270520717396E-01,  -2.9650700506240962E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,   8.7241270520717396E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,   8.7241270520717396E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,  -8.7241270520717396E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,   8.7241270520717396E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,  -8.7241270520717396E-01,   3.8856102190263597E-01,   4.2704686427102413E-03],
            [   2.9650700506240962E-01,  -8.7241270520717396E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,   8.7241270520717396E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [  -2.9650700506240962E-01,  -8.7241270520717396E-01,  -3.8856102190263597E-01,   4.2704686427102413E-03],
            [   4.2882737760627648E-01,   3.3636414887344968E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,   3.3636414887344968E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,  -3.3636414887344968E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,   3.3636414887344968E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,  -3.3636414887344968E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,  -3.3636414887344968E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,   3.3636414887344968E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,  -3.3636414887344968E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,   4.2882737760627648E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,   4.2882737760627648E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,  -4.2882737760627648E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,   4.2882737760627648E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,  -4.2882737760627648E-01,   8.3843081978656042E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,  -4.2882737760627648E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,   4.2882737760627648E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,  -4.2882737760627648E-01,  -8.3843081978656042E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,   4.2882737760627648E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,   4.2882737760627648E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,  -4.2882737760627648E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,   4.2882737760627648E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,  -4.2882737760627648E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,  -4.2882737760627648E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,   4.2882737760627648E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,  -4.2882737760627648E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,   3.3636414887344968E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,   3.3636414887344968E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,  -3.3636414887344968E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,   3.3636414887344968E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,  -3.3636414887344968E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   8.3843081978656042E-01,  -3.3636414887344968E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,   3.3636414887344968E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -8.3843081978656042E-01,  -3.3636414887344968E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,   8.3843081978656042E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,   8.3843081978656042E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,  -8.3843081978656042E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,   8.3843081978656042E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,  -8.3843081978656042E-01,   3.3636414887344968E-01,   4.3564564597955123E-03],
            [   4.2882737760627648E-01,  -8.3843081978656042E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,   8.3843081978656042E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [  -4.2882737760627648E-01,  -8.3843081978656042E-01,  -3.3636414887344968E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,   8.3843081978656042E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,   8.3843081978656042E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,  -8.3843081978656042E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,   8.3843081978656042E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,  -8.3843081978656042E-01,   4.2882737760627648E-01,   4.3564564597955123E-03],
            [   3.3636414887344968E-01,  -8.3843081978656042E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,   8.3843081978656042E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [  -3.3636414887344968E-01,  -8.3843081978656042E-01,  -4.2882737760627648E-01,   4.3564564597955123E-03],
            [   4.6776624713029480E-01,   3.7534000298367881E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,   3.7534000298367881E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,  -3.7534000298367881E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,   3.7534000298367881E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,  -3.7534000298367881E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,  -3.7534000298367881E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,   3.7534000298367881E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,  -3.7534000298367881E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,   4.6776624713029480E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,   4.6776624713029480E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,  -4.6776624713029480E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,   4.6776624713029480E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,  -4.6776624713029480E-01,   8.0019661346812254E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,  -4.6776624713029480E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,   4.6776624713029480E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,  -4.6776624713029480E-01,  -8.0019661346812254E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,   4.6776624713029480E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,   4.6776624713029480E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,  -4.6776624713029480E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,   4.6776624713029480E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,  -4.6776624713029480E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,  -4.6776624713029480E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,   4.6776624713029480E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,  -4.6776624713029480E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,   3.7534000298367881E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,   3.7534000298367881E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,  -3.7534000298367881E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,   3.7534000298367881E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,  -3.7534000298367881E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   8.0019661346812254E-01,  -3.7534000298367881E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,   3.7534000298367881E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -8.0019661346812254E-01,  -3.7534000298367881E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,   8.0019661346812254E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,   8.0019661346812254E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,  -8.0019661346812254E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,   8.0019661346812254E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,  -8.0019661346812254E-01,   3.7534000298367881E-01,   4.4184564486946234E-03],
            [   4.6776624713029480E-01,  -8.0019661346812254E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,   8.0019661346812254E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [  -4.6776624713029480E-01,  -8.0019661346812254E-01,  -3.7534000298367881E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,   8.0019661346812254E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,   8.0019661346812254E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,  -8.0019661346812254E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,   8.0019661346812254E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,  -8.0019661346812254E-01,   4.6776624713029480E-01,   4.4184564486946234E-03],
            [   3.7534000298367881E-01,  -8.0019661346812254E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,   8.0019661346812254E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [  -3.7534000298367881E-01,  -8.0019661346812254E-01,  -4.6776624713029480E-01,   4.4184564486946234E-03],
            [   5.0513335895533595E-01,   4.1312975221442860E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,   4.1312975221442860E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,  -4.1312975221442860E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,   4.1312975221442860E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,  -4.1312975221442860E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,  -4.1312975221442860E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,   4.1312975221442860E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,  -4.1312975221442860E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,   5.0513335895533595E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,   5.0513335895533595E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,  -5.0513335895533595E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,   5.0513335895533595E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,  -5.0513335895533595E-01,   7.5773616615926720E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,  -5.0513335895533595E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,   5.0513335895533595E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,  -5.0513335895533595E-01,  -7.5773616615926720E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,   5.0513335895533595E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,   5.0513335895533595E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,  -5.0513335895533595E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,   5.0513335895533595E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,  -5.0513335895533595E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,  -5.0513335895533595E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,   5.0513335895533595E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,  -5.0513335895533595E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,   4.1312975221442860E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,   4.1312975221442860E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,  -4.1312975221442860E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,   4.1312975221442860E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,  -4.1312975221442860E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   7.5773616615926720E-01,  -4.1312975221442860E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,   4.1312975221442860E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -7.5773616615926720E-01,  -4.1312975221442860E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,   7.5773616615926720E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,   7.5773616615926720E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,  -7.5773616615926720E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,   7.5773616615926720E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,  -7.5773616615926720E-01,   4.1312975221442860E-01,   4.4606156932228448E-03],
            [   5.0513335895533595E-01,  -7.5773616615926720E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,   7.5773616615926720E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [  -5.0513335895533595E-01,  -7.5773616615926720E-01,  -4.1312975221442860E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,   7.5773616615926720E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,   7.5773616615926720E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,  -7.5773616615926720E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,   7.5773616615926720E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,  -7.5773616615926720E-01,   5.0513335895533595E-01,   4.4606156932228448E-03],
            [   4.1312975221442860E-01,  -7.5773616615926720E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,   7.5773616615926720E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [  -4.1312975221442860E-01,  -7.5773616615926720E-01,  -5.0513335895533595E-01,   4.4606156932228448E-03],
            [   5.4069421458104916E-01,   4.4944237760817951E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,   4.4944237760817951E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,  -4.4944237760817951E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,   4.4944237760817951E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,  -4.4944237760817951E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,  -4.4944237760817951E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,   4.4944237760817951E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,  -4.4944237760817951E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,   5.4069421458104916E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,   5.4069421458104916E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,  -5.4069421458104916E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,   5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,  -5.4069421458104916E-01,   7.1109163651985741E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,  -5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,   5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,  -5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,   5.4069421458104916E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,   5.4069421458104916E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,   5.4069421458104916E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,  -5.4069421458104916E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,   5.4069421458104916E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,  -5.4069421458104916E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,   4.4944237760817951E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,   4.4944237760817951E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,  -4.4944237760817951E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,   4.4944237760817951E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,  -4.4944237760817951E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   7.1109163651985741E-01,  -4.4944237760817951E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,   4.4944237760817951E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -7.1109163651985741E-01,  -4.4944237760817951E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,   7.1109163651985741E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,   7.1109163651985741E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,   7.1109163651985741E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,  -7.1109163651985741E-01,   4.4944237760817951E-01,   4.4867170319427023E-03],
            [   5.4069421458104916E-01,  -7.1109163651985741E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,   7.1109163651985741E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [  -5.4069421458104916E-01,  -7.1109163651985741E-01,  -4.4944237760817951E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,   7.1109163651985741E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,   7.1109163651985741E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,  -7.1109163651985741E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,   7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,  -7.1109163651985741E-01,   5.4069421458104916E-01,   4.4867170319427023E-03],
            [   4.4944237760817951E-01,  -7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,   7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [  -4.4944237760817951E-01,  -7.1109163651985741E-01,  -5.4069421458104916E-01,   4.4867170319427023E-03],
            [   5.7422041225764575E-01,   4.8399389588415020E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,   4.8399389588415020E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,  -4.8399389588415020E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,   4.8399389588415020E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,  -4.8399389588415020E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,  -4.8399389588415020E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,   4.8399389588415020E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,  -4.8399389588415020E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,   5.7422041225764575E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,   5.7422041225764575E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,  -5.7422041225764575E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,   5.7422041225764575E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,  -5.7422041225764575E-01,   6.6031873129083785E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,  -5.7422041225764575E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,   5.7422041225764575E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,  -5.7422041225764575E-01,  -6.6031873129083785E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,   5.7422041225764575E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,   5.7422041225764575E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,  -5.7422041225764575E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,   5.7422041225764575E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,  -5.7422041225764575E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,  -5.7422041225764575E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,   5.7422041225764575E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,  -5.7422041225764575E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,   4.8399389588415020E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,   4.8399389588415020E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,  -4.8399389588415020E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,   4.8399389588415020E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,  -4.8399389588415020E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   6.6031873129083785E-01,  -4.8399389588415020E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,   4.8399389588415020E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -6.6031873129083785E-01,  -4.8399389588415020E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,   6.6031873129083785E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,   6.6031873129083785E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,  -6.6031873129083785E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,   6.6031873129083785E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,  -6.6031873129083785E-01,   4.8399389588415020E-01,   4.5003337363242555E-03],
            [   5.7422041225764575E-01,  -6.6031873129083785E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,   6.6031873129083785E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [  -5.7422041225764575E-01,  -6.6031873129083785E-01,  -4.8399389588415020E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,   6.6031873129083785E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,   6.6031873129083785E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,  -6.6031873129083785E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,   6.6031873129083785E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,  -6.6031873129083785E-01,   5.7422041225764575E-01,   4.5003337363242555E-03],
            [   4.8399389588415020E-01,  -6.6031873129083785E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,   6.6031873129083785E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [  -4.8399389588415020E-01,  -6.6031873129083785E-01,  -5.7422041225764575E-01,   4.5003337363242555E-03],
            [   1.8654070272251880E-01,   3.2591448510707957E-02,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,   3.2591448510707957E-02,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,  -3.2591448510707957E-02,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,   3.2591448510707957E-02,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,  -3.2591448510707957E-02,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,  -3.2591448510707957E-02,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,   3.2591448510707957E-02,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,  -3.2591448510707957E-02,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,   1.8654070272251880E-01,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,   1.8654070272251880E-01,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,  -1.8654070272251880E-01,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,   1.8654070272251880E-01,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,  -1.8654070272251880E-01,   9.8190649438312749E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,  -1.8654070272251880E-01,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,   1.8654070272251880E-01,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,  -1.8654070272251880E-01,  -9.8190649438312749E-01,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,   1.8654070272251880E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,   1.8654070272251880E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,  -1.8654070272251880E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,   1.8654070272251880E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,  -1.8654070272251880E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,  -1.8654070272251880E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,   1.8654070272251880E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,  -1.8654070272251880E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,   3.2591448510707957E-02,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,   3.2591448510707957E-02,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,  -3.2591448510707957E-02,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,   3.2591448510707957E-02,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,  -3.2591448510707957E-02,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   9.8190649438312749E-01,  -3.2591448510707957E-02,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,   3.2591448510707957E-02,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -9.8190649438312749E-01,  -3.2591448510707957E-02,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,   9.8190649438312749E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,   9.8190649438312749E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,  -9.8190649438312749E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,   9.8190649438312749E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,  -9.8190649438312749E-01,   3.2591448510707957E-02,   3.1962454706100430E-03],
            [   1.8654070272251880E-01,  -9.8190649438312749E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,   9.8190649438312749E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [  -1.8654070272251880E-01,  -9.8190649438312749E-01,  -3.2591448510707957E-02,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,   9.8190649438312749E-01,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,   9.8190649438312749E-01,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,  -9.8190649438312749E-01,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,   9.8190649438312749E-01,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,  -9.8190649438312749E-01,   1.8654070272251880E-01,   3.1962454706100430E-03],
            [   3.2591448510707957E-02,  -9.8190649438312749E-01,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,   9.8190649438312749E-01,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [  -3.2591448510707957E-02,  -9.8190649438312749E-01,  -1.8654070272251880E-01,   3.1962454706100430E-03],
            [   2.3211864536894319E-01,   6.8356795052973429E-02,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,   6.8356795052973429E-02,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,  -6.8356795052973429E-02,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,   6.8356795052973429E-02,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,  -6.8356795052973429E-02,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,  -6.8356795052973429E-02,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,   6.8356795052973429E-02,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,  -6.8356795052973429E-02,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,   2.3211864536894319E-01,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,   2.3211864536894319E-01,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,  -2.3211864536894319E-01,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,   2.3211864536894319E-01,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,  -2.3211864536894319E-01,   9.7028257896458836E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,  -2.3211864536894319E-01,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,   2.3211864536894319E-01,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,  -2.3211864536894319E-01,  -9.7028257896458836E-01,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,   2.3211864536894319E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,   2.3211864536894319E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,  -2.3211864536894319E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,   2.3211864536894319E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,  -2.3211864536894319E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,  -2.3211864536894319E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,   2.3211864536894319E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,  -2.3211864536894319E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,   6.8356795052973429E-02,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,   6.8356795052973429E-02,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,  -6.8356795052973429E-02,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,   6.8356795052973429E-02,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,  -6.8356795052973429E-02,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   9.7028257896458836E-01,  -6.8356795052973429E-02,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,   6.8356795052973429E-02,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -9.7028257896458836E-01,  -6.8356795052973429E-02,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,   9.7028257896458836E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,   9.7028257896458836E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,  -9.7028257896458836E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,   9.7028257896458836E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,  -9.7028257896458836E-01,   6.8356795052973429E-02,   3.5018843866153021E-03],
            [   2.3211864536894319E-01,  -9.7028257896458836E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,   9.7028257896458836E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [  -2.3211864536894319E-01,  -9.7028257896458836E-01,  -6.8356795052973429E-02,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,   9.7028257896458836E-01,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,   9.7028257896458836E-01,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,  -9.7028257896458836E-01,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,   9.7028257896458836E-01,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,  -9.7028257896458836E-01,   2.3211864536894319E-01,   3.5018843866153021E-03],
            [   6.8356795052973429E-02,  -9.7028257896458836E-01,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,   9.7028257896458836E-01,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [  -6.8356795052973429E-02,  -9.7028257896458836E-01,  -2.3211864536894319E-01,   3.5018843866153021E-03],
            [   2.7731591425238822E-01,   1.0622848644519890E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,   1.0622848644519890E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,  -1.0622848644519890E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,   1.0622848644519890E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,  -1.0622848644519890E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,  -1.0622848644519890E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,   1.0622848644519890E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,  -1.0622848644519890E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,   2.7731591425238822E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,   2.7731591425238822E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,  -2.7731591425238822E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,   2.7731591425238822E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,  -2.7731591425238822E-01,   9.5488815699532281E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,  -2.7731591425238822E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,   2.7731591425238822E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,  -2.7731591425238822E-01,  -9.5488815699532281E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,   2.7731591425238822E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,   2.7731591425238822E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,  -2.7731591425238822E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,   2.7731591425238822E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,  -2.7731591425238822E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,  -2.7731591425238822E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,   2.7731591425238822E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,  -2.7731591425238822E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,   1.0622848644519890E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,   1.0622848644519890E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,  -1.0622848644519890E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,   1.0622848644519890E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,  -1.0622848644519890E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   9.5488815699532281E-01,  -1.0622848644519890E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,   1.0622848644519890E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -9.5488815699532281E-01,  -1.0622848644519890E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,   9.5488815699532281E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,   9.5488815699532281E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,  -9.5488815699532281E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,   9.5488815699532281E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,  -9.5488815699532281E-01,   1.0622848644519890E-01,   3.7517557457952587E-03],
            [   2.7731591425238822E-01,  -9.5488815699532281E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,   9.5488815699532281E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [  -2.7731591425238822E-01,  -9.5488815699532281E-01,  -1.0622848644519890E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,   9.5488815699532281E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,   9.5488815699532281E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,  -9.5488815699532281E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,   9.5488815699532281E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,  -9.5488815699532281E-01,   2.7731591425238822E-01,   3.7517557457952587E-03],
            [   1.0622848644519890E-01,  -9.5488815699532281E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,   9.5488815699532281E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [  -1.0622848644519890E-01,  -9.5488815699532281E-01,  -2.7731591425238822E-01,   3.7517557457952587E-03],
            [   3.2192001922372537E-01,   1.4544044093230471E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,   1.4544044093230471E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,  -1.4544044093230471E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,   1.4544044093230471E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,  -1.4544044093230471E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,  -1.4544044093230471E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,   1.4544044093230471E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,  -1.4544044093230471E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,   3.2192001922372537E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,   3.2192001922372537E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,  -3.2192001922372537E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,   3.2192001922372537E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,  -3.2192001922372537E-01,   9.3552903715727231E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,  -3.2192001922372537E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,   3.2192001922372537E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,  -3.2192001922372537E-01,  -9.3552903715727231E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,   3.2192001922372537E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,   3.2192001922372537E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,  -3.2192001922372537E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,   3.2192001922372537E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,  -3.2192001922372537E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,  -3.2192001922372537E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,   3.2192001922372537E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,  -3.2192001922372537E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,   1.4544044093230471E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,   1.4544044093230471E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,  -1.4544044093230471E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,   1.4544044093230471E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,  -1.4544044093230471E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   9.3552903715727231E-01,  -1.4544044093230471E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,   1.4544044093230471E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -9.3552903715727231E-01,  -1.4544044093230471E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,   9.3552903715727231E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,   9.3552903715727231E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,  -9.3552903715727231E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,   9.3552903715727231E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,  -9.3552903715727231E-01,   1.4544044093230471E-01,   3.9532142301576256E-03],
            [   3.2192001922372537E-01,  -9.3552903715727231E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,   9.3552903715727231E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [  -3.2192001922372537E-01,  -9.3552903715727231E-01,  -1.4544044093230471E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,   9.3552903715727231E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,   9.3552903715727231E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,  -9.3552903715727231E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,   9.3552903715727231E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,  -9.3552903715727231E-01,   3.2192001922372537E-01,   3.9532142301576256E-03],
            [   1.4544044093230471E-01,  -9.3552903715727231E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,   9.3552903715727231E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [  -1.4544044093230471E-01,  -9.3552903715727231E-01,  -3.2192001922372537E-01,   3.9532142301576256E-03],
            [   3.6570325939440290E-01,   1.8540182825825099E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,   1.8540182825825099E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,  -1.8540182825825099E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,   1.8540182825825099E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,  -1.8540182825825099E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,  -1.8540182825825099E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,   1.8540182825825099E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,  -1.8540182825825099E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,   3.6570325939440290E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,   3.6570325939440290E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,  -3.6570325939440290E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,   3.6570325939440290E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,  -3.6570325939440290E-01,   9.1207855371497915E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,  -3.6570325939440290E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,   3.6570325939440290E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,  -3.6570325939440290E-01,  -9.1207855371497915E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,   3.6570325939440290E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,   3.6570325939440290E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,  -3.6570325939440290E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,   3.6570325939440290E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,  -3.6570325939440290E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,  -3.6570325939440290E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,   3.6570325939440290E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,  -3.6570325939440290E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,   1.8540182825825099E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,   1.8540182825825099E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,  -1.8540182825825099E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,   1.8540182825825099E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,  -1.8540182825825099E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   9.1207855371497915E-01,  -1.8540182825825099E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,   1.8540182825825099E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -9.1207855371497915E-01,  -1.8540182825825099E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,   9.1207855371497915E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,   9.1207855371497915E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,  -9.1207855371497915E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,   9.1207855371497915E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,  -9.1207855371497915E-01,   1.8540182825825099E-01,   4.1133383588062679E-03],
            [   3.6570325939440290E-01,  -9.1207855371497915E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,   9.1207855371497915E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [  -3.6570325939440290E-01,  -9.1207855371497915E-01,  -1.8540182825825099E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,   9.1207855371497915E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,   9.1207855371497915E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,  -9.1207855371497915E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,   9.1207855371497915E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,  -9.1207855371497915E-01,   3.6570325939440290E-01,   4.1133383588062679E-03],
            [   1.8540182825825099E-01,  -9.1207855371497915E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,   9.1207855371497915E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [  -1.8540182825825099E-01,  -9.1207855371497915E-01,  -3.6570325939440290E-01,   4.1133383588062679E-03],
            [   4.0843767783636220E-01,   2.2562974120147500E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,   2.2562974120147500E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,  -2.2562974120147500E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,   2.2562974120147500E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,  -2.2562974120147500E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,  -2.2562974120147500E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,   2.2562974120147500E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,  -2.2562974120147500E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,   4.0843767783636220E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,   4.0843767783636220E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,  -4.0843767783636220E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,   4.0843767783636220E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,  -4.0843767783636220E-01,   8.8446022138307345E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,  -4.0843767783636220E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,   4.0843767783636220E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,  -4.0843767783636220E-01,  -8.8446022138307345E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,   4.0843767783636220E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,   4.0843767783636220E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,  -4.0843767783636220E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,   4.0843767783636220E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,  -4.0843767783636220E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,  -4.0843767783636220E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,   4.0843767783636220E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,  -4.0843767783636220E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,   2.2562974120147500E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,   2.2562974120147500E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,  -2.2562974120147500E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,   2.2562974120147500E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,  -2.2562974120147500E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   8.8446022138307345E-01,  -2.2562974120147500E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,   2.2562974120147500E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -8.8446022138307345E-01,  -2.2562974120147500E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,   8.8446022138307345E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,   8.8446022138307345E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,  -8.8446022138307345E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,   8.8446022138307345E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,  -8.8446022138307345E-01,   2.2562974120147500E-01,   4.2382667436174021E-03],
            [   4.0843767783636220E-01,  -8.8446022138307345E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,   8.8446022138307345E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [  -4.0843767783636220E-01,  -8.8446022138307345E-01,  -2.2562974120147500E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,   8.8446022138307345E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,   8.8446022138307345E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,  -8.8446022138307345E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,   8.8446022138307345E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,  -8.8446022138307345E-01,   4.0843767783636220E-01,   4.2382667436174021E-03],
            [   2.2562974120147500E-01,  -8.8446022138307345E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,   8.8446022138307345E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [  -2.2562974120147500E-01,  -8.8446022138307345E-01,  -4.0843767783636220E-01,   4.2382667436174021E-03],
            [   4.4990049457514270E-01,   2.6571044250008963E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,   2.6571044250008963E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,  -2.6571044250008963E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,   2.6571044250008963E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,  -2.6571044250008963E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,  -2.6571044250008963E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,   2.6571044250008963E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,  -2.6571044250008963E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,   4.4990049457514270E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,   4.4990049457514270E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,  -4.4990049457514270E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,   4.4990049457514270E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,  -4.4990049457514270E-01,   8.5263562306969587E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,  -4.4990049457514270E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,   4.4990049457514270E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,  -4.4990049457514270E-01,  -8.5263562306969587E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,   4.4990049457514270E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,   4.4990049457514270E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,  -4.4990049457514270E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,   4.4990049457514270E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,  -4.4990049457514270E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,  -4.4990049457514270E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,   4.4990049457514270E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,  -4.4990049457514270E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,   2.6571044250008963E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,   2.6571044250008963E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,  -2.6571044250008963E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,   2.6571044250008963E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,  -2.6571044250008963E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   8.5263562306969587E-01,  -2.6571044250008963E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,   2.6571044250008963E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -8.5263562306969587E-01,  -2.6571044250008963E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,   8.5263562306969587E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,   8.5263562306969587E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,  -8.5263562306969587E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,   8.5263562306969587E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,  -8.5263562306969587E-01,   2.6571044250008963E-01,   4.3332294566063110E-03],
            [   4.4990049457514270E-01,  -8.5263562306969587E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,   8.5263562306969587E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [  -4.4990049457514270E-01,  -8.5263562306969587E-01,  -2.6571044250008963E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,   8.5263562306969587E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,   8.5263562306969587E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,  -8.5263562306969587E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,   8.5263562306969587E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,  -8.5263562306969587E-01,   4.4990049457514270E-01,   4.3332294566063110E-03],
            [   2.6571044250008963E-01,  -8.5263562306969587E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,   8.5263562306969587E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [  -2.6571044250008963E-01,  -8.5263562306969587E-01,  -4.4990049457514270E-01,   4.3332294566063110E-03],
            [   4.8987581413263348E-01,   3.0527554876315571E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,   3.0527554876315571E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,  -3.0527554876315571E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,   3.0527554876315571E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,  -3.0527554876315571E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,  -3.0527554876315571E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,   3.0527554876315571E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,  -3.0527554876315571E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,   4.8987581413263348E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,   4.8987581413263348E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,  -4.8987581413263348E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,   4.8987581413263348E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,  -4.8987581413263348E-01,   8.1659569314027347E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,  -4.8987581413263348E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,   4.8987581413263348E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,  -4.8987581413263348E-01,  -8.1659569314027347E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,   4.8987581413263348E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,   4.8987581413263348E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,  -4.8987581413263348E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,   4.8987581413263348E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,  -4.8987581413263348E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,  -4.8987581413263348E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,   4.8987581413263348E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,  -4.8987581413263348E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,   3.0527554876315571E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,   3.0527554876315571E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,  -3.0527554876315571E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,   3.0527554876315571E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,  -3.0527554876315571E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   8.1659569314027347E-01,  -3.0527554876315571E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,   3.0527554876315571E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -8.1659569314027347E-01,  -3.0527554876315571E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,   8.1659569314027347E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,   8.1659569314027347E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,  -8.1659569314027347E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,   8.1659569314027347E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,  -8.1659569314027347E-01,   3.0527554876315571E-01,   4.4027445393582587E-03],
            [   4.8987581413263348E-01,  -8.1659569314027347E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,   8.1659569314027347E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [  -4.8987581413263348E-01,  -8.1659569314027347E-01,  -3.0527554876315571E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,   8.1659569314027347E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,   8.1659569314027347E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,  -8.1659569314027347E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,   8.1659569314027347E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,  -8.1659569314027347E-01,   4.8987581413263348E-01,   4.4027445393582587E-03],
            [   3.0527554876315571E-01,  -8.1659569314027347E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,   8.1659569314027347E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [  -3.0527554876315571E-01,  -8.1659569314027347E-01,  -4.8987581413263348E-01,   4.4027445393582587E-03],
            [   5.2815474422663089E-01,   3.4398639206454229E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,   3.4398639206454229E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,  -3.4398639206454229E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,   3.4398639206454229E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,  -3.4398639206454229E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,  -3.4398639206454229E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,   3.4398639206454229E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,  -3.4398639206454229E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,   5.2815474422663089E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,   5.2815474422663089E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,  -5.2815474422663089E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,   5.2815474422663089E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,  -5.2815474422663089E-01,   7.7635425433581617E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,  -5.2815474422663089E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,   5.2815474422663089E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,  -5.2815474422663089E-01,  -7.7635425433581617E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,   5.2815474422663089E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,   5.2815474422663089E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,  -5.2815474422663089E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,   5.2815474422663089E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,  -5.2815474422663089E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,  -5.2815474422663089E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,   5.2815474422663089E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,  -5.2815474422663089E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,   3.4398639206454229E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,   3.4398639206454229E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,  -3.4398639206454229E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,   3.4398639206454229E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,  -3.4398639206454229E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   7.7635425433581617E-01,  -3.4398639206454229E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,   3.4398639206454229E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -7.7635425433581617E-01,  -3.4398639206454229E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,   7.7635425433581617E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,   7.7635425433581617E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,  -7.7635425433581617E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,   7.7635425433581617E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,  -7.7635425433581617E-01,   3.4398639206454229E-01,   4.4508259986849562E-03],
            [   5.2815474422663089E-01,  -7.7635425433581617E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,   7.7635425433581617E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [  -5.2815474422663089E-01,  -7.7635425433581617E-01,  -3.4398639206454229E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,   7.7635425433581617E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,   7.7635425433581617E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,  -7.7635425433581617E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,   7.7635425433581617E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,  -7.7635425433581617E-01,   5.2815474422663089E-01,   4.4508259986849562E-03],
            [   3.4398639206454229E-01,  -7.7635425433581617E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,   7.7635425433581617E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [  -3.4398639206454229E-01,  -7.7635425433581617E-01,  -5.2815474422663089E-01,   4.4508259986849562E-03],
            [   5.6453469898139919E-01,   3.8152294561219141E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,   3.8152294561219141E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,  -3.8152294561219141E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,   3.8152294561219141E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,  -3.8152294561219141E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,  -3.8152294561219141E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,   3.8152294561219141E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,  -3.8152294561219141E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,   5.6453469898139919E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,   5.6453469898139919E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,  -5.6453469898139919E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,   5.6453469898139919E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,  -5.6453469898139919E-01,   7.3194317786108076E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,  -5.6453469898139919E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,   5.6453469898139919E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,  -5.6453469898139919E-01,  -7.3194317786108076E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,   5.6453469898139919E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,   5.6453469898139919E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,  -5.6453469898139919E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,   5.6453469898139919E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,  -5.6453469898139919E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,  -5.6453469898139919E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,   5.6453469898139919E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,  -5.6453469898139919E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,   3.8152294561219141E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,   3.8152294561219141E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,  -3.8152294561219141E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,   3.8152294561219141E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,  -3.8152294561219141E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   7.3194317786108076E-01,  -3.8152294561219141E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,   3.8152294561219141E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -7.3194317786108076E-01,  -3.8152294561219141E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,   7.3194317786108076E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,   7.3194317786108076E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,  -7.3194317786108076E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,   7.3194317786108076E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,  -7.3194317786108076E-01,   3.8152294561219141E-01,   4.4811621287193550E-03],
            [   5.6453469898139919E-01,  -7.3194317786108076E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,   7.3194317786108076E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [  -5.6453469898139919E-01,  -7.3194317786108076E-01,  -3.8152294561219141E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,   7.3194317786108076E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,   7.3194317786108076E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,  -7.3194317786108076E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,   7.3194317786108076E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,  -7.3194317786108076E-01,   5.6453469898139919E-01,   4.4811621287193550E-03],
            [   3.8152294561219141E-01,  -7.3194317786108076E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,   7.3194317786108076E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [  -3.8152294561219141E-01,  -7.3194317786108076E-01,  -5.6453469898139919E-01,   4.4811621287193550E-03],
            [   5.9881812521598476E-01,   4.1757524209667340E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,   4.1757524209667340E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,  -4.1757524209667340E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,   4.1757524209667340E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,  -4.1757524209667340E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,  -4.1757524209667340E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,   4.1757524209667340E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,  -4.1757524209667340E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,   5.9881812521598476E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,   5.9881812521598476E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,  -5.9881812521598476E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,   5.9881812521598476E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,  -5.9881812521598476E-01,   6.8340893329010399E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,  -5.9881812521598476E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,   5.9881812521598476E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,  -5.9881812521598476E-01,  -6.8340893329010399E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,   5.9881812521598476E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,   5.9881812521598476E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,  -5.9881812521598476E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,   5.9881812521598476E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,  -5.9881812521598476E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,  -5.9881812521598476E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,   5.9881812521598476E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,  -5.9881812521598476E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,   4.1757524209667340E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,   4.1757524209667340E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,  -4.1757524209667340E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,   4.1757524209667340E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,  -4.1757524209667340E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   6.8340893329010399E-01,  -4.1757524209667340E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,   4.1757524209667340E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -6.8340893329010399E-01,  -4.1757524209667340E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,   6.8340893329010399E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,   6.8340893329010399E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,  -6.8340893329010399E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,   6.8340893329010399E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,  -6.8340893329010399E-01,   4.1757524209667340E-01,   4.4972553271393073E-03],
            [   5.9881812521598476E-01,  -6.8340893329010399E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,   6.8340893329010399E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [  -5.9881812521598476E-01,  -6.8340893329010399E-01,  -4.1757524209667340E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,   6.8340893329010399E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,   6.8340893329010399E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,  -6.8340893329010399E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,   6.8340893329010399E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,  -6.8340893329010399E-01,   5.9881812521598476E-01,   4.4972553271393073E-03],
            [   4.1757524209667340E-01,  -6.8340893329010399E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,   6.8340893329010399E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [  -4.1757524209667340E-01,  -6.8340893329010399E-01,  -5.9881812521598476E-01,   4.4972553271393073E-03],
            [   2.8504254244716032E-01,   3.5621495098625361E-02,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,   3.5621495098625361E-02,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,  -3.5621495098625361E-02,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,   3.5621495098625361E-02,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,  -3.5621495098625361E-02,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,  -3.5621495098625361E-02,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,   3.5621495098625361E-02,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,  -3.5621495098625361E-02,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,   2.8504254244716032E-01,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,   2.8504254244716032E-01,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,  -2.8504254244716032E-01,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,   2.8504254244716032E-01,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,  -2.8504254244716032E-01,   9.5785273298257989E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,  -2.8504254244716032E-01,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,   2.8504254244716032E-01,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,  -2.8504254244716032E-01,  -9.5785273298257989E-01,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,   2.8504254244716032E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,   2.8504254244716032E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,  -2.8504254244716032E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,   2.8504254244716032E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,  -2.8504254244716032E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,  -2.8504254244716032E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,   2.8504254244716032E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,  -2.8504254244716032E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,   3.5621495098625361E-02,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,   3.5621495098625361E-02,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,  -3.5621495098625361E-02,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,   3.5621495098625361E-02,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,  -3.5621495098625361E-02,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   9.5785273298257989E-01,  -3.5621495098625361E-02,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,   3.5621495098625361E-02,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -9.5785273298257989E-01,  -3.5621495098625361E-02,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,   9.5785273298257989E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,   9.5785273298257989E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,  -9.5785273298257989E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,   9.5785273298257989E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,  -9.5785273298257989E-01,   3.5621495098625361E-02,   3.7179424470060903E-03],
            [   2.8504254244716032E-01,  -9.5785273298257989E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,   9.5785273298257989E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [  -2.8504254244716032E-01,  -9.5785273298257989E-01,  -3.5621495098625361E-02,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,   9.5785273298257989E-01,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,   9.5785273298257989E-01,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,  -9.5785273298257989E-01,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,   9.5785273298257989E-01,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,  -9.5785273298257989E-01,   2.8504254244716032E-01,   3.7179424470060903E-03],
            [   3.5621495098625361E-02,  -9.5785273298257989E-01,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,   9.5785273298257989E-01,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [  -3.5621495098625361E-02,  -9.5785273298257989E-01,  -2.8504254244716032E-01,   3.7179424470060903E-03],
            [   3.3246194330278761E-01,   7.3303188868710956E-02,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,   7.3303188868710956E-02,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,  -7.3303188868710956E-02,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,   7.3303188868710956E-02,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,  -7.3303188868710956E-02,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,  -7.3303188868710956E-02,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,   7.3303188868710956E-02,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,  -7.3303188868710956E-02,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,   3.3246194330278761E-01,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,   3.3246194330278761E-01,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,  -3.3246194330278761E-01,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,   3.3246194330278761E-01,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,  -3.3246194330278761E-01,   9.4026363258237955E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,  -3.3246194330278761E-01,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,   3.3246194330278761E-01,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,  -3.3246194330278761E-01,  -9.4026363258237955E-01,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,   3.3246194330278761E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,   3.3246194330278761E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,  -3.3246194330278761E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,   3.3246194330278761E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,  -3.3246194330278761E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,  -3.3246194330278761E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,   3.3246194330278761E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,  -3.3246194330278761E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,   7.3303188868710956E-02,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,   7.3303188868710956E-02,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,  -7.3303188868710956E-02,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,   7.3303188868710956E-02,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,  -7.3303188868710956E-02,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   9.4026363258237955E-01,  -7.3303188868710956E-02,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,   7.3303188868710956E-02,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -9.4026363258237955E-01,  -7.3303188868710956E-02,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,   9.4026363258237955E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,   9.4026363258237955E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,  -9.4026363258237955E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,   9.4026363258237955E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,  -9.4026363258237955E-01,   7.3303188868710956E-02,   3.9201397939812935E-03],
            [   3.3246194330278761E-01,  -9.4026363258237955E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,   9.4026363258237955E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [  -3.3246194330278761E-01,  -9.4026363258237955E-01,  -7.3303188868710956E-02,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,   9.4026363258237955E-01,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,   9.4026363258237955E-01,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,  -9.4026363258237955E-01,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,   9.4026363258237955E-01,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,  -9.4026363258237955E-01,   3.3246194330278761E-01,   3.9201397939812935E-03],
            [   7.3303188868710956E-02,  -9.4026363258237955E-01,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,   9.4026363258237955E-01,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [  -7.3303188868710956E-02,  -9.4026363258237955E-01,  -3.3246194330278761E-01,   3.9201397939812935E-03],
            [   3.7858483330762821E-01,   1.1232262960084720E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,   1.1232262960084720E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,  -1.1232262960084720E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,   1.1232262960084720E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,  -1.1232262960084720E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,  -1.1232262960084720E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,   1.1232262960084720E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,  -1.1232262960084720E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,   3.7858483330762821E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,   3.7858483330762821E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,  -3.7858483330762821E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,   3.7858483330762821E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,  -3.7858483330762821E-01,   9.1872583008696684E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,  -3.7858483330762821E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,   3.7858483330762821E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,  -3.7858483330762821E-01,  -9.1872583008696684E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,   3.7858483330762821E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,   3.7858483330762821E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,  -3.7858483330762821E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,   3.7858483330762821E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,  -3.7858483330762821E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,  -3.7858483330762821E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,   3.7858483330762821E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,  -3.7858483330762821E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,   1.1232262960084720E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,   1.1232262960084720E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,  -1.1232262960084720E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,   1.1232262960084720E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,  -1.1232262960084720E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   9.1872583008696684E-01,  -1.1232262960084720E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,   1.1232262960084720E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -9.1872583008696684E-01,  -1.1232262960084720E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,   9.1872583008696684E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,   9.1872583008696684E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,  -9.1872583008696684E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,   9.1872583008696684E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,  -9.1872583008696684E-01,   1.1232262960084720E-01,   4.0850069270283599E-03],
            [   3.7858483330762821E-01,  -9.1872583008696684E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,   9.1872583008696684E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [  -3.7858483330762821E-01,  -9.1872583008696684E-01,  -1.1232262960084720E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,   9.1872583008696684E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,   9.1872583008696684E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,  -9.1872583008696684E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,   9.1872583008696684E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,  -9.1872583008696684E-01,   3.7858483330762821E-01,   4.0850069270283599E-03],
            [   1.1232262960084720E-01,  -9.1872583008696684E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,   9.1872583008696684E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [  -1.1232262960084720E-01,  -9.1872583008696684E-01,  -3.7858483330762821E-01,   4.0850069270283599E-03],
            [   4.2328910285621152E-01,   1.5210841933377081E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,   1.5210841933377081E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,  -1.5210841933377081E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,   1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,  -1.5210841933377081E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,  -1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,   1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,  -1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,   4.2328910285621152E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,   4.2328910285621152E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,  -4.2328910285621152E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,   4.2328910285621152E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,  -4.2328910285621152E-01,   8.9313457226274995E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,  -4.2328910285621152E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,   4.2328910285621152E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,  -4.2328910285621152E-01,  -8.9313457226274995E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,   4.2328910285621152E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,   4.2328910285621152E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,  -4.2328910285621152E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,   4.2328910285621152E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,  -4.2328910285621152E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,  -4.2328910285621152E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,   4.2328910285621152E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,  -4.2328910285621152E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,   1.5210841933377081E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,   1.5210841933377081E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,   1.5210841933377081E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   8.9313457226274995E-01,  -1.5210841933377081E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,   1.5210841933377081E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -8.9313457226274995E-01,  -1.5210841933377081E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,   8.9313457226274995E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,   8.9313457226274995E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,  -8.9313457226274995E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,   8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,  -8.9313457226274995E-01,   1.5210841933377081E-01,   4.2162101292675001E-03],
            [   4.2328910285621152E-01,  -8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,   8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [  -4.2328910285621152E-01,  -8.9313457226274995E-01,  -1.5210841933377081E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,   8.9313457226274995E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,   8.9313457226274995E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,   8.9313457226274995E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,  -8.9313457226274995E-01,   4.2328910285621152E-01,   4.2162101292675001E-03],
            [   1.5210841933377081E-01,  -8.9313457226274995E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,   8.9313457226274995E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [  -1.5210841933377081E-01,  -8.9313457226274995E-01,  -4.2328910285621152E-01,   4.2162101292675001E-03],
            [   4.6642870508297218E-01,   1.9218444592236100E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,   1.9218444592236100E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,  -1.9218444592236100E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,   1.9218444592236100E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,  -1.9218444592236100E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,  -1.9218444592236100E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,   1.9218444592236100E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,  -1.9218444592236100E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,   4.6642870508297218E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,   4.6642870508297218E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,  -4.6642870508297218E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,   4.6642870508297218E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,  -4.6642870508297218E-01,   8.6342886320769752E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,  -4.6642870508297218E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,   4.6642870508297218E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,  -4.6642870508297218E-01,  -8.6342886320769752E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,   4.6642870508297218E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,   4.6642870508297218E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,  -4.6642870508297218E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,   4.6642870508297218E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,  -4.6642870508297218E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,  -4.6642870508297218E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,   4.6642870508297218E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,  -4.6642870508297218E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,   1.9218444592236100E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,   1.9218444592236100E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,  -1.9218444592236100E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,   1.9218444592236100E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,  -1.9218444592236100E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   8.6342886320769752E-01,  -1.9218444592236100E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,   1.9218444592236100E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -8.6342886320769752E-01,  -1.9218444592236100E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,   8.6342886320769752E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,   8.6342886320769752E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,  -8.6342886320769752E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,   8.6342886320769752E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,  -8.6342886320769752E-01,   1.9218444592236100E-01,   4.3176133920835693E-03],
            [   4.6642870508297218E-01,  -8.6342886320769752E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,   8.6342886320769752E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [  -4.6642870508297218E-01,  -8.6342886320769752E-01,  -1.9218444592236100E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,   8.6342886320769752E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,   8.6342886320769752E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,  -8.6342886320769752E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,   8.6342886320769752E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,  -8.6342886320769752E-01,   4.6642870508297218E-01,   4.3176133920835693E-03],
            [   1.9218444592236100E-01,  -8.6342886320769752E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,   8.6342886320769752E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [  -1.9218444592236100E-01,  -8.6342886320769752E-01,  -4.6642870508297218E-01,   4.3176133920835693E-03],
            [   5.0784584937357258E-01,   2.3213609896783030E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,   2.3213609896783030E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,  -2.3213609896783030E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,   2.3213609896783030E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,  -2.3213609896783030E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,  -2.3213609896783030E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,   2.3213609896783030E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,  -2.3213609896783030E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,   5.0784584937357258E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,   5.0784584937357258E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,  -5.0784584937357258E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,   5.0784584937357258E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,  -5.0784584937357258E-01,   8.2958147570328034E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,  -5.0784584937357258E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,   5.0784584937357258E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,  -5.0784584937357258E-01,  -8.2958147570328034E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,   5.0784584937357258E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,   5.0784584937357258E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,  -5.0784584937357258E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,   5.0784584937357258E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,  -5.0784584937357258E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,  -5.0784584937357258E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,   5.0784584937357258E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,  -5.0784584937357258E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,   2.3213609896783030E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,   2.3213609896783030E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,  -2.3213609896783030E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,   2.3213609896783030E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,  -2.3213609896783030E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   8.2958147570328034E-01,  -2.3213609896783030E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,   2.3213609896783030E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -8.2958147570328034E-01,  -2.3213609896783030E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,   8.2958147570328034E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,   8.2958147570328034E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,  -8.2958147570328034E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,   8.2958147570328034E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,  -8.2958147570328034E-01,   2.3213609896783030E-01,   4.3929352914964586E-03],
            [   5.0784584937357258E-01,  -8.2958147570328034E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,   8.2958147570328034E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [  -5.0784584937357258E-01,  -8.2958147570328034E-01,  -2.3213609896783030E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,   8.2958147570328034E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,   8.2958147570328034E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,  -8.2958147570328034E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,   8.2958147570328034E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,  -8.2958147570328034E-01,   5.0784584937357258E-01,   4.3929352914964586E-03],
            [   2.3213609896783030E-01,  -8.2958147570328034E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,   8.2958147570328034E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [  -2.3213609896783030E-01,  -8.2958147570328034E-01,  -5.0784584937357258E-01,   4.3929352914964586E-03],
            [   5.4737798162041795E-01,   2.7158864863605198E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,   2.7158864863605198E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,  -2.7158864863605198E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,   2.7158864863605198E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,  -2.7158864863605198E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,  -2.7158864863605198E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,   2.7158864863605198E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,  -2.7158864863605198E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,   5.4737798162041795E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,   5.4737798162041795E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,  -5.4737798162041795E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,   5.4737798162041795E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,  -5.4737798162041795E-01,   7.9159140417844387E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,  -5.4737798162041795E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,   5.4737798162041795E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,  -5.4737798162041795E-01,  -7.9159140417844387E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,   5.4737798162041795E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,   5.4737798162041795E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,  -5.4737798162041795E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,   5.4737798162041795E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,  -5.4737798162041795E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,  -5.4737798162041795E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,   5.4737798162041795E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,  -5.4737798162041795E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,   2.7158864863605198E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,   2.7158864863605198E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,  -2.7158864863605198E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,   2.7158864863605198E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,  -2.7158864863605198E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   7.9159140417844387E-01,  -2.7158864863605198E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,   2.7158864863605198E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -7.9159140417844387E-01,  -2.7158864863605198E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,   7.9159140417844387E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,   7.9159140417844387E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,  -7.9159140417844387E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,   7.9159140417844387E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,  -7.9159140417844387E-01,   2.7158864863605198E-01,   4.4456901391896203E-03],
            [   5.4737798162041795E-01,  -7.9159140417844387E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,   7.9159140417844387E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [  -5.4737798162041795E-01,  -7.9159140417844387E-01,  -2.7158864863605198E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,   7.9159140417844387E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,   7.9159140417844387E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,  -7.9159140417844387E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,   7.9159140417844387E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,  -7.9159140417844387E-01,   5.4737798162041795E-01,   4.4456901391896203E-03],
            [   2.7158864863605198E-01,  -7.9159140417844387E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,   7.9159140417844387E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [  -2.7158864863605198E-01,  -7.9159140417844387E-01,  -5.4737798162041795E-01,   4.4456901391896203E-03],
            [   5.8486171338113757E-01,   3.1019247075713552E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,   3.1019247075713552E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,  -3.1019247075713552E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,   3.1019247075713552E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,  -3.1019247075713552E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,  -3.1019247075713552E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,   3.1019247075713552E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,  -3.1019247075713552E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,   5.8486171338113757E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,   5.8486171338113757E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,  -5.8486171338113757E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,   5.8486171338113757E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,  -5.8486171338113757E-01,   7.4947808994423826E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,  -5.8486171338113757E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,   5.8486171338113757E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,  -5.8486171338113757E-01,  -7.4947808994423826E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,   5.8486171338113757E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,   5.8486171338113757E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,  -5.8486171338113757E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,   5.8486171338113757E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,  -5.8486171338113757E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,  -5.8486171338113757E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,   5.8486171338113757E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,  -5.8486171338113757E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,   3.1019247075713552E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,   3.1019247075713552E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,  -3.1019247075713552E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,   3.1019247075713552E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,  -3.1019247075713552E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   7.4947808994423826E-01,  -3.1019247075713552E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,   3.1019247075713552E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -7.4947808994423826E-01,  -3.1019247075713552E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,   7.4947808994423826E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,   7.4947808994423826E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,  -7.4947808994423826E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,   7.4947808994423826E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,  -7.4947808994423826E-01,   3.1019247075713552E-01,   4.4792323080575956E-03],
            [   5.8486171338113757E-01,  -7.4947808994423826E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,   7.4947808994423826E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [  -5.8486171338113757E-01,  -7.4947808994423826E-01,  -3.1019247075713552E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,   7.4947808994423826E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,   7.4947808994423826E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,  -7.4947808994423826E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,   7.4947808994423826E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,  -7.4947808994423826E-01,   5.8486171338113757E-01,   4.4792323080575956E-03],
            [   3.1019247075713552E-01,  -7.4947808994423826E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,   7.4947808994423826E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [  -3.1019247075713552E-01,  -7.4947808994423826E-01,  -5.8486171338113757E-01,   4.4792323080575956E-03],
            [   6.2013482815848875E-01,   3.4761210528909731E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,   3.4761210528909731E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,  -3.4761210528909731E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,   3.4761210528909731E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,  -3.4761210528909731E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,  -3.4761210528909731E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,   3.4761210528909731E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,  -3.4761210528909731E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,   6.2013482815848875E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,   6.2013482815848875E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,  -6.2013482815848875E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,   6.2013482815848875E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,  -6.2013482815848875E-01,   7.0327705718395450E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,  -6.2013482815848875E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,   6.2013482815848875E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,  -6.2013482815848875E-01,  -7.0327705718395450E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,   6.2013482815848875E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,   6.2013482815848875E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,  -6.2013482815848875E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,   6.2013482815848875E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,  -6.2013482815848875E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,  -6.2013482815848875E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,   6.2013482815848875E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,  -6.2013482815848875E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,   3.4761210528909731E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,   3.4761210528909731E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,  -3.4761210528909731E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,   3.4761210528909731E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,  -3.4761210528909731E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   7.0327705718395450E-01,  -3.4761210528909731E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,   3.4761210528909731E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -7.0327705718395450E-01,  -3.4761210528909731E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,   7.0327705718395450E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,   7.0327705718395450E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,  -7.0327705718395450E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,   7.0327705718395450E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,  -7.0327705718395450E-01,   3.4761210528909731E-01,   4.4968305623524106E-03],
            [   6.2013482815848875E-01,  -7.0327705718395450E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,   7.0327705718395450E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [  -6.2013482815848875E-01,  -7.0327705718395450E-01,  -3.4761210528909731E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,   7.0327705718395450E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,   7.0327705718395450E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,  -7.0327705718395450E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,   7.0327705718395450E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,  -7.0327705718395450E-01,   6.2013482815848875E-01,   4.4968305623524106E-03],
            [   3.4761210528909731E-01,  -7.0327705718395450E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,   7.0327705718395450E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [  -3.4761210528909731E-01,  -7.0327705718395450E-01,  -6.2013482815848875E-01,   4.4968305623524106E-03],
            [   3.8521911853878710E-01,   3.7632248800351077E-02,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,   3.7632248800351077E-02,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,  -3.7632248800351077E-02,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,   3.7632248800351077E-02,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,  -3.7632248800351077E-02,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,  -3.7632248800351077E-02,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,   3.7632248800351077E-02,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,  -3.7632248800351077E-02,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,   3.8521911853878710E-01,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,   3.8521911853878710E-01,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,  -3.8521911853878710E-01,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,   3.8521911853878710E-01,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,  -3.8521911853878710E-01,   9.2205750610383752E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,  -3.8521911853878710E-01,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,   3.8521911853878710E-01,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,  -3.8521911853878710E-01,  -9.2205750610383752E-01,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,   3.8521911853878710E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,   3.8521911853878710E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,  -3.8521911853878710E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,   3.8521911853878710E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,  -3.8521911853878710E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,  -3.8521911853878710E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,   3.8521911853878710E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,  -3.8521911853878710E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,   3.7632248800351077E-02,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,   3.7632248800351077E-02,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,  -3.7632248800351077E-02,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,   3.7632248800351077E-02,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,  -3.7632248800351077E-02,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   9.2205750610383752E-01,  -3.7632248800351077E-02,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,   3.7632248800351077E-02,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -9.2205750610383752E-01,  -3.7632248800351077E-02,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,   9.2205750610383752E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,   9.2205750610383752E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,  -9.2205750610383752E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,   9.2205750610383752E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,  -9.2205750610383752E-01,   3.7632248800351077E-02,   4.0711883651211459E-03],
            [   3.8521911853878710E-01,  -9.2205750610383752E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,   9.2205750610383752E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [  -3.8521911853878710E-01,  -9.2205750610383752E-01,  -3.7632248800351077E-02,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,   9.2205750610383752E-01,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,   9.2205750610383752E-01,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,  -9.2205750610383752E-01,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,   9.2205750610383752E-01,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,  -9.2205750610383752E-01,   3.8521911853878710E-01,   4.0711883651211459E-03],
            [   3.7632248800351077E-02,  -9.2205750610383752E-01,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,   9.2205750610383752E-01,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [  -3.7632248800351077E-02,  -9.2205750610383752E-01,  -3.8521911853878710E-01,   4.0711883651211459E-03],
            [   4.3250250610734231E-01,   7.6595819356371345E-02,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,   7.6595819356371345E-02,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,  -7.6595819356371345E-02,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,   7.6595819356371345E-02,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,  -7.6595819356371345E-02,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,  -7.6595819356371345E-02,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,   7.6595819356371345E-02,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,  -7.6595819356371345E-02,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,   4.3250250610734231E-01,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,   4.3250250610734231E-01,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,  -4.3250250610734231E-01,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,   4.3250250610734231E-01,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,  -4.3250250610734231E-01,   8.9837334258536106E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,  -4.3250250610734231E-01,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,   4.3250250610734231E-01,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,  -4.3250250610734231E-01,  -8.9837334258536106E-01,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,   4.3250250610734231E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,   4.3250250610734231E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,  -4.3250250610734231E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,   4.3250250610734231E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,  -4.3250250610734231E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,  -4.3250250610734231E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,   4.3250250610734231E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,  -4.3250250610734231E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,   7.6595819356371345E-02,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,   7.6595819356371345E-02,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,  -7.6595819356371345E-02,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,   7.6595819356371345E-02,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,  -7.6595819356371345E-02,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   8.9837334258536106E-01,  -7.6595819356371345E-02,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,   7.6595819356371345E-02,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -8.9837334258536106E-01,  -7.6595819356371345E-02,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,   8.9837334258536106E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,   8.9837334258536106E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,  -8.9837334258536106E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,   8.9837334258536106E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,  -8.9837334258536106E-01,   7.6595819356371345E-02,   4.2040689647227800E-03],
            [   4.3250250610734231E-01,  -8.9837334258536106E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,   8.9837334258536106E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [  -4.3250250610734231E-01,  -8.9837334258536106E-01,  -7.6595819356371345E-02,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,   8.9837334258536106E-01,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,   8.9837334258536106E-01,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,  -8.9837334258536106E-01,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,   8.9837334258536106E-01,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,  -8.9837334258536106E-01,   4.3250250610734231E-01,   4.2040689647227800E-03],
            [   7.6595819356371345E-02,  -8.9837334258536106E-01,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,   8.9837334258536106E-01,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [  -7.6595819356371345E-02,  -8.9837334258536106E-01,  -4.3250250610734231E-01,   4.2040689647227800E-03],
            [   4.7784862297344899E-01,   1.1633813060839000E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,   1.1633813060839000E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,  -1.1633813060839000E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,   1.1633813060839000E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,  -1.1633813060839000E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,  -1.1633813060839000E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,   1.1633813060839000E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,  -1.1633813060839000E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,   4.7784862297344899E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,   4.7784862297344899E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,  -4.7784862297344899E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,   4.7784862297344899E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,  -4.7784862297344899E-01,   8.7070438892251134E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,  -4.7784862297344899E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,   4.7784862297344899E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,  -4.7784862297344899E-01,  -8.7070438892251134E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,   4.7784862297344899E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,   4.7784862297344899E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,  -4.7784862297344899E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,   4.7784862297344899E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,  -4.7784862297344899E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,  -4.7784862297344899E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,   4.7784862297344899E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,  -4.7784862297344899E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,   1.1633813060839000E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,   1.1633813060839000E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,  -1.1633813060839000E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,   1.1633813060839000E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,  -1.1633813060839000E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   8.7070438892251134E-01,  -1.1633813060839000E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,   1.1633813060839000E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -8.7070438892251134E-01,  -1.1633813060839000E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,   8.7070438892251134E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,   8.7070438892251134E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,  -8.7070438892251134E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,   8.7070438892251134E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,  -8.7070438892251134E-01,   1.1633813060839000E-01,   4.3091670427374915E-03],
            [   4.7784862297344899E-01,  -8.7070438892251134E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,   8.7070438892251134E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [  -4.7784862297344899E-01,  -8.7070438892251134E-01,  -1.1633813060839000E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,   8.7070438892251134E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,   8.7070438892251134E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,  -8.7070438892251134E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,   8.7070438892251134E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,  -8.7070438892251134E-01,   4.7784862297344899E-01,   4.3091670427374915E-03],
            [   1.1633813060839000E-01,  -8.7070438892251134E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,   8.7070438892251134E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [  -1.1633813060839000E-01,  -8.7070438892251134E-01,  -4.7784862297344899E-01,   4.3091670427374915E-03],
            [   5.2116636930089999E-01,   1.5638905987528989E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,   1.5638905987528989E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,  -1.5638905987528989E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,   1.5638905987528989E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,  -1.5638905987528989E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,  -1.5638905987528989E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,   1.5638905987528989E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,  -1.5638905987528989E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,   5.2116636930089999E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,   5.2116636930089999E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,  -5.2116636930089999E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,   5.2116636930089999E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,  -5.2116636930089999E-01,   8.3900421778501266E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,  -5.2116636930089999E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,   5.2116636930089999E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,  -5.2116636930089999E-01,  -8.3900421778501266E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,   5.2116636930089999E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,   5.2116636930089999E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,  -5.2116636930089999E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,   5.2116636930089999E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,  -5.2116636930089999E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,  -5.2116636930089999E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,   5.2116636930089999E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,  -5.2116636930089999E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,   1.5638905987528989E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,   1.5638905987528989E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,  -1.5638905987528989E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,   1.5638905987528989E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,  -1.5638905987528989E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   8.3900421778501266E-01,  -1.5638905987528989E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,   1.5638905987528989E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -8.3900421778501266E-01,  -1.5638905987528989E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,   8.3900421778501266E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,   8.3900421778501266E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,  -8.3900421778501266E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,   8.3900421778501266E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,  -8.3900421778501266E-01,   1.5638905987528989E-01,   4.3887048372489613E-03],
            [   5.2116636930089999E-01,  -8.3900421778501266E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,   8.3900421778501266E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [  -5.2116636930089999E-01,  -8.3900421778501266E-01,  -1.5638905987528989E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,   8.3900421778501266E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,   8.3900421778501266E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,  -8.3900421778501266E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,   8.3900421778501266E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,  -8.3900421778501266E-01,   5.2116636930089999E-01,   4.3887048372489613E-03],
            [   1.5638905987528989E-01,  -8.3900421778501266E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,   8.3900421778501266E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [  -1.5638905987528989E-01,  -8.3900421778501266E-01,  -5.2116636930089999E-01,   4.3887048372489613E-03],
            [   5.6234695048537031E-01,   1.9633208101492000E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,   1.9633208101492000E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,  -1.9633208101492000E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,   1.9633208101492000E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,  -1.9633208101492000E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,  -1.9633208101492000E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,   1.9633208101492000E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,  -1.9633208101492000E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,   5.6234695048537031E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,   5.6234695048537031E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,  -5.6234695048537031E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,   5.6234695048537031E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,  -5.6234695048537031E-01,   8.0325563878764983E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,  -5.6234695048537031E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,   5.6234695048537031E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,  -5.6234695048537031E-01,  -8.0325563878764983E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,   5.6234695048537031E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,   5.6234695048537031E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,  -5.6234695048537031E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,   5.6234695048537031E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,  -5.6234695048537031E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,  -5.6234695048537031E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,   5.6234695048537031E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,  -5.6234695048537031E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,   1.9633208101492000E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,   1.9633208101492000E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,  -1.9633208101492000E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,   1.9633208101492000E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,  -1.9633208101492000E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   8.0325563878764983E-01,  -1.9633208101492000E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,   1.9633208101492000E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -8.0325563878764983E-01,  -1.9633208101492000E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,   8.0325563878764983E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,   8.0325563878764983E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,  -8.0325563878764983E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,   8.0325563878764983E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,  -8.0325563878764983E-01,   1.9633208101492000E-01,   4.4452267476138381E-03],
            [   5.6234695048537031E-01,  -8.0325563878764983E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,   8.0325563878764983E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [  -5.6234695048537031E-01,  -8.0325563878764983E-01,  -1.9633208101492000E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,   8.0325563878764983E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,   8.0325563878764983E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,  -8.0325563878764983E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,   8.0325563878764983E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,  -8.0325563878764983E-01,   5.6234695048537031E-01,   4.4452267476138381E-03],
            [   1.9633208101492000E-01,  -8.0325563878764983E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,   8.0325563878764983E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [  -1.9633208101492000E-01,  -8.0325563878764983E-01,  -5.6234695048537031E-01,   4.4452267476138381E-03],
            [   6.0127181886592462E-01,   2.3578474072587380E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,   2.3578474072587380E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,  -2.3578474072587380E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,   2.3578474072587380E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,  -2.3578474072587380E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,  -2.3578474072587380E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,   2.3578474072587380E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,  -2.3578474072587380E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,   6.0127181886592462E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,   6.0127181886592462E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,  -6.0127181886592462E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,   6.0127181886592462E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,  -6.0127181886592462E-01,   7.6346431211844812E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,  -6.0127181886592462E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,   6.0127181886592462E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,  -6.0127181886592462E-01,  -7.6346431211844812E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,   6.0127181886592462E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,   6.0127181886592462E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,  -6.0127181886592462E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,   6.0127181886592462E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,  -6.0127181886592462E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,  -6.0127181886592462E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,   6.0127181886592462E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,  -6.0127181886592462E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,   2.3578474072587380E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,   2.3578474072587380E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,  -2.3578474072587380E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,   2.3578474072587380E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,  -2.3578474072587380E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   7.6346431211844812E-01,  -2.3578474072587380E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,   2.3578474072587380E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -7.6346431211844812E-01,  -2.3578474072587380E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,   7.6346431211844812E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,   7.6346431211844812E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,  -7.6346431211844812E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,   7.6346431211844812E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,  -7.6346431211844812E-01,   2.3578474072587380E-01,   4.4814305900634944E-03],
            [   6.0127181886592462E-01,  -7.6346431211844812E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,   7.6346431211844812E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [  -6.0127181886592462E-01,  -7.6346431211844812E-01,  -2.3578474072587380E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,   7.6346431211844812E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,   7.6346431211844812E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,  -7.6346431211844812E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,   7.6346431211844812E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,  -7.6346431211844812E-01,   6.0127181886592462E-01,   4.4814305900634944E-03],
            [   2.3578474072587380E-01,  -7.6346431211844812E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,   7.6346431211844812E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [  -2.3578474072587380E-01,  -7.6346431211844812E-01,  -6.0127181886592462E-01,   4.4814305900634944E-03],
            [   6.3781792063901166E-01,   2.7438461212440601E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,   2.7438461212440601E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,  -2.7438461212440601E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,   2.7438461212440601E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,  -2.7438461212440601E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,  -2.7438461212440601E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,   2.7438461212440601E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,  -2.7438461212440601E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,   6.3781792063901166E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,   6.3781792063901166E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,  -6.3781792063901166E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,   6.3781792063901166E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,  -6.3781792063901166E-01,   7.1965365610206322E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,  -6.3781792063901166E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,   6.3781792063901166E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,  -6.3781792063901166E-01,  -7.1965365610206322E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,   6.3781792063901166E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,   6.3781792063901166E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,  -6.3781792063901166E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,   6.3781792063901166E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,  -6.3781792063901166E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,  -6.3781792063901166E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,   6.3781792063901166E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,  -6.3781792063901166E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,   2.7438461212440601E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,   2.7438461212440601E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,  -2.7438461212440601E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,   2.7438461212440601E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,  -2.7438461212440601E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   7.1965365610206322E-01,  -2.7438461212440601E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,   2.7438461212440601E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -7.1965365610206322E-01,  -2.7438461212440601E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,   7.1965365610206322E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,   7.1965365610206322E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,  -7.1965365610206322E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,   7.1965365610206322E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,  -7.1965365610206322E-01,   2.7438461212440601E-01,   4.5001232790515093E-03],
            [   6.3781792063901166E-01,  -7.1965365610206322E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,   7.1965365610206322E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [  -6.3781792063901166E-01,  -7.1965365610206322E-01,  -2.7438461212440601E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,   7.1965365610206322E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,   7.1965365610206322E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,  -7.1965365610206322E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,   7.1965365610206322E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,  -7.1965365610206322E-01,   6.3781792063901166E-01,   4.5001232790515093E-03],
            [   2.7438461212440601E-01,  -7.1965365610206322E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,   7.1965365610206322E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [  -2.7438461212440601E-01,  -7.1965365610206322E-01,  -6.3781792063901166E-01,   4.5001232790515093E-03],
            [   4.8369364602145343E-01,   3.8959026107390243E-02,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,   3.8959026107390243E-02,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,  -3.8959026107390243E-02,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,   3.8959026107390243E-02,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,  -3.8959026107390243E-02,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,  -3.8959026107390243E-02,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,   3.8959026107390243E-02,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,  -3.8959026107390243E-02,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,   4.8369364602145343E-01,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,   4.8369364602145343E-01,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,  -4.8369364602145343E-01,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,   4.8369364602145343E-01,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,  -4.8369364602145343E-01,   8.7436985943205781E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,  -4.8369364602145343E-01,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,   4.8369364602145343E-01,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,  -4.8369364602145343E-01,  -8.7436985943205781E-01,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,   4.8369364602145343E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,   4.8369364602145343E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,  -4.8369364602145343E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,   4.8369364602145343E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,  -4.8369364602145343E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,  -4.8369364602145343E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,   4.8369364602145343E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,  -4.8369364602145343E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,   3.8959026107390243E-02,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,   3.8959026107390243E-02,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,  -3.8959026107390243E-02,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,   3.8959026107390243E-02,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,  -3.8959026107390243E-02,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   8.7436985943205781E-01,  -3.8959026107390243E-02,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,   3.8959026107390243E-02,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -8.7436985943205781E-01,  -3.8959026107390243E-02,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,   8.7436985943205781E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,   8.7436985943205781E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,  -8.7436985943205781E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,   8.7436985943205781E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,  -8.7436985943205781E-01,   3.8959026107390243E-02,   4.3058946847953743E-03],
            [   4.8369364602145343E-01,  -8.7436985943205781E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,   8.7436985943205781E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [  -4.8369364602145343E-01,  -8.7436985943205781E-01,  -3.8959026107390243E-02,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,   8.7436985943205781E-01,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,   8.7436985943205781E-01,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,  -8.7436985943205781E-01,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,   8.7436985943205781E-01,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,  -8.7436985943205781E-01,   4.8369364602145343E-01,   4.3058946847953743E-03],
            [   3.8959026107390243E-02,  -8.7436985943205781E-01,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,   8.7436985943205781E-01,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [  -3.8959026107390243E-02,  -8.7436985943205781E-01,  -4.8369364602145343E-01,   4.3058946847953743E-03],
            [   5.2937925626837967E-01,   7.8712468193126398E-02,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,   7.8712468193126398E-02,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,  -7.8712468193126398E-02,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,   7.8712468193126398E-02,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,  -7.8712468193126398E-02,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,  -7.8712468193126398E-02,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,   7.8712468193126398E-02,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,  -7.8712468193126398E-02,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,   5.2937925626837967E-01,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,   5.2937925626837967E-01,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,  -5.2937925626837967E-01,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,   5.2937925626837967E-01,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,  -5.2937925626837967E-01,   8.4472596170810521E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,  -5.2937925626837967E-01,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,   5.2937925626837967E-01,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,  -5.2937925626837967E-01,  -8.4472596170810521E-01,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,   5.2937925626837967E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,   5.2937925626837967E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,  -5.2937925626837967E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,   5.2937925626837967E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,  -5.2937925626837967E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,  -5.2937925626837967E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,   5.2937925626837967E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,  -5.2937925626837967E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,   7.8712468193126398E-02,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,   7.8712468193126398E-02,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,  -7.8712468193126398E-02,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,   7.8712468193126398E-02,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,  -7.8712468193126398E-02,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   8.4472596170810521E-01,  -7.8712468193126398E-02,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,   7.8712468193126398E-02,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -8.4472596170810521E-01,  -7.8712468193126398E-02,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,   8.4472596170810521E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,   8.4472596170810521E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,  -8.4472596170810521E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,   8.4472596170810521E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,  -8.4472596170810521E-01,   7.8712468193126398E-02,   4.3879865774639508E-03],
            [   5.2937925626837967E-01,  -8.4472596170810521E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,   8.4472596170810521E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [  -5.2937925626837967E-01,  -8.4472596170810521E-01,  -7.8712468193126398E-02,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,   8.4472596170810521E-01,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,   8.4472596170810521E-01,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,  -8.4472596170810521E-01,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,   8.4472596170810521E-01,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,  -8.4472596170810521E-01,   5.2937925626837967E-01,   4.3879865774639508E-03],
            [   7.8712468193126398E-02,  -8.4472596170810521E-01,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,   8.4472596170810521E-01,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [  -7.8712468193126398E-02,  -8.4472596170810521E-01,  -5.2937925626837967E-01,   4.3879865774639508E-03],
            [   5.7262812531000329E-01,   1.1879638082029810E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,   1.1879638082029810E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,  -1.1879638082029810E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,   1.1879638082029810E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,  -1.1879638082029810E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,  -1.1879638082029810E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,   1.1879638082029810E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,  -1.1879638082029810E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,   5.7262812531000329E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,   5.7262812531000329E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,  -5.7262812531000329E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,   5.7262812531000329E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,  -5.7262812531000329E-01,   8.1116240667818795E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,  -5.7262812531000329E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,   5.7262812531000329E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,  -5.7262812531000329E-01,  -8.1116240667818795E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,   5.7262812531000329E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,   5.7262812531000329E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,  -5.7262812531000329E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,   5.7262812531000329E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,  -5.7262812531000329E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,  -5.7262812531000329E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,   5.7262812531000329E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,  -5.7262812531000329E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,   1.1879638082029810E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,   1.1879638082029810E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,  -1.1879638082029810E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,   1.1879638082029810E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,  -1.1879638082029810E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   8.1116240667818795E-01,  -1.1879638082029810E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,   1.1879638082029810E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -8.1116240667818795E-01,  -1.1879638082029810E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,   8.1116240667818795E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,   8.1116240667818795E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,  -8.1116240667818795E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,   8.1116240667818795E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,  -8.1116240667818795E-01,   1.1879638082029810E-01,   4.4476384666078386E-03],
            [   5.7262812531000329E-01,  -8.1116240667818795E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,   8.1116240667818795E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [  -5.7262812531000329E-01,  -8.1116240667818795E-01,  -1.1879638082029810E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,   8.1116240667818795E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,   8.1116240667818795E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,  -8.1116240667818795E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,   8.1116240667818795E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,  -8.1116240667818795E-01,   5.7262812531000329E-01,   4.4476384666078386E-03],
            [   1.1879638082029810E-01,  -8.1116240667818795E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,   8.1116240667818795E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [  -1.1879638082029810E-01,  -8.1116240667818795E-01,  -5.7262812531000329E-01,   4.4476384666078386E-03],
            [   6.1336587761690675E-01,   1.5879147080617870E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,   1.5879147080617870E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,  -1.5879147080617870E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,   1.5879147080617870E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,  -1.5879147080617870E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,  -1.5879147080617870E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,   1.5879147080617870E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,  -1.5879147080617870E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,   6.1336587761690675E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,   6.1336587761690675E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,  -6.1336587761690675E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,   6.1336587761690675E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,  -6.1336587761690675E-01,   7.7367148646854778E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,  -6.1336587761690675E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,   6.1336587761690675E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,  -6.1336587761690675E-01,  -7.7367148646854778E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,   6.1336587761690675E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,   6.1336587761690675E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,  -6.1336587761690675E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,   6.1336587761690675E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,  -6.1336587761690675E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,  -6.1336587761690675E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,   6.1336587761690675E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,  -6.1336587761690675E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,   1.5879147080617870E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,   1.5879147080617870E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,  -1.5879147080617870E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,   1.5879147080617870E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,  -1.5879147080617870E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   7.7367148646854778E-01,  -1.5879147080617870E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,   1.5879147080617870E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -7.7367148646854778E-01,  -1.5879147080617870E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,   7.7367148646854778E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,   7.7367148646854778E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,  -7.7367148646854778E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,   7.7367148646854778E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,  -7.7367148646854778E-01,   1.5879147080617870E-01,   4.4864851434708612E-03],
            [   6.1336587761690675E-01,  -7.7367148646854778E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,   7.7367148646854778E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [  -6.1336587761690675E-01,  -7.7367148646854778E-01,  -1.5879147080617870E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,   7.7367148646854778E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,   7.7367148646854778E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,  -7.7367148646854778E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,   7.7367148646854778E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,  -7.7367148646854778E-01,   6.1336587761690675E-01,   4.4864851434708612E-03],
            [   1.5879147080617870E-01,  -7.7367148646854778E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,   7.7367148646854778E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [  -1.5879147080617870E-01,  -7.7367148646854778E-01,  -6.1336587761690675E-01,   4.4864851434708612E-03],
            [   6.5150854918653067E-01,   1.9830585752276461E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,   1.9830585752276461E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,  -1.9830585752276461E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,   1.9830585752276461E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,  -1.9830585752276461E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,  -1.9830585752276461E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,   1.9830585752276461E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,  -1.9830585752276461E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,   6.5150854918653067E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,   6.5150854918653067E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,  -6.5150854918653067E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,   6.5150854918653067E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,  -6.5150854918653067E-01,   7.3226456776838722E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,  -6.5150854918653067E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,   6.5150854918653067E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,  -6.5150854918653067E-01,  -7.3226456776838722E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,   6.5150854918653067E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,   6.5150854918653067E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,  -6.5150854918653067E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,   6.5150854918653067E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,  -6.5150854918653067E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,  -6.5150854918653067E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,   6.5150854918653067E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,  -6.5150854918653067E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,   1.9830585752276461E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,   1.9830585752276461E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,  -1.9830585752276461E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,   1.9830585752276461E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,  -1.9830585752276461E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   7.3226456776838722E-01,  -1.9830585752276461E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,   1.9830585752276461E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -7.3226456776838722E-01,  -1.9830585752276461E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,   7.3226456776838722E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,   7.3226456776838722E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,  -7.3226456776838722E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,   7.3226456776838722E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,  -7.3226456776838722E-01,   1.9830585752276461E-01,   4.5065610472193179E-03],
            [   6.5150854918653067E-01,  -7.3226456776838722E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,   7.3226456776838722E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [  -6.5150854918653067E-01,  -7.3226456776838722E-01,  -1.9830585752276461E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,   7.3226456776838722E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,   7.3226456776838722E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,  -7.3226456776838722E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,   7.3226456776838722E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,  -7.3226456776838722E-01,   6.5150854918653067E-01,   4.5065610472193179E-03],
            [   1.9830585752276461E-01,  -7.3226456776838722E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,   7.3226456776838722E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [  -1.9830585752276461E-01,  -7.3226456776838722E-01,  -6.5150854918653067E-01,   4.5065610472193179E-03],
            [   5.7786927160649759E-01,   3.9772096897915422E-02,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,   3.9772096897915422E-02,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,  -3.9772096897915422E-02,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,   3.9772096897915422E-02,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,  -3.9772096897915422E-02,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,  -3.9772096897915422E-02,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,   3.9772096897915422E-02,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,  -3.9772096897915422E-02,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,   5.7786927160649759E-01,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,   5.7786927160649759E-01,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,  -5.7786927160649759E-01,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,   5.7786927160649759E-01,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,  -5.7786927160649759E-01,   8.1515966855660782E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,  -5.7786927160649759E-01,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,   5.7786927160649759E-01,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,  -5.7786927160649759E-01,  -8.1515966855660782E-01,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,   5.7786927160649759E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,   5.7786927160649759E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,  -5.7786927160649759E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,   5.7786927160649759E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,  -5.7786927160649759E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,  -5.7786927160649759E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,   5.7786927160649759E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,  -5.7786927160649759E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,   3.9772096897915422E-02,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,   3.9772096897915422E-02,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,  -3.9772096897915422E-02,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,   3.9772096897915422E-02,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,  -3.9772096897915422E-02,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   8.1515966855660782E-01,  -3.9772096897915422E-02,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,   3.9772096897915422E-02,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -8.1515966855660782E-01,  -3.9772096897915422E-02,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,   8.1515966855660782E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,   8.1515966855660782E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,  -8.1515966855660782E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,   8.1515966855660782E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,  -8.1515966855660782E-01,   3.9772096897915422E-02,   4.4499983932253422E-03],
            [   5.7786927160649759E-01,  -8.1515966855660782E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,   8.1515966855660782E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [  -5.7786927160649759E-01,  -8.1515966855660782E-01,  -3.9772096897915422E-02,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,   8.1515966855660782E-01,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,   8.1515966855660782E-01,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,  -8.1515966855660782E-01,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,   8.1515966855660782E-01,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,  -8.1515966855660782E-01,   5.7786927160649759E-01,   4.4499983932253422E-03],
            [   3.9772096897915422E-02,  -8.1515966855660782E-01,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,   8.1515966855660782E-01,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [  -3.9772096897915422E-02,  -8.1515966855660782E-01,  -5.7786927160649759E-01,   4.4499983932253422E-03],
            [   6.2079042880861923E-01,   7.9901575929811522E-02,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,   7.9901575929811522E-02,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,  -7.9901575929811522E-02,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,   7.9901575929811522E-02,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,  -7.9901575929811522E-02,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,  -7.9901575929811522E-02,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,   7.9901575929811522E-02,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,  -7.9901575929811522E-02,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,   6.2079042880861923E-01,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,   6.2079042880861923E-01,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,  -6.2079042880861923E-01,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,   6.2079042880861923E-01,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,  -6.2079042880861923E-01,   7.7989421184128771E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,  -6.2079042880861923E-01,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,   6.2079042880861923E-01,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,  -6.2079042880861923E-01,  -7.7989421184128771E-01,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,   6.2079042880861923E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,   6.2079042880861923E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,  -6.2079042880861923E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,   6.2079042880861923E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,  -6.2079042880861923E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,  -6.2079042880861923E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,   6.2079042880861923E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,  -6.2079042880861923E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,   7.9901575929811522E-02,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,   7.9901575929811522E-02,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,  -7.9901575929811522E-02,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,   7.9901575929811522E-02,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,  -7.9901575929811522E-02,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.7989421184128771E-01,  -7.9901575929811522E-02,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,   7.9901575929811522E-02,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.7989421184128771E-01,  -7.9901575929811522E-02,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,   7.7989421184128771E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,   7.7989421184128771E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,  -7.7989421184128771E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,   7.7989421184128771E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,  -7.7989421184128771E-01,   7.9901575929811522E-02,   4.4915939676597669E-03],
            [   6.2079042880861923E-01,  -7.7989421184128771E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,   7.7989421184128771E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [  -6.2079042880861923E-01,  -7.7989421184128771E-01,  -7.9901575929811522E-02,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,   7.7989421184128771E-01,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,   7.7989421184128771E-01,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,  -7.7989421184128771E-01,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,   7.7989421184128771E-01,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,  -7.7989421184128771E-01,   6.2079042880861923E-01,   4.4915939676597669E-03],
            [   7.9901575929811522E-02,  -7.7989421184128771E-01,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,   7.7989421184128771E-01,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [  -7.9901575929811522E-02,  -7.7989421184128771E-01,  -6.2079042880861923E-01,   4.4915939676597669E-03],
            [   6.6086881710468015E-01,   1.1996713087543090E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,   1.1996713087543090E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,  -1.1996713087543090E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,   1.1996713087543090E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,  -1.1996713087543090E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,  -1.1996713087543090E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,   1.1996713087543090E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,  -1.1996713087543090E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,   6.6086881710468015E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,   6.6086881710468015E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,  -6.6086881710468015E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,   6.6086881710468015E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,  -6.6086881710468015E-01,   7.4085106066481277E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,  -6.6086881710468015E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,   6.6086881710468015E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,  -6.6086881710468015E-01,  -7.4085106066481277E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,   6.6086881710468015E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,   6.6086881710468015E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,  -6.6086881710468015E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,   6.6086881710468015E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,  -6.6086881710468015E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,  -6.6086881710468015E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,   6.6086881710468015E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,  -6.6086881710468015E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,   1.1996713087543090E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,   1.1996713087543090E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,  -1.1996713087543090E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,   1.1996713087543090E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,  -1.1996713087543090E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   7.4085106066481277E-01,  -1.1996713087543090E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,   1.1996713087543090E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -7.4085106066481277E-01,  -1.1996713087543090E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,   7.4085106066481277E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,   7.4085106066481277E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,  -7.4085106066481277E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,   7.4085106066481277E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,  -7.4085106066481277E-01,   1.1996713087543090E-01,   4.5138318798492640E-03],
            [   6.6086881710468015E-01,  -7.4085106066481277E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,   7.4085106066481277E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [  -6.6086881710468015E-01,  -7.4085106066481277E-01,  -1.1996713087543090E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,   7.4085106066481277E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,   7.4085106066481277E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,  -7.4085106066481277E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,   7.4085106066481277E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,  -7.4085106066481277E-01,   6.6086881710468015E-01,   4.5138318798492640E-03],
            [   1.1996713087543090E-01,  -7.4085106066481277E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,   7.4085106066481277E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [  -1.1996713087543090E-01,  -7.4085106066481277E-01,  -6.6086881710468015E-01,   4.5138318798492640E-03],
            [   6.6562630894891295E-01,   4.0159559578059688E-02,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,   4.0159559578059688E-02,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,  -4.0159559578059688E-02,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,   4.0159559578059688E-02,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,  -4.0159559578059688E-02,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,  -4.0159559578059688E-02,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,   4.0159559578059688E-02,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,  -4.0159559578059688E-02,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,   6.6562630894891295E-01,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,   6.6562630894891295E-01,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,  -6.6562630894891295E-01,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,   6.6562630894891295E-01,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,  -6.6562630894891295E-01,   7.4520388257814552E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,  -6.6562630894891295E-01,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,   6.6562630894891295E-01,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,  -6.6562630894891295E-01,  -7.4520388257814552E-01,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,   6.6562630894891295E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,   6.6562630894891295E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,  -6.6562630894891295E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,   6.6562630894891295E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,  -6.6562630894891295E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,  -6.6562630894891295E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,   6.6562630894891295E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,  -6.6562630894891295E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,   4.0159559578059688E-02,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,   4.0159559578059688E-02,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,  -4.0159559578059688E-02,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,   4.0159559578059688E-02,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,  -4.0159559578059688E-02,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   7.4520388257814552E-01,  -4.0159559578059688E-02,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,   4.0159559578059688E-02,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -7.4520388257814552E-01,  -4.0159559578059688E-02,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,   7.4520388257814552E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,   7.4520388257814552E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,  -7.4520388257814552E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,   7.4520388257814552E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,  -7.4520388257814552E-01,   4.0159559578059688E-02,   4.5186847041072007E-03],
            [   6.6562630894891295E-01,  -7.4520388257814552E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,   7.4520388257814552E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [  -6.6562630894891295E-01,  -7.4520388257814552E-01,  -4.0159559578059688E-02,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,   7.4520388257814552E-01,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,   7.4520388257814552E-01,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,  -7.4520388257814552E-01,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,   7.4520388257814552E-01,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,  -7.4520388257814552E-01,   6.6562630894891295E-01,   4.5186847041072007E-03],
            [   4.0159559578059688E-02,  -7.4520388257814552E-01,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,   7.4520388257814552E-01,  -6.6562630894891295E-01,   4.5186847041072007E-03],
            [  -4.0159559578059688E-02,  -7.4520388257814552E-01,  -6.6562630894891295E-01,   4.5186847041072007E-03],
        ])
  
        order = 95
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build3470():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.5640205590701912E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.5640205590701912E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   2.5640205590701912E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   2.5640205590701912E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   2.5640205590701912E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   2.5640205590701912E-04],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.9937807046991868E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.9937807046991868E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.9937807046991868E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.9937807046991868E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.9937807046991868E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.9937807046991868E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.9937807046991868E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.9937807046991868E-03],
            [   1.7214208329062331E-02,   1.7214208329062331E-02,   9.9970362711315963E-01,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,   1.7214208329062331E-02,   9.9970362711315963E-01,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,  -1.7214208329062331E-02,   9.9970362711315963E-01,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,   1.7214208329062331E-02,  -9.9970362711315963E-01,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,  -1.7214208329062331E-02,   9.9970362711315963E-01,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,   1.7214208329062331E-02,  -9.9970362711315963E-01,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,  -1.7214208329062331E-02,  -9.9970362711315963E-01,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,  -1.7214208329062331E-02,  -9.9970362711315963E-01,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,   9.9970362711315963E-01,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,  -9.9970362711315963E-01,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,   9.9970362711315963E-01,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,  -9.9970362711315963E-01,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,   9.9970362711315963E-01,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,  -9.9970362711315963E-01,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -1.7214208329062331E-02,  -9.9970362711315963E-01,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [   1.7214208329062331E-02,   9.9970362711315963E-01,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [   9.9970362711315963E-01,   1.7214208329062331E-02,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -9.9970362711315963E-01,   1.7214208329062331E-02,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [   9.9970362711315963E-01,  -1.7214208329062331E-02,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [   9.9970362711315963E-01,   1.7214208329062331E-02,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -9.9970362711315963E-01,  -1.7214208329062331E-02,   1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -9.9970362711315963E-01,   1.7214208329062331E-02,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [   9.9970362711315963E-01,  -1.7214208329062331E-02,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [  -9.9970362711315963E-01,  -1.7214208329062331E-02,  -1.7214208329062331E-02,   1.0415152639388135E-03],
            [   4.4088753749817702E-02,   4.4088753749817702E-02,   9.9805428889693970E-01,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,   4.4088753749817702E-02,   9.9805428889693970E-01,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,  -4.4088753749817702E-02,   9.9805428889693970E-01,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,   4.4088753749817702E-02,  -9.9805428889693970E-01,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,  -4.4088753749817702E-02,   9.9805428889693970E-01,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,   4.4088753749817702E-02,  -9.9805428889693970E-01,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,  -4.4088753749817702E-02,  -9.9805428889693970E-01,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,  -4.4088753749817702E-02,  -9.9805428889693970E-01,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,   9.9805428889693970E-01,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,  -9.9805428889693970E-01,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,   9.9805428889693970E-01,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,  -9.9805428889693970E-01,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,   9.9805428889693970E-01,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,  -9.9805428889693970E-01,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -4.4088753749817702E-02,  -9.9805428889693970E-01,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [   4.4088753749817702E-02,   9.9805428889693970E-01,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [   9.9805428889693970E-01,   4.4088753749817702E-02,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -9.9805428889693970E-01,   4.4088753749817702E-02,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [   9.9805428889693970E-01,  -4.4088753749817702E-02,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [   9.9805428889693970E-01,   4.4088753749817702E-02,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -9.9805428889693970E-01,  -4.4088753749817702E-02,   4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -9.9805428889693970E-01,   4.4088753749817702E-02,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [   9.9805428889693970E-01,  -4.4088753749817702E-02,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [  -9.9805428889693970E-01,  -4.4088753749817702E-02,  -4.4088753749817702E-02,   1.7101362560095743E-03],
            [   7.5946808138786806E-02,   7.5946808138786806E-02,   9.9421535125296701E-01,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,   7.5946808138786806E-02,   9.9421535125296701E-01,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,  -7.5946808138786806E-02,   9.9421535125296701E-01,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,   7.5946808138786806E-02,  -9.9421535125296701E-01,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,  -7.5946808138786806E-02,   9.9421535125296701E-01,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,   7.5946808138786806E-02,  -9.9421535125296701E-01,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,  -7.5946808138786806E-02,  -9.9421535125296701E-01,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,  -7.5946808138786806E-02,  -9.9421535125296701E-01,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,   9.9421535125296701E-01,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,  -9.9421535125296701E-01,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,   9.9421535125296701E-01,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,  -9.9421535125296701E-01,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,   9.9421535125296701E-01,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,  -9.9421535125296701E-01,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -7.5946808138786806E-02,  -9.9421535125296701E-01,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [   7.5946808138786806E-02,   9.9421535125296701E-01,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [   9.9421535125296701E-01,   7.5946808138786806E-02,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -9.9421535125296701E-01,   7.5946808138786806E-02,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [   9.9421535125296701E-01,  -7.5946808138786806E-02,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [   9.9421535125296701E-01,   7.5946808138786806E-02,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -9.9421535125296701E-01,  -7.5946808138786806E-02,   7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -9.9421535125296701E-01,   7.5946808138786806E-02,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [   9.9421535125296701E-01,  -7.5946808138786806E-02,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [  -9.9421535125296701E-01,  -7.5946808138786806E-02,  -7.5946808138786806E-02,   2.2202947897414513E-03],
            [   1.1083353592047990E-01,   1.1083353592047990E-01,   9.8763953678998051E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,   1.1083353592047990E-01,   9.8763953678998051E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,  -1.1083353592047990E-01,   9.8763953678998051E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,   1.1083353592047990E-01,  -9.8763953678998051E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,  -1.1083353592047990E-01,   9.8763953678998051E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,   1.1083353592047990E-01,  -9.8763953678998051E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,  -1.1083353592047990E-01,  -9.8763953678998051E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,  -1.1083353592047990E-01,  -9.8763953678998051E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,   9.8763953678998051E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,  -9.8763953678998051E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,   9.8763953678998051E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,  -9.8763953678998051E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,   9.8763953678998051E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,  -9.8763953678998051E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -1.1083353592047990E-01,  -9.8763953678998051E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [   1.1083353592047990E-01,   9.8763953678998051E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [   9.8763953678998051E-01,   1.1083353592047990E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -9.8763953678998051E-01,   1.1083353592047990E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [   9.8763953678998051E-01,  -1.1083353592047990E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [   9.8763953678998051E-01,   1.1083353592047990E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -9.8763953678998051E-01,  -1.1083353592047990E-01,   1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -9.8763953678998051E-01,   1.1083353592047990E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [   9.8763953678998051E-01,  -1.1083353592047990E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [  -9.8763953678998051E-01,  -1.1083353592047990E-01,  -1.1083353592047990E-01,   2.6177674670492010E-03],
            [   1.4765170543885670E-01,   1.4765170543885670E-01,   9.7795600502374036E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,   1.4765170543885670E-01,   9.7795600502374036E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,  -1.4765170543885670E-01,   9.7795600502374036E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,   1.4765170543885670E-01,  -9.7795600502374036E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,  -1.4765170543885670E-01,   9.7795600502374036E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,   1.4765170543885670E-01,  -9.7795600502374036E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,  -1.4765170543885670E-01,  -9.7795600502374036E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,  -1.4765170543885670E-01,  -9.7795600502374036E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,   9.7795600502374036E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,  -9.7795600502374036E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,   9.7795600502374036E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,  -9.7795600502374036E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,   9.7795600502374036E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,  -9.7795600502374036E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -1.4765170543885670E-01,  -9.7795600502374036E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [   1.4765170543885670E-01,   9.7795600502374036E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [   9.7795600502374036E-01,   1.4765170543885670E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -9.7795600502374036E-01,   1.4765170543885670E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [   9.7795600502374036E-01,  -1.4765170543885670E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [   9.7795600502374036E-01,   1.4765170543885670E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -9.7795600502374036E-01,  -1.4765170543885670E-01,   1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -9.7795600502374036E-01,   1.4765170543885670E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [   9.7795600502374036E-01,  -1.4765170543885670E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [  -9.7795600502374036E-01,  -1.4765170543885670E-01,  -1.4765170543885670E-01,   2.9320855505065059E-03],
            [   1.8567318708606151E-01,   1.8567318708606151E-01,   9.6490980676673033E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,   1.8567318708606151E-01,   9.6490980676673033E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,  -1.8567318708606151E-01,   9.6490980676673033E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,   1.8567318708606151E-01,  -9.6490980676673033E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,  -1.8567318708606151E-01,   9.6490980676673033E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,   1.8567318708606151E-01,  -9.6490980676673033E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,  -1.8567318708606151E-01,  -9.6490980676673033E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,  -1.8567318708606151E-01,  -9.6490980676673033E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,   9.6490980676673033E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,  -9.6490980676673033E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,   9.6490980676673033E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,  -9.6490980676673033E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,   9.6490980676673033E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,  -9.6490980676673033E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -1.8567318708606151E-01,  -9.6490980676673033E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [   1.8567318708606151E-01,   9.6490980676673033E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [   9.6490980676673033E-01,   1.8567318708606151E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -9.6490980676673033E-01,   1.8567318708606151E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [   9.6490980676673033E-01,  -1.8567318708606151E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [   9.6490980676673033E-01,   1.8567318708606151E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -9.6490980676673033E-01,  -1.8567318708606151E-01,   1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -9.6490980676673033E-01,   1.8567318708606151E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [   9.6490980676673033E-01,  -1.8567318708606151E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [  -9.6490980676673033E-01,  -1.8567318708606151E-01,  -1.8567318708606151E-01,   3.1828223374348033E-03],
            [   2.2436340994288209E-01,   2.2436340994288209E-01,   9.4832595691439581E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,   2.2436340994288209E-01,   9.4832595691439581E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,  -2.2436340994288209E-01,   9.4832595691439581E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,   2.2436340994288209E-01,  -9.4832595691439581E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,  -2.2436340994288209E-01,   9.4832595691439581E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,   2.2436340994288209E-01,  -9.4832595691439581E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,  -2.2436340994288209E-01,  -9.4832595691439581E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,  -2.2436340994288209E-01,  -9.4832595691439581E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,   9.4832595691439581E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,  -9.4832595691439581E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,   9.4832595691439581E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,  -9.4832595691439581E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,   9.4832595691439581E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,  -9.4832595691439581E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -2.2436340994288209E-01,  -9.4832595691439581E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [   2.2436340994288209E-01,   9.4832595691439581E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [   9.4832595691439581E-01,   2.2436340994288209E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -9.4832595691439581E-01,   2.2436340994288209E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [   9.4832595691439581E-01,  -2.2436340994288209E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [   9.4832595691439581E-01,   2.2436340994288209E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -9.4832595691439581E-01,  -2.2436340994288209E-01,   2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -9.4832595691439581E-01,   2.2436340994288209E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [   9.4832595691439581E-01,  -2.2436340994288209E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [  -9.4832595691439581E-01,  -2.2436340994288209E-01,  -2.2436340994288209E-01,   3.3834603335650554E-03],
            [   2.6330068816627272E-01,   2.6330068816627272E-01,   9.2808700843311798E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,   2.6330068816627272E-01,   9.2808700843311798E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,  -2.6330068816627272E-01,   9.2808700843311798E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,   2.6330068816627272E-01,  -9.2808700843311798E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,  -2.6330068816627272E-01,   9.2808700843311798E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,   2.6330068816627272E-01,  -9.2808700843311798E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,  -2.6330068816627272E-01,  -9.2808700843311798E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,  -2.6330068816627272E-01,  -9.2808700843311798E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,   9.2808700843311798E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,  -9.2808700843311798E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,   9.2808700843311798E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,  -9.2808700843311798E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,   9.2808700843311798E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,  -9.2808700843311798E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -2.6330068816627272E-01,  -9.2808700843311798E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [   2.6330068816627272E-01,   9.2808700843311798E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [   9.2808700843311798E-01,   2.6330068816627272E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -9.2808700843311798E-01,   2.6330068816627272E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [   9.2808700843311798E-01,  -2.6330068816627272E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [   9.2808700843311798E-01,   2.6330068816627272E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -9.2808700843311798E-01,  -2.6330068816627272E-01,   2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -9.2808700843311798E-01,   2.6330068816627272E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [   9.2808700843311798E-01,  -2.6330068816627272E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [  -9.2808700843311798E-01,  -2.6330068816627272E-01,  -2.6330068816627272E-01,   3.5436536145580580E-03],
            [   3.0213409049162832E-01,   3.0213409049162832E-01,   9.0411834553093384E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,   3.0213409049162832E-01,   9.0411834553093384E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,  -3.0213409049162832E-01,   9.0411834553093384E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,   3.0213409049162832E-01,  -9.0411834553093384E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,  -3.0213409049162832E-01,   9.0411834553093384E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,   3.0213409049162832E-01,  -9.0411834553093384E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,  -3.0213409049162832E-01,  -9.0411834553093384E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,  -3.0213409049162832E-01,  -9.0411834553093384E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,   9.0411834553093384E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,  -9.0411834553093384E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,   9.0411834553093384E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,  -9.0411834553093384E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,   9.0411834553093384E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,  -9.0411834553093384E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -3.0213409049162832E-01,  -9.0411834553093384E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [   3.0213409049162832E-01,   9.0411834553093384E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [   9.0411834553093384E-01,   3.0213409049162832E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -9.0411834553093384E-01,   3.0213409049162832E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [   9.0411834553093384E-01,  -3.0213409049162832E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [   9.0411834553093384E-01,   3.0213409049162832E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -9.0411834553093384E-01,  -3.0213409049162832E-01,   3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -9.0411834553093384E-01,   3.0213409049162832E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [   9.0411834553093384E-01,  -3.0213409049162832E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [  -9.0411834553093384E-01,  -3.0213409049162832E-01,  -3.0213409049162832E-01,   3.6705785409209498E-03],
            [   3.4055940480300889E-01,   3.4055940480300889E-01,   8.7637810538627714E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,   3.4055940480300889E-01,   8.7637810538627714E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,  -3.4055940480300889E-01,   8.7637810538627714E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,   3.4055940480300889E-01,  -8.7637810538627714E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,  -3.4055940480300889E-01,   8.7637810538627714E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,   3.4055940480300889E-01,  -8.7637810538627714E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,  -3.4055940480300889E-01,  -8.7637810538627714E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,  -3.4055940480300889E-01,  -8.7637810538627714E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,   8.7637810538627714E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,  -8.7637810538627714E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,   8.7637810538627714E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,  -8.7637810538627714E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,   8.7637810538627714E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,  -8.7637810538627714E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -3.4055940480300889E-01,  -8.7637810538627714E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [   3.4055940480300889E-01,   8.7637810538627714E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [   8.7637810538627714E-01,   3.4055940480300889E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -8.7637810538627714E-01,   3.4055940480300889E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [   8.7637810538627714E-01,  -3.4055940480300889E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [   8.7637810538627714E-01,   3.4055940480300889E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -8.7637810538627714E-01,  -3.4055940480300889E-01,   3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -8.7637810538627714E-01,   3.4055940480300889E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [   8.7637810538627714E-01,  -3.4055940480300889E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [  -8.7637810538627714E-01,  -3.4055940480300889E-01,  -3.4055940480300889E-01,   3.7697726814758491E-03],
            [   3.7830444340073721E-01,   3.7830444340073721E-01,   8.4484998443896342E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,   3.7830444340073721E-01,   8.4484998443896342E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,  -3.7830444340073721E-01,   8.4484998443896342E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,   3.7830444340073721E-01,  -8.4484998443896342E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,  -3.7830444340073721E-01,   8.4484998443896342E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,   3.7830444340073721E-01,  -8.4484998443896342E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,  -3.7830444340073721E-01,  -8.4484998443896342E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,  -3.7830444340073721E-01,  -8.4484998443896342E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,   8.4484998443896342E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,  -8.4484998443896342E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,   8.4484998443896342E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,  -8.4484998443896342E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,   8.4484998443896342E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,  -8.4484998443896342E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -3.7830444340073721E-01,  -8.4484998443896342E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [   3.7830444340073721E-01,   8.4484998443896342E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [   8.4484998443896342E-01,   3.7830444340073721E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -8.4484998443896342E-01,   3.7830444340073721E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [   8.4484998443896342E-01,  -3.7830444340073721E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [   8.4484998443896342E-01,   3.7830444340073721E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -8.4484998443896342E-01,  -3.7830444340073721E-01,   3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -8.4484998443896342E-01,   3.7830444340073721E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [   8.4484998443896342E-01,  -3.7830444340073721E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [  -8.4484998443896342E-01,  -3.7830444340073721E-01,  -3.7830444340073721E-01,   3.8456764974367187E-03],
            [   4.1511947674079103E-01,   4.1511947674079103E-01,   8.0953791761776284E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,   4.1511947674079103E-01,   8.0953791761776284E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,  -4.1511947674079103E-01,   8.0953791761776284E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,   4.1511947674079103E-01,  -8.0953791761776284E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,  -4.1511947674079103E-01,   8.0953791761776284E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,   4.1511947674079103E-01,  -8.0953791761776284E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,  -4.1511947674079103E-01,  -8.0953791761776284E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,  -4.1511947674079103E-01,  -8.0953791761776284E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,   8.0953791761776284E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,  -8.0953791761776284E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,   8.0953791761776284E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,  -8.0953791761776284E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,   8.0953791761776284E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,  -8.0953791761776284E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -4.1511947674079103E-01,  -8.0953791761776284E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [   4.1511947674079103E-01,   8.0953791761776284E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [   8.0953791761776284E-01,   4.1511947674079103E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -8.0953791761776284E-01,   4.1511947674079103E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [   8.0953791761776284E-01,  -4.1511947674079103E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [   8.0953791761776284E-01,   4.1511947674079103E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -8.0953791761776284E-01,  -4.1511947674079103E-01,   4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -8.0953791761776284E-01,   4.1511947674079103E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [   8.0953791761776284E-01,  -4.1511947674079103E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [  -8.0953791761776284E-01,  -4.1511947674079103E-01,  -4.1511947674079103E-01,   3.9019952597128143E-03],
            [   4.5077057664432568E-01,   4.5077057664432568E-01,   7.7046205257850575E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,   4.5077057664432568E-01,   7.7046205257850575E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,  -4.5077057664432568E-01,   7.7046205257850575E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,   4.5077057664432568E-01,  -7.7046205257850575E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,  -4.5077057664432568E-01,   7.7046205257850575E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,   4.5077057664432568E-01,  -7.7046205257850575E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,  -4.5077057664432568E-01,  -7.7046205257850575E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,  -4.5077057664432568E-01,  -7.7046205257850575E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,   7.7046205257850575E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,  -7.7046205257850575E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,   7.7046205257850575E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,  -7.7046205257850575E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,   7.7046205257850575E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,  -7.7046205257850575E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -4.5077057664432568E-01,  -7.7046205257850575E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [   4.5077057664432568E-01,   7.7046205257850575E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [   7.7046205257850575E-01,   4.5077057664432568E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -7.7046205257850575E-01,   4.5077057664432568E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [   7.7046205257850575E-01,  -4.5077057664432568E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [   7.7046205257850575E-01,   4.5077057664432568E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -7.7046205257850575E-01,  -4.5077057664432568E-01,   4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -7.7046205257850575E-01,   4.5077057664432568E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [   7.7046205257850575E-01,  -4.5077057664432568E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [  -7.7046205257850575E-01,  -4.5077057664432568E-01,  -4.5077057664432568E-01,   3.9419477983025373E-03],
            [   4.8503460565731871E-01,   4.8503460565731871E-01,   7.2765573084371338E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,   4.8503460565731871E-01,   7.2765573084371338E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,  -4.8503460565731871E-01,   7.2765573084371338E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,   4.8503460565731871E-01,  -7.2765573084371338E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,  -4.8503460565731871E-01,   7.2765573084371338E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,   4.8503460565731871E-01,  -7.2765573084371338E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,  -4.8503460565731871E-01,  -7.2765573084371338E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,  -4.8503460565731871E-01,  -7.2765573084371338E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,   7.2765573084371338E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,  -7.2765573084371338E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,   7.2765573084371338E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,  -7.2765573084371338E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,   7.2765573084371338E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,  -7.2765573084371338E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -4.8503460565731871E-01,  -7.2765573084371338E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [   4.8503460565731871E-01,   7.2765573084371338E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [   7.2765573084371338E-01,   4.8503460565731871E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -7.2765573084371338E-01,   4.8503460565731871E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [   7.2765573084371338E-01,  -4.8503460565731871E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [   7.2765573084371338E-01,   4.8503460565731871E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -7.2765573084371338E-01,  -4.8503460565731871E-01,   4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -7.2765573084371338E-01,   4.8503460565731871E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [   7.2765573084371338E-01,  -4.8503460565731871E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [  -7.2765573084371338E-01,  -4.8503460565731871E-01,  -4.8503460565731871E-01,   3.9684405537203154E-03],
            [   5.1769508177924695E-01,   5.1769508177924695E-01,   6.8116341989507756E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,   5.1769508177924695E-01,   6.8116341989507756E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,  -5.1769508177924695E-01,   6.8116341989507756E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,   5.1769508177924695E-01,  -6.8116341989507756E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,  -5.1769508177924695E-01,   6.8116341989507756E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,   5.1769508177924695E-01,  -6.8116341989507756E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,  -5.1769508177924695E-01,  -6.8116341989507756E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,  -5.1769508177924695E-01,  -6.8116341989507756E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,   6.8116341989507756E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,  -6.8116341989507756E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,   6.8116341989507756E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,  -6.8116341989507756E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,   6.8116341989507756E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,  -6.8116341989507756E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -5.1769508177924695E-01,  -6.8116341989507756E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [   5.1769508177924695E-01,   6.8116341989507756E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [   6.8116341989507756E-01,   5.1769508177924695E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -6.8116341989507756E-01,   5.1769508177924695E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [   6.8116341989507756E-01,  -5.1769508177924695E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [   6.8116341989507756E-01,   5.1769508177924695E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -6.8116341989507756E-01,  -5.1769508177924695E-01,   5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -6.8116341989507756E-01,   5.1769508177924695E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [   6.8116341989507756E-01,  -5.1769508177924695E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [  -6.8116341989507756E-01,  -5.1769508177924695E-01,  -5.1769508177924695E-01,   3.9841885609481573E-03],
            [   5.4853842408209885E-01,   5.4853842408209885E-01,   6.3103977260633493E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,   5.4853842408209885E-01,   6.3103977260633493E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,  -5.4853842408209885E-01,   6.3103977260633493E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,   5.4853842408209885E-01,  -6.3103977260633493E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,  -5.4853842408209885E-01,   6.3103977260633493E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,   5.4853842408209885E-01,  -6.3103977260633493E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,  -5.4853842408209885E-01,  -6.3103977260633493E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,  -5.4853842408209885E-01,  -6.3103977260633493E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,   6.3103977260633493E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,  -6.3103977260633493E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,   6.3103977260633493E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,  -6.3103977260633493E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,   6.3103977260633493E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,  -6.3103977260633493E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -5.4853842408209885E-01,  -6.3103977260633493E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [   5.4853842408209885E-01,   6.3103977260633493E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [   6.3103977260633493E-01,   5.4853842408209885E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -6.3103977260633493E-01,   5.4853842408209885E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [   6.3103977260633493E-01,  -5.4853842408209885E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [   6.3103977260633493E-01,   5.4853842408209885E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -6.3103977260633493E-01,  -5.4853842408209885E-01,   5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -6.3103977260633493E-01,   5.4853842408209885E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [   6.3103977260633493E-01,  -5.4853842408209885E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [  -6.3103977260633493E-01,  -5.4853842408209885E-01,  -5.4853842408209885E-01,   3.9917936118385195E-03],
            [   6.0391172389433079E-01,   6.0391172389433079E-01,   5.2017425876907364E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,   6.0391172389433079E-01,   5.2017425876907364E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,  -6.0391172389433079E-01,   5.2017425876907364E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,   6.0391172389433079E-01,  -5.2017425876907364E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,  -6.0391172389433079E-01,   5.2017425876907364E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,   6.0391172389433079E-01,  -5.2017425876907364E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,  -6.0391172389433079E-01,  -5.2017425876907364E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,  -6.0391172389433079E-01,  -5.2017425876907364E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,   5.2017425876907364E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,  -5.2017425876907364E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,   5.2017425876907364E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,  -5.2017425876907364E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,   5.2017425876907364E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,  -5.2017425876907364E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -6.0391172389433079E-01,  -5.2017425876907364E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [   6.0391172389433079E-01,   5.2017425876907364E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [   5.2017425876907364E-01,   6.0391172389433079E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -5.2017425876907364E-01,   6.0391172389433079E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [   5.2017425876907364E-01,  -6.0391172389433079E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [   5.2017425876907364E-01,   6.0391172389433079E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -5.2017425876907364E-01,  -6.0391172389433079E-01,   6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -5.2017425876907364E-01,   6.0391172389433079E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [   5.2017425876907364E-01,  -6.0391172389433079E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [  -5.2017425876907364E-01,  -6.0391172389433079E-01,  -6.0391172389433079E-01,   3.9925852750581073E-03],
            [   6.2799566555731134E-01,   6.2799566555731134E-01,   4.5961167095979966E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,   6.2799566555731134E-01,   4.5961167095979966E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,  -6.2799566555731134E-01,   4.5961167095979966E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,   6.2799566555731134E-01,  -4.5961167095979966E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,  -6.2799566555731134E-01,   4.5961167095979966E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,   6.2799566555731134E-01,  -4.5961167095979966E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,  -6.2799566555731134E-01,  -4.5961167095979966E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,  -6.2799566555731134E-01,  -4.5961167095979966E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,   4.5961167095979966E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,  -4.5961167095979966E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,   4.5961167095979966E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,  -4.5961167095979966E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,   4.5961167095979966E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,  -4.5961167095979966E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -6.2799566555731134E-01,  -4.5961167095979966E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [   6.2799566555731134E-01,   4.5961167095979966E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [   4.5961167095979966E-01,   6.2799566555731134E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -4.5961167095979966E-01,   6.2799566555731134E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [   4.5961167095979966E-01,  -6.2799566555731134E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [   4.5961167095979966E-01,   6.2799566555731134E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -4.5961167095979966E-01,  -6.2799566555731134E-01,   6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -4.5961167095979966E-01,   6.2799566555731134E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [   4.5961167095979966E-01,  -6.2799566555731134E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [  -4.5961167095979966E-01,  -6.2799566555731134E-01,  -6.2799566555731134E-01,   3.9904754834553923E-03],
            [   6.4936361695689515E-01,   6.4936361695689515E-01,   3.9579513128046123E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,   6.4936361695689515E-01,   3.9579513128046123E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9579513128046123E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,   6.4936361695689515E-01,  -3.9579513128046123E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9579513128046123E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,   6.4936361695689515E-01,  -3.9579513128046123E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,  -6.4936361695689515E-01,  -3.9579513128046123E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,  -6.4936361695689515E-01,  -3.9579513128046123E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,   3.9579513128046123E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,  -3.9579513128046123E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,   3.9579513128046123E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,  -3.9579513128046123E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,   3.9579513128046123E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,  -3.9579513128046123E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -6.4936361695689515E-01,  -3.9579513128046123E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [   6.4936361695689515E-01,   3.9579513128046123E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [   3.9579513128046123E-01,   6.4936361695689515E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -3.9579513128046123E-01,   6.4936361695689515E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [   3.9579513128046123E-01,  -6.4936361695689515E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [   3.9579513128046123E-01,   6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -3.9579513128046123E-01,  -6.4936361695689515E-01,   6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -3.9579513128046123E-01,   6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [   3.9579513128046123E-01,  -6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [  -3.9579513128046123E-01,  -6.4936361695689515E-01,  -6.4936361695689515E-01,   3.9893890707519203E-03],
            [   6.6776441177045043E-01,   6.6776441177045043E-01,   3.2890938075057802E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,   6.6776441177045043E-01,   3.2890938075057802E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,  -6.6776441177045043E-01,   3.2890938075057802E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,   6.6776441177045043E-01,  -3.2890938075057802E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,  -6.6776441177045043E-01,   3.2890938075057802E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,   6.6776441177045043E-01,  -3.2890938075057802E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,  -6.6776441177045043E-01,  -3.2890938075057802E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,  -6.6776441177045043E-01,  -3.2890938075057802E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,   3.2890938075057802E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,  -3.2890938075057802E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,   3.2890938075057802E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,  -3.2890938075057802E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,   3.2890938075057802E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,  -3.2890938075057802E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -6.6776441177045043E-01,  -3.2890938075057802E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [   6.6776441177045043E-01,   3.2890938075057802E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [   3.2890938075057802E-01,   6.6776441177045043E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -3.2890938075057802E-01,   6.6776441177045043E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [   3.2890938075057802E-01,  -6.6776441177045043E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [   3.2890938075057802E-01,   6.6776441177045043E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -3.2890938075057802E-01,  -6.6776441177045043E-01,   6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -3.2890938075057802E-01,   6.6776441177045043E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [   3.2890938075057802E-01,  -6.6776441177045043E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [  -3.2890938075057802E-01,  -6.6776441177045043E-01,  -6.6776441177045043E-01,   3.9906726788046199E-03],
            [   6.8293685721156239E-01,   6.8293685721156239E-01,   2.5921901574535028E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,   6.8293685721156239E-01,   2.5921901574535028E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,  -6.8293685721156239E-01,   2.5921901574535028E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,   6.8293685721156239E-01,  -2.5921901574535028E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,  -6.8293685721156239E-01,   2.5921901574535028E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,   6.8293685721156239E-01,  -2.5921901574535028E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,  -6.8293685721156239E-01,  -2.5921901574535028E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,  -6.8293685721156239E-01,  -2.5921901574535028E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,   2.5921901574535028E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,  -2.5921901574535028E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,   2.5921901574535028E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,  -2.5921901574535028E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,   2.5921901574535028E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,  -2.5921901574535028E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -6.8293685721156239E-01,  -2.5921901574535028E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [   6.8293685721156239E-01,   2.5921901574535028E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [   2.5921901574535028E-01,   6.8293685721156239E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -2.5921901574535028E-01,   6.8293685721156239E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [   2.5921901574535028E-01,  -6.8293685721156239E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [   2.5921901574535028E-01,   6.8293685721156239E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -2.5921901574535028E-01,  -6.8293685721156239E-01,   6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -2.5921901574535028E-01,   6.8293685721156239E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [   2.5921901574535028E-01,  -6.8293685721156239E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [  -2.5921901574535028E-01,  -6.8293685721156239E-01,  -6.8293685721156239E-01,   3.9947529823185120E-03],
            [   6.9461958181841210E-01,   6.9461958181841210E-01,   1.8710230652995319E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,   6.9461958181841210E-01,   1.8710230652995319E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,  -6.9461958181841210E-01,   1.8710230652995319E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,   6.9461958181841210E-01,  -1.8710230652995319E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,  -6.9461958181841210E-01,   1.8710230652995319E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,   6.9461958181841210E-01,  -1.8710230652995319E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,  -6.9461958181841210E-01,  -1.8710230652995319E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,  -6.9461958181841210E-01,  -1.8710230652995319E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,   1.8710230652995319E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,  -1.8710230652995319E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,   1.8710230652995319E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,  -1.8710230652995319E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,   1.8710230652995319E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,  -1.8710230652995319E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -6.9461958181841210E-01,  -1.8710230652995319E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [   6.9461958181841210E-01,   1.8710230652995319E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [   1.8710230652995319E-01,   6.9461958181841210E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -1.8710230652995319E-01,   6.9461958181841210E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [   1.8710230652995319E-01,  -6.9461958181841210E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [   1.8710230652995319E-01,   6.9461958181841210E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -1.8710230652995319E-01,  -6.9461958181841210E-01,   6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -1.8710230652995319E-01,   6.9461958181841210E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [   1.8710230652995319E-01,  -6.9461958181841210E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [  -1.8710230652995319E-01,  -6.9461958181841210E-01,  -6.9461958181841210E-01,   4.0008663578781894E-03],
            [   7.0257115420570260E-01,   7.0257115420570260E-01,   1.1308203463032347E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,   7.0257115420570260E-01,   1.1308203463032347E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,  -7.0257115420570260E-01,   1.1308203463032347E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,   7.0257115420570260E-01,  -1.1308203463032347E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,  -7.0257115420570260E-01,   1.1308203463032347E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,   7.0257115420570260E-01,  -1.1308203463032347E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,  -7.0257115420570260E-01,  -1.1308203463032347E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,  -7.0257115420570260E-01,  -1.1308203463032347E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,   1.1308203463032347E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,  -1.1308203463032347E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,   1.1308203463032347E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,  -1.1308203463032347E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,   1.1308203463032347E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,  -1.1308203463032347E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -7.0257115420570260E-01,  -1.1308203463032347E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [   7.0257115420570260E-01,   1.1308203463032347E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [   1.1308203463032347E-01,   7.0257115420570260E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -1.1308203463032347E-01,   7.0257115420570260E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [   1.1308203463032347E-01,  -7.0257115420570260E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [   1.1308203463032347E-01,   7.0257115420570260E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -1.1308203463032347E-01,  -7.0257115420570260E-01,   7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -1.1308203463032347E-01,   7.0257115420570260E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [   1.1308203463032347E-01,  -7.0257115420570260E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [  -1.1308203463032347E-01,  -7.0257115420570260E-01,  -7.0257115420570260E-01,   4.0071079037458908E-03],
            [   7.0660047671401194E-01,   7.0660047671401194E-01,   3.7835599837482761E-02,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,   7.0660047671401194E-01,   3.7835599837482761E-02,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,  -7.0660047671401194E-01,   3.7835599837482761E-02,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,   7.0660047671401194E-01,  -3.7835599837482761E-02,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,  -7.0660047671401194E-01,   3.7835599837482761E-02,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,   7.0660047671401194E-01,  -3.7835599837482761E-02,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,  -7.0660047671401194E-01,  -3.7835599837482761E-02,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,  -7.0660047671401194E-01,  -3.7835599837482761E-02,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,   3.7835599837482761E-02,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,  -3.7835599837482761E-02,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,   3.7835599837482761E-02,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,  -3.7835599837482761E-02,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,   3.7835599837482761E-02,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,  -3.7835599837482761E-02,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -7.0660047671401194E-01,  -3.7835599837482761E-02,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [   7.0660047671401194E-01,   3.7835599837482761E-02,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [   3.7835599837482761E-02,   7.0660047671401194E-01,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -3.7835599837482761E-02,   7.0660047671401194E-01,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [   3.7835599837482761E-02,  -7.0660047671401194E-01,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [   3.7835599837482761E-02,   7.0660047671401194E-01,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -3.7835599837482761E-02,  -7.0660047671401194E-01,   7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -3.7835599837482761E-02,   7.0660047671401194E-01,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [   3.7835599837482761E-02,  -7.0660047671401194E-01,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [  -3.7835599837482761E-02,  -7.0660047671401194E-01,  -7.0660047671401194E-01,   4.0110810601350294E-03],
            [   5.1325376899460623E-02,   9.9868198426031918E-01,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [  -5.1325376899460623E-02,   9.9868198426031918E-01,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [   5.1325376899460623E-02,  -9.9868198426031918E-01,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [  -5.1325376899460623E-02,  -9.9868198426031918E-01,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [   9.9868198426031918E-01,   5.1325376899460623E-02,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [  -9.9868198426031918E-01,   5.1325376899460623E-02,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [   9.9868198426031918E-01,  -5.1325376899460623E-02,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [  -9.9868198426031918E-01,  -5.1325376899460623E-02,   0.0000000000000000E+00,   1.5478999116392935E-03],
            [   5.1325376899460623E-02,   0.0000000000000000E+00,   9.9868198426031918E-01,   1.5478999116392935E-03],
            [  -5.1325376899460623E-02,   0.0000000000000000E+00,   9.9868198426031918E-01,   1.5478999116392935E-03],
            [   5.1325376899460623E-02,   0.0000000000000000E+00,  -9.9868198426031918E-01,   1.5478999116392935E-03],
            [  -5.1325376899460623E-02,   0.0000000000000000E+00,  -9.9868198426031918E-01,   1.5478999116392935E-03],
            [   9.9868198426031918E-01,   0.0000000000000000E+00,   5.1325376899460623E-02,   1.5478999116392935E-03],
            [  -9.9868198426031918E-01,   0.0000000000000000E+00,   5.1325376899460623E-02,   1.5478999116392935E-03],
            [   9.9868198426031918E-01,   0.0000000000000000E+00,  -5.1325376899460623E-02,   1.5478999116392935E-03],
            [  -9.9868198426031918E-01,   0.0000000000000000E+00,  -5.1325376899460623E-02,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,   5.1325376899460623E-02,   9.9868198426031918E-01,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,  -5.1325376899460623E-02,   9.9868198426031918E-01,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,   5.1325376899460623E-02,  -9.9868198426031918E-01,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,  -5.1325376899460623E-02,  -9.9868198426031918E-01,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,   9.9868198426031918E-01,   5.1325376899460623E-02,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,  -9.9868198426031918E-01,   5.1325376899460623E-02,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,   9.9868198426031918E-01,  -5.1325376899460623E-02,   1.5478999116392935E-03],
            [   0.0000000000000000E+00,  -9.9868198426031918E-01,  -5.1325376899460623E-02,   1.5478999116392935E-03],
            [   1.2979946613312249E-01,   9.9154026574393661E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [  -1.2979946613312249E-01,   9.9154026574393661E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [   1.2979946613312249E-01,  -9.9154026574393661E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [  -1.2979946613312249E-01,  -9.9154026574393661E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [   9.9154026574393661E-01,   1.2979946613312249E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [  -9.9154026574393661E-01,   1.2979946613312249E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [   9.9154026574393661E-01,  -1.2979946613312249E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [  -9.9154026574393661E-01,  -1.2979946613312249E-01,   0.0000000000000000E+00,   2.4186008130813621E-03],
            [   1.2979946613312249E-01,   0.0000000000000000E+00,   9.9154026574393661E-01,   2.4186008130813621E-03],
            [  -1.2979946613312249E-01,   0.0000000000000000E+00,   9.9154026574393661E-01,   2.4186008130813621E-03],
            [   1.2979946613312249E-01,   0.0000000000000000E+00,  -9.9154026574393661E-01,   2.4186008130813621E-03],
            [  -1.2979946613312249E-01,   0.0000000000000000E+00,  -9.9154026574393661E-01,   2.4186008130813621E-03],
            [   9.9154026574393661E-01,   0.0000000000000000E+00,   1.2979946613312249E-01,   2.4186008130813621E-03],
            [  -9.9154026574393661E-01,   0.0000000000000000E+00,   1.2979946613312249E-01,   2.4186008130813621E-03],
            [   9.9154026574393661E-01,   0.0000000000000000E+00,  -1.2979946613312249E-01,   2.4186008130813621E-03],
            [  -9.9154026574393661E-01,   0.0000000000000000E+00,  -1.2979946613312249E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,   1.2979946613312249E-01,   9.9154026574393661E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,  -1.2979946613312249E-01,   9.9154026574393661E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,   1.2979946613312249E-01,  -9.9154026574393661E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,  -1.2979946613312249E-01,  -9.9154026574393661E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,   9.9154026574393661E-01,   1.2979946613312249E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,  -9.9154026574393661E-01,   1.2979946613312249E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,   9.9154026574393661E-01,  -1.2979946613312249E-01,   2.4186008130813621E-03],
            [   0.0000000000000000E+00,  -9.9154026574393661E-01,  -1.2979946613312249E-01,   2.4186008130813621E-03],
            [   2.1888520494013070E-01,   9.7575061724721290E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [  -2.1888520494013070E-01,   9.7575061724721290E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [   2.1888520494013070E-01,  -9.7575061724721290E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [  -2.1888520494013070E-01,  -9.7575061724721290E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [   9.7575061724721290E-01,   2.1888520494013070E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [  -9.7575061724721290E-01,   2.1888520494013070E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [   9.7575061724721290E-01,  -2.1888520494013070E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [  -9.7575061724721290E-01,  -2.1888520494013070E-01,   0.0000000000000000E+00,   2.9919043934798976E-03],
            [   2.1888520494013070E-01,   0.0000000000000000E+00,   9.7575061724721290E-01,   2.9919043934798976E-03],
            [  -2.1888520494013070E-01,   0.0000000000000000E+00,   9.7575061724721290E-01,   2.9919043934798976E-03],
            [   2.1888520494013070E-01,   0.0000000000000000E+00,  -9.7575061724721290E-01,   2.9919043934798976E-03],
            [  -2.1888520494013070E-01,   0.0000000000000000E+00,  -9.7575061724721290E-01,   2.9919043934798976E-03],
            [   9.7575061724721290E-01,   0.0000000000000000E+00,   2.1888520494013070E-01,   2.9919043934798976E-03],
            [  -9.7575061724721290E-01,   0.0000000000000000E+00,   2.1888520494013070E-01,   2.9919043934798976E-03],
            [   9.7575061724721290E-01,   0.0000000000000000E+00,  -2.1888520494013070E-01,   2.9919043934798976E-03],
            [  -9.7575061724721290E-01,   0.0000000000000000E+00,  -2.1888520494013070E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,   2.1888520494013070E-01,   9.7575061724721290E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,  -2.1888520494013070E-01,   9.7575061724721290E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,   2.1888520494013070E-01,  -9.7575061724721290E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,  -2.1888520494013070E-01,  -9.7575061724721290E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,   9.7575061724721290E-01,   2.1888520494013070E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,  -9.7575061724721290E-01,   2.1888520494013070E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,   9.7575061724721290E-01,  -2.1888520494013070E-01,   2.9919043934798976E-03],
            [   0.0000000000000000E+00,  -9.7575061724721290E-01,  -2.1888520494013070E-01,   2.9919043934798976E-03],
            [   3.1231748249034569E-01,   9.4997778401965405E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [  -3.1231748249034569E-01,   9.4997778401965405E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [   3.1231748249034569E-01,  -9.4997778401965405E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [  -3.1231748249034569E-01,  -9.4997778401965405E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [   9.4997778401965405E-01,   3.1231748249034569E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [  -9.4997778401965405E-01,   3.1231748249034569E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [   9.4997778401965405E-01,  -3.1231748249034569E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [  -9.4997778401965405E-01,  -3.1231748249034569E-01,   0.0000000000000000E+00,   3.3842501033510483E-03],
            [   3.1231748249034569E-01,   0.0000000000000000E+00,   9.4997778401965405E-01,   3.3842501033510483E-03],
            [  -3.1231748249034569E-01,   0.0000000000000000E+00,   9.4997778401965405E-01,   3.3842501033510483E-03],
            [   3.1231748249034569E-01,   0.0000000000000000E+00,  -9.4997778401965405E-01,   3.3842501033510483E-03],
            [  -3.1231748249034569E-01,   0.0000000000000000E+00,  -9.4997778401965405E-01,   3.3842501033510483E-03],
            [   9.4997778401965405E-01,   0.0000000000000000E+00,   3.1231748249034569E-01,   3.3842501033510483E-03],
            [  -9.4997778401965405E-01,   0.0000000000000000E+00,   3.1231748249034569E-01,   3.3842501033510483E-03],
            [   9.4997778401965405E-01,   0.0000000000000000E+00,  -3.1231748249034569E-01,   3.3842501033510483E-03],
            [  -9.4997778401965405E-01,   0.0000000000000000E+00,  -3.1231748249034569E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,   3.1231748249034569E-01,   9.4997778401965405E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,  -3.1231748249034569E-01,   9.4997778401965405E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,   3.1231748249034569E-01,  -9.4997778401965405E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,  -3.1231748249034569E-01,  -9.4997778401965405E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,   9.4997778401965405E-01,   3.1231748249034569E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,  -9.4997778401965405E-01,   3.1231748249034569E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,   9.4997778401965405E-01,  -3.1231748249034569E-01,   3.3842501033510483E-03],
            [   0.0000000000000000E+00,  -9.4997778401965405E-01,  -3.1231748249034569E-01,   3.3842501033510483E-03],
            [   4.0640376207381951E-01,   9.1369359315486409E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [  -4.0640376207381951E-01,   9.1369359315486409E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [   4.0640376207381951E-01,  -9.1369359315486409E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [  -4.0640376207381951E-01,  -9.1369359315486409E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [   9.1369359315486409E-01,   4.0640376207381951E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [  -9.1369359315486409E-01,   4.0640376207381951E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [   9.1369359315486409E-01,  -4.0640376207381951E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [  -9.1369359315486409E-01,  -4.0640376207381951E-01,   0.0000000000000000E+00,   3.6551467724818460E-03],
            [   4.0640376207381951E-01,   0.0000000000000000E+00,   9.1369359315486409E-01,   3.6551467724818460E-03],
            [  -4.0640376207381951E-01,   0.0000000000000000E+00,   9.1369359315486409E-01,   3.6551467724818460E-03],
            [   4.0640376207381951E-01,   0.0000000000000000E+00,  -9.1369359315486409E-01,   3.6551467724818460E-03],
            [  -4.0640376207381951E-01,   0.0000000000000000E+00,  -9.1369359315486409E-01,   3.6551467724818460E-03],
            [   9.1369359315486409E-01,   0.0000000000000000E+00,   4.0640376207381951E-01,   3.6551467724818460E-03],
            [  -9.1369359315486409E-01,   0.0000000000000000E+00,   4.0640376207381951E-01,   3.6551467724818460E-03],
            [   9.1369359315486409E-01,   0.0000000000000000E+00,  -4.0640376207381951E-01,   3.6551467724818460E-03],
            [  -9.1369359315486409E-01,   0.0000000000000000E+00,  -4.0640376207381951E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,   4.0640376207381951E-01,   9.1369359315486409E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,  -4.0640376207381951E-01,   9.1369359315486409E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,   4.0640376207381951E-01,  -9.1369359315486409E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,  -4.0640376207381951E-01,  -9.1369359315486409E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,   9.1369359315486409E-01,   4.0640376207381951E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,  -9.1369359315486409E-01,   4.0640376207381951E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,   9.1369359315486409E-01,  -4.0640376207381951E-01,   3.6551467724818460E-03],
            [   0.0000000000000000E+00,  -9.1369359315486409E-01,  -4.0640376207381951E-01,   3.6551467724818460E-03],
            [   4.9849583969447819E-01,   8.6689209121279742E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [  -4.9849583969447819E-01,   8.6689209121279742E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [   4.9849583969447819E-01,  -8.6689209121279742E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [  -4.9849583969447819E-01,  -8.6689209121279742E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [   8.6689209121279742E-01,   4.9849583969447819E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [  -8.6689209121279742E-01,   4.9849583969447819E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [   8.6689209121279742E-01,  -4.9849583969447819E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [  -8.6689209121279742E-01,  -4.9849583969447819E-01,   0.0000000000000000E+00,   3.8376622931757995E-03],
            [   4.9849583969447819E-01,   0.0000000000000000E+00,   8.6689209121279742E-01,   3.8376622931757995E-03],
            [  -4.9849583969447819E-01,   0.0000000000000000E+00,   8.6689209121279742E-01,   3.8376622931757995E-03],
            [   4.9849583969447819E-01,   0.0000000000000000E+00,  -8.6689209121279742E-01,   3.8376622931757995E-03],
            [  -4.9849583969447819E-01,   0.0000000000000000E+00,  -8.6689209121279742E-01,   3.8376622931757995E-03],
            [   8.6689209121279742E-01,   0.0000000000000000E+00,   4.9849583969447819E-01,   3.8376622931757995E-03],
            [  -8.6689209121279742E-01,   0.0000000000000000E+00,   4.9849583969447819E-01,   3.8376622931757995E-03],
            [   8.6689209121279742E-01,   0.0000000000000000E+00,  -4.9849583969447819E-01,   3.8376622931757995E-03],
            [  -8.6689209121279742E-01,   0.0000000000000000E+00,  -4.9849583969447819E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,   4.9849583969447819E-01,   8.6689209121279742E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,  -4.9849583969447819E-01,   8.6689209121279742E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,   4.9849583969447819E-01,  -8.6689209121279742E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,  -4.9849583969447819E-01,  -8.6689209121279742E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,   8.6689209121279742E-01,   4.9849583969447819E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,  -8.6689209121279742E-01,   4.9849583969447819E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,   8.6689209121279742E-01,  -4.9849583969447819E-01,   3.8376622931757995E-03],
            [   0.0000000000000000E+00,  -8.6689209121279742E-01,  -4.9849583969447819E-01,   3.8376622931757995E-03],
            [   5.8649750460213645E-01,   8.0995103376405841E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [  -5.8649750460213645E-01,   8.0995103376405841E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [   5.8649750460213645E-01,  -8.0995103376405841E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [  -5.8649750460213645E-01,  -8.0995103376405841E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [   8.0995103376405841E-01,   5.8649750460213645E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [  -8.0995103376405841E-01,   5.8649750460213645E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [   8.0995103376405841E-01,  -5.8649750460213645E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [  -8.0995103376405841E-01,  -5.8649750460213645E-01,   0.0000000000000000E+00,   3.9507622233668155E-03],
            [   5.8649750460213645E-01,   0.0000000000000000E+00,   8.0995103376405841E-01,   3.9507622233668155E-03],
            [  -5.8649750460213645E-01,   0.0000000000000000E+00,   8.0995103376405841E-01,   3.9507622233668155E-03],
            [   5.8649750460213645E-01,   0.0000000000000000E+00,  -8.0995103376405841E-01,   3.9507622233668155E-03],
            [  -5.8649750460213645E-01,   0.0000000000000000E+00,  -8.0995103376405841E-01,   3.9507622233668155E-03],
            [   8.0995103376405841E-01,   0.0000000000000000E+00,   5.8649750460213645E-01,   3.9507622233668155E-03],
            [  -8.0995103376405841E-01,   0.0000000000000000E+00,   5.8649750460213645E-01,   3.9507622233668155E-03],
            [   8.0995103376405841E-01,   0.0000000000000000E+00,  -5.8649750460213645E-01,   3.9507622233668155E-03],
            [  -8.0995103376405841E-01,   0.0000000000000000E+00,  -5.8649750460213645E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,   5.8649750460213645E-01,   8.0995103376405841E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,  -5.8649750460213645E-01,   8.0995103376405841E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,   5.8649750460213645E-01,  -8.0995103376405841E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,  -5.8649750460213645E-01,  -8.0995103376405841E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,   8.0995103376405841E-01,   5.8649750460213645E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,  -8.0995103376405841E-01,   5.8649750460213645E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,   8.0995103376405841E-01,  -5.8649750460213645E-01,   3.9507622233668155E-03],
            [   0.0000000000000000E+00,  -8.0995103376405841E-01,  -5.8649750460213645E-01,   3.9507622233668155E-03],
            [   6.6867116345801747E-01,   7.4355825270095777E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [  -6.6867116345801747E-01,   7.4355825270095777E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [   6.6867116345801747E-01,  -7.4355825270095777E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [  -6.6867116345801747E-01,  -7.4355825270095777E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [   7.4355825270095777E-01,   6.6867116345801747E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [  -7.4355825270095777E-01,   6.6867116345801747E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [   7.4355825270095777E-01,  -6.6867116345801747E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [  -7.4355825270095777E-01,  -6.6867116345801747E-01,   0.0000000000000000E+00,   4.0049554002418632E-03],
            [   6.6867116345801747E-01,   0.0000000000000000E+00,   7.4355825270095777E-01,   4.0049554002418632E-03],
            [  -6.6867116345801747E-01,   0.0000000000000000E+00,   7.4355825270095777E-01,   4.0049554002418632E-03],
            [   6.6867116345801747E-01,   0.0000000000000000E+00,  -7.4355825270095777E-01,   4.0049554002418632E-03],
            [  -6.6867116345801747E-01,   0.0000000000000000E+00,  -7.4355825270095777E-01,   4.0049554002418632E-03],
            [   7.4355825270095777E-01,   0.0000000000000000E+00,   6.6867116345801747E-01,   4.0049554002418632E-03],
            [  -7.4355825270095777E-01,   0.0000000000000000E+00,   6.6867116345801747E-01,   4.0049554002418632E-03],
            [   7.4355825270095777E-01,   0.0000000000000000E+00,  -6.6867116345801747E-01,   4.0049554002418632E-03],
            [  -7.4355825270095777E-01,   0.0000000000000000E+00,  -6.6867116345801747E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,   6.6867116345801747E-01,   7.4355825270095777E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,  -6.6867116345801747E-01,   7.4355825270095777E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,   6.6867116345801747E-01,  -7.4355825270095777E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,  -6.6867116345801747E-01,  -7.4355825270095777E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,   7.4355825270095777E-01,   6.6867116345801747E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,  -7.4355825270095777E-01,   6.6867116345801747E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,   7.4355825270095777E-01,  -6.6867116345801747E-01,   4.0049554002418632E-03],
            [   0.0000000000000000E+00,  -7.4355825270095777E-01,  -6.6867116345801747E-01,   4.0049554002418632E-03],
            [   8.7157387808359493E-02,   2.5571752333675781E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,   2.5571752333675781E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,  -2.5571752333675781E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,   2.5571752333675781E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,  -2.5571752333675781E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,  -2.5571752333675781E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,   2.5571752333675781E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,  -2.5571752333675781E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,   8.7157387808359493E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,   8.7157387808359493E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,  -8.7157387808359493E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,   8.7157387808359493E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,  -8.7157387808359493E-02,   9.9586629385325032E-01,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,  -8.7157387808359493E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,   8.7157387808359493E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,  -8.7157387808359493E-02,  -9.9586629385325032E-01,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,   8.7157387808359493E-02,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,   8.7157387808359493E-02,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,  -8.7157387808359493E-02,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,   8.7157387808359493E-02,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,  -8.7157387808359493E-02,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,  -8.7157387808359493E-02,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,   8.7157387808359493E-02,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,  -8.7157387808359493E-02,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,   2.5571752333675781E-02,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,   2.5571752333675781E-02,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,  -2.5571752333675781E-02,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,   2.5571752333675781E-02,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,  -2.5571752333675781E-02,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   9.9586629385325032E-01,  -2.5571752333675781E-02,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,   2.5571752333675781E-02,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -9.9586629385325032E-01,  -2.5571752333675781E-02,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,   9.9586629385325032E-01,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,   9.9586629385325032E-01,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,  -9.9586629385325032E-01,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,   9.9586629385325032E-01,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,  -9.9586629385325032E-01,   2.5571752333675781E-02,   2.0548774723580174E-03],
            [   8.7157387808359493E-02,  -9.9586629385325032E-01,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,   9.9586629385325032E-01,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [  -8.7157387808359493E-02,  -9.9586629385325032E-01,  -2.5571752333675781E-02,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,   9.9586629385325032E-01,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,   9.9586629385325032E-01,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,  -9.9586629385325032E-01,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,   9.9586629385325032E-01,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,  -9.9586629385325032E-01,   8.7157387808359493E-02,   2.0548774723580174E-03],
            [   2.5571752333675781E-02,  -9.9586629385325032E-01,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,   9.9586629385325032E-01,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [  -2.5571752333675781E-02,  -9.9586629385325032E-01,  -8.7157387808359493E-02,   2.0548774723580174E-03],
            [   1.2483831231340070E-01,   5.6048233833766808E-02,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,   5.6048233833766808E-02,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,  -5.6048233833766808E-02,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,   5.6048233833766808E-02,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,  -5.6048233833766808E-02,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,  -5.6048233833766808E-02,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,   5.6048233833766808E-02,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,  -5.6048233833766808E-02,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,   1.2483831231340070E-01,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,   1.2483831231340070E-01,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,  -1.2483831231340070E-01,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,   1.2483831231340070E-01,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,  -1.2483831231340070E-01,   9.9059274743097991E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,  -1.2483831231340070E-01,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,   1.2483831231340070E-01,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,  -1.2483831231340070E-01,  -9.9059274743097991E-01,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,   1.2483831231340070E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,   1.2483831231340070E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,  -1.2483831231340070E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,   1.2483831231340070E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,  -1.2483831231340070E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,  -1.2483831231340070E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,   1.2483831231340070E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,  -1.2483831231340070E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,   5.6048233833766808E-02,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,   5.6048233833766808E-02,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,  -5.6048233833766808E-02,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,   5.6048233833766808E-02,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,  -5.6048233833766808E-02,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   9.9059274743097991E-01,  -5.6048233833766808E-02,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,   5.6048233833766808E-02,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -9.9059274743097991E-01,  -5.6048233833766808E-02,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,   9.9059274743097991E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,   9.9059274743097991E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,  -9.9059274743097991E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,   9.9059274743097991E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,  -9.9059274743097991E-01,   5.6048233833766808E-02,   2.4731998635564743E-03],
            [   1.2483831231340070E-01,  -9.9059274743097991E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,   9.9059274743097991E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [  -1.2483831231340070E-01,  -9.9059274743097991E-01,  -5.6048233833766808E-02,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,   9.9059274743097991E-01,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,   9.9059274743097991E-01,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,  -9.9059274743097991E-01,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,   9.9059274743097991E-01,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,  -9.9059274743097991E-01,   1.2483831231340070E-01,   2.4731998635564743E-03],
            [   5.6048233833766808E-02,  -9.9059274743097991E-01,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,   9.9059274743097991E-01,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [  -5.6048233833766808E-02,  -9.9059274743097991E-01,  -1.2483831231340070E-01,   2.4731998635564743E-03],
            [   1.6380626933833781E-01,   8.9685686019007643E-02,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,   8.9685686019007643E-02,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,  -8.9685686019007643E-02,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,   8.9685686019007643E-02,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,  -8.9685686019007643E-02,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,  -8.9685686019007643E-02,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,   8.9685686019007643E-02,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,  -8.9685686019007643E-02,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,   1.6380626933833781E-01,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,   1.6380626933833781E-01,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,  -1.6380626933833781E-01,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,   1.6380626933833781E-01,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,  -1.6380626933833781E-01,   9.8240723931003071E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,  -1.6380626933833781E-01,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,   1.6380626933833781E-01,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,  -1.6380626933833781E-01,  -9.8240723931003071E-01,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,   1.6380626933833781E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,   1.6380626933833781E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,  -1.6380626933833781E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,   1.6380626933833781E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,  -1.6380626933833781E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,  -1.6380626933833781E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,   1.6380626933833781E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,  -1.6380626933833781E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,   8.9685686019007643E-02,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,   8.9685686019007643E-02,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,  -8.9685686019007643E-02,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,   8.9685686019007643E-02,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,  -8.9685686019007643E-02,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   9.8240723931003071E-01,  -8.9685686019007643E-02,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,   8.9685686019007643E-02,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -9.8240723931003071E-01,  -8.9685686019007643E-02,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,   9.8240723931003071E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,   9.8240723931003071E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,  -9.8240723931003071E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,   9.8240723931003071E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,  -9.8240723931003071E-01,   8.9685686019007643E-02,   2.8107884037990353E-03],
            [   1.6380626933833781E-01,  -9.8240723931003071E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,   9.8240723931003071E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [  -1.6380626933833781E-01,  -9.8240723931003071E-01,  -8.9685686019007643E-02,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,   9.8240723931003071E-01,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,   9.8240723931003071E-01,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,  -9.8240723931003071E-01,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,   9.8240723931003071E-01,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,  -9.8240723931003071E-01,   1.6380626933833781E-01,   2.8107884037990353E-03],
            [   8.9685686019007643E-02,  -9.8240723931003071E-01,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,   9.8240723931003071E-01,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [  -8.9685686019007643E-02,  -9.8240723931003071E-01,  -1.6380626933833781E-01,   2.8107884037990353E-03],
            [   2.0355862033731759E-01,   1.2540866519762789E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,   1.2540866519762789E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,  -1.2540866519762789E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,   1.2540866519762789E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,  -1.2540866519762789E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,  -1.2540866519762789E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,   1.2540866519762789E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,  -1.2540866519762789E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,   2.0355862033731759E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,   2.0355862033731759E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,  -2.0355862033731759E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,   2.0355862033731759E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,  -2.0355862033731759E-01,   9.7099771100642507E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,  -2.0355862033731759E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,   2.0355862033731759E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,  -2.0355862033731759E-01,  -9.7099771100642507E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,   2.0355862033731759E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,   2.0355862033731759E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,  -2.0355862033731759E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,   2.0355862033731759E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,  -2.0355862033731759E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,  -2.0355862033731759E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,   2.0355862033731759E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,  -2.0355862033731759E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,   1.2540866519762789E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,   1.2540866519762789E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,  -1.2540866519762789E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,   1.2540866519762789E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,  -1.2540866519762789E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   9.7099771100642507E-01,  -1.2540866519762789E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,   1.2540866519762789E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -9.7099771100642507E-01,  -1.2540866519762789E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,   9.7099771100642507E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,   9.7099771100642507E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,  -9.7099771100642507E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,   9.7099771100642507E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,  -9.7099771100642507E-01,   1.2540866519762789E-01,   3.0827653095269834E-03],
            [   2.0355862033731759E-01,  -9.7099771100642507E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,   9.7099771100642507E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [  -2.0355862033731759E-01,  -9.7099771100642507E-01,  -1.2540866519762789E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,   9.7099771100642507E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,   9.7099771100642507E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,  -9.7099771100642507E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,   9.7099771100642507E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,  -9.7099771100642507E-01,   2.0355862033731759E-01,   3.0827653095269834E-03],
            [   1.2540866519762789E-01,  -9.7099771100642507E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,   9.7099771100642507E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [  -1.2540866519762789E-01,  -9.7099771100642507E-01,  -2.0355862033731759E-01,   3.0827653095269834E-03],
            [   2.4367989752937741E-01,   1.6247801501620121E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,   1.6247801501620121E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,  -1.6247801501620121E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,   1.6247801501620121E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,  -1.6247801501620121E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,  -1.6247801501620121E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,   1.6247801501620121E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,  -1.6247801501620121E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,   2.4367989752937741E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,   2.4367989752937741E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,  -2.4367989752937741E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,   2.4367989752937741E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,  -2.4367989752937741E-01,   9.5614904809682633E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,  -2.4367989752937741E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,   2.4367989752937741E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,  -2.4367989752937741E-01,  -9.5614904809682633E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,   2.4367989752937741E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,   2.4367989752937741E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,  -2.4367989752937741E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,   2.4367989752937741E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,  -2.4367989752937741E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,  -2.4367989752937741E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,   2.4367989752937741E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,  -2.4367989752937741E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,   1.6247801501620121E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,   1.6247801501620121E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,  -1.6247801501620121E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,   1.6247801501620121E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,  -1.6247801501620121E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   9.5614904809682633E-01,  -1.6247801501620121E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,   1.6247801501620121E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -9.5614904809682633E-01,  -1.6247801501620121E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,   9.5614904809682633E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,   9.5614904809682633E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,  -9.5614904809682633E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,   9.5614904809682633E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,  -9.5614904809682633E-01,   1.6247801501620121E-01,   3.3018789621424506E-03],
            [   2.4367989752937741E-01,  -9.5614904809682633E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,   9.5614904809682633E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [  -2.4367989752937741E-01,  -9.5614904809682633E-01,  -1.6247801501620121E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,   9.5614904809682633E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,   9.5614904809682633E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,  -9.5614904809682633E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,   9.5614904809682633E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,  -9.5614904809682633E-01,   2.4367989752937741E-01,   3.3018789621424506E-03],
            [   1.6247801501620121E-01,  -9.5614904809682633E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,   9.5614904809682633E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [  -1.6247801501620121E-01,  -9.5614904809682633E-01,  -2.4367989752937741E-01,   3.3018789621424506E-03],
            [   2.8382075077738061E-01,   2.0034223426832079E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,   2.0034223426832079E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,  -2.0034223426832079E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,   2.0034223426832079E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,  -2.0034223426832079E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,  -2.0034223426832079E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,   2.0034223426832079E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,  -2.0034223426832079E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,   2.8382075077738061E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,   2.8382075077738061E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,  -2.8382075077738061E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,   2.8382075077738061E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,  -2.8382075077738061E-01,   9.3771465307765201E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,  -2.8382075077738061E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,   2.8382075077738061E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,  -2.8382075077738061E-01,  -9.3771465307765201E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,   2.8382075077738061E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,   2.8382075077738061E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,  -2.8382075077738061E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,   2.8382075077738061E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,  -2.8382075077738061E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,  -2.8382075077738061E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,   2.8382075077738061E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,  -2.8382075077738061E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,   2.0034223426832079E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,   2.0034223426832079E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,  -2.0034223426832079E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,   2.0034223426832079E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,  -2.0034223426832079E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   9.3771465307765201E-01,  -2.0034223426832079E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,   2.0034223426832079E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -9.3771465307765201E-01,  -2.0034223426832079E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,   9.3771465307765201E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,   9.3771465307765201E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,  -9.3771465307765201E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,   9.3771465307765201E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,  -9.3771465307765201E-01,   2.0034223426832079E-01,   3.4779376705305200E-03],
            [   2.8382075077738061E-01,  -9.3771465307765201E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,   9.3771465307765201E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [  -2.8382075077738061E-01,  -9.3771465307765201E-01,  -2.0034223426832079E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,   9.3771465307765201E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,   9.3771465307765201E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,  -9.3771465307765201E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,   9.3771465307765201E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,  -9.3771465307765201E-01,   2.8382075077738061E-01,   3.4779376705305200E-03],
            [   2.0034223426832079E-01,  -9.3771465307765201E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,   9.3771465307765201E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [  -2.0034223426832079E-01,  -9.3771465307765201E-01,  -2.8382075077738061E-01,   3.4779376705305200E-03],
            [   3.2367875022176917E-01,   2.3856280262552629E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,   2.3856280262552629E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,  -2.3856280262552629E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,   2.3856280262552629E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,  -2.3856280262552629E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,  -2.3856280262552629E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,   2.3856280262552629E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,  -2.3856280262552629E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,   3.2367875022176917E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,   3.2367875022176917E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,  -3.2367875022176917E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,   3.2367875022176917E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,  -3.2367875022176917E-01,   9.1559808642128981E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,  -3.2367875022176917E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,   3.2367875022176917E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,  -3.2367875022176917E-01,  -9.1559808642128981E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,   3.2367875022176917E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,   3.2367875022176917E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,  -3.2367875022176917E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,   3.2367875022176917E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,  -3.2367875022176917E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,  -3.2367875022176917E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,   3.2367875022176917E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,  -3.2367875022176917E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,   2.3856280262552629E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,   2.3856280262552629E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,  -2.3856280262552629E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,   2.3856280262552629E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,  -2.3856280262552629E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   9.1559808642128981E-01,  -2.3856280262552629E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,   2.3856280262552629E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -9.1559808642128981E-01,  -2.3856280262552629E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,   9.1559808642128981E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,   9.1559808642128981E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,  -9.1559808642128981E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,   9.1559808642128981E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,  -9.1559808642128981E-01,   2.3856280262552629E-01,   3.6184449842733492E-03],
            [   3.2367875022176917E-01,  -9.1559808642128981E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,   9.1559808642128981E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [  -3.2367875022176917E-01,  -9.1559808642128981E-01,  -2.3856280262552629E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,   9.1559808642128981E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,   9.1559808642128981E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,  -9.1559808642128981E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,   9.1559808642128981E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,  -9.1559808642128981E-01,   3.2367875022176917E-01,   3.6184449842733492E-03],
            [   2.3856280262552629E-01,  -9.1559808642128981E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,   9.1559808642128981E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [  -2.3856280262552629E-01,  -9.1559808642128981E-01,  -3.2367875022176917E-01,   3.6184449842733492E-03],
            [   3.6298495548406912E-01,   2.7677311487835782E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,   2.7677311487835782E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,  -2.7677311487835782E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,   2.7677311487835782E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,  -2.7677311487835782E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,  -2.7677311487835782E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,   2.7677311487835782E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,  -2.7677311487835782E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,   3.6298495548406912E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,   3.6298495548406912E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,  -3.6298495548406912E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,   3.6298495548406912E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,  -3.6298495548406912E-01,   8.8974072907379020E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,  -3.6298495548406912E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,   3.6298495548406912E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,  -3.6298495548406912E-01,  -8.8974072907379020E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,   3.6298495548406912E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,   3.6298495548406912E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,  -3.6298495548406912E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,   3.6298495548406912E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,  -3.6298495548406912E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,  -3.6298495548406912E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,   3.6298495548406912E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,  -3.6298495548406912E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,   2.7677311487835782E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,   2.7677311487835782E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,  -2.7677311487835782E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,   2.7677311487835782E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,  -2.7677311487835782E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   8.8974072907379020E-01,  -2.7677311487835782E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,   2.7677311487835782E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -8.8974072907379020E-01,  -2.7677311487835782E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,   8.8974072907379020E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,   8.8974072907379020E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,  -8.8974072907379020E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,   8.8974072907379020E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,  -8.8974072907379020E-01,   2.7677311487835782E-01,   3.7292463071099216E-03],
            [   3.6298495548406912E-01,  -8.8974072907379020E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,   8.8974072907379020E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [  -3.6298495548406912E-01,  -8.8974072907379020E-01,  -2.7677311487835782E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,   8.8974072907379020E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,   8.8974072907379020E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,  -8.8974072907379020E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,   8.8974072907379020E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,  -8.8974072907379020E-01,   3.6298495548406912E-01,   3.7292463071099216E-03],
            [   2.7677311487835782E-01,  -8.8974072907379020E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,   8.8974072907379020E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [  -2.7677311487835782E-01,  -8.8974072907379020E-01,  -3.6298495548406912E-01,   3.7292463071099216E-03],
            [   4.0149480819920869E-01,   3.1465423082453092E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,   3.1465423082453092E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,  -3.1465423082453092E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,   3.1465423082453092E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,  -3.1465423082453092E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,  -3.1465423082453092E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,   3.1465423082453092E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,  -3.1465423082453092E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,   4.0149480819920869E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,   4.0149480819920869E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,  -4.0149480819920869E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,   4.0149480819920869E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,  -4.0149480819920869E-01,   8.6011315186625503E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,  -4.0149480819920869E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,   4.0149480819920869E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,  -4.0149480819920869E-01,  -8.6011315186625503E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,   4.0149480819920869E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,   4.0149480819920869E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,  -4.0149480819920869E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,   4.0149480819920869E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,  -4.0149480819920869E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,  -4.0149480819920869E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,   4.0149480819920869E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,  -4.0149480819920869E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,   3.1465423082453092E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,   3.1465423082453092E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,  -3.1465423082453092E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,   3.1465423082453092E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,  -3.1465423082453092E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   8.6011315186625503E-01,  -3.1465423082453092E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,   3.1465423082453092E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -8.6011315186625503E-01,  -3.1465423082453092E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,   8.6011315186625503E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,   8.6011315186625503E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,  -8.6011315186625503E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,   8.6011315186625503E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,  -8.6011315186625503E-01,   3.1465423082453092E-01,   3.8150253151828725E-03],
            [   4.0149480819920869E-01,  -8.6011315186625503E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,   8.6011315186625503E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [  -4.0149480819920869E-01,  -8.6011315186625503E-01,  -3.1465423082453092E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,   8.6011315186625503E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,   8.6011315186625503E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,  -8.6011315186625503E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,   8.6011315186625503E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,  -8.6011315186625503E-01,   4.0149480819920869E-01,   3.8150253151828725E-03],
            [   3.1465423082453092E-01,  -8.6011315186625503E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,   8.6011315186625503E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [  -3.1465423082453092E-01,  -8.6011315186625503E-01,  -4.0149480819920869E-01,   3.8150253151828725E-03],
            [   4.3898183792602252E-01,   3.5191964158950878E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,   3.5191964158950878E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,  -3.5191964158950878E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,   3.5191964158950878E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,  -3.5191964158950878E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,  -3.5191964158950878E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,   3.5191964158950878E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,  -3.5191964158950878E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,   4.3898183792602252E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,   4.3898183792602252E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,  -4.3898183792602252E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,   4.3898183792602252E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,  -4.3898183792602252E-01,   8.2670884344768136E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,  -4.3898183792602252E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,   4.3898183792602252E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,  -4.3898183792602252E-01,  -8.2670884344768136E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,   4.3898183792602252E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,   4.3898183792602252E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,  -4.3898183792602252E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,   4.3898183792602252E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,  -4.3898183792602252E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,  -4.3898183792602252E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,   4.3898183792602252E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,  -4.3898183792602252E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,   3.5191964158950878E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,   3.5191964158950878E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,  -3.5191964158950878E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,   3.5191964158950878E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,  -3.5191964158950878E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   8.2670884344768136E-01,  -3.5191964158950878E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,   3.5191964158950878E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -8.2670884344768136E-01,  -3.5191964158950878E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,   8.2670884344768136E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,   8.2670884344768136E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,  -8.2670884344768136E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,   8.2670884344768136E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,  -8.2670884344768136E-01,   3.5191964158950878E-01,   3.8796636501772907E-03],
            [   4.3898183792602252E-01,  -8.2670884344768136E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,   8.2670884344768136E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [  -4.3898183792602252E-01,  -8.2670884344768136E-01,  -3.5191964158950878E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,   8.2670884344768136E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,   8.2670884344768136E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,  -8.2670884344768136E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,   8.2670884344768136E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,  -8.2670884344768136E-01,   4.3898183792602252E-01,   3.8796636501772907E-03],
            [   3.5191964158950878E-01,  -8.2670884344768136E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,   8.2670884344768136E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [  -3.5191964158950878E-01,  -8.2670884344768136E-01,  -4.3898183792602252E-01,   3.8796636501772907E-03],
            [   4.7523311436743770E-01,   3.8830509840236538E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,   3.8830509840236538E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,  -3.8830509840236538E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,   3.8830509840236538E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,  -3.8830509840236538E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,  -3.8830509840236538E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,   3.8830509840236538E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,  -3.8830509840236538E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,   4.7523311436743770E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,   4.7523311436743770E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,  -4.7523311436743770E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,   4.7523311436743770E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,  -4.7523311436743770E-01,   7.8953950981781484E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,  -4.7523311436743770E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,   4.7523311436743770E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,  -4.7523311436743770E-01,  -7.8953950981781484E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,   4.7523311436743770E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,   4.7523311436743770E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,  -4.7523311436743770E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,   4.7523311436743770E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,  -4.7523311436743770E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,  -4.7523311436743770E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,   4.7523311436743770E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,  -4.7523311436743770E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,   3.8830509840236538E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,   3.8830509840236538E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,  -3.8830509840236538E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,   3.8830509840236538E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,  -3.8830509840236538E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   7.8953950981781484E-01,  -3.8830509840236538E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,   3.8830509840236538E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -7.8953950981781484E-01,  -3.8830509840236538E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,   7.8953950981781484E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,   7.8953950981781484E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,  -7.8953950981781484E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,   7.8953950981781484E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,  -7.8953950981781484E-01,   3.8830509840236538E-01,   3.9264992694019339E-03],
            [   4.7523311436743770E-01,  -7.8953950981781484E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,   7.8953950981781484E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [  -4.7523311436743770E-01,  -7.8953950981781484E-01,  -3.8830509840236538E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,   7.8953950981781484E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,   7.8953950981781484E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,  -7.8953950981781484E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,   7.8953950981781484E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,  -7.8953950981781484E-01,   4.7523311436743770E-01,   3.9264992694019339E-03],
            [   3.8830509840236538E-01,  -7.8953950981781484E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,   7.8953950981781484E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [  -3.8830509840236538E-01,  -7.8953950981781484E-01,  -4.7523311436743770E-01,   3.9264992694019339E-03],
            [   5.1004573183740176E-01,   4.2356134239086490E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,   4.2356134239086490E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,  -4.2356134239086490E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,   4.2356134239086490E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,  -4.2356134239086490E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,  -4.2356134239086490E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,   4.2356134239086490E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,  -4.2356134239086490E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,   5.1004573183740176E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,   5.1004573183740176E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,  -5.1004573183740176E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,   5.1004573183740176E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,  -5.1004573183740176E-01,   7.4863151193794786E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,  -5.1004573183740176E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,   5.1004573183740176E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,  -5.1004573183740176E-01,  -7.4863151193794786E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,   5.1004573183740176E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,   5.1004573183740176E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,  -5.1004573183740176E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,   5.1004573183740176E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,  -5.1004573183740176E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,  -5.1004573183740176E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,   5.1004573183740176E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,  -5.1004573183740176E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,   4.2356134239086490E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,   4.2356134239086490E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,  -4.2356134239086490E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,   4.2356134239086490E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,  -4.2356134239086490E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   7.4863151193794786E-01,  -4.2356134239086490E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,   4.2356134239086490E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -7.4863151193794786E-01,  -4.2356134239086490E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,   7.4863151193794786E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,   7.4863151193794786E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,  -7.4863151193794786E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,   7.4863151193794786E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,  -7.4863151193794786E-01,   4.2356134239086490E-01,   3.9585126707725295E-03],
            [   5.1004573183740176E-01,  -7.4863151193794786E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,   7.4863151193794786E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [  -5.1004573183740176E-01,  -7.4863151193794786E-01,  -4.2356134239086490E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,   7.4863151193794786E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,   7.4863151193794786E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,  -7.4863151193794786E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,   7.4863151193794786E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,  -7.4863151193794786E-01,   5.1004573183740176E-01,   3.9585126707725295E-03],
            [   4.2356134239086490E-01,  -7.4863151193794786E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,   7.4863151193794786E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [  -4.2356134239086490E-01,  -7.4863151193794786E-01,  -5.1004573183740176E-01,   3.9585126707725295E-03],
            [   5.4322383889548675E-01,   4.5744847171962200E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,   4.5744847171962200E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,  -4.5744847171962200E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,   4.5744847171962200E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,  -4.5744847171962200E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,  -4.5744847171962200E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,   4.5744847171962200E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,  -4.5744847171962200E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,   5.4322383889548675E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,   5.4322383889548675E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,  -5.4322383889548675E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,   5.4322383889548675E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,  -5.4322383889548675E-01,   7.0402326422997730E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,  -5.4322383889548675E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,   5.4322383889548675E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,  -5.4322383889548675E-01,  -7.0402326422997730E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,   5.4322383889548675E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,   5.4322383889548675E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,  -5.4322383889548675E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,   5.4322383889548675E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,  -5.4322383889548675E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,  -5.4322383889548675E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,   5.4322383889548675E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,  -5.4322383889548675E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,   4.5744847171962200E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,   4.5744847171962200E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,  -4.5744847171962200E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,   4.5744847171962200E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,  -4.5744847171962200E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   7.0402326422997730E-01,  -4.5744847171962200E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,   4.5744847171962200E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -7.0402326422997730E-01,  -4.5744847171962200E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,   7.0402326422997730E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,   7.0402326422997730E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,  -7.0402326422997730E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,   7.0402326422997730E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,  -7.0402326422997730E-01,   4.5744847171962200E-01,   3.9784606586430581E-03],
            [   5.4322383889548675E-01,  -7.0402326422997730E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,   7.0402326422997730E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [  -5.4322383889548675E-01,  -7.0402326422997730E-01,  -4.5744847171962200E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,   7.0402326422997730E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,   7.0402326422997730E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,  -7.0402326422997730E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,   7.0402326422997730E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,  -7.0402326422997730E-01,   5.4322383889548675E-01,   3.9784606586430581E-03],
            [   4.5744847171962200E-01,  -7.0402326422997730E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,   7.0402326422997730E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [  -4.5744847171962200E-01,  -7.0402326422997730E-01,  -5.4322383889548675E-01,   3.9784606586430581E-03],
            [   5.7457586850724418E-01,   4.8973116392555238E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,   4.8973116392555238E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,  -4.8973116392555238E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,   4.8973116392555238E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,  -4.8973116392555238E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,  -4.8973116392555238E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,   4.8973116392555238E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,  -4.8973116392555238E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,   5.7457586850724418E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,   5.7457586850724418E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,  -5.7457586850724418E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,   5.7457586850724418E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,  -5.7457586850724418E-01,   6.5576364523299846E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,  -5.7457586850724418E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,   5.7457586850724418E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,  -5.7457586850724418E-01,  -6.5576364523299846E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,   5.7457586850724418E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,   5.7457586850724418E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,  -5.7457586850724418E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,   5.7457586850724418E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,  -5.7457586850724418E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,  -5.7457586850724418E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,   5.7457586850724418E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,  -5.7457586850724418E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,   4.8973116392555238E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,   4.8973116392555238E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,  -4.8973116392555238E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,   4.8973116392555238E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,  -4.8973116392555238E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   6.5576364523299846E-01,  -4.8973116392555238E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,   4.8973116392555238E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -6.5576364523299846E-01,  -4.8973116392555238E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,   6.5576364523299846E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,   6.5576364523299846E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,  -6.5576364523299846E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,   6.5576364523299846E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,  -6.5576364523299846E-01,   4.8973116392555238E-01,   3.9889687109806371E-03],
            [   5.7457586850724418E-01,  -6.5576364523299846E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,   6.5576364523299846E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [  -5.7457586850724418E-01,  -6.5576364523299846E-01,  -4.8973116392555238E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,   6.5576364523299846E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,   6.5576364523299846E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,  -6.5576364523299846E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,   6.5576364523299846E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,  -6.5576364523299846E-01,   5.7457586850724418E-01,   3.9889687109806371E-03],
            [   4.8973116392555238E-01,  -6.5576364523299846E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,   6.5576364523299846E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [  -4.8973116392555238E-01,  -6.5576364523299846E-01,  -5.7457586850724418E-01,   3.9889687109806371E-03],
            [   1.7239814375928089E-01,   3.0106305978811049E-02,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,   3.0106305978811049E-02,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,  -3.0106305978811049E-02,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,   3.0106305978811049E-02,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,  -3.0106305978811049E-02,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,  -3.0106305978811049E-02,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,   3.0106305978811049E-02,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,  -3.0106305978811049E-02,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,   1.7239814375928089E-01,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,   1.7239814375928089E-01,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,  -1.7239814375928089E-01,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,   1.7239814375928089E-01,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,  -1.7239814375928089E-01,   9.8456715889199986E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,  -1.7239814375928089E-01,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,   1.7239814375928089E-01,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,  -1.7239814375928089E-01,  -9.8456715889199986E-01,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,   1.7239814375928089E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,   1.7239814375928089E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,  -1.7239814375928089E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,   1.7239814375928089E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,  -1.7239814375928089E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,  -1.7239814375928089E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,   1.7239814375928089E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,  -1.7239814375928089E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,   3.0106305978811049E-02,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,   3.0106305978811049E-02,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,  -3.0106305978811049E-02,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,   3.0106305978811049E-02,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,  -3.0106305978811049E-02,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   9.8456715889199986E-01,  -3.0106305978811049E-02,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,   3.0106305978811049E-02,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -9.8456715889199986E-01,  -3.0106305978811049E-02,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,   9.8456715889199986E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,   9.8456715889199986E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,  -9.8456715889199986E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,   9.8456715889199986E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,  -9.8456715889199986E-01,   3.0106305978811049E-02,   2.7422194591249522E-03],
            [   1.7239814375928089E-01,  -9.8456715889199986E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,   9.8456715889199986E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [  -1.7239814375928089E-01,  -9.8456715889199986E-01,  -3.0106305978811049E-02,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,   9.8456715889199986E-01,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,   9.8456715889199986E-01,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,  -9.8456715889199986E-01,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,   9.8456715889199986E-01,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,  -9.8456715889199986E-01,   1.7239814375928089E-01,   2.7422194591249522E-03],
            [   3.0106305978811049E-02,  -9.8456715889199986E-01,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,   9.8456715889199986E-01,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [  -3.0106305978811049E-02,  -9.8456715889199986E-01,  -1.7239814375928089E-01,   2.7422194591249522E-03],
            [   2.1495532578445969E-01,   6.3260315542046947E-02,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,   6.3260315542046947E-02,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,  -6.3260315542046947E-02,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,   6.3260315542046947E-02,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,  -6.3260315542046947E-02,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,  -6.3260315542046947E-02,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,   6.3260315542046947E-02,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,  -6.3260315542046947E-02,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,   2.1495532578445969E-01,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,   2.1495532578445969E-01,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,  -2.1495532578445969E-01,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,   2.1495532578445969E-01,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,  -2.1495532578445969E-01,   9.7457290152887865E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,  -2.1495532578445969E-01,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,   2.1495532578445969E-01,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,  -2.1495532578445969E-01,  -9.7457290152887865E-01,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,   2.1495532578445969E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,   2.1495532578445969E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,  -2.1495532578445969E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,   2.1495532578445969E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,  -2.1495532578445969E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,  -2.1495532578445969E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,   2.1495532578445969E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,  -2.1495532578445969E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,   6.3260315542046947E-02,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,   6.3260315542046947E-02,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,  -6.3260315542046947E-02,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,   6.3260315542046947E-02,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,  -6.3260315542046947E-02,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   9.7457290152887865E-01,  -6.3260315542046947E-02,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,   6.3260315542046947E-02,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -9.7457290152887865E-01,  -6.3260315542046947E-02,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,   9.7457290152887865E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,   9.7457290152887865E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,  -9.7457290152887865E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,   9.7457290152887865E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,  -9.7457290152887865E-01,   6.3260315542046947E-02,   3.0155870591287294E-03],
            [   2.1495532578445969E-01,  -9.7457290152887865E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,   9.7457290152887865E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [  -2.1495532578445969E-01,  -9.7457290152887865E-01,  -6.3260315542046947E-02,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,   9.7457290152887865E-01,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,   9.7457290152887865E-01,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,  -9.7457290152887865E-01,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,   9.7457290152887865E-01,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,  -9.7457290152887865E-01,   2.1495532578445969E-01,   3.0155870591287294E-03],
            [   6.3260315542046947E-02,  -9.7457290152887865E-01,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,   9.7457290152887865E-01,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [  -6.3260315542046947E-02,  -9.7457290152887865E-01,  -2.1495532578445969E-01,   3.0155870591287294E-03],
            [   2.5732560812474220E-01,   9.8485669802586315E-02,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,   9.8485669802586315E-02,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,  -9.8485669802586315E-02,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,   9.8485669802586315E-02,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,  -9.8485669802586315E-02,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,  -9.8485669802586315E-02,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,   9.8485669802586315E-02,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,  -9.8485669802586315E-02,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,   2.5732560812474220E-01,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,   2.5732560812474220E-01,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,  -2.5732560812474220E-01,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,   2.5732560812474220E-01,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,  -2.5732560812474220E-01,   9.6129293362989388E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,  -2.5732560812474220E-01,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,   2.5732560812474220E-01,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,  -2.5732560812474220E-01,  -9.6129293362989388E-01,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,   2.5732560812474220E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,   2.5732560812474220E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,  -2.5732560812474220E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,   2.5732560812474220E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,  -2.5732560812474220E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,  -2.5732560812474220E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,   2.5732560812474220E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,  -2.5732560812474220E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,   9.8485669802586315E-02,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,   9.8485669802586315E-02,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,  -9.8485669802586315E-02,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,   9.8485669802586315E-02,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,  -9.8485669802586315E-02,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.6129293362989388E-01,  -9.8485669802586315E-02,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,   9.8485669802586315E-02,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.6129293362989388E-01,  -9.8485669802586315E-02,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,   9.6129293362989388E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,   9.6129293362989388E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,  -9.6129293362989388E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,   9.6129293362989388E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,  -9.6129293362989388E-01,   9.8485669802586315E-02,   3.2418674323235934E-03],
            [   2.5732560812474220E-01,  -9.6129293362989388E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,   9.6129293362989388E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [  -2.5732560812474220E-01,  -9.6129293362989388E-01,  -9.8485669802586315E-02,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,   9.6129293362989388E-01,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,   9.6129293362989388E-01,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,  -9.6129293362989388E-01,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,   9.6129293362989388E-01,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,  -9.6129293362989388E-01,   2.5732560812474220E-01,   3.2418674323235934E-03],
            [   9.8485669802586315E-02,  -9.6129293362989388E-01,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,   9.6129293362989388E-01,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [  -9.8485669802586315E-02,  -9.6129293362989388E-01,  -2.5732560812474220E-01,   3.2418674323235934E-03],
            [   2.9931637512381060E-01,   1.3508359523842661E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,   1.3508359523842661E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,  -1.3508359523842661E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,   1.3508359523842661E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,  -1.3508359523842661E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,  -1.3508359523842661E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,   1.3508359523842661E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,  -1.3508359523842661E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,   2.9931637512381060E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,   2.9931637512381060E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,  -2.9931637512381060E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,   2.9931637512381060E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,  -2.9931637512381060E-01,   9.4454334462755241E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,  -2.9931637512381060E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,   2.9931637512381060E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,  -2.9931637512381060E-01,  -9.4454334462755241E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,   2.9931637512381060E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,   2.9931637512381060E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,  -2.9931637512381060E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,   2.9931637512381060E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,  -2.9931637512381060E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,  -2.9931637512381060E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,   2.9931637512381060E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,  -2.9931637512381060E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,   1.3508359523842661E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,   1.3508359523842661E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,  -1.3508359523842661E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,   1.3508359523842661E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,  -1.3508359523842661E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   9.4454334462755241E-01,  -1.3508359523842661E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,   1.3508359523842661E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -9.4454334462755241E-01,  -1.3508359523842661E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,   9.4454334462755241E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,   9.4454334462755241E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,  -9.4454334462755241E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,   9.4454334462755241E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,  -9.4454334462755241E-01,   1.3508359523842661E-01,   3.4269925892894343E-03],
            [   2.9931637512381060E-01,  -9.4454334462755241E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,   9.4454334462755241E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [  -2.9931637512381060E-01,  -9.4454334462755241E-01,  -1.3508359523842661E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,   9.4454334462755241E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,   9.4454334462755241E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,  -9.4454334462755241E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,   9.4454334462755241E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,  -9.4454334462755241E-01,   2.9931637512381060E-01,   3.4269925892894343E-03],
            [   1.3508359523842661E-01,  -9.4454334462755241E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,   9.4454334462755241E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [  -1.3508359523842661E-01,  -9.4454334462755241E-01,  -2.9931637512381060E-01,   3.4269925892894343E-03],
            [   3.4072380051480000E-01,   1.7251840554421810E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,   1.7251840554421810E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,  -1.7251840554421810E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,   1.7251840554421810E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,  -1.7251840554421810E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,  -1.7251840554421810E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,   1.7251840554421810E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,  -1.7251840554421810E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,   3.4072380051480000E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,   3.4072380051480000E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,  -3.4072380051480000E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,   3.4072380051480000E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,  -3.4072380051480000E-01,   9.2419948685942876E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,  -3.4072380051480000E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,   3.4072380051480000E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,  -3.4072380051480000E-01,  -9.2419948685942876E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,   3.4072380051480000E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,   3.4072380051480000E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,  -3.4072380051480000E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,   3.4072380051480000E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,  -3.4072380051480000E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,  -3.4072380051480000E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,   3.4072380051480000E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,  -3.4072380051480000E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,   1.7251840554421810E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,   1.7251840554421810E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,  -1.7251840554421810E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,   1.7251840554421810E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,  -1.7251840554421810E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   9.2419948685942876E-01,  -1.7251840554421810E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,   1.7251840554421810E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -9.2419948685942876E-01,  -1.7251840554421810E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,   9.2419948685942876E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,   9.2419948685942876E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,  -9.2419948685942876E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,   9.2419948685942876E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,  -9.2419948685942876E-01,   1.7251840554421810E-01,   3.5768008218731834E-03],
            [   3.4072380051480000E-01,  -9.2419948685942876E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,   9.2419948685942876E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [  -3.4072380051480000E-01,  -9.2419948685942876E-01,  -1.7251840554421810E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,   9.2419948685942876E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,   9.2419948685942876E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,  -9.2419948685942876E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,   9.2419948685942876E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,  -9.2419948685942876E-01,   3.4072380051480000E-01,   3.5768008218731834E-03],
            [   1.7251840554421810E-01,  -9.2419948685942876E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,   9.2419948685942876E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [  -1.7251840554421810E-01,  -9.2419948685942876E-01,  -3.4072380051480000E-01,   3.5768008218731834E-03],
            [   3.8134549784832639E-01,   2.1035592797307251E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,   2.1035592797307251E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,  -2.1035592797307251E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,   2.1035592797307251E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,  -2.1035592797307251E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,  -2.1035592797307251E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,   2.1035592797307251E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,  -2.1035592797307251E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,   3.8134549784832639E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,   3.8134549784832639E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,  -3.8134549784832639E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,   3.8134549784832639E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,  -3.8134549784832639E-01,   9.0018109002433477E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,  -3.8134549784832639E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,   3.8134549784832639E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,  -3.8134549784832639E-01,  -9.0018109002433477E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,   3.8134549784832639E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,   3.8134549784832639E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,  -3.8134549784832639E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,   3.8134549784832639E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,  -3.8134549784832639E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,  -3.8134549784832639E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,   3.8134549784832639E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,  -3.8134549784832639E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,   2.1035592797307251E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,   2.1035592797307251E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,  -2.1035592797307251E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,   2.1035592797307251E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,  -2.1035592797307251E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   9.0018109002433477E-01,  -2.1035592797307251E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,   2.1035592797307251E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -9.0018109002433477E-01,  -2.1035592797307251E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,   9.0018109002433477E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,   9.0018109002433477E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,  -9.0018109002433477E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,   9.0018109002433477E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,  -9.0018109002433477E-01,   2.1035592797307251E-01,   3.6963867347216857E-03],
            [   3.8134549784832639E-01,  -9.0018109002433477E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,   9.0018109002433477E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [  -3.8134549784832639E-01,  -9.0018109002433477E-01,  -2.1035592797307251E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,   9.0018109002433477E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,   9.0018109002433477E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,  -9.0018109002433477E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,   9.0018109002433477E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,  -9.0018109002433477E-01,   3.8134549784832639E-01,   3.6963867347216857E-03],
            [   2.1035592797307251E-01,  -9.0018109002433477E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,   9.0018109002433477E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [  -2.1035592797307251E-01,  -9.0018109002433477E-01,  -3.8134549784832639E-01,   3.6963867347216857E-03],
            [   4.2098481044233432E-01,   2.4822787745548600E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,   2.4822787745548600E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,  -2.4822787745548600E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,   2.4822787745548600E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,  -2.4822787745548600E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,  -2.4822787745548600E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,   2.4822787745548600E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,  -2.4822787745548600E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,   4.2098481044233432E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,   4.2098481044233432E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,  -4.2098481044233432E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,   4.2098481044233432E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,  -4.2098481044233432E-01,   8.7244180907999591E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,  -4.2098481044233432E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,   4.2098481044233432E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,  -4.2098481044233432E-01,  -8.7244180907999591E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,   4.2098481044233432E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,   4.2098481044233432E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,  -4.2098481044233432E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,   4.2098481044233432E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,  -4.2098481044233432E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,  -4.2098481044233432E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,   4.2098481044233432E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,  -4.2098481044233432E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,   2.4822787745548600E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,   2.4822787745548600E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,  -2.4822787745548600E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,   2.4822787745548600E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,  -2.4822787745548600E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   8.7244180907999591E-01,  -2.4822787745548600E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,   2.4822787745548600E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -8.7244180907999591E-01,  -2.4822787745548600E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,   8.7244180907999591E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,   8.7244180907999591E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,  -8.7244180907999591E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,   8.7244180907999591E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,  -8.7244180907999591E-01,   2.4822787745548600E-01,   3.7900795709432077E-03],
            [   4.2098481044233432E-01,  -8.7244180907999591E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,   8.7244180907999591E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [  -4.2098481044233432E-01,  -8.7244180907999591E-01,  -2.4822787745548600E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,   8.7244180907999591E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,   8.7244180907999591E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,  -8.7244180907999591E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,   8.7244180907999591E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,  -8.7244180907999591E-01,   4.2098481044233432E-01,   3.7900795709432077E-03],
            [   2.4822787745548600E-01,  -8.7244180907999591E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,   8.7244180907999591E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [  -2.4822787745548600E-01,  -8.7244180907999591E-01,  -4.2098481044233432E-01,   3.7900795709432077E-03],
            [   4.5945196999963001E-01,   2.8580995099828832E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,   2.8580995099828832E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,  -2.8580995099828832E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,   2.8580995099828832E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,  -2.8580995099828832E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,  -2.8580995099828832E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,   2.8580995099828832E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,  -2.8580995099828832E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,   4.5945196999963001E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,   4.5945196999963001E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,  -4.5945196999963001E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,   4.5945196999963001E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,  -4.5945196999963001E-01,   8.4096168710222174E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,  -4.5945196999963001E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,   4.5945196999963001E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,  -4.5945196999963001E-01,  -8.4096168710222174E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,   4.5945196999963001E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,   4.5945196999963001E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,  -4.5945196999963001E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,   4.5945196999963001E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,  -4.5945196999963001E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,  -4.5945196999963001E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,   4.5945196999963001E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,  -4.5945196999963001E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,   2.8580995099828832E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,   2.8580995099828832E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,  -2.8580995099828832E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,   2.8580995099828832E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,  -2.8580995099828832E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   8.4096168710222174E-01,  -2.8580995099828832E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,   2.8580995099828832E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -8.4096168710222174E-01,  -2.8580995099828832E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,   8.4096168710222174E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,   8.4096168710222174E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,  -8.4096168710222174E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,   8.4096168710222174E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,  -8.4096168710222174E-01,   2.8580995099828832E-01,   3.8615825138416725E-03],
            [   4.5945196999963001E-01,  -8.4096168710222174E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,   8.4096168710222174E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [  -4.5945196999963001E-01,  -8.4096168710222174E-01,  -2.8580995099828832E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,   8.4096168710222174E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,   8.4096168710222174E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,  -8.4096168710222174E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,   8.4096168710222174E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,  -8.4096168710222174E-01,   4.5945196999963001E-01,   3.8615825138416725E-03],
            [   2.8580995099828832E-01,  -8.4096168710222174E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,   8.4096168710222174E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [  -2.8580995099828832E-01,  -8.4096168710222174E-01,  -4.5945196999963001E-01,   3.8615825138416725E-03],
            [   4.9656401661859301E-01,   3.2280756599154281E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,   3.2280756599154281E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,  -3.2280756599154281E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,   3.2280756599154281E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,  -3.2280756599154281E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,  -3.2280756599154281E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,   3.2280756599154281E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,  -3.2280756599154281E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,   4.9656401661859301E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,   4.9656401661859301E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,  -4.9656401661859301E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,   4.9656401661859301E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,  -4.9656401661859301E-01,   8.0574155455594154E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,  -4.9656401661859301E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,   4.9656401661859301E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,  -4.9656401661859301E-01,  -8.0574155455594154E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,   4.9656401661859301E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,   4.9656401661859301E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,  -4.9656401661859301E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,   4.9656401661859301E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,  -4.9656401661859301E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,  -4.9656401661859301E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,   4.9656401661859301E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,  -4.9656401661859301E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,   3.2280756599154281E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,   3.2280756599154281E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,  -3.2280756599154281E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,   3.2280756599154281E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,  -3.2280756599154281E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   8.0574155455594154E-01,  -3.2280756599154281E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,   3.2280756599154281E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -8.0574155455594154E-01,  -3.2280756599154281E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,   8.0574155455594154E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,   8.0574155455594154E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,  -8.0574155455594154E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,   8.0574155455594154E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,  -8.0574155455594154E-01,   3.2280756599154281E-01,   3.9141330861310504E-03],
            [   4.9656401661859301E-01,  -8.0574155455594154E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,   8.0574155455594154E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [  -4.9656401661859301E-01,  -8.0574155455594154E-01,  -3.2280756599154281E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,   8.0574155455594154E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,   8.0574155455594154E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,  -8.0574155455594154E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,   8.0574155455594154E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,  -8.0574155455594154E-01,   4.9656401661859301E-01,   3.9141330861310504E-03],
            [   3.2280756599154281E-01,  -8.0574155455594154E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,   8.0574155455594154E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [  -3.2280756599154281E-01,  -8.0574155455594154E-01,  -4.9656401661859301E-01,   3.9141330861310504E-03],
            [   5.3214416555715616E-01,   3.5894599072041511E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,   3.5894599072041511E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,  -3.5894599072041511E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,   3.5894599072041511E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,  -3.5894599072041511E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,  -3.5894599072041511E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,   3.5894599072041511E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,  -3.5894599072041511E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,   5.3214416555715616E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,   5.3214416555715616E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,  -5.3214416555715616E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,   5.3214416555715616E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,  -5.3214416555715616E-01,   7.6679877595704171E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,  -5.3214416555715616E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,   5.3214416555715616E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,  -5.3214416555715616E-01,  -7.6679877595704171E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,   5.3214416555715616E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,   5.3214416555715616E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,  -5.3214416555715616E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,   5.3214416555715616E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,  -5.3214416555715616E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,  -5.3214416555715616E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,   5.3214416555715616E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,  -5.3214416555715616E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,   3.5894599072041511E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,   3.5894599072041511E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,  -3.5894599072041511E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,   3.5894599072041511E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,  -3.5894599072041511E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   7.6679877595704171E-01,  -3.5894599072041511E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,   3.5894599072041511E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -7.6679877595704171E-01,  -3.5894599072041511E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,   7.6679877595704171E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,   7.6679877595704171E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,  -7.6679877595704171E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,   7.6679877595704171E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,  -7.6679877595704171E-01,   3.5894599072041511E-01,   3.9506453429485923E-03],
            [   5.3214416555715616E-01,  -7.6679877595704171E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,   7.6679877595704171E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [  -5.3214416555715616E-01,  -7.6679877595704171E-01,  -3.5894599072041511E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,   7.6679877595704171E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,   7.6679877595704171E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,  -7.6679877595704171E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,   7.6679877595704171E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,  -7.6679877595704171E-01,   5.3214416555715616E-01,   3.9506453429485923E-03],
            [   3.5894599072041511E-01,  -7.6679877595704171E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,   7.6679877595704171E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [  -3.5894599072041511E-01,  -7.6679877595704171E-01,  -5.3214416555715616E-01,   3.9506453429485923E-03],
            [   5.6602084385821660E-01,   3.9396300888643099E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,   3.9396300888643099E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,  -3.9396300888643099E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,   3.9396300888643099E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,  -3.9396300888643099E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,  -3.9396300888643099E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,   3.9396300888643099E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,  -3.9396300888643099E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,   5.6602084385821660E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,   5.6602084385821660E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,  -5.6602084385821660E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,   5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,  -5.6602084385821660E-01,   7.2416403662925866E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,  -5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,   5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,  -5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,   5.6602084385821660E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,   5.6602084385821660E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,   5.6602084385821660E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,  -5.6602084385821660E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,   5.6602084385821660E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,  -5.6602084385821660E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,   3.9396300888643099E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,   3.9396300888643099E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,  -3.9396300888643099E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,   3.9396300888643099E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,  -3.9396300888643099E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   7.2416403662925866E-01,  -3.9396300888643099E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,   3.9396300888643099E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -7.2416403662925866E-01,  -3.9396300888643099E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,   7.2416403662925866E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,   7.2416403662925866E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,   7.2416403662925866E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,  -7.2416403662925866E-01,   3.9396300888643099E-01,   3.9738253845319213E-03],
            [   5.6602084385821660E-01,  -7.2416403662925866E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,   7.2416403662925866E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [  -5.6602084385821660E-01,  -7.2416403662925866E-01,  -3.9396300888643099E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,   7.2416403662925866E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,   7.2416403662925866E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,  -7.2416403662925866E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,   7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,  -7.2416403662925866E-01,   5.6602084385821660E-01,   3.9738253845319213E-03],
            [   3.9396300888643099E-01,  -7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,   7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [  -3.9396300888643099E-01,  -7.2416403662925866E-01,  -5.6602084385821660E-01,   3.9738253845319213E-03],
            [   5.9802643159643643E-01,   4.2760299229490889E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,   4.2760299229490889E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,  -4.2760299229490889E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,   4.2760299229490889E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,  -4.2760299229490889E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,  -4.2760299229490889E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,   4.2760299229490889E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,  -4.2760299229490889E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,   5.9802643159643643E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,   5.9802643159643643E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,  -5.9802643159643643E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,   5.9802643159643643E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,  -5.9802643159643643E-01,   6.7787909548272174E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,  -5.9802643159643643E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,   5.9802643159643643E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,  -5.9802643159643643E-01,  -6.7787909548272174E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,   5.9802643159643643E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,   5.9802643159643643E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,  -5.9802643159643643E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,   5.9802643159643643E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,  -5.9802643159643643E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,  -5.9802643159643643E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,   5.9802643159643643E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,  -5.9802643159643643E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,   4.2760299229490889E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,   4.2760299229490889E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,  -4.2760299229490889E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,   4.2760299229490889E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,  -4.2760299229490889E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   6.7787909548272174E-01,  -4.2760299229490889E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,   4.2760299229490889E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -6.7787909548272174E-01,  -4.2760299229490889E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,   6.7787909548272174E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,   6.7787909548272174E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,  -6.7787909548272174E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,   6.7787909548272174E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,  -6.7787909548272174E-01,   4.2760299229490889E-01,   3.9862596814579957E-03],
            [   5.9802643159643643E-01,  -6.7787909548272174E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,   6.7787909548272174E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [  -5.9802643159643643E-01,  -6.7787909548272174E-01,  -4.2760299229490889E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,   6.7787909548272174E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,   6.7787909548272174E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,  -6.7787909548272174E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,   6.7787909548272174E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,  -6.7787909548272174E-01,   5.9802643159643643E-01,   3.9862596814579957E-03],
            [   4.2760299229490889E-01,  -6.7787909548272174E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,   6.7787909548272174E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [  -4.2760299229490889E-01,  -6.7787909548272174E-01,  -5.9802643159643643E-01,   3.9862596814579957E-03],
            [   2.6442158523507331E-01,   3.3009394290725518E-02,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,   3.3009394290725518E-02,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,  -3.3009394290725518E-02,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,   3.3009394290725518E-02,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,  -3.3009394290725518E-02,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,  -3.3009394290725518E-02,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,   3.3009394290725518E-02,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,  -3.3009394290725518E-02,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,   2.6442158523507331E-01,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,   2.6442158523507331E-01,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,  -2.6442158523507331E-01,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,   2.6442158523507331E-01,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,  -2.6442158523507331E-01,   9.6384210592312802E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,  -2.6442158523507331E-01,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,   2.6442158523507331E-01,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,  -2.6442158523507331E-01,  -9.6384210592312802E-01,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,   2.6442158523507331E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,   2.6442158523507331E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,  -2.6442158523507331E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,   2.6442158523507331E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,  -2.6442158523507331E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,  -2.6442158523507331E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,   2.6442158523507331E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,  -2.6442158523507331E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,   3.3009394290725518E-02,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,   3.3009394290725518E-02,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,  -3.3009394290725518E-02,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,   3.3009394290725518E-02,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,  -3.3009394290725518E-02,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   9.6384210592312802E-01,  -3.3009394290725518E-02,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,   3.3009394290725518E-02,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -9.6384210592312802E-01,  -3.3009394290725518E-02,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,   9.6384210592312802E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,   9.6384210592312802E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,  -9.6384210592312802E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,   9.6384210592312802E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,  -9.6384210592312802E-01,   3.3009394290725518E-02,   3.2101741225749238E-03],
            [   2.6442158523507331E-01,  -9.6384210592312802E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,   9.6384210592312802E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [  -2.6442158523507331E-01,  -9.6384210592312802E-01,  -3.3009394290725518E-02,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,   9.6384210592312802E-01,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,   9.6384210592312802E-01,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,  -9.6384210592312802E-01,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,   9.6384210592312802E-01,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,  -9.6384210592312802E-01,   2.6442158523507331E-01,   3.2101741225749238E-03],
            [   3.3009394290725518E-02,  -9.6384210592312802E-01,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,   9.6384210592312802E-01,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [  -3.3009394290725518E-02,  -9.6384210592312802E-01,  -2.6442158523507331E-01,   3.2101741225749238E-03],
            [   3.0901137434430631E-01,   6.8038876500785009E-02,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,   6.8038876500785009E-02,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,  -6.8038876500785009E-02,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,   6.8038876500785009E-02,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,  -6.8038876500785009E-02,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,  -6.8038876500785009E-02,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,   6.8038876500785009E-02,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,  -6.8038876500785009E-02,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,   3.0901137434430631E-01,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,   3.0901137434430631E-01,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,  -3.0901137434430631E-01,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,   3.0901137434430631E-01,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,  -3.0901137434430631E-01,   9.4862146392033209E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,  -3.0901137434430631E-01,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,   3.0901137434430631E-01,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,  -3.0901137434430631E-01,  -9.4862146392033209E-01,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,   3.0901137434430631E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,   3.0901137434430631E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,  -3.0901137434430631E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,   3.0901137434430631E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,  -3.0901137434430631E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,  -3.0901137434430631E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,   3.0901137434430631E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,  -3.0901137434430631E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,   6.8038876500785009E-02,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,   6.8038876500785009E-02,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,  -6.8038876500785009E-02,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,   6.8038876500785009E-02,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,  -6.8038876500785009E-02,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   9.4862146392033209E-01,  -6.8038876500785009E-02,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,   6.8038876500785009E-02,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -9.4862146392033209E-01,  -6.8038876500785009E-02,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,   9.4862146392033209E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,   9.4862146392033209E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,  -9.4862146392033209E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,   9.4862146392033209E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,  -9.4862146392033209E-01,   6.8038876500785009E-02,   3.3950614623081171E-03],
            [   3.0901137434430631E-01,  -9.4862146392033209E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,   9.4862146392033209E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [  -3.0901137434430631E-01,  -9.4862146392033209E-01,  -6.8038876500785009E-02,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,   9.4862146392033209E-01,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,   9.4862146392033209E-01,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,  -9.4862146392033209E-01,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,   9.4862146392033209E-01,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,  -9.4862146392033209E-01,   3.0901137434430631E-01,   3.3950614623081171E-03],
            [   6.8038876500785009E-02,  -9.4862146392033209E-01,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,   9.4862146392033209E-01,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [  -6.8038876500785009E-02,  -9.4862146392033209E-01,  -3.0901137434430631E-01,   3.3950614623081171E-03],
            [   3.5258710791978082E-01,   1.0443261362067090E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,   1.0443261362067090E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,  -1.0443261362067090E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,   1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,  -1.0443261362067090E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,  -1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,   1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,  -1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,   3.5258710791978082E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,   3.5258710791978082E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,  -3.5258710791978082E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,   3.5258710791978082E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,  -3.5258710791978082E-01,   9.2993341726229006E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,  -3.5258710791978082E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,   3.5258710791978082E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,  -3.5258710791978082E-01,  -9.2993341726229006E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,   3.5258710791978082E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,   3.5258710791978082E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,  -3.5258710791978082E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,   3.5258710791978082E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,  -3.5258710791978082E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,  -3.5258710791978082E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,   3.5258710791978082E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,  -3.5258710791978082E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,   1.0443261362067090E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,   1.0443261362067090E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,   1.0443261362067090E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   9.2993341726229006E-01,  -1.0443261362067090E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,   1.0443261362067090E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -9.2993341726229006E-01,  -1.0443261362067090E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,   9.2993341726229006E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,   9.2993341726229006E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,  -9.2993341726229006E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,   9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,  -9.2993341726229006E-01,   1.0443261362067090E-01,   3.5483577934975630E-03],
            [   3.5258710791978082E-01,  -9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,   9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [  -3.5258710791978082E-01,  -9.2993341726229006E-01,  -1.0443261362067090E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,   9.2993341726229006E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,   9.2993341726229006E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,   9.2993341726229006E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,  -9.2993341726229006E-01,   3.5258710791978082E-01,   3.5483577934975630E-03],
            [   1.0443261362067090E-01,  -9.2993341726229006E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,   9.2993341726229006E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [  -1.0443261362067090E-01,  -9.2993341726229006E-01,  -3.5258710791978082E-01,   3.5483577934975630E-03],
            [   3.9504180053540289E-01,   1.4167515975176789E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,   1.4167515975176789E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,  -1.4167515975176789E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,   1.4167515975176789E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,  -1.4167515975176789E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,  -1.4167515975176789E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,   1.4167515975176789E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,  -1.4167515975176789E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,   3.9504180053540289E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,   3.9504180053540289E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,  -3.9504180053540289E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,   3.9504180053540289E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,  -3.9504180053540289E-01,   9.0767291737666056E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,  -3.9504180053540289E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,   3.9504180053540289E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,  -3.9504180053540289E-01,  -9.0767291737666056E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,   3.9504180053540289E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,   3.9504180053540289E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,  -3.9504180053540289E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,   3.9504180053540289E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,  -3.9504180053540289E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,  -3.9504180053540289E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,   3.9504180053540289E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,  -3.9504180053540289E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,   1.4167515975176789E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,   1.4167515975176789E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,  -1.4167515975176789E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,   1.4167515975176789E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,  -1.4167515975176789E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   9.0767291737666056E-01,  -1.4167515975176789E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,   1.4167515975176789E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -9.0767291737666056E-01,  -1.4167515975176789E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,   9.0767291737666056E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,   9.0767291737666056E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,  -9.0767291737666056E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,   9.0767291737666056E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,  -9.0767291737666056E-01,   1.4167515975176789E-01,   3.6730225356891625E-03],
            [   3.9504180053540289E-01,  -9.0767291737666056E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,   9.0767291737666056E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [  -3.9504180053540289E-01,  -9.0767291737666056E-01,  -1.4167515975176789E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,   9.0767291737666056E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,   9.0767291737666056E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,  -9.0767291737666056E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,   9.0767291737666056E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,  -9.0767291737666056E-01,   3.9504180053540289E-01,   3.6730225356891625E-03],
            [   1.4167515975176789E-01,  -9.0767291737666056E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,   9.0767291737666056E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [  -1.4167515975176789E-01,  -9.0767291737666056E-01,  -3.9504180053540289E-01,   3.6730225356891625E-03],
            [   4.3624756634301631E-01,   1.7934086105048211E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,   1.7934086105048211E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,  -1.7934086105048211E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,   1.7934086105048211E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,  -1.7934086105048211E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,  -1.7934086105048211E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,   1.7934086105048211E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,  -1.7934086105048211E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,   4.3624756634301631E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,   4.3624756634301631E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,  -4.3624756634301631E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,   4.3624756634301631E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,  -4.3624756634301631E-01,   8.8177373311834784E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,  -4.3624756634301631E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,   4.3624756634301631E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,  -4.3624756634301631E-01,  -8.8177373311834784E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,   4.3624756634301631E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,   4.3624756634301631E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,  -4.3624756634301631E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,   4.3624756634301631E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,  -4.3624756634301631E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,  -4.3624756634301631E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,   4.3624756634301631E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,  -4.3624756634301631E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,   1.7934086105048211E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,   1.7934086105048211E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,  -1.7934086105048211E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,   1.7934086105048211E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,  -1.7934086105048211E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   8.8177373311834784E-01,  -1.7934086105048211E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,   1.7934086105048211E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -8.8177373311834784E-01,  -1.7934086105048211E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,   8.8177373311834784E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,   8.8177373311834784E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,  -8.8177373311834784E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,   8.8177373311834784E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,  -8.8177373311834784E-01,   1.7934086105048211E-01,   3.7722096516087291E-03],
            [   4.3624756634301631E-01,  -8.8177373311834784E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,   8.8177373311834784E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [  -4.3624756634301631E-01,  -8.8177373311834784E-01,  -1.7934086105048211E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,   8.8177373311834784E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,   8.8177373311834784E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,  -8.8177373311834784E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,   8.8177373311834784E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,  -8.8177373311834784E-01,   4.3624756634301631E-01,   3.7722096516087291E-03],
            [   1.7934086105048211E-01,  -8.8177373311834784E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,   8.8177373311834784E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [  -1.7934086105048211E-01,  -8.8177373311834784E-01,  -4.3624756634301631E-01,   3.7722096516087291E-03],
            [   4.7606618121458538E-01,   2.1706307501757219E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,   2.1706307501757219E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,  -2.1706307501757219E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,   2.1706307501757219E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,  -2.1706307501757219E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,  -2.1706307501757219E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,   2.1706307501757219E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,  -2.1706307501757219E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,   4.7606618121458538E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,   4.7606618121458538E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,  -4.7606618121458538E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,   4.7606618121458538E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,  -4.7606618121458538E-01,   8.5219986656164015E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,  -4.7606618121458538E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,   4.7606618121458538E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,  -4.7606618121458538E-01,  -8.5219986656164015E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,   4.7606618121458538E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,   4.7606618121458538E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,  -4.7606618121458538E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,   4.7606618121458538E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,  -4.7606618121458538E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,  -4.7606618121458538E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,   4.7606618121458538E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,  -4.7606618121458538E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,   2.1706307501757219E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,   2.1706307501757219E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,  -2.1706307501757219E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,   2.1706307501757219E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,  -2.1706307501757219E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   8.5219986656164015E-01,  -2.1706307501757219E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,   2.1706307501757219E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -8.5219986656164015E-01,  -2.1706307501757219E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,   8.5219986656164015E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,   8.5219986656164015E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,  -8.5219986656164015E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,   8.5219986656164015E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,  -8.5219986656164015E-01,   2.1706307501757219E-01,   3.8489421755181722E-03],
            [   4.7606618121458538E-01,  -8.5219986656164015E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,   8.5219986656164015E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [  -4.7606618121458538E-01,  -8.5219986656164015E-01,  -2.1706307501757219E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,   8.5219986656164015E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,   8.5219986656164015E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,  -8.5219986656164015E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,   8.5219986656164015E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,  -8.5219986656164015E-01,   4.7606618121458538E-01,   3.8489421755181722E-03],
            [   2.1706307501757219E-01,  -8.5219986656164015E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,   8.5219986656164015E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [  -2.1706307501757219E-01,  -8.5219986656164015E-01,  -4.7606618121458538E-01,   3.8489421755181722E-03],
            [   5.1435510425121034E-01,   2.5451451578158069E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,   2.5451451578158069E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,  -2.5451451578158069E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,   2.5451451578158069E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,  -2.5451451578158069E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,  -2.5451451578158069E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,   2.5451451578158069E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,  -2.5451451578158069E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,   5.1435510425121034E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,   5.1435510425121034E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,  -5.1435510425121034E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,   5.1435510425121034E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,  -5.1435510425121034E-01,   8.1893906243822201E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,  -5.1435510425121034E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,   5.1435510425121034E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,  -5.1435510425121034E-01,  -8.1893906243822201E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,   5.1435510425121034E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,   5.1435510425121034E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,  -5.1435510425121034E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,   5.1435510425121034E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,  -5.1435510425121034E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,  -5.1435510425121034E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,   5.1435510425121034E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,  -5.1435510425121034E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,   2.5451451578158069E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,   2.5451451578158069E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,  -2.5451451578158069E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,   2.5451451578158069E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,  -2.5451451578158069E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   8.1893906243822201E-01,  -2.5451451578158069E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,   2.5451451578158069E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -8.1893906243822201E-01,  -2.5451451578158069E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,   8.1893906243822201E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,   8.1893906243822201E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,  -8.1893906243822201E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,   8.1893906243822201E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,  -8.1893906243822201E-01,   2.5451451578158069E-01,   3.9060405148334115E-03],
            [   5.1435510425121034E-01,  -8.1893906243822201E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,   8.1893906243822201E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [  -5.1435510425121034E-01,  -8.1893906243822201E-01,  -2.5451451578158069E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,   8.1893906243822201E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,   8.1893906243822201E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,  -8.1893906243822201E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,   8.1893906243822201E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,  -8.1893906243822201E-01,   5.1435510425121034E-01,   3.9060405148334115E-03],
            [   2.5451451578158069E-01,  -8.1893906243822201E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,   8.1893906243822201E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [  -2.5451451578158069E-01,  -8.1893906243822201E-01,  -5.1435510425121034E-01,   3.9060405148334115E-03],
            [   5.5097090269355975E-01,   2.9139401017066008E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,   2.9139401017066008E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,  -2.9139401017066008E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,   2.9139401017066008E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,  -2.9139401017066008E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,  -2.9139401017066008E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,   2.9139401017066008E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,  -2.9139401017066008E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,   5.5097090269355975E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,   5.5097090269355975E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,  -5.5097090269355975E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,   5.5097090269355975E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,  -5.5097090269355975E-01,   7.8199782302875065E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,  -5.5097090269355975E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,   5.5097090269355975E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,  -5.5097090269355975E-01,  -7.8199782302875065E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,   5.5097090269355975E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,   5.5097090269355975E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,  -5.5097090269355975E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,   5.5097090269355975E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,  -5.5097090269355975E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,  -5.5097090269355975E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,   5.5097090269355975E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,  -5.5097090269355975E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,   2.9139401017066008E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,   2.9139401017066008E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,  -2.9139401017066008E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,   2.9139401017066008E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,  -2.9139401017066008E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   7.8199782302875065E-01,  -2.9139401017066008E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,   2.9139401017066008E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -7.8199782302875065E-01,  -2.9139401017066008E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,   7.8199782302875065E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,   7.8199782302875065E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,  -7.8199782302875065E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,   7.8199782302875065E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,  -7.8199782302875065E-01,   2.9139401017066008E-01,   3.9461459194366118E-03],
            [   5.5097090269355975E-01,  -7.8199782302875065E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,   7.8199782302875065E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [  -5.5097090269355975E-01,  -7.8199782302875065E-01,  -2.9139401017066008E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,   7.8199782302875065E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,   7.8199782302875065E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,  -7.8199782302875065E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,   7.8199782302875065E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,  -7.8199782302875065E-01,   5.5097090269355975E-01,   3.9461459194366118E-03],
            [   2.9139401017066008E-01,  -7.8199782302875065E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,   7.8199782302875065E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [  -2.9139401017066008E-01,  -7.8199782302875065E-01,  -5.5097090269355975E-01,   3.9461459194366118E-03],
            [   5.8577110303294277E-01,   3.2741699109107048E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,   3.2741699109107048E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,  -3.2741699109107048E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,   3.2741699109107048E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,  -3.2741699109107048E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,  -3.2741699109107048E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,   3.2741699109107048E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,  -3.2741699109107048E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,   5.8577110303294277E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,   5.8577110303294277E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,  -5.8577110303294277E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,   5.8577110303294277E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,  -5.8577110303294277E-01,   7.4139755111305794E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,  -5.8577110303294277E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,   5.8577110303294277E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,  -5.8577110303294277E-01,  -7.4139755111305794E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,   5.8577110303294277E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,   5.8577110303294277E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,  -5.8577110303294277E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,   5.8577110303294277E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,  -5.8577110303294277E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,  -5.8577110303294277E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,   5.8577110303294277E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,  -5.8577110303294277E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,   3.2741699109107048E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,   3.2741699109107048E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,  -3.2741699109107048E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,   3.2741699109107048E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,  -3.2741699109107048E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   7.4139755111305794E-01,  -3.2741699109107048E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,   3.2741699109107048E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -7.4139755111305794E-01,  -3.2741699109107048E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,   7.4139755111305794E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,   7.4139755111305794E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,  -7.4139755111305794E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,   7.4139755111305794E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,  -7.4139755111305794E-01,   3.2741699109107048E-01,   3.9717748875097046E-03],
            [   5.8577110303294277E-01,  -7.4139755111305794E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,   7.4139755111305794E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [  -5.8577110303294277E-01,  -7.4139755111305794E-01,  -3.2741699109107048E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,   7.4139755111305794E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,   7.4139755111305794E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,  -7.4139755111305794E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,   7.4139755111305794E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,  -7.4139755111305794E-01,   5.8577110303294277E-01,   3.9717748875097046E-03],
            [   3.2741699109107048E-01,  -7.4139755111305794E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,   7.4139755111305794E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [  -3.2741699109107048E-01,  -7.4139755111305794E-01,  -5.8577110303294277E-01,   3.9717748875097046E-03],
            [   6.1861499174043921E-01,   3.6230813293172648E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,   3.6230813293172648E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,  -3.6230813293172648E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,   3.6230813293172648E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,  -3.6230813293172648E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,  -3.6230813293172648E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,   3.6230813293172648E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,  -3.6230813293172648E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,   6.1861499174043921E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,   6.1861499174043921E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,  -6.1861499174043921E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,   6.1861499174043921E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,  -6.1861499174043921E-01,   6.9717164945621724E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,  -6.1861499174043921E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,   6.1861499174043921E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,  -6.1861499174043921E-01,  -6.9717164945621724E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,   6.1861499174043921E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,   6.1861499174043921E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,  -6.1861499174043921E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,   6.1861499174043921E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,  -6.1861499174043921E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,  -6.1861499174043921E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,   6.1861499174043921E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,  -6.1861499174043921E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,   3.6230813293172648E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,   3.6230813293172648E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,  -3.6230813293172648E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,   3.6230813293172648E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,  -3.6230813293172648E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   6.9717164945621724E-01,  -3.6230813293172648E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,   3.6230813293172648E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -6.9717164945621724E-01,  -3.6230813293172648E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,   6.9717164945621724E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,   6.9717164945621724E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,  -6.9717164945621724E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,   6.9717164945621724E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,  -6.9717164945621724E-01,   3.6230813293172648E-01,   3.9853777967487781E-03],
            [   6.1861499174043921E-01,  -6.9717164945621724E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,   6.9717164945621724E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [  -6.1861499174043921E-01,  -6.9717164945621724E-01,  -3.6230813293172648E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,   6.9717164945621724E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,   6.9717164945621724E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,  -6.9717164945621724E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,   6.9717164945621724E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,  -6.9717164945621724E-01,   6.1861499174043921E-01,   3.9853777967487781E-03],
            [   3.6230813293172648E-01,  -6.9717164945621724E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,   6.9717164945621724E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [  -3.6230813293172648E-01,  -6.9717164945621724E-01,  -6.1861499174043921E-01,   3.9853777967487781E-03],
            [   3.5868945695570642E-01,   3.4973543864500398E-02,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,   3.4973543864500398E-02,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,  -3.4973543864500398E-02,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,   3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,  -3.4973543864500398E-02,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,  -3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,   3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,  -3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,   3.5868945695570642E-01,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,   3.5868945695570642E-01,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,  -3.5868945695570642E-01,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,   3.5868945695570642E-01,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,  -3.5868945695570642E-01,   9.3280154625642542E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,  -3.5868945695570642E-01,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,   3.5868945695570642E-01,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,  -3.5868945695570642E-01,  -9.3280154625642542E-01,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,   3.5868945695570642E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,   3.5868945695570642E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,  -3.5868945695570642E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,   3.5868945695570642E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,  -3.5868945695570642E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,  -3.5868945695570642E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,   3.5868945695570642E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,  -3.5868945695570642E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,   3.4973543864500398E-02,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,   3.4973543864500398E-02,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,   3.4973543864500398E-02,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   9.3280154625642542E-01,  -3.4973543864500398E-02,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,   3.4973543864500398E-02,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -9.3280154625642542E-01,  -3.4973543864500398E-02,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,   9.3280154625642542E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,   9.3280154625642542E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,  -9.3280154625642542E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,   9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,  -9.3280154625642542E-01,   3.4973543864500398E-02,   3.5341515147386104E-03],
            [   3.5868945695570642E-01,  -9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,   9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [  -3.5868945695570642E-01,  -9.3280154625642542E-01,  -3.4973543864500398E-02,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,   9.3280154625642542E-01,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,   9.3280154625642542E-01,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,   9.3280154625642542E-01,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,  -9.3280154625642542E-01,   3.5868945695570642E-01,   3.5341515147386104E-03],
            [   3.4973543864500398E-02,  -9.3280154625642542E-01,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,   9.3280154625642542E-01,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [  -3.4973543864500398E-02,  -9.3280154625642542E-01,  -3.5868945695570642E-01,   3.5341515147386104E-03],
            [   4.0352666100194412E-01,   7.1297367397570949E-02,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,   7.1297367397570949E-02,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,  -7.1297367397570949E-02,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,   7.1297367397570949E-02,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,  -7.1297367397570949E-02,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,  -7.1297367397570949E-02,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,   7.1297367397570949E-02,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,  -7.1297367397570949E-02,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,   4.0352666100194412E-01,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,   4.0352666100194412E-01,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,  -4.0352666100194412E-01,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,   4.0352666100194412E-01,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,  -4.0352666100194412E-01,   9.1218579207461781E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,  -4.0352666100194412E-01,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,   4.0352666100194412E-01,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,  -4.0352666100194412E-01,  -9.1218579207461781E-01,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,   4.0352666100194412E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,   4.0352666100194412E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,  -4.0352666100194412E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,   4.0352666100194412E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,  -4.0352666100194412E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,  -4.0352666100194412E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,   4.0352666100194412E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,  -4.0352666100194412E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,   7.1297367397570949E-02,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,   7.1297367397570949E-02,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,  -7.1297367397570949E-02,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,   7.1297367397570949E-02,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,  -7.1297367397570949E-02,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   9.1218579207461781E-01,  -7.1297367397570949E-02,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,   7.1297367397570949E-02,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -9.1218579207461781E-01,  -7.1297367397570949E-02,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,   9.1218579207461781E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,   9.1218579207461781E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,  -9.1218579207461781E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,   9.1218579207461781E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,  -9.1218579207461781E-01,   7.1297367397570949E-02,   3.6594999108593065E-03],
            [   4.0352666100194412E-01,  -9.1218579207461781E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,   9.1218579207461781E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [  -4.0352666100194412E-01,  -9.1218579207461781E-01,  -7.1297367397570949E-02,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,   9.1218579207461781E-01,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,   9.1218579207461781E-01,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,  -9.1218579207461781E-01,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,   9.1218579207461781E-01,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,  -9.1218579207461781E-01,   4.0352666100194412E-01,   3.6594999108593065E-03],
            [   7.1297367397570949E-02,  -9.1218579207461781E-01,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,   9.1218579207461781E-01,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [  -7.1297367397570949E-02,  -9.1218579207461781E-01,  -4.0352666100194412E-01,   3.6594999108593065E-03],
            [   4.4677753123325098E-01,   1.0847586201931650E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,   1.0847586201931650E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,  -1.0847586201931650E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,   1.0847586201931650E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,  -1.0847586201931650E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,  -1.0847586201931650E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,   1.0847586201931650E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,  -1.0847586201931650E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,   4.4677753123325098E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,   4.4677753123325098E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,  -4.4677753123325098E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,   4.4677753123325098E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,  -4.4677753123325098E-01,   8.8804438230546101E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,  -4.4677753123325098E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,   4.4677753123325098E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,  -4.4677753123325098E-01,  -8.8804438230546101E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,   4.4677753123325098E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,   4.4677753123325098E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,  -4.4677753123325098E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,   4.4677753123325098E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,  -4.4677753123325098E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,  -4.4677753123325098E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,   4.4677753123325098E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,  -4.4677753123325098E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,   1.0847586201931650E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,   1.0847586201931650E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,  -1.0847586201931650E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,   1.0847586201931650E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,  -1.0847586201931650E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   8.8804438230546101E-01,  -1.0847586201931650E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,   1.0847586201931650E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -8.8804438230546101E-01,  -1.0847586201931650E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,   8.8804438230546101E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,   8.8804438230546101E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,  -8.8804438230546101E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,   8.8804438230546101E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,  -8.8804438230546101E-01,   1.0847586201931650E-01,   3.7614178967396847E-03],
            [   4.4677753123325098E-01,  -8.8804438230546101E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,   8.8804438230546101E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [  -4.4677753123325098E-01,  -8.8804438230546101E-01,  -1.0847586201931650E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,   8.8804438230546101E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,   8.8804438230546101E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,  -8.8804438230546101E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,   8.8804438230546101E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,  -8.8804438230546101E-01,   4.4677753123325098E-01,   3.7614178967396847E-03],
            [   1.0847586201931650E-01,  -8.8804438230546101E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,   8.8804438230546101E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [  -1.0847586201931650E-01,  -8.8804438230546101E-01,  -4.4677753123325098E-01,   3.7614178967396847E-03],
            [   4.8836383466085431E-01,   1.4609156892417721E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,   1.4609156892417721E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,  -1.4609156892417721E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,   1.4609156892417721E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,  -1.4609156892417721E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,  -1.4609156892417721E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,   1.4609156892417721E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,  -1.4609156892417721E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,   4.8836383466085431E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,   4.8836383466085431E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,  -4.8836383466085431E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,   4.8836383466085431E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,  -4.8836383466085431E-01,   8.6032436818017544E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,  -4.8836383466085431E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,   4.8836383466085431E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,  -4.8836383466085431E-01,  -8.6032436818017544E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,   4.8836383466085431E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,   4.8836383466085431E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,  -4.8836383466085431E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,   4.8836383466085431E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,  -4.8836383466085431E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,  -4.8836383466085431E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,   4.8836383466085431E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,  -4.8836383466085431E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,   1.4609156892417721E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,   1.4609156892417721E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,  -1.4609156892417721E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,   1.4609156892417721E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,  -1.4609156892417721E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   8.6032436818017544E-01,  -1.4609156892417721E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,   1.4609156892417721E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -8.6032436818017544E-01,  -1.4609156892417721E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,   8.6032436818017544E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,   8.6032436818017544E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,  -8.6032436818017544E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,   8.6032436818017544E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,  -8.6032436818017544E-01,   1.4609156892417721E-01,   3.8416673457872625E-03],
            [   4.8836383466085431E-01,  -8.6032436818017544E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,   8.6032436818017544E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [  -4.8836383466085431E-01,  -8.6032436818017544E-01,  -1.4609156892417721E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,   8.6032436818017544E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,   8.6032436818017544E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,  -8.6032436818017544E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,   8.6032436818017544E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,  -8.6032436818017544E-01,   4.8836383466085431E-01,   3.8416673457872625E-03],
            [   1.4609156892417721E-01,  -8.6032436818017544E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,   8.6032436818017544E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [  -1.4609156892417721E-01,  -8.6032436818017544E-01,  -4.8836383466085431E-01,   3.8416673457872625E-03],
            [   5.2819083484346008E-01,   1.8377908323699799E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,   1.8377908323699799E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,  -1.8377908323699799E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,   1.8377908323699799E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,  -1.8377908323699799E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,  -1.8377908323699799E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,   1.8377908323699799E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,  -1.8377908323699799E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,   5.2819083484346008E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,   5.2819083484346008E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,  -5.2819083484346008E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,   5.2819083484346008E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,  -5.2819083484346008E-01,   8.2899921022395273E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,  -5.2819083484346008E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,   5.2819083484346008E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,  -5.2819083484346008E-01,  -8.2899921022395273E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,   5.2819083484346008E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,   5.2819083484346008E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,  -5.2819083484346008E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,   5.2819083484346008E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,  -5.2819083484346008E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,  -5.2819083484346008E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,   5.2819083484346008E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,  -5.2819083484346008E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,   1.8377908323699799E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,   1.8377908323699799E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,  -1.8377908323699799E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,   1.8377908323699799E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,  -1.8377908323699799E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   8.2899921022395273E-01,  -1.8377908323699799E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,   1.8377908323699799E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -8.2899921022395273E-01,  -1.8377908323699799E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,   8.2899921022395273E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,   8.2899921022395273E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,  -8.2899921022395273E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,   8.2899921022395273E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,  -8.2899921022395273E-01,   1.8377908323699799E-01,   3.9022593529607617E-03],
            [   5.2819083484346008E-01,  -8.2899921022395273E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,   8.2899921022395273E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [  -5.2819083484346008E-01,  -8.2899921022395273E-01,  -1.8377908323699799E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,   8.2899921022395273E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,   8.2899921022395273E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,  -8.2899921022395273E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,   8.2899921022395273E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,  -8.2899921022395273E-01,   5.2819083484346008E-01,   3.9022593529607617E-03],
            [   1.8377908323699799E-01,  -8.2899921022395273E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,   8.2899921022395273E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [  -1.8377908323699799E-01,  -8.2899921022395273E-01,  -5.2819083484346008E-01,   3.9022593529607617E-03],
            [   5.6615426871493113E-01,   2.2120753908740209E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,   2.2120753908740209E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,  -2.2120753908740209E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,   2.2120753908740209E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,  -2.2120753908740209E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,  -2.2120753908740209E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,   2.2120753908740209E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,  -2.2120753908740209E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,   5.6615426871493113E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,   5.6615426871493113E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,  -5.6615426871493113E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,   5.6615426871493113E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,  -5.6615426871493113E-01,   7.9406332786923051E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,  -5.6615426871493113E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,   5.6615426871493113E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,  -5.6615426871493113E-01,  -7.9406332786923051E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,   5.6615426871493113E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,   5.6615426871493113E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,  -5.6615426871493113E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,   5.6615426871493113E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,  -5.6615426871493113E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,  -5.6615426871493113E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,   5.6615426871493113E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,  -5.6615426871493113E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,   2.2120753908740209E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,   2.2120753908740209E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,  -2.2120753908740209E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,   2.2120753908740209E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,  -2.2120753908740209E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   7.9406332786923051E-01,  -2.2120753908740209E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,   2.2120753908740209E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -7.9406332786923051E-01,  -2.2120753908740209E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,   7.9406332786923051E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,   7.9406332786923051E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,  -7.9406332786923051E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,   7.9406332786923051E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,  -7.9406332786923051E-01,   2.2120753908740209E-01,   3.9452943822365560E-03],
            [   5.6615426871493113E-01,  -7.9406332786923051E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,   7.9406332786923051E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [  -5.6615426871493113E-01,  -7.9406332786923051E-01,  -2.2120753908740209E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,   7.9406332786923051E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,   7.9406332786923051E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,  -7.9406332786923051E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,   7.9406332786923051E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,  -7.9406332786923051E-01,   5.6615426871493113E-01,   3.9452943822365560E-03],
            [   2.2120753908740209E-01,  -7.9406332786923051E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,   7.9406332786923051E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [  -2.2120753908740209E-01,  -7.9406332786923051E-01,  -5.6615426871493113E-01,   3.9452943822365560E-03],
            [   6.0214501020314515E-01,   2.5806828411609850E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,   2.5806828411609850E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,  -2.5806828411609850E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,   2.5806828411609850E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,  -2.5806828411609850E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,  -2.5806828411609850E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,   2.5806828411609850E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,  -2.5806828411609850E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,   6.0214501020314515E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,   6.0214501020314515E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,  -6.0214501020314515E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,   6.0214501020314515E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,  -6.0214501020314515E-01,   7.5552772776439314E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,  -6.0214501020314515E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,   6.0214501020314515E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,  -6.0214501020314515E-01,  -7.5552772776439314E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,   6.0214501020314515E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,   6.0214501020314515E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,  -6.0214501020314515E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,   6.0214501020314515E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,  -6.0214501020314515E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,  -6.0214501020314515E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,   6.0214501020314515E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,  -6.0214501020314515E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,   2.5806828411609850E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,   2.5806828411609850E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,  -2.5806828411609850E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,   2.5806828411609850E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,  -2.5806828411609850E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   7.5552772776439314E-01,  -2.5806828411609850E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,   2.5806828411609850E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -7.5552772776439314E-01,  -2.5806828411609850E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,   7.5552772776439314E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,   7.5552772776439314E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,  -7.5552772776439314E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,   7.5552772776439314E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,  -7.5552772776439314E-01,   2.5806828411609850E-01,   3.9729121136764262E-03],
            [   6.0214501020314515E-01,  -7.5552772776439314E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,   7.5552772776439314E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [  -6.0214501020314515E-01,  -7.5552772776439314E-01,  -2.5806828411609850E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,   7.5552772776439314E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,   7.5552772776439314E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,  -7.5552772776439314E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,   7.5552772776439314E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,  -7.5552772776439314E-01,   6.0214501020314515E-01,   3.9729121136764262E-03],
            [   2.5806828411609850E-01,  -7.5552772776439314E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,   7.5552772776439314E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [  -2.5806828411609850E-01,  -7.5552772776439314E-01,  -6.0214501020314515E-01,   3.9729121136764262E-03],
            [   6.3605207836100497E-01,   2.9406563620941212E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,   2.9406563620941212E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,  -2.9406563620941212E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,   2.9406563620941212E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,  -2.9406563620941212E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,  -2.9406563620941212E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,   2.9406563620941212E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,  -2.9406563620941212E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,   6.3605207836100497E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,   6.3605207836100497E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,  -6.3605207836100497E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,   6.3605207836100497E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,  -6.3605207836100497E-01,   7.1341653696378504E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,  -6.3605207836100497E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,   6.3605207836100497E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,  -6.3605207836100497E-01,  -7.1341653696378504E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,   6.3605207836100497E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,   6.3605207836100497E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,  -6.3605207836100497E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,   6.3605207836100497E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,  -6.3605207836100497E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,  -6.3605207836100497E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,   6.3605207836100497E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,  -6.3605207836100497E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,   2.9406563620941212E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,   2.9406563620941212E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,  -2.9406563620941212E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,   2.9406563620941212E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,  -2.9406563620941212E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   7.1341653696378504E-01,  -2.9406563620941212E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,   2.9406563620941212E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -7.1341653696378504E-01,  -2.9406563620941212E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,   7.1341653696378504E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,   7.1341653696378504E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,  -7.1341653696378504E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,   7.1341653696378504E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,  -7.1341653696378504E-01,   2.9406563620941212E-01,   3.9872917535225105E-03],
            [   6.3605207836100497E-01,  -7.1341653696378504E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,   7.1341653696378504E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [  -6.3605207836100497E-01,  -7.1341653696378504E-01,  -2.9406563620941212E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,   7.1341653696378504E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,   7.1341653696378504E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,  -7.1341653696378504E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,   7.1341653696378504E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,  -7.1341653696378504E-01,   6.3605207836100497E-01,   3.9872917535225105E-03],
            [   2.9406563620941212E-01,  -7.1341653696378504E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,   7.1341653696378504E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [  -2.9406563620941212E-01,  -7.1341653696378504E-01,  -6.3605207836100497E-01,   3.9872917535225105E-03],
            [   4.5216110650871960E-01,   3.6310553658670017E-02,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,   3.6310553658670017E-02,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,  -3.6310553658670017E-02,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,   3.6310553658670017E-02,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,  -3.6310553658670017E-02,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,  -3.6310553658670017E-02,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,   3.6310553658670017E-02,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,  -3.6310553658670017E-02,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,   4.5216110650871960E-01,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,   4.5216110650871960E-01,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,  -4.5216110650871960E-01,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,   4.5216110650871960E-01,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,  -4.5216110650871960E-01,   8.9119687917643153E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,  -4.5216110650871960E-01,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,   4.5216110650871960E-01,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,  -4.5216110650871960E-01,  -8.9119687917643153E-01,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,   4.5216110650871960E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,   4.5216110650871960E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,  -4.5216110650871960E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,   4.5216110650871960E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,  -4.5216110650871960E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,  -4.5216110650871960E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,   4.5216110650871960E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,  -4.5216110650871960E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,   3.6310553658670017E-02,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,   3.6310553658670017E-02,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,  -3.6310553658670017E-02,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,   3.6310553658670017E-02,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,  -3.6310553658670017E-02,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   8.9119687917643153E-01,  -3.6310553658670017E-02,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,   3.6310553658670017E-02,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -8.9119687917643153E-01,  -3.6310553658670017E-02,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,   8.9119687917643153E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,   8.9119687917643153E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,  -8.9119687917643153E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,   8.9119687917643153E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,  -8.9119687917643153E-01,   3.6310553658670017E-02,   3.7565912548193554E-03],
            [   4.5216110650871960E-01,  -8.9119687917643153E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,   8.9119687917643153E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [  -4.5216110650871960E-01,  -8.9119687917643153E-01,  -3.6310553658670017E-02,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,   8.9119687917643153E-01,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,   8.9119687917643153E-01,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,  -8.9119687917643153E-01,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,   8.9119687917643153E-01,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,  -8.9119687917643153E-01,   4.5216110650871960E-01,   3.7565912548193554E-03],
            [   3.6310553658670017E-02,  -8.9119687917643153E-01,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,   8.9119687917643153E-01,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [  -3.6310553658670017E-02,  -8.9119687917643153E-01,  -4.5216110650871960E-01,   3.7565912548193554E-03],
            [   4.9593656515609630E-01,   7.3483184684843494E-02,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,   7.3483184684843494E-02,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,  -7.3483184684843494E-02,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,   7.3483184684843494E-02,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,  -7.3483184684843494E-02,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,  -7.3483184684843494E-02,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,   7.3483184684843494E-02,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,  -7.3483184684843494E-02,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,   4.9593656515609630E-01,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,   4.9593656515609630E-01,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,  -4.9593656515609630E-01,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,   4.9593656515609630E-01,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,  -4.9593656515609630E-01,   8.6524397999046854E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,  -4.9593656515609630E-01,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,   4.9593656515609630E-01,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,  -4.9593656515609630E-01,  -8.6524397999046854E-01,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,   4.9593656515609630E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,   4.9593656515609630E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,  -4.9593656515609630E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,   4.9593656515609630E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,  -4.9593656515609630E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,  -4.9593656515609630E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,   4.9593656515609630E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,  -4.9593656515609630E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,   7.3483184684843494E-02,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,   7.3483184684843494E-02,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,  -7.3483184684843494E-02,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,   7.3483184684843494E-02,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,  -7.3483184684843494E-02,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   8.6524397999046854E-01,  -7.3483184684843494E-02,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,   7.3483184684843494E-02,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -8.6524397999046854E-01,  -7.3483184684843494E-02,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,   8.6524397999046854E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,   8.6524397999046854E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,  -8.6524397999046854E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,   8.6524397999046854E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,  -8.6524397999046854E-01,   7.3483184684843494E-02,   3.8384681299957995E-03],
            [   4.9593656515609630E-01,  -8.6524397999046854E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,   8.6524397999046854E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [  -4.9593656515609630E-01,  -8.6524397999046854E-01,  -7.3483184684843494E-02,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,   8.6524397999046854E-01,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,   8.6524397999046854E-01,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,  -8.6524397999046854E-01,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,   8.6524397999046854E-01,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,  -8.6524397999046854E-01,   4.9593656515609630E-01,   3.8384681299957995E-03],
            [   7.3483184684843494E-02,  -8.6524397999046854E-01,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,   8.6524397999046854E-01,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [  -7.3483184684843494E-02,  -8.6524397999046854E-01,  -4.9593656515609630E-01,   3.8384681299957995E-03],
            [   5.3768158040382830E-01,   1.1110876438126480E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,   1.1110876438126480E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,  -1.1110876438126480E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,   1.1110876438126480E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,  -1.1110876438126480E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,  -1.1110876438126480E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,   1.1110876438126480E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,  -1.1110876438126480E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,   5.3768158040382830E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,   5.3768158040382830E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,  -5.3768158040382830E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,   5.3768158040382830E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,  -5.3768158040382830E-01,   8.3579504698945795E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,  -5.3768158040382830E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,   5.3768158040382830E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,  -5.3768158040382830E-01,  -8.3579504698945795E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,   5.3768158040382830E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,   5.3768158040382830E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,  -5.3768158040382830E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,   5.3768158040382830E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,  -5.3768158040382830E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,  -5.3768158040382830E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,   5.3768158040382830E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,  -5.3768158040382830E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,   1.1110876438126480E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,   1.1110876438126480E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,  -1.1110876438126480E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,   1.1110876438126480E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,  -1.1110876438126480E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   8.3579504698945795E-01,  -1.1110876438126480E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,   1.1110876438126480E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -8.3579504698945795E-01,  -1.1110876438126480E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,   8.3579504698945795E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,   8.3579504698945795E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,  -8.3579504698945795E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,   8.3579504698945795E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,  -8.3579504698945795E-01,   1.1110876438126480E-01,   3.9015627167985917E-03],
            [   5.3768158040382830E-01,  -8.3579504698945795E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,   8.3579504698945795E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [  -5.3768158040382830E-01,  -8.3579504698945795E-01,  -1.1110876438126480E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,   8.3579504698945795E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,   8.3579504698945795E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,  -8.3579504698945795E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,   8.3579504698945795E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,  -8.3579504698945795E-01,   5.3768158040382830E-01,   3.9015627167985917E-03],
            [   1.1110876438126480E-01,  -8.3579504698945795E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,   8.3579504698945795E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [  -1.1110876438126480E-01,  -8.3579504698945795E-01,  -5.3768158040382830E-01,   3.9015627167985917E-03],
            [   5.7733144802437675E-01,   1.4882260851454079E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,   1.4882260851454079E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,  -1.4882260851454079E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,   1.4882260851454079E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,  -1.4882260851454079E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,  -1.4882260851454079E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,   1.4882260851454079E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,  -1.4882260851454079E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,   5.7733144802437675E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,   5.7733144802437675E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,  -5.7733144802437675E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,   5.7733144802437675E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,  -5.7733144802437675E-01,   8.0283262908093378E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,  -5.7733144802437675E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,   5.7733144802437675E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,  -5.7733144802437675E-01,  -8.0283262908093378E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,   5.7733144802437675E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,   5.7733144802437675E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,  -5.7733144802437675E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,   5.7733144802437675E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,  -5.7733144802437675E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,  -5.7733144802437675E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,   5.7733144802437675E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,  -5.7733144802437675E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,   1.4882260851454079E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,   1.4882260851454079E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,  -1.4882260851454079E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,   1.4882260851454079E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,  -1.4882260851454079E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   8.0283262908093378E-01,  -1.4882260851454079E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,   1.4882260851454079E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -8.0283262908093378E-01,  -1.4882260851454079E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,   8.0283262908093378E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,   8.0283262908093378E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,  -8.0283262908093378E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,   8.0283262908093378E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,  -8.0283262908093378E-01,   1.4882260851454079E-01,   3.9471168974802217E-03],
            [   5.7733144802437675E-01,  -8.0283262908093378E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,   8.0283262908093378E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [  -5.7733144802437675E-01,  -8.0283262908093378E-01,  -1.4882260851454079E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,   8.0283262908093378E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,   8.0283262908093378E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,  -8.0283262908093378E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,   8.0283262908093378E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,  -8.0283262908093378E-01,   5.7733144802437675E-01,   3.9471168974802217E-03],
            [   1.4882260851454079E-01,  -8.0283262908093378E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,   8.0283262908093378E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [  -1.4882260851454079E-01,  -8.0283262908093378E-01,  -5.7733144802437675E-01,   3.9471168974802217E-03],
            [   6.1481132455750565E-01,   1.8628922741351511E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,   1.8628922741351511E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,  -1.8628922741351511E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,   1.8628922741351511E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,  -1.8628922741351511E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,  -1.8628922741351511E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,   1.8628922741351511E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,  -1.8628922741351511E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,   6.1481132455750565E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,   6.1481132455750565E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,  -6.1481132455750565E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,   6.1481132455750565E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,  -6.1481132455750565E-01,   7.6635720062221713E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,  -6.1481132455750565E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,   6.1481132455750565E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,  -6.1481132455750565E-01,  -7.6635720062221713E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,   6.1481132455750565E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,   6.1481132455750565E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,  -6.1481132455750565E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,   6.1481132455750565E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,  -6.1481132455750565E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,  -6.1481132455750565E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,   6.1481132455750565E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,  -6.1481132455750565E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,   1.8628922741351511E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,   1.8628922741351511E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,  -1.8628922741351511E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,   1.8628922741351511E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,  -1.8628922741351511E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   7.6635720062221713E-01,  -1.8628922741351511E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,   1.8628922741351511E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -7.6635720062221713E-01,  -1.8628922741351511E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,   7.6635720062221713E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,   7.6635720062221713E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,  -7.6635720062221713E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,   7.6635720062221713E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,  -7.6635720062221713E-01,   1.8628922741351511E-01,   3.9766538942277354E-03],
            [   6.1481132455750565E-01,  -7.6635720062221713E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,   7.6635720062221713E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [  -6.1481132455750565E-01,  -7.6635720062221713E-01,  -1.8628922741351511E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,   7.6635720062221713E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,   7.6635720062221713E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,  -7.6635720062221713E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,   7.6635720062221713E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,  -7.6635720062221713E-01,   6.1481132455750565E-01,   3.9766538942277354E-03],
            [   1.8628922741351511E-01,  -7.6635720062221713E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,   7.6635720062221713E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [  -1.8628922741351511E-01,  -7.6635720062221713E-01,  -6.1481132455750565E-01,   3.9766538942277354E-03],
            [   6.5004074628423802E-01,   2.2319097017144560E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,   2.2319097017144560E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,  -2.2319097017144560E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,   2.2319097017144560E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,  -2.2319097017144560E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,  -2.2319097017144560E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,   2.2319097017144560E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,  -2.2319097017144560E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,   6.5004074628423802E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,   6.5004074628423802E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,  -6.5004074628423802E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,   6.5004074628423802E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,  -6.5004074628423802E-01,   7.2638338293504467E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,  -6.5004074628423802E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,   6.5004074628423802E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,  -6.5004074628423802E-01,  -7.2638338293504467E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,   6.5004074628423802E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,   6.5004074628423802E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,  -6.5004074628423802E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,   6.5004074628423802E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,  -6.5004074628423802E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,  -6.5004074628423802E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,   6.5004074628423802E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,  -6.5004074628423802E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,   2.2319097017144560E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,   2.2319097017144560E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,  -2.2319097017144560E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,   2.2319097017144560E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,  -2.2319097017144560E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   7.2638338293504467E-01,  -2.2319097017144560E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,   2.2319097017144560E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -7.2638338293504467E-01,  -2.2319097017144560E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,   7.2638338293504467E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,   7.2638338293504467E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,  -7.2638338293504467E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,   7.2638338293504467E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,  -7.2638338293504467E-01,   2.2319097017144560E-01,   3.9918990189051424E-03],
            [   6.5004074628423802E-01,  -7.2638338293504467E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,   7.2638338293504467E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [  -6.5004074628423802E-01,  -7.2638338293504467E-01,  -2.2319097017144560E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,   7.2638338293504467E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,   7.2638338293504467E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,  -7.2638338293504467E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,   7.2638338293504467E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,  -7.2638338293504467E-01,   6.5004074628423802E-01,   3.9918990189051424E-03],
            [   2.2319097017144560E-01,  -7.2638338293504467E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,   7.2638338293504467E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [  -2.2319097017144560E-01,  -7.2638338293504467E-01,  -6.5004074628423802E-01,   3.9918990189051424E-03],
            [   5.4251514487072128E-01,   3.7182013061189442E-02,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,   3.7182013061189442E-02,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,  -3.7182013061189442E-02,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,   3.7182013061189442E-02,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,  -3.7182013061189442E-02,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,  -3.7182013061189442E-02,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,   3.7182013061189442E-02,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,  -3.7182013061189442E-02,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,   5.4251514487072128E-01,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,   5.4251514487072128E-01,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,  -5.4251514487072128E-01,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,   5.4251514487072128E-01,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,  -5.4251514487072128E-01,   8.3922274486015802E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,  -5.4251514487072128E-01,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,   5.4251514487072128E-01,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,  -5.4251514487072128E-01,  -8.3922274486015802E-01,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,   5.4251514487072128E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,   5.4251514487072128E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,  -5.4251514487072128E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,   5.4251514487072128E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,  -5.4251514487072128E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,  -5.4251514487072128E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,   5.4251514487072128E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,  -5.4251514487072128E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,   3.7182013061189442E-02,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,   3.7182013061189442E-02,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,  -3.7182013061189442E-02,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,   3.7182013061189442E-02,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,  -3.7182013061189442E-02,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   8.3922274486015802E-01,  -3.7182013061189442E-02,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,   3.7182013061189442E-02,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -8.3922274486015802E-01,  -3.7182013061189442E-02,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,   8.3922274486015802E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,   8.3922274486015802E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,  -8.3922274486015802E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,   8.3922274486015802E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,  -8.3922274486015802E-01,   3.7182013061189442E-02,   3.9019801719021321E-03],
            [   5.4251514487072128E-01,  -8.3922274486015802E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,   8.3922274486015802E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [  -5.4251514487072128E-01,  -8.3922274486015802E-01,  -3.7182013061189442E-02,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,   8.3922274486015802E-01,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,   8.3922274486015802E-01,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,  -8.3922274486015802E-01,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,   8.3922274486015802E-01,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,  -8.3922274486015802E-01,   5.4251514487072128E-01,   3.9019801719021321E-03],
            [   3.7182013061189442E-02,  -8.3922274486015802E-01,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,   8.3922274486015802E-01,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [  -3.7182013061189442E-02,  -8.3922274486015802E-01,  -5.4251514487072128E-01,   3.9019801719021321E-03],
            [   5.8418605569079307E-01,   7.4836163350673460E-02,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,   7.4836163350673460E-02,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,  -7.4836163350673460E-02,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,   7.4836163350673460E-02,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,  -7.4836163350673460E-02,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,  -7.4836163350673460E-02,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,   7.4836163350673460E-02,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,  -7.4836163350673460E-02,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,   5.8418605569079307E-01,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,   5.8418605569079307E-01,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,  -5.8418605569079307E-01,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,   5.8418605569079307E-01,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,  -5.8418605569079307E-01,   8.0816223680111721E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,  -5.8418605569079307E-01,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,   5.8418605569079307E-01,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,  -5.8418605569079307E-01,  -8.0816223680111721E-01,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,   5.8418605569079307E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,   5.8418605569079307E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,  -5.8418605569079307E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,   5.8418605569079307E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,  -5.8418605569079307E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,  -5.8418605569079307E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,   5.8418605569079307E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,  -5.8418605569079307E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,   7.4836163350673460E-02,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,   7.4836163350673460E-02,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,  -7.4836163350673460E-02,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,   7.4836163350673460E-02,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,  -7.4836163350673460E-02,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   8.0816223680111721E-01,  -7.4836163350673460E-02,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,   7.4836163350673460E-02,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -8.0816223680111721E-01,  -7.4836163350673460E-02,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,   8.0816223680111721E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,   8.0816223680111721E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,  -8.0816223680111721E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,   8.0816223680111721E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,  -8.0816223680111721E-01,   7.4836163350673460E-02,   3.9496280251575828E-03],
            [   5.8418605569079307E-01,  -8.0816223680111721E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,   8.0816223680111721E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [  -5.8418605569079307E-01,  -8.0816223680111721E-01,  -7.4836163350673460E-02,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,   8.0816223680111721E-01,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,   8.0816223680111721E-01,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,  -8.0816223680111721E-01,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,   8.0816223680111721E-01,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,  -8.0816223680111721E-01,   5.8418605569079307E-01,   3.9496280251575828E-03],
            [   7.4836163350673460E-02,  -8.0816223680111721E-01,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,   8.0816223680111721E-01,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [  -7.4836163350673460E-02,  -8.0816223680111721E-01,  -5.8418605569079307E-01,   3.9496280251575828E-03],
            [   6.2346321868514998E-01,   1.1259908342661200E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,   1.1259908342661200E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,  -1.1259908342661200E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,   1.1259908342661200E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,  -1.1259908342661200E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,  -1.1259908342661200E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,   1.1259908342661200E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,  -1.1259908342661200E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,   6.2346321868514998E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,   6.2346321868514998E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,  -6.2346321868514998E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,   6.2346321868514998E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,  -6.2346321868514998E-01,   7.7370217872139901E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,  -6.2346321868514998E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,   6.2346321868514998E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,  -6.2346321868514998E-01,  -7.7370217872139901E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,   6.2346321868514998E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,   6.2346321868514998E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,  -6.2346321868514998E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,   6.2346321868514998E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,  -6.2346321868514998E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,  -6.2346321868514998E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,   6.2346321868514998E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,  -6.2346321868514998E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,   1.1259908342661200E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,   1.1259908342661200E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,  -1.1259908342661200E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,   1.1259908342661200E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,  -1.1259908342661200E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   7.7370217872139901E-01,  -1.1259908342661200E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,   1.1259908342661200E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -7.7370217872139901E-01,  -1.1259908342661200E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,   7.7370217872139901E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,   7.7370217872139901E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,  -7.7370217872139901E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,   7.7370217872139901E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,  -7.7370217872139901E-01,   1.1259908342661200E-01,   3.9812434408121539E-03],
            [   6.2346321868514998E-01,  -7.7370217872139901E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,   7.7370217872139901E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [  -6.2346321868514998E-01,  -7.7370217872139901E-01,  -1.1259908342661200E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,   7.7370217872139901E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,   7.7370217872139901E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,  -7.7370217872139901E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,   7.7370217872139901E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,  -7.7370217872139901E-01,   6.2346321868514998E-01,   3.9812434408121539E-03],
            [   1.1259908342661200E-01,  -7.7370217872139901E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,   7.7370217872139901E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [  -1.1259908342661200E-01,  -7.7370217872139901E-01,  -6.2346321868514998E-01,   3.9812434408121539E-03],
            [   6.6029345518488425E-01,   1.5013038131576190E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,   1.5013038131576190E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,  -1.5013038131576190E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,   1.5013038131576190E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,  -1.5013038131576190E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,  -1.5013038131576190E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,   1.5013038131576190E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,  -1.5013038131576190E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,   6.6029345518488425E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,   6.6029345518488425E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,  -6.6029345518488425E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,   6.6029345518488425E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,  -6.6029345518488425E-01,   7.3584877634334023E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,  -6.6029345518488425E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,   6.6029345518488425E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,  -6.6029345518488425E-01,  -7.3584877634334023E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,   6.6029345518488425E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,   6.6029345518488425E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,  -6.6029345518488425E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,   6.6029345518488425E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,  -6.6029345518488425E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,  -6.6029345518488425E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,   6.6029345518488425E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,  -6.6029345518488425E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,   1.5013038131576190E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,   1.5013038131576190E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,  -1.5013038131576190E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,   1.5013038131576190E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,  -1.5013038131576190E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   7.3584877634334023E-01,  -1.5013038131576190E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,   1.5013038131576190E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -7.3584877634334023E-01,  -1.5013038131576190E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,   7.3584877634334023E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,   7.3584877634334023E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,  -7.3584877634334023E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,   7.3584877634334023E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,  -7.3584877634334023E-01,   1.5013038131576190E-01,   3.9978674915978462E-03],
            [   6.6029345518488425E-01,  -7.3584877634334023E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,   7.3584877634334023E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [  -6.6029345518488425E-01,  -7.3584877634334023E-01,  -1.5013038131576190E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,   7.3584877634334023E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,   7.3584877634334023E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,  -7.3584877634334023E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,   7.3584877634334023E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,  -7.3584877634334023E-01,   6.6029345518488425E-01,   3.9978674915978462E-03],
            [   1.5013038131576190E-01,  -7.3584877634334023E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,   7.3584877634334023E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [  -1.5013038131576190E-01,  -7.3584877634334023E-01,  -6.6029345518488425E-01,   3.9978674915978462E-03],
            [   6.2785739683751052E-01,   3.7675599302457202E-02,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,   3.7675599302457202E-02,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,  -3.7675599302457202E-02,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,   3.7675599302457202E-02,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,  -3.7675599302457202E-02,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,  -3.7675599302457202E-02,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,   3.7675599302457202E-02,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,  -3.7675599302457202E-02,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,   6.2785739683751052E-01,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,   6.2785739683751052E-01,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,  -6.2785739683751052E-01,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,   6.2785739683751052E-01,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,  -6.2785739683751052E-01,   7.7741600089889162E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,  -6.2785739683751052E-01,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,   6.2785739683751052E-01,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,  -6.2785739683751052E-01,  -7.7741600089889162E-01,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,   6.2785739683751052E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,   6.2785739683751052E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,  -6.2785739683751052E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,   6.2785739683751052E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,  -6.2785739683751052E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,  -6.2785739683751052E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,   6.2785739683751052E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,  -6.2785739683751052E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,   3.7675599302457202E-02,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,   3.7675599302457202E-02,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,  -3.7675599302457202E-02,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,   3.7675599302457202E-02,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,  -3.7675599302457202E-02,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   7.7741600089889162E-01,  -3.7675599302457202E-02,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,   3.7675599302457202E-02,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -7.7741600089889162E-01,  -3.7675599302457202E-02,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,   7.7741600089889162E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,   7.7741600089889162E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,  -7.7741600089889162E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,   7.7741600089889162E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,  -7.7741600089889162E-01,   3.7675599302457202E-02,   3.9843734634434956E-03],
            [   6.2785739683751052E-01,  -7.7741600089889162E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,   7.7741600089889162E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [  -6.2785739683751052E-01,  -7.7741600089889162E-01,  -3.7675599302457202E-02,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,   7.7741600089889162E-01,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,   7.7741600089889162E-01,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,  -7.7741600089889162E-01,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,   7.7741600089889162E-01,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,  -7.7741600089889162E-01,   6.2785739683751052E-01,   3.9843734634434956E-03],
            [   3.7675599302457202E-02,  -7.7741600089889162E-01,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,   7.7741600089889162E-01,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [  -3.7675599302457202E-02,  -7.7741600089889162E-01,  -6.2785739683751052E-01,   3.9843734634434956E-03],
            [   6.6656117112645774E-01,   7.5484433013601582E-02,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,   7.5484433013601582E-02,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,  -7.5484433013601582E-02,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,   7.5484433013601582E-02,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,  -7.5484433013601582E-02,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,  -7.5484433013601582E-02,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,   7.5484433013601582E-02,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,  -7.5484433013601582E-02,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,   6.6656117112645774E-01,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,   6.6656117112645774E-01,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,  -6.6656117112645774E-01,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,   6.6656117112645774E-01,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,  -6.6656117112645774E-01,   7.4161870628992377E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,  -6.6656117112645774E-01,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,   6.6656117112645774E-01,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,  -6.6656117112645774E-01,  -7.4161870628992377E-01,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,   6.6656117112645774E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,   6.6656117112645774E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,  -6.6656117112645774E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,   6.6656117112645774E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,  -6.6656117112645774E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,  -6.6656117112645774E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,   6.6656117112645774E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,  -6.6656117112645774E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,   7.5484433013601582E-02,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,   7.5484433013601582E-02,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,  -7.5484433013601582E-02,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,   7.5484433013601582E-02,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,  -7.5484433013601582E-02,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.4161870628992377E-01,  -7.5484433013601582E-02,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,   7.5484433013601582E-02,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.4161870628992377E-01,  -7.5484433013601582E-02,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,   7.4161870628992377E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,   7.4161870628992377E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,  -7.4161870628992377E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,   7.4161870628992377E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,  -7.4161870628992377E-01,   7.5484433013601582E-02,   4.0029519444912832E-03],
            [   6.6656117112645774E-01,  -7.4161870628992377E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,   7.4161870628992377E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [  -6.6656117112645774E-01,  -7.4161870628992377E-01,  -7.5484433013601582E-02,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,   7.4161870628992377E-01,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,   7.4161870628992377E-01,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,  -7.4161870628992377E-01,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,   7.4161870628992377E-01,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,  -7.4161870628992377E-01,   6.6656117112645774E-01,   4.0029519444912832E-03],
            [   7.5484433013601582E-02,  -7.4161870628992377E-01,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,   7.4161870628992377E-01,  -6.6656117112645774E-01,   4.0029519444912832E-03],
            [  -7.5484433013601582E-02,  -7.4161870628992377E-01,  -6.6656117112645774E-01,   4.0029519444912832E-03],
        ])
  
        order = 101
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build3890():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.2712398585739659E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   2.2712398585739659E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   2.2712398585739659E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   2.2712398585739659E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   2.2712398585739659E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   2.2712398585739659E-04],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   3.5789133870562850E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   3.5789133870562850E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   3.5789133870562850E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   3.5789133870562850E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   3.5789133870562850E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   3.5789133870562850E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   3.5789133870562850E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   3.5789133870562850E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   3.5789133870562850E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   3.5789133870562850E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   3.5789133870562850E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   3.5789133870562850E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.5639054401132228E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.5639054401132228E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.5639054401132228E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.5639054401132228E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.5639054401132228E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.5639054401132228E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.5639054401132228E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.5639054401132228E-03],
            [   1.5878764198583521E-02,   1.5878764198583521E-02,   9.9974783305344128E-01,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,   1.5878764198583521E-02,   9.9974783305344128E-01,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,  -1.5878764198583521E-02,   9.9974783305344128E-01,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,   1.5878764198583521E-02,  -9.9974783305344128E-01,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,  -1.5878764198583521E-02,   9.9974783305344128E-01,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,   1.5878764198583521E-02,  -9.9974783305344128E-01,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,  -1.5878764198583521E-02,  -9.9974783305344128E-01,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,  -1.5878764198583521E-02,  -9.9974783305344128E-01,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,   9.9974783305344128E-01,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,  -9.9974783305344128E-01,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,   9.9974783305344128E-01,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,  -9.9974783305344128E-01,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,   9.9974783305344128E-01,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,  -9.9974783305344128E-01,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -1.5878764198583521E-02,  -9.9974783305344128E-01,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [   1.5878764198583521E-02,   9.9974783305344128E-01,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [   9.9974783305344128E-01,   1.5878764198583521E-02,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -9.9974783305344128E-01,   1.5878764198583521E-02,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [   9.9974783305344128E-01,  -1.5878764198583521E-02,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [   9.9974783305344128E-01,   1.5878764198583521E-02,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -9.9974783305344128E-01,  -1.5878764198583521E-02,   1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -9.9974783305344128E-01,   1.5878764198583521E-02,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [   9.9974783305344128E-01,  -1.5878764198583521E-02,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [  -9.9974783305344128E-01,  -1.5878764198583521E-02,  -1.5878764198583521E-02,   8.8129832858844419E-04],
            [   4.0691935937512060E-02,   4.0691935937512060E-02,   9.9834279318243935E-01,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,   4.0691935937512060E-02,   9.9834279318243935E-01,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,  -4.0691935937512060E-02,   9.9834279318243935E-01,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,   4.0691935937512060E-02,  -9.9834279318243935E-01,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,  -4.0691935937512060E-02,   9.9834279318243935E-01,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,   4.0691935937512060E-02,  -9.9834279318243935E-01,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,  -4.0691935937512060E-02,  -9.9834279318243935E-01,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,  -4.0691935937512060E-02,  -9.9834279318243935E-01,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,   9.9834279318243935E-01,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,  -9.9834279318243935E-01,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,   9.9834279318243935E-01,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,  -9.9834279318243935E-01,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,   9.9834279318243935E-01,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,  -9.9834279318243935E-01,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -4.0691935937512060E-02,  -9.9834279318243935E-01,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [   4.0691935937512060E-02,   9.9834279318243935E-01,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [   9.9834279318243935E-01,   4.0691935937512060E-02,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -9.9834279318243935E-01,   4.0691935937512060E-02,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [   9.9834279318243935E-01,  -4.0691935937512060E-02,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [   9.9834279318243935E-01,   4.0691935937512060E-02,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -9.9834279318243935E-01,  -4.0691935937512060E-02,   4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -9.9834279318243935E-01,   4.0691935937512060E-02,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [   9.9834279318243935E-01,  -4.0691935937512060E-02,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [  -9.9834279318243935E-01,  -4.0691935937512060E-02,  -4.0691935937512060E-02,   1.4612150893552477E-03],
            [   7.0258881152579972E-02,   7.0258881152579972E-02,   9.9505144552348412E-01,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,   7.0258881152579972E-02,   9.9505144552348412E-01,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,  -7.0258881152579972E-02,   9.9505144552348412E-01,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,   7.0258881152579972E-02,  -9.9505144552348412E-01,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,  -7.0258881152579972E-02,   9.9505144552348412E-01,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,   7.0258881152579972E-02,  -9.9505144552348412E-01,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,  -7.0258881152579972E-02,  -9.9505144552348412E-01,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,  -7.0258881152579972E-02,  -9.9505144552348412E-01,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,   9.9505144552348412E-01,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,  -9.9505144552348412E-01,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,   9.9505144552348412E-01,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,  -9.9505144552348412E-01,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,   9.9505144552348412E-01,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,  -9.9505144552348412E-01,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -7.0258881152579972E-02,  -9.9505144552348412E-01,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [   7.0258881152579972E-02,   9.9505144552348412E-01,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [   9.9505144552348412E-01,   7.0258881152579972E-02,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -9.9505144552348412E-01,   7.0258881152579972E-02,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [   9.9505144552348412E-01,  -7.0258881152579972E-02,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [   9.9505144552348412E-01,   7.0258881152579972E-02,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -9.9505144552348412E-01,  -7.0258881152579972E-02,   7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -9.9505144552348412E-01,   7.0258881152579972E-02,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [   9.9505144552348412E-01,  -7.0258881152579972E-02,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [  -9.9505144552348412E-01,  -7.0258881152579972E-02,  -7.0258881152579972E-02,   1.9084906248814375E-03],
            [   1.0274954500287040E-01,   1.0274954500287040E-01,   9.8938620467611438E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,   1.0274954500287040E-01,   9.8938620467611438E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,  -1.0274954500287040E-01,   9.8938620467611438E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,   1.0274954500287040E-01,  -9.8938620467611438E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,  -1.0274954500287040E-01,   9.8938620467611438E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,   1.0274954500287040E-01,  -9.8938620467611438E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,  -1.0274954500287040E-01,  -9.8938620467611438E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,  -1.0274954500287040E-01,  -9.8938620467611438E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,   9.8938620467611438E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,  -9.8938620467611438E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,   9.8938620467611438E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,  -9.8938620467611438E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,   9.8938620467611438E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,  -9.8938620467611438E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -1.0274954500287040E-01,  -9.8938620467611438E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [   1.0274954500287040E-01,   9.8938620467611438E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [   9.8938620467611438E-01,   1.0274954500287040E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -9.8938620467611438E-01,   1.0274954500287040E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [   9.8938620467611438E-01,  -1.0274954500287040E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [   9.8938620467611438E-01,   1.0274954500287040E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -9.8938620467611438E-01,  -1.0274954500287040E-01,   1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -9.8938620467611438E-01,   1.0274954500287040E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [   9.8938620467611438E-01,  -1.0274954500287040E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [  -9.8938620467611438E-01,  -1.0274954500287040E-01,  -1.0274954500287040E-01,   2.2604338555520923E-03],
            [   1.3714577308934259E-01,   1.3714577308934259E-01,   9.8101074094397822E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,   1.3714577308934259E-01,   9.8101074094397822E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,  -1.3714577308934259E-01,   9.8101074094397822E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,   1.3714577308934259E-01,  -9.8101074094397822E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,  -1.3714577308934259E-01,   9.8101074094397822E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,   1.3714577308934259E-01,  -9.8101074094397822E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,  -1.3714577308934259E-01,  -9.8101074094397822E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,  -1.3714577308934259E-01,  -9.8101074094397822E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,   9.8101074094397822E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,  -9.8101074094397822E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,   9.8101074094397822E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,  -9.8101074094397822E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,   9.8101074094397822E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,  -9.8101074094397822E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -1.3714577308934259E-01,  -9.8101074094397822E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [   1.3714577308934259E-01,   9.8101074094397822E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [   9.8101074094397822E-01,   1.3714577308934259E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -9.8101074094397822E-01,   1.3714577308934259E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [   9.8101074094397822E-01,  -1.3714577308934259E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [   9.8101074094397822E-01,   1.3714577308934259E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -9.8101074094397822E-01,  -1.3714577308934259E-01,   1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -9.8101074094397822E-01,   1.3714577308934259E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [   9.8101074094397822E-01,  -1.3714577308934259E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [  -9.8101074094397822E-01,  -1.3714577308934259E-01,  -1.3714577308934259E-01,   2.5416658090285623E-03],
            [   1.7277585326719530E-01,   1.7277585326719530E-01,   9.6968913011108115E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,   1.7277585326719530E-01,   9.6968913011108115E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,  -1.7277585326719530E-01,   9.6968913011108115E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,   1.7277585326719530E-01,  -9.6968913011108115E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,  -1.7277585326719530E-01,   9.6968913011108115E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,   1.7277585326719530E-01,  -9.6968913011108115E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,  -1.7277585326719530E-01,  -9.6968913011108115E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,  -1.7277585326719530E-01,  -9.6968913011108115E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,   9.6968913011108115E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,  -9.6968913011108115E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,   9.6968913011108115E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,  -9.6968913011108115E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,   9.6968913011108115E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,  -9.6968913011108115E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -1.7277585326719530E-01,  -9.6968913011108115E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [   1.7277585326719530E-01,   9.6968913011108115E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [   9.6968913011108115E-01,   1.7277585326719530E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -9.6968913011108115E-01,   1.7277585326719530E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [   9.6968913011108115E-01,  -1.7277585326719530E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [   9.6968913011108115E-01,   1.7277585326719530E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -9.6968913011108115E-01,  -1.7277585326719530E-01,   1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -9.6968913011108115E-01,   1.7277585326719530E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [   9.6968913011108115E-01,  -1.7277585326719530E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [  -9.6968913011108115E-01,  -1.7277585326719530E-01,  -1.7277585326719530E-01,   2.7684884462600800E-03],
            [   2.0914920389290370E-01,   2.0914920389290370E-01,   9.5525557890123269E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,   2.0914920389290370E-01,   9.5525557890123269E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,  -2.0914920389290370E-01,   9.5525557890123269E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,   2.0914920389290370E-01,  -9.5525557890123269E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,  -2.0914920389290370E-01,   9.5525557890123269E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,   2.0914920389290370E-01,  -9.5525557890123269E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,  -2.0914920389290370E-01,  -9.5525557890123269E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,  -2.0914920389290370E-01,  -9.5525557890123269E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,   9.5525557890123269E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,  -9.5525557890123269E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,   9.5525557890123269E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,  -9.5525557890123269E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,   9.5525557890123269E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,  -9.5525557890123269E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -2.0914920389290370E-01,  -9.5525557890123269E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [   2.0914920389290370E-01,   9.5525557890123269E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [   9.5525557890123269E-01,   2.0914920389290370E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -9.5525557890123269E-01,   2.0914920389290370E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [   9.5525557890123269E-01,  -2.0914920389290370E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [   9.5525557890123269E-01,   2.0914920389290370E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -9.5525557890123269E-01,  -2.0914920389290370E-01,   2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -9.5525557890123269E-01,   2.0914920389290370E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [   9.5525557890123269E-01,  -2.0914920389290370E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [  -9.5525557890123269E-01,  -2.0914920389290370E-01,  -2.0914920389290370E-01,   2.9522102030389132E-03],
            [   2.4588132817519151E-01,   2.4588132817519151E-01,   9.3759519245226908E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,   2.4588132817519151E-01,   9.3759519245226908E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,  -2.4588132817519151E-01,   9.3759519245226908E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,   2.4588132817519151E-01,  -9.3759519245226908E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,  -2.4588132817519151E-01,   9.3759519245226908E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,   2.4588132817519151E-01,  -9.3759519245226908E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,  -2.4588132817519151E-01,  -9.3759519245226908E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,  -2.4588132817519151E-01,  -9.3759519245226908E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,   9.3759519245226908E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,  -9.3759519245226908E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,   9.3759519245226908E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,  -9.3759519245226908E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,   9.3759519245226908E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,  -9.3759519245226908E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -2.4588132817519151E-01,  -9.3759519245226908E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [   2.4588132817519151E-01,   9.3759519245226908E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [   9.3759519245226908E-01,   2.4588132817519151E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -9.3759519245226908E-01,   2.4588132817519151E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [   9.3759519245226908E-01,  -2.4588132817519151E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [   9.3759519245226908E-01,   2.4588132817519151E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -9.3759519245226908E-01,  -2.4588132817519151E-01,   2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -9.3759519245226908E-01,   2.4588132817519151E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [   9.3759519245226908E-01,  -2.4588132817519151E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [  -9.3759519245226908E-01,  -2.4588132817519151E-01,  -2.4588132817519151E-01,   3.1009807308619683E-03],
            [   2.8265458594500659E-01,   2.8265458594500659E-01,   9.1663120724122948E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,   2.8265458594500659E-01,   9.1663120724122948E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,  -2.8265458594500659E-01,   9.1663120724122948E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,   2.8265458594500659E-01,  -9.1663120724122948E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,  -2.8265458594500659E-01,   9.1663120724122948E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,   2.8265458594500659E-01,  -9.1663120724122948E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,  -2.8265458594500659E-01,  -9.1663120724122948E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,  -2.8265458594500659E-01,  -9.1663120724122948E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,   9.1663120724122948E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,  -9.1663120724122948E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,   9.1663120724122948E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,  -9.1663120724122948E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,   9.1663120724122948E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,  -9.1663120724122948E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -2.8265458594500659E-01,  -9.1663120724122948E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [   2.8265458594500659E-01,   9.1663120724122948E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [   9.1663120724122948E-01,   2.8265458594500659E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -9.1663120724122948E-01,   2.8265458594500659E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [   9.1663120724122948E-01,  -2.8265458594500659E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [   9.1663120724122948E-01,   2.8265458594500659E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -9.1663120724122948E-01,  -2.8265458594500659E-01,   2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -9.1663120724122948E-01,   2.8265458594500659E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [   9.1663120724122948E-01,  -2.8265458594500659E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [  -9.1663120724122948E-01,  -2.8265458594500659E-01,  -2.8265458594500659E-01,   3.2208772580720984E-03],
            [   3.1919572917996220E-01,   3.1919572917996220E-01,   8.9231618440244853E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,   3.1919572917996220E-01,   8.9231618440244853E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,  -3.1919572917996220E-01,   8.9231618440244853E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,   3.1919572917996220E-01,  -8.9231618440244853E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,  -3.1919572917996220E-01,   8.9231618440244853E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,   3.1919572917996220E-01,  -8.9231618440244853E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,  -3.1919572917996220E-01,  -8.9231618440244853E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,  -3.1919572917996220E-01,  -8.9231618440244853E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,   8.9231618440244853E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,  -8.9231618440244853E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,   8.9231618440244853E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,  -8.9231618440244853E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,   8.9231618440244853E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,  -8.9231618440244853E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -3.1919572917996220E-01,  -8.9231618440244853E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [   3.1919572917996220E-01,   8.9231618440244853E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [   8.9231618440244853E-01,   3.1919572917996220E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -8.9231618440244853E-01,   3.1919572917996220E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [   8.9231618440244853E-01,  -3.1919572917996220E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [   8.9231618440244853E-01,   3.1919572917996220E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -8.9231618440244853E-01,  -3.1919572917996220E-01,   3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -8.9231618440244853E-01,   3.1919572917996220E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [   8.9231618440244853E-01,  -3.1919572917996220E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [  -8.9231618440244853E-01,  -3.1919572917996220E-01,  -3.1919572917996220E-01,   3.3165842612119497E-03],
            [   3.5526214692995778E-01,   3.5526214692995778E-01,   8.6462570741184541E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,   3.5526214692995778E-01,   8.6462570741184541E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,  -3.5526214692995778E-01,   8.6462570741184541E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,   3.5526214692995778E-01,  -8.6462570741184541E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,  -3.5526214692995778E-01,   8.6462570741184541E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,   3.5526214692995778E-01,  -8.6462570741184541E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,  -3.5526214692995778E-01,  -8.6462570741184541E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,  -3.5526214692995778E-01,  -8.6462570741184541E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,   8.6462570741184541E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,  -8.6462570741184541E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,   8.6462570741184541E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,  -8.6462570741184541E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,   8.6462570741184541E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,  -8.6462570741184541E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -3.5526214692995778E-01,  -8.6462570741184541E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [   3.5526214692995778E-01,   8.6462570741184541E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [   8.6462570741184541E-01,   3.5526214692995778E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -8.6462570741184541E-01,   3.5526214692995778E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [   8.6462570741184541E-01,  -3.5526214692995778E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [   8.6462570741184541E-01,   3.5526214692995778E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -8.6462570741184541E-01,  -3.5526214692995778E-01,   3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -8.6462570741184541E-01,   3.5526214692995778E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [   8.6462570741184541E-01,  -3.5526214692995778E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [  -8.6462570741184541E-01,  -3.5526214692995778E-01,  -3.5526214692995778E-01,   3.3918361903552546E-03],
            [   3.9063295034062301E-01,   3.9063295034062301E-01,   8.3355371525556810E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,   3.9063295034062301E-01,   8.3355371525556810E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,  -3.9063295034062301E-01,   8.3355371525556810E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,   3.9063295034062301E-01,  -8.3355371525556810E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,  -3.9063295034062301E-01,   8.3355371525556810E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,   3.9063295034062301E-01,  -8.3355371525556810E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,  -3.9063295034062301E-01,  -8.3355371525556810E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,  -3.9063295034062301E-01,  -8.3355371525556810E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,   8.3355371525556810E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,  -8.3355371525556810E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,   8.3355371525556810E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,  -8.3355371525556810E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,   8.3355371525556810E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,  -8.3355371525556810E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -3.9063295034062301E-01,  -8.3355371525556810E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [   3.9063295034062301E-01,   8.3355371525556810E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [   8.3355371525556810E-01,   3.9063295034062301E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -8.3355371525556810E-01,   3.9063295034062301E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [   8.3355371525556810E-01,  -3.9063295034062301E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [   8.3355371525556810E-01,   3.9063295034062301E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -8.3355371525556810E-01,  -3.9063295034062301E-01,   3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -8.3355371525556810E-01,   3.9063295034062301E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [   8.3355371525556810E-01,  -3.9063295034062301E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [  -8.3355371525556810E-01,  -3.9063295034062301E-01,  -3.9063295034062301E-01,   3.4497155625027305E-03],
            [   4.2510286140930309E-01,   4.2510286140930309E-01,   7.9910895029604423E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,   4.2510286140930309E-01,   7.9910895029604423E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,  -4.2510286140930309E-01,   7.9910895029604423E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,   4.2510286140930309E-01,  -7.9910895029604423E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,  -4.2510286140930309E-01,   7.9910895029604423E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,   4.2510286140930309E-01,  -7.9910895029604423E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,  -4.2510286140930309E-01,  -7.9910895029604423E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,  -4.2510286140930309E-01,  -7.9910895029604423E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,   7.9910895029604423E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,  -7.9910895029604423E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,   7.9910895029604423E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,  -7.9910895029604423E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,   7.9910895029604423E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,  -7.9910895029604423E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -4.2510286140930309E-01,  -7.9910895029604423E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [   4.2510286140930309E-01,   7.9910895029604423E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [   7.9910895029604423E-01,   4.2510286140930309E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -7.9910895029604423E-01,   4.2510286140930309E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [   7.9910895029604423E-01,  -4.2510286140930309E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [   7.9910895029604423E-01,   4.2510286140930309E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -7.9910895029604423E-01,  -4.2510286140930309E-01,   4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -7.9910895029604423E-01,   4.2510286140930309E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [   7.9910895029604423E-01,  -4.2510286140930309E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [  -7.9910895029604423E-01,  -4.2510286140930309E-01,  -4.2510286140930309E-01,   3.4928594027930451E-03],
            [   4.5847775201118701E-01,   4.5847775201118701E-01,   7.6131222361232120E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,   4.5847775201118701E-01,   7.6131222361232120E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,  -4.5847775201118701E-01,   7.6131222361232120E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,   4.5847775201118701E-01,  -7.6131222361232120E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,  -4.5847775201118701E-01,   7.6131222361232120E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,   4.5847775201118701E-01,  -7.6131222361232120E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,  -4.5847775201118701E-01,  -7.6131222361232120E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,  -4.5847775201118701E-01,  -7.6131222361232120E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,   7.6131222361232120E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,  -7.6131222361232120E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,   7.6131222361232120E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,  -7.6131222361232120E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,   7.6131222361232120E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,  -7.6131222361232120E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -4.5847775201118701E-01,  -7.6131222361232120E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [   4.5847775201118701E-01,   7.6131222361232120E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [   7.6131222361232120E-01,   4.5847775201118701E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -7.6131222361232120E-01,   4.5847775201118701E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [   7.6131222361232120E-01,  -4.5847775201118701E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [   7.6131222361232120E-01,   4.5847775201118701E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -7.6131222361232120E-01,  -4.5847775201118701E-01,   4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -7.6131222361232120E-01,   4.5847775201118701E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [   7.6131222361232120E-01,  -4.5847775201118701E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [  -7.6131222361232120E-01,  -4.5847775201118701E-01,  -4.5847775201118701E-01,   3.5236054026487264E-03],
            [   4.9057113587101930E-01,   4.9057113587101930E-01,   7.2019436355780775E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,   4.9057113587101930E-01,   7.2019436355780775E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,  -4.9057113587101930E-01,   7.2019436355780775E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,   4.9057113587101930E-01,  -7.2019436355780775E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,  -4.9057113587101930E-01,   7.2019436355780775E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,   4.9057113587101930E-01,  -7.2019436355780775E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,  -4.9057113587101930E-01,  -7.2019436355780775E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,  -4.9057113587101930E-01,  -7.2019436355780775E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,   7.2019436355780775E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,  -7.2019436355780775E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,   7.2019436355780775E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,  -7.2019436355780775E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,   7.2019436355780775E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,  -7.2019436355780775E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -4.9057113587101930E-01,  -7.2019436355780775E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [   4.9057113587101930E-01,   7.2019436355780775E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [   7.2019436355780775E-01,   4.9057113587101930E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -7.2019436355780775E-01,   4.9057113587101930E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [   7.2019436355780775E-01,  -4.9057113587101930E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [   7.2019436355780775E-01,   4.9057113587101930E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -7.2019436355780775E-01,  -4.9057113587101930E-01,   4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -7.2019436355780775E-01,   4.9057113587101930E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [   7.2019436355780775E-01,  -4.9057113587101930E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [  -7.2019436355780775E-01,  -4.9057113587101930E-01,  -4.9057113587101930E-01,   3.5440964659041877E-03],
            [   5.2120116698473851E-01,   5.2120116698473851E-01,   6.7579485575690312E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,   5.2120116698473851E-01,   6.7579485575690312E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,  -5.2120116698473851E-01,   6.7579485575690312E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,   5.2120116698473851E-01,  -6.7579485575690312E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,  -5.2120116698473851E-01,   6.7579485575690312E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,   5.2120116698473851E-01,  -6.7579485575690312E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,  -5.2120116698473851E-01,  -6.7579485575690312E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,  -5.2120116698473851E-01,  -6.7579485575690312E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,   6.7579485575690312E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,  -6.7579485575690312E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,   6.7579485575690312E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,  -6.7579485575690312E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,   6.7579485575690312E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,  -6.7579485575690312E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -5.2120116698473851E-01,  -6.7579485575690312E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [   5.2120116698473851E-01,   6.7579485575690312E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [   6.7579485575690312E-01,   5.2120116698473851E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -6.7579485575690312E-01,   5.2120116698473851E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [   6.7579485575690312E-01,  -5.2120116698473851E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [   6.7579485575690312E-01,   5.2120116698473851E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -6.7579485575690312E-01,  -5.2120116698473851E-01,   5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -6.7579485575690312E-01,   5.2120116698473851E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [   6.7579485575690312E-01,  -5.2120116698473851E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [  -6.7579485575690312E-01,  -5.2120116698473851E-01,  -5.2120116698473851E-01,   3.5563541948640657E-03],
            [   5.5018784887379946E-01,   5.5018784887379946E-01,   6.2816133429497423E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,   5.5018784887379946E-01,   6.2816133429497423E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,  -5.5018784887379946E-01,   6.2816133429497423E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,   5.5018784887379946E-01,  -6.2816133429497423E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,  -5.5018784887379946E-01,   6.2816133429497423E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,   5.5018784887379946E-01,  -6.2816133429497423E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,  -5.5018784887379946E-01,  -6.2816133429497423E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,  -5.5018784887379946E-01,  -6.2816133429497423E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,   6.2816133429497423E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,  -6.2816133429497423E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,   6.2816133429497423E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,  -6.2816133429497423E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,   6.2816133429497423E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,  -6.2816133429497423E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -5.5018784887379946E-01,  -6.2816133429497423E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [   5.5018784887379946E-01,   6.2816133429497423E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [   6.2816133429497423E-01,   5.5018784887379946E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -6.2816133429497423E-01,   5.5018784887379946E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [   6.2816133429497423E-01,  -5.5018784887379946E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [   6.2816133429497423E-01,   5.5018784887379946E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -6.2816133429497423E-01,  -5.5018784887379946E-01,   5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -6.2816133429497423E-01,   5.5018784887379946E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [   6.2816133429497423E-01,  -5.5018784887379946E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [  -6.2816133429497423E-01,  -5.5018784887379946E-01,  -5.5018784887379946E-01,   3.5623259896364430E-03],
            [   6.0250378774793423E-01,   6.0250378774793423E-01,   5.2342943316055934E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,   6.0250378774793423E-01,   5.2342943316055934E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,  -6.0250378774793423E-01,   5.2342943316055934E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,   6.0250378774793423E-01,  -5.2342943316055934E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,  -6.0250378774793423E-01,   5.2342943316055934E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,   6.0250378774793423E-01,  -5.2342943316055934E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,  -6.0250378774793423E-01,  -5.2342943316055934E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,  -6.0250378774793423E-01,  -5.2342943316055934E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,   5.2342943316055934E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,  -5.2342943316055934E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,   5.2342943316055934E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,  -5.2342943316055934E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,   5.2342943316055934E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,  -5.2342943316055934E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -6.0250378774793423E-01,  -5.2342943316055934E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [   6.0250378774793423E-01,   5.2342943316055934E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [   5.2342943316055934E-01,   6.0250378774793423E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -5.2342943316055934E-01,   6.0250378774793423E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [   5.2342943316055934E-01,  -6.0250378774793423E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [   5.2342943316055934E-01,   6.0250378774793423E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -5.2342943316055934E-01,  -6.0250378774793423E-01,   6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -5.2342943316055934E-01,   6.0250378774793423E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [   5.2342943316055934E-01,  -6.0250378774793423E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [  -5.2342943316055934E-01,  -6.0250378774793423E-01,  -6.0250378774793423E-01,   3.5629208669212993E-03],
            [   6.2545726895490161E-01,   6.2545726895490161E-01,   4.6648302158058413E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,   6.2545726895490161E-01,   4.6648302158058413E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,  -6.2545726895490161E-01,   4.6648302158058413E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,   6.2545726895490161E-01,  -4.6648302158058413E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,  -6.2545726895490161E-01,   4.6648302158058413E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,   6.2545726895490161E-01,  -4.6648302158058413E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,  -6.2545726895490161E-01,  -4.6648302158058413E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,  -6.2545726895490161E-01,  -4.6648302158058413E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,   4.6648302158058413E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,  -4.6648302158058413E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,   4.6648302158058413E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,  -4.6648302158058413E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,   4.6648302158058413E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,  -4.6648302158058413E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -6.2545726895490161E-01,  -4.6648302158058413E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [   6.2545726895490161E-01,   4.6648302158058413E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [   4.6648302158058413E-01,   6.2545726895490161E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -4.6648302158058413E-01,   6.2545726895490161E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [   4.6648302158058413E-01,  -6.2545726895490161E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [   4.6648302158058413E-01,   6.2545726895490161E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -4.6648302158058413E-01,  -6.2545726895490161E-01,   6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -4.6648302158058413E-01,   6.2545726895490161E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [   4.6648302158058413E-01,  -6.2545726895490161E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [  -4.6648302158058413E-01,  -6.2545726895490161E-01,  -6.2545726895490161E-01,   3.5610823164060517E-03],
            [   6.4601071795282483E-01,   6.4601071795282483E-01,   4.0662059045276050E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,   6.4601071795282483E-01,   4.0662059045276050E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,  -6.4601071795282483E-01,   4.0662059045276050E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,   6.4601071795282483E-01,  -4.0662059045276050E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,  -6.4601071795282483E-01,   4.0662059045276050E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,   6.4601071795282483E-01,  -4.0662059045276050E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,  -6.4601071795282483E-01,  -4.0662059045276050E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,  -6.4601071795282483E-01,  -4.0662059045276050E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,   4.0662059045276050E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,  -4.0662059045276050E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,   4.0662059045276050E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,  -4.0662059045276050E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,   4.0662059045276050E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,  -4.0662059045276050E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -6.4601071795282483E-01,  -4.0662059045276050E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [   6.4601071795282483E-01,   4.0662059045276050E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [   4.0662059045276050E-01,   6.4601071795282483E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -4.0662059045276050E-01,   6.4601071795282483E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [   4.0662059045276050E-01,  -6.4601071795282483E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [   4.0662059045276050E-01,   6.4601071795282483E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -4.0662059045276050E-01,  -6.4601071795282483E-01,   6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -4.0662059045276050E-01,   6.4601071795282483E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [   4.0662059045276050E-01,  -6.4601071795282483E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [  -4.0662059045276050E-01,  -6.4601071795282483E-01,  -6.4601071795282483E-01,   3.5598747759547802E-03],
            [   6.6395411381542513E-01,   6.6395411381542513E-01,   3.4399108926707245E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,   6.6395411381542513E-01,   3.4399108926707245E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,  -6.6395411381542513E-01,   3.4399108926707245E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,   6.6395411381542513E-01,  -3.4399108926707245E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,  -6.6395411381542513E-01,   3.4399108926707245E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,   6.6395411381542513E-01,  -3.4399108926707245E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,  -6.6395411381542513E-01,  -3.4399108926707245E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,  -6.6395411381542513E-01,  -3.4399108926707245E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,   3.4399108926707245E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,  -3.4399108926707245E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,   3.4399108926707245E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,  -3.4399108926707245E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,   3.4399108926707245E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,  -3.4399108926707245E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -6.6395411381542513E-01,  -3.4399108926707245E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [   6.6395411381542513E-01,   3.4399108926707245E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [   3.4399108926707245E-01,   6.6395411381542513E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -3.4399108926707245E-01,   6.6395411381542513E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [   3.4399108926707245E-01,  -6.6395411381542513E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [   3.4399108926707245E-01,   6.6395411381542513E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -3.4399108926707245E-01,  -6.6395411381542513E-01,   6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -3.4399108926707245E-01,   6.6395411381542513E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [   3.4399108926707245E-01,  -6.6395411381542513E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [  -3.4399108926707245E-01,  -6.6395411381542513E-01,  -6.6395411381542513E-01,   3.5603898696571776E-03],
            [   6.7906885156674945E-01,   6.7906885156674945E-01,   2.7880277915335067E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,   6.7906885156674945E-01,   2.7880277915335067E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,  -6.7906885156674945E-01,   2.7880277915335067E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,   6.7906885156674945E-01,  -2.7880277915335067E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,  -6.7906885156674945E-01,   2.7880277915335067E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,   6.7906885156674945E-01,  -2.7880277915335067E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,  -6.7906885156674945E-01,  -2.7880277915335067E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,  -6.7906885156674945E-01,  -2.7880277915335067E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,   2.7880277915335067E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,  -2.7880277915335067E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,   2.7880277915335067E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,  -2.7880277915335067E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,   2.7880277915335067E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,  -2.7880277915335067E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -6.7906885156674945E-01,  -2.7880277915335067E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [   6.7906885156674945E-01,   2.7880277915335067E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [   2.7880277915335067E-01,   6.7906885156674945E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -2.7880277915335067E-01,   6.7906885156674945E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [   2.7880277915335067E-01,  -6.7906885156674945E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [   2.7880277915335067E-01,   6.7906885156674945E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -2.7880277915335067E-01,  -6.7906885156674945E-01,   6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -2.7880277915335067E-01,   6.7906885156674945E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [   2.7880277915335067E-01,  -6.7906885156674945E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [  -2.7880277915335067E-01,  -6.7906885156674945E-01,  -6.7906885156674945E-01,   3.5631097871614164E-03],
            [   6.9113385803715122E-01,   6.9113385803715122E-01,   2.1134800815093061E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,   6.9113385803715122E-01,   2.1134800815093061E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,  -6.9113385803715122E-01,   2.1134800815093061E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,   6.9113385803715122E-01,  -2.1134800815093061E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,  -6.9113385803715122E-01,   2.1134800815093061E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,   6.9113385803715122E-01,  -2.1134800815093061E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,  -6.9113385803715122E-01,  -2.1134800815093061E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,  -6.9113385803715122E-01,  -2.1134800815093061E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,   2.1134800815093061E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,  -2.1134800815093061E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,   2.1134800815093061E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,  -2.1134800815093061E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,   2.1134800815093061E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,  -2.1134800815093061E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -6.9113385803715122E-01,  -2.1134800815093061E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [   6.9113385803715122E-01,   2.1134800815093061E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [   2.1134800815093061E-01,   6.9113385803715122E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -2.1134800815093061E-01,   6.9113385803715122E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [   2.1134800815093061E-01,  -6.9113385803715122E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [   2.1134800815093061E-01,   6.9113385803715122E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -2.1134800815093061E-01,  -6.9113385803715122E-01,   6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -2.1134800815093061E-01,   6.9113385803715122E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [   2.1134800815093061E-01,  -6.9113385803715122E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [  -2.1134800815093061E-01,  -6.9113385803715122E-01,  -6.9113385803715122E-01,   3.5677078796148608E-03],
            [   6.9993859561264904E-01,   6.9993859561264904E-01,   1.4202790128557519E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,   6.9993859561264904E-01,   1.4202790128557519E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,  -6.9993859561264904E-01,   1.4202790128557519E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,   6.9993859561264904E-01,  -1.4202790128557519E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,  -6.9993859561264904E-01,   1.4202790128557519E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,   6.9993859561264904E-01,  -1.4202790128557519E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,  -6.9993859561264904E-01,  -1.4202790128557519E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,  -6.9993859561264904E-01,  -1.4202790128557519E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,   1.4202790128557519E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,  -1.4202790128557519E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,   1.4202790128557519E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,  -1.4202790128557519E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,   1.4202790128557519E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,  -1.4202790128557519E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -6.9993859561264904E-01,  -1.4202790128557519E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [   6.9993859561264904E-01,   1.4202790128557519E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [   1.4202790128557519E-01,   6.9993859561264904E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -1.4202790128557519E-01,   6.9993859561264904E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [   1.4202790128557519E-01,  -6.9993859561264904E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [   1.4202790128557519E-01,   6.9993859561264904E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -1.4202790128557519E-01,  -6.9993859561264904E-01,   6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -1.4202790128557519E-01,   6.9993859561264904E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [   1.4202790128557519E-01,  -6.9993859561264904E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [  -1.4202790128557519E-01,  -6.9993859561264904E-01,  -6.9993859561264904E-01,   3.5730064346592462E-03],
            [   7.0530377486568963E-01,   7.0530377486568963E-01,   7.1366450944524540E-02,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,   7.0530377486568963E-01,   7.1366450944524540E-02,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,  -7.0530377486568963E-01,   7.1366450944524540E-02,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,   7.0530377486568963E-01,  -7.1366450944524540E-02,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,  -7.0530377486568963E-01,   7.1366450944524540E-02,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,   7.0530377486568963E-01,  -7.1366450944524540E-02,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,  -7.0530377486568963E-01,  -7.1366450944524540E-02,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,  -7.0530377486568963E-01,  -7.1366450944524540E-02,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,   7.1366450944524540E-02,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,  -7.1366450944524540E-02,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,   7.1366450944524540E-02,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,  -7.1366450944524540E-02,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,   7.1366450944524540E-02,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,  -7.1366450944524540E-02,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.0530377486568963E-01,  -7.1366450944524540E-02,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.0530377486568963E-01,   7.1366450944524540E-02,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.1366450944524540E-02,   7.0530377486568963E-01,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.1366450944524540E-02,   7.0530377486568963E-01,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.1366450944524540E-02,  -7.0530377486568963E-01,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.1366450944524540E-02,   7.0530377486568963E-01,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.1366450944524540E-02,  -7.0530377486568963E-01,   7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.1366450944524540E-02,   7.0530377486568963E-01,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [   7.1366450944524540E-02,  -7.0530377486568963E-01,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [  -7.1366450944524540E-02,  -7.0530377486568963E-01,  -7.0530377486568963E-01,   3.5772731845220441E-03],
            [   4.7322243871801152E-02,   9.9887967505347597E-01,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [  -4.7322243871801152E-02,   9.9887967505347597E-01,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [   4.7322243871801152E-02,  -9.9887967505347597E-01,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [  -4.7322243871801152E-02,  -9.9887967505347597E-01,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [   9.9887967505347597E-01,   4.7322243871801152E-02,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [  -9.9887967505347597E-01,   4.7322243871801152E-02,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [   9.9887967505347597E-01,  -4.7322243871801152E-02,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [  -9.9887967505347597E-01,  -4.7322243871801152E-02,   0.0000000000000000E+00,   1.3209685939379787E-03],
            [   4.7322243871801152E-02,   0.0000000000000000E+00,   9.9887967505347597E-01,   1.3209685939379787E-03],
            [  -4.7322243871801152E-02,   0.0000000000000000E+00,   9.9887967505347597E-01,   1.3209685939379787E-03],
            [   4.7322243871801152E-02,   0.0000000000000000E+00,  -9.9887967505347597E-01,   1.3209685939379787E-03],
            [  -4.7322243871801152E-02,   0.0000000000000000E+00,  -9.9887967505347597E-01,   1.3209685939379787E-03],
            [   9.9887967505347597E-01,   0.0000000000000000E+00,   4.7322243871801152E-02,   1.3209685939379787E-03],
            [  -9.9887967505347597E-01,   0.0000000000000000E+00,   4.7322243871801152E-02,   1.3209685939379787E-03],
            [   9.9887967505347597E-01,   0.0000000000000000E+00,  -4.7322243871801152E-02,   1.3209685939379787E-03],
            [  -9.9887967505347597E-01,   0.0000000000000000E+00,  -4.7322243871801152E-02,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,   4.7322243871801152E-02,   9.9887967505347597E-01,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,  -4.7322243871801152E-02,   9.9887967505347597E-01,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,   4.7322243871801152E-02,  -9.9887967505347597E-01,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,  -4.7322243871801152E-02,  -9.9887967505347597E-01,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,   9.9887967505347597E-01,   4.7322243871801152E-02,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,  -9.9887967505347597E-01,   4.7322243871801152E-02,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,   9.9887967505347597E-01,  -4.7322243871801152E-02,   1.3209685939379787E-03],
            [   0.0000000000000000E+00,  -9.9887967505347597E-01,  -4.7322243871801152E-02,   1.3209685939379787E-03],
            [   1.2021005293268031E-01,   9.9274847931080823E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [  -1.2021005293268031E-01,   9.9274847931080823E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [   1.2021005293268031E-01,  -9.9274847931080823E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [  -1.2021005293268031E-01,  -9.9274847931080823E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [   9.9274847931080823E-01,   1.2021005293268031E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [  -9.9274847931080823E-01,   1.2021005293268031E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [   9.9274847931080823E-01,  -1.2021005293268031E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [  -9.9274847931080823E-01,  -1.2021005293268031E-01,   0.0000000000000000E+00,   2.0833431957431900E-03],
            [   1.2021005293268031E-01,   0.0000000000000000E+00,   9.9274847931080823E-01,   2.0833431957431900E-03],
            [  -1.2021005293268031E-01,   0.0000000000000000E+00,   9.9274847931080823E-01,   2.0833431957431900E-03],
            [   1.2021005293268031E-01,   0.0000000000000000E+00,  -9.9274847931080823E-01,   2.0833431957431900E-03],
            [  -1.2021005293268031E-01,   0.0000000000000000E+00,  -9.9274847931080823E-01,   2.0833431957431900E-03],
            [   9.9274847931080823E-01,   0.0000000000000000E+00,   1.2021005293268031E-01,   2.0833431957431900E-03],
            [  -9.9274847931080823E-01,   0.0000000000000000E+00,   1.2021005293268031E-01,   2.0833431957431900E-03],
            [   9.9274847931080823E-01,   0.0000000000000000E+00,  -1.2021005293268031E-01,   2.0833431957431900E-03],
            [  -9.9274847931080823E-01,   0.0000000000000000E+00,  -1.2021005293268031E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,   1.2021005293268031E-01,   9.9274847931080823E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,  -1.2021005293268031E-01,   9.9274847931080823E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,   1.2021005293268031E-01,  -9.9274847931080823E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,  -1.2021005293268031E-01,  -9.9274847931080823E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,   9.9274847931080823E-01,   1.2021005293268031E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,  -9.9274847931080823E-01,   1.2021005293268031E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,   9.9274847931080823E-01,  -1.2021005293268031E-01,   2.0833431957431900E-03],
            [   0.0000000000000000E+00,  -9.9274847931080823E-01,  -1.2021005293268031E-01,   2.0833431957431900E-03],
            [   2.0343048206648551E-01,   9.7908939273500317E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [  -2.0343048206648551E-01,   9.7908939273500317E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [   2.0343048206648551E-01,  -9.7908939273500317E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [  -2.0343048206648551E-01,  -9.7908939273500317E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [   9.7908939273500317E-01,   2.0343048206648551E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [  -9.7908939273500317E-01,   2.0343048206648551E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [   9.7908939273500317E-01,  -2.0343048206648551E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [  -9.7908939273500317E-01,  -2.0343048206648551E-01,   0.0000000000000000E+00,   2.5945133385170622E-03],
            [   2.0343048206648551E-01,   0.0000000000000000E+00,   9.7908939273500317E-01,   2.5945133385170622E-03],
            [  -2.0343048206648551E-01,   0.0000000000000000E+00,   9.7908939273500317E-01,   2.5945133385170622E-03],
            [   2.0343048206648551E-01,   0.0000000000000000E+00,  -9.7908939273500317E-01,   2.5945133385170622E-03],
            [  -2.0343048206648551E-01,   0.0000000000000000E+00,  -9.7908939273500317E-01,   2.5945133385170622E-03],
            [   9.7908939273500317E-01,   0.0000000000000000E+00,   2.0343048206648551E-01,   2.5945133385170622E-03],
            [  -9.7908939273500317E-01,   0.0000000000000000E+00,   2.0343048206648551E-01,   2.5945133385170622E-03],
            [   9.7908939273500317E-01,   0.0000000000000000E+00,  -2.0343048206648551E-01,   2.5945133385170622E-03],
            [  -9.7908939273500317E-01,   0.0000000000000000E+00,  -2.0343048206648551E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,   2.0343048206648551E-01,   9.7908939273500317E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,  -2.0343048206648551E-01,   9.7908939273500317E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,   2.0343048206648551E-01,  -9.7908939273500317E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,  -2.0343048206648551E-01,  -9.7908939273500317E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,   9.7908939273500317E-01,   2.0343048206648551E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,  -9.7908939273500317E-01,   2.0343048206648551E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,   9.7908939273500317E-01,  -2.0343048206648551E-01,   2.5945133385170622E-03],
            [   0.0000000000000000E+00,  -9.7908939273500317E-01,  -2.0343048206648551E-01,   2.5945133385170622E-03],
            [   2.9122856435730021E-01,   9.5665350221612933E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [  -2.9122856435730021E-01,   9.5665350221612933E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [   2.9122856435730021E-01,  -9.5665350221612933E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [  -2.9122856435730021E-01,  -9.5665350221612933E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [   9.5665350221612933E-01,   2.9122856435730021E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [  -9.5665350221612933E-01,   2.9122856435730021E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [   9.5665350221612933E-01,  -2.9122856435730021E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [  -9.5665350221612933E-01,  -2.9122856435730021E-01,   0.0000000000000000E+00,   2.9505118725266983E-03],
            [   2.9122856435730021E-01,   0.0000000000000000E+00,   9.5665350221612933E-01,   2.9505118725266983E-03],
            [  -2.9122856435730021E-01,   0.0000000000000000E+00,   9.5665350221612933E-01,   2.9505118725266983E-03],
            [   2.9122856435730021E-01,   0.0000000000000000E+00,  -9.5665350221612933E-01,   2.9505118725266983E-03],
            [  -2.9122856435730021E-01,   0.0000000000000000E+00,  -9.5665350221612933E-01,   2.9505118725266983E-03],
            [   9.5665350221612933E-01,   0.0000000000000000E+00,   2.9122856435730021E-01,   2.9505118725266983E-03],
            [  -9.5665350221612933E-01,   0.0000000000000000E+00,   2.9122856435730021E-01,   2.9505118725266983E-03],
            [   9.5665350221612933E-01,   0.0000000000000000E+00,  -2.9122856435730021E-01,   2.9505118725266983E-03],
            [  -9.5665350221612933E-01,   0.0000000000000000E+00,  -2.9122856435730021E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,   2.9122856435730021E-01,   9.5665350221612933E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,  -2.9122856435730021E-01,   9.5665350221612933E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,   2.9122856435730021E-01,  -9.5665350221612933E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,  -2.9122856435730021E-01,  -9.5665350221612933E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,   9.5665350221612933E-01,   2.9122856435730021E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,  -9.5665350221612933E-01,   2.9122856435730021E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,   9.5665350221612933E-01,  -2.9122856435730021E-01,   2.9505118725266983E-03],
            [   0.0000000000000000E+00,  -9.5665350221612933E-01,  -2.9122856435730021E-01,   2.9505118725266983E-03],
            [   3.8023617927267678E-01,   9.2488942472714908E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [  -3.8023617927267678E-01,   9.2488942472714908E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [   3.8023617927267678E-01,  -9.2488942472714908E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [  -3.8023617927267678E-01,  -9.2488942472714908E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [   9.2488942472714908E-01,   3.8023617927267678E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [  -9.2488942472714908E-01,   3.8023617927267678E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [   9.2488942472714908E-01,  -3.8023617927267678E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [  -9.2488942472714908E-01,  -3.8023617927267678E-01,   0.0000000000000000E+00,   3.2016288996147006E-03],
            [   3.8023617927267678E-01,   0.0000000000000000E+00,   9.2488942472714908E-01,   3.2016288996147006E-03],
            [  -3.8023617927267678E-01,   0.0000000000000000E+00,   9.2488942472714908E-01,   3.2016288996147006E-03],
            [   3.8023617927267678E-01,   0.0000000000000000E+00,  -9.2488942472714908E-01,   3.2016288996147006E-03],
            [  -3.8023617927267678E-01,   0.0000000000000000E+00,  -9.2488942472714908E-01,   3.2016288996147006E-03],
            [   9.2488942472714908E-01,   0.0000000000000000E+00,   3.8023617927267678E-01,   3.2016288996147006E-03],
            [  -9.2488942472714908E-01,   0.0000000000000000E+00,   3.8023617927267678E-01,   3.2016288996147006E-03],
            [   9.2488942472714908E-01,   0.0000000000000000E+00,  -3.8023617927267678E-01,   3.2016288996147006E-03],
            [  -9.2488942472714908E-01,   0.0000000000000000E+00,  -3.8023617927267678E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,   3.8023617927267678E-01,   9.2488942472714908E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,  -3.8023617927267678E-01,   9.2488942472714908E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,   3.8023617927267678E-01,  -9.2488942472714908E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,  -3.8023617927267678E-01,  -9.2488942472714908E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,   9.2488942472714908E-01,   3.8023617927267678E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,  -9.2488942472714908E-01,   3.8023617927267678E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,   9.2488942472714908E-01,  -3.8023617927267678E-01,   3.2016288996147006E-03],
            [   0.0000000000000000E+00,  -9.2488942472714908E-01,  -3.8023617927267678E-01,   3.2016288996147006E-03],
            [   4.6805985110561460E-01,   8.8369676687367704E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [  -4.6805985110561460E-01,   8.8369676687367704E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [   4.6805985110561460E-01,  -8.8369676687367704E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [  -4.6805985110561460E-01,  -8.8369676687367704E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [   8.8369676687367704E-01,   4.6805985110561460E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [  -8.8369676687367704E-01,   4.6805985110561460E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [   8.8369676687367704E-01,  -4.6805985110561460E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [  -8.8369676687367704E-01,  -4.6805985110561460E-01,   0.0000000000000000E+00,   3.3764288216868448E-03],
            [   4.6805985110561460E-01,   0.0000000000000000E+00,   8.8369676687367704E-01,   3.3764288216868448E-03],
            [  -4.6805985110561460E-01,   0.0000000000000000E+00,   8.8369676687367704E-01,   3.3764288216868448E-03],
            [   4.6805985110561460E-01,   0.0000000000000000E+00,  -8.8369676687367704E-01,   3.3764288216868448E-03],
            [  -4.6805985110561460E-01,   0.0000000000000000E+00,  -8.8369676687367704E-01,   3.3764288216868448E-03],
            [   8.8369676687367704E-01,   0.0000000000000000E+00,   4.6805985110561460E-01,   3.3764288216868448E-03],
            [  -8.8369676687367704E-01,   0.0000000000000000E+00,   4.6805985110561460E-01,   3.3764288216868448E-03],
            [   8.8369676687367704E-01,   0.0000000000000000E+00,  -4.6805985110561460E-01,   3.3764288216868448E-03],
            [  -8.8369676687367704E-01,   0.0000000000000000E+00,  -4.6805985110561460E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,   4.6805985110561460E-01,   8.8369676687367704E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,  -4.6805985110561460E-01,   8.8369676687367704E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,   4.6805985110561460E-01,  -8.8369676687367704E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,  -4.6805985110561460E-01,  -8.8369676687367704E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,   8.8369676687367704E-01,   4.6805985110561460E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,  -8.8369676687367704E-01,   4.6805985110561460E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,   8.8369676687367704E-01,  -4.6805985110561460E-01,   3.3764288216868448E-03],
            [   0.0000000000000000E+00,  -8.8369676687367704E-01,  -4.6805985110561460E-01,   3.3764288216868448E-03],
            [   5.5281510521555988E-01,   8.3330394181565559E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [  -5.5281510521555988E-01,   8.3330394181565559E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [   5.5281510521555988E-01,  -8.3330394181565559E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [  -5.5281510521555988E-01,  -8.3330394181565559E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [   8.3330394181565559E-01,   5.5281510521555988E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [  -8.3330394181565559E-01,   5.5281510521555988E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [   8.3330394181565559E-01,  -5.5281510521555988E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [  -8.3330394181565559E-01,  -5.5281510521555988E-01,   0.0000000000000000E+00,   3.4917743697240717E-03],
            [   5.5281510521555988E-01,   0.0000000000000000E+00,   8.3330394181565559E-01,   3.4917743697240717E-03],
            [  -5.5281510521555988E-01,   0.0000000000000000E+00,   8.3330394181565559E-01,   3.4917743697240717E-03],
            [   5.5281510521555988E-01,   0.0000000000000000E+00,  -8.3330394181565559E-01,   3.4917743697240717E-03],
            [  -5.5281510521555988E-01,   0.0000000000000000E+00,  -8.3330394181565559E-01,   3.4917743697240717E-03],
            [   8.3330394181565559E-01,   0.0000000000000000E+00,   5.5281510521555988E-01,   3.4917743697240717E-03],
            [  -8.3330394181565559E-01,   0.0000000000000000E+00,   5.5281510521555988E-01,   3.4917743697240717E-03],
            [   8.3330394181565559E-01,   0.0000000000000000E+00,  -5.5281510521555988E-01,   3.4917743697240717E-03],
            [  -8.3330394181565559E-01,   0.0000000000000000E+00,  -5.5281510521555988E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,   5.5281510521555988E-01,   8.3330394181565559E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,  -5.5281510521555988E-01,   8.3330394181565559E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,   5.5281510521555988E-01,  -8.3330394181565559E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,  -5.5281510521555988E-01,  -8.3330394181565559E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,   8.3330394181565559E-01,   5.5281510521555988E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,  -8.3330394181565559E-01,   5.5281510521555988E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,   8.3330394181565559E-01,  -5.5281510521555988E-01,   3.4917743697240717E-03],
            [   0.0000000000000000E+00,  -8.3330394181565559E-01,  -5.5281510521555988E-01,   3.4917743697240717E-03],
            [   6.3293863078030410E-01,   7.7420196955701037E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [  -6.3293863078030410E-01,   7.7420196955701037E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [   6.3293863078030410E-01,  -7.7420196955701037E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [  -6.3293863078030410E-01,  -7.7420196955701037E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [   7.7420196955701037E-01,   6.3293863078030410E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [  -7.7420196955701037E-01,   6.3293863078030410E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [   7.7420196955701037E-01,  -6.3293863078030410E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [  -7.7420196955701037E-01,  -6.3293863078030410E-01,   0.0000000000000000E+00,   3.5575352694491237E-03],
            [   6.3293863078030410E-01,   0.0000000000000000E+00,   7.7420196955701037E-01,   3.5575352694491237E-03],
            [  -6.3293863078030410E-01,   0.0000000000000000E+00,   7.7420196955701037E-01,   3.5575352694491237E-03],
            [   6.3293863078030410E-01,   0.0000000000000000E+00,  -7.7420196955701037E-01,   3.5575352694491237E-03],
            [  -6.3293863078030410E-01,   0.0000000000000000E+00,  -7.7420196955701037E-01,   3.5575352694491237E-03],
            [   7.7420196955701037E-01,   0.0000000000000000E+00,   6.3293863078030410E-01,   3.5575352694491237E-03],
            [  -7.7420196955701037E-01,   0.0000000000000000E+00,   6.3293863078030410E-01,   3.5575352694491237E-03],
            [   7.7420196955701037E-01,   0.0000000000000000E+00,  -6.3293863078030410E-01,   3.5575352694491237E-03],
            [  -7.7420196955701037E-01,   0.0000000000000000E+00,  -6.3293863078030410E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,   6.3293863078030410E-01,   7.7420196955701037E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,  -6.3293863078030410E-01,   7.7420196955701037E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,   6.3293863078030410E-01,  -7.7420196955701037E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,  -6.3293863078030410E-01,  -7.7420196955701037E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,   7.7420196955701037E-01,   6.3293863078030410E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,  -7.7420196955701037E-01,   6.3293863078030410E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,   7.7420196955701037E-01,  -6.3293863078030410E-01,   3.5575352694491237E-03],
            [   0.0000000000000000E+00,  -7.7420196955701037E-01,  -6.3293863078030410E-01,   3.5575352694491237E-03],
            [   8.0565166513690695E-02,   2.3634546840031238E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,   2.3634546840031238E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,  -2.3634546840031238E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,   2.3634546840031238E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,  -2.3634546840031238E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,  -2.3634546840031238E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,   2.3634546840031238E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,  -2.3634546840031238E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,   8.0565166513690695E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,   8.0565166513690695E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,  -8.0565166513690695E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,   8.0565166513690695E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,  -8.0565166513690695E-02,   9.9646909743367740E-01,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,  -8.0565166513690695E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,   8.0565166513690695E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,  -8.0565166513690695E-02,  -9.9646909743367740E-01,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,   8.0565166513690695E-02,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,   8.0565166513690695E-02,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,  -8.0565166513690695E-02,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,   8.0565166513690695E-02,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,  -8.0565166513690695E-02,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,  -8.0565166513690695E-02,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,   8.0565166513690695E-02,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,  -8.0565166513690695E-02,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,   2.3634546840031238E-02,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,   2.3634546840031238E-02,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,  -2.3634546840031238E-02,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,   2.3634546840031238E-02,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,  -2.3634546840031238E-02,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   9.9646909743367740E-01,  -2.3634546840031238E-02,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,   2.3634546840031238E-02,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -9.9646909743367740E-01,  -2.3634546840031238E-02,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,   9.9646909743367740E-01,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,   9.9646909743367740E-01,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,  -9.9646909743367740E-01,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,   9.9646909743367740E-01,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,  -9.9646909743367740E-01,   2.3634546840031238E-02,   1.7631413927976457E-03],
            [   8.0565166513690695E-02,  -9.9646909743367740E-01,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,   9.9646909743367740E-01,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [  -8.0565166513690695E-02,  -9.9646909743367740E-01,  -2.3634546840031238E-02,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,   9.9646909743367740E-01,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,   9.9646909743367740E-01,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,  -9.9646909743367740E-01,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,   9.9646909743367740E-01,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,  -9.9646909743367740E-01,   8.0565166513690695E-02,   1.7631413927976457E-03],
            [   2.3634546840031238E-02,  -9.9646909743367740E-01,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,   9.9646909743367740E-01,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [  -2.3634546840031238E-02,  -9.9646909743367740E-01,  -8.0565166513690695E-02,   1.7631413927976457E-03],
            [   1.1564760771393889E-01,   5.1912916325459357E-02,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,   5.1912916325459357E-02,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,  -5.1912916325459357E-02,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,   5.1912916325459357E-02,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,  -5.1912916325459357E-02,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,  -5.1912916325459357E-02,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,   5.1912916325459357E-02,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,  -5.1912916325459357E-02,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,   1.1564760771393889E-01,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,   1.1564760771393889E-01,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,  -1.1564760771393889E-01,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,   1.1564760771393889E-01,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,  -1.1564760771393889E-01,   9.9193280011734097E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,  -1.1564760771393889E-01,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,   1.1564760771393889E-01,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,  -1.1564760771393889E-01,  -9.9193280011734097E-01,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,   1.1564760771393889E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,   1.1564760771393889E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,  -1.1564760771393889E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,   1.1564760771393889E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,  -1.1564760771393889E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,  -1.1564760771393889E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,   1.1564760771393889E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,  -1.1564760771393889E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,   5.1912916325459357E-02,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,   5.1912916325459357E-02,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,  -5.1912916325459357E-02,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,   5.1912916325459357E-02,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,  -5.1912916325459357E-02,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   9.9193280011734097E-01,  -5.1912916325459357E-02,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,   5.1912916325459357E-02,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -9.9193280011734097E-01,  -5.1912916325459357E-02,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,   9.9193280011734097E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,   9.9193280011734097E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,  -9.9193280011734097E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,   9.9193280011734097E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,  -9.9193280011734097E-01,   5.1912916325459357E-02,   2.1318899595344936E-03],
            [   1.1564760771393889E-01,  -9.9193280011734097E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,   9.9193280011734097E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [  -1.1564760771393889E-01,  -9.9193280011734097E-01,  -5.1912916325459357E-02,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,   9.9193280011734097E-01,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,   9.9193280011734097E-01,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,  -9.9193280011734097E-01,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,   9.9193280011734097E-01,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,  -9.9193280011734097E-01,   1.1564760771393889E-01,   2.1318899595344936E-03],
            [   5.1912916325459357E-02,  -9.9193280011734097E-01,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,   9.9193280011734097E-01,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [  -5.1912916325459357E-02,  -9.9193280011734097E-01,  -1.1564760771393889E-01,   2.1318899595344936E-03],
            [   1.5204733827604211E-01,   8.3227157369945196E-02,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,   8.3227157369945196E-02,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,  -8.3227157369945196E-02,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,   8.3227157369945196E-02,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,  -8.3227157369945196E-02,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,  -8.3227157369945196E-02,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,   8.3227157369945196E-02,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,  -8.3227157369945196E-02,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,   1.5204733827604211E-01,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,   1.5204733827604211E-01,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,  -1.5204733827604211E-01,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,   1.5204733827604211E-01,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,  -1.5204733827604211E-01,   9.8486285705132026E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,  -1.5204733827604211E-01,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,   1.5204733827604211E-01,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,  -1.5204733827604211E-01,  -9.8486285705132026E-01,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,   1.5204733827604211E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,   1.5204733827604211E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,  -1.5204733827604211E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,   1.5204733827604211E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,  -1.5204733827604211E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,  -1.5204733827604211E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,   1.5204733827604211E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,  -1.5204733827604211E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,   8.3227157369945196E-02,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,   8.3227157369945196E-02,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,  -8.3227157369945196E-02,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,   8.3227157369945196E-02,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,  -8.3227157369945196E-02,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   9.8486285705132026E-01,  -8.3227157369945196E-02,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,   8.3227157369945196E-02,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -9.8486285705132026E-01,  -8.3227157369945196E-02,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,   9.8486285705132026E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,   9.8486285705132026E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,  -9.8486285705132026E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,   9.8486285705132026E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,  -9.8486285705132026E-01,   8.3227157369945196E-02,   2.4325819922887035E-03],
            [   1.5204733827604211E-01,  -9.8486285705132026E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,   9.8486285705132026E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [  -1.5204733827604211E-01,  -9.8486285705132026E-01,  -8.3227157369945196E-02,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,   9.8486285705132026E-01,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,   9.8486285705132026E-01,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,  -9.8486285705132026E-01,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,   9.8486285705132026E-01,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,  -9.8486285705132026E-01,   1.5204733827604211E-01,   2.4325819922887035E-03],
            [   8.3227157369945196E-02,  -9.8486285705132026E-01,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,   9.8486285705132026E-01,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [  -8.3227157369945196E-02,  -9.8486285705132026E-01,  -1.5204733827604211E-01,   2.4325819922887035E-03],
            [   1.8929866997459310E-01,   1.1658556679937120E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,   1.1658556679937120E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,  -1.1658556679937120E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,   1.1658556679937120E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,  -1.1658556679937120E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,  -1.1658556679937120E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,   1.1658556679937120E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,  -1.1658556679937120E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,   1.8929866997459310E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,   1.8929866997459310E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,  -1.8929866997459310E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,   1.8929866997459310E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,  -1.8929866997459310E-01,   9.7497375306206036E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,  -1.8929866997459310E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,   1.8929866997459310E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,  -1.8929866997459310E-01,  -9.7497375306206036E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,   1.8929866997459310E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,   1.8929866997459310E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,  -1.8929866997459310E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,   1.8929866997459310E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,  -1.8929866997459310E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,  -1.8929866997459310E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,   1.8929866997459310E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,  -1.8929866997459310E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,   1.1658556679937120E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,   1.1658556679937120E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,  -1.1658556679937120E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,   1.1658556679937120E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,  -1.1658556679937120E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   9.7497375306206036E-01,  -1.1658556679937120E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,   1.1658556679937120E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -9.7497375306206036E-01,  -1.1658556679937120E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,   9.7497375306206036E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,   9.7497375306206036E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,  -9.7497375306206036E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,   9.7497375306206036E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,  -9.7497375306206036E-01,   1.1658556679937120E-01,   2.6774091575550510E-03],
            [   1.8929866997459310E-01,  -9.7497375306206036E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,   9.7497375306206036E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [  -1.8929866997459310E-01,  -9.7497375306206036E-01,  -1.1658556679937120E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,   9.7497375306206036E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,   9.7497375306206036E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,  -9.7497375306206036E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,   9.7497375306206036E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,  -9.7497375306206036E-01,   1.8929866997459310E-01,   2.6774091575550510E-03],
            [   1.1658556679937120E-01,  -9.7497375306206036E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,   9.7497375306206036E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [  -1.1658556679937120E-01,  -9.7497375306206036E-01,  -1.8929866997459310E-01,   2.6774091575550510E-03],
            [   2.2701944467777921E-01,   1.5130771674095039E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,   1.5130771674095039E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,  -1.5130771674095039E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,   1.5130771674095039E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,  -1.5130771674095039E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,  -1.5130771674095039E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,   1.5130771674095039E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,  -1.5130771674095039E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,   2.2701944467777921E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,   2.2701944467777921E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,  -2.2701944467777921E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,   2.2701944467777921E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,  -2.2701944467777921E-01,   9.6206452309230961E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,  -2.2701944467777921E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,   2.2701944467777921E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,  -2.2701944467777921E-01,  -9.6206452309230961E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,   2.2701944467777921E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,   2.2701944467777921E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,  -2.2701944467777921E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,   2.2701944467777921E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,  -2.2701944467777921E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,  -2.2701944467777921E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,   2.2701944467777921E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,  -2.2701944467777921E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,   1.5130771674095039E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,   1.5130771674095039E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,  -1.5130771674095039E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,   1.5130771674095039E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,  -1.5130771674095039E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   9.6206452309230961E-01,  -1.5130771674095039E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,   1.5130771674095039E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -9.6206452309230961E-01,  -1.5130771674095039E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,   9.6206452309230961E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,   9.6206452309230961E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,  -9.6206452309230961E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,   9.6206452309230961E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,  -9.6206452309230961E-01,   1.5130771674095039E-01,   2.8769213465260324E-03],
            [   2.2701944467777921E-01,  -9.6206452309230961E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,   9.6206452309230961E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [  -2.2701944467777921E-01,  -9.6206452309230961E-01,  -1.5130771674095039E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,   9.6206452309230961E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,   9.6206452309230961E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,  -9.6206452309230961E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,   9.6206452309230961E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,  -9.6206452309230961E-01,   2.2701944467777921E-01,   2.8769213465260324E-03],
            [   1.5130771674095039E-01,  -9.6206452309230961E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,   9.6206452309230961E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [  -1.5130771674095039E-01,  -9.6206452309230961E-01,  -2.2701944467777921E-01,   2.8769213465260324E-03],
            [   2.6489081850932727E-01,   1.8688820258078589E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,   1.8688820258078589E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,  -1.8688820258078589E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,   1.8688820258078589E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,  -1.8688820258078589E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,  -1.8688820258078589E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,   1.8688820258078589E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,  -1.8688820258078589E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,   2.6489081850932727E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,   2.6489081850932727E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,  -2.6489081850932727E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,   2.6489081850932727E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,  -2.6489081850932727E-01,   9.4599453169961911E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,  -2.6489081850932727E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,   2.6489081850932727E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,  -2.6489081850932727E-01,  -9.4599453169961911E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,   2.6489081850932727E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,   2.6489081850932727E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,  -2.6489081850932727E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,   2.6489081850932727E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,  -2.6489081850932727E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,  -2.6489081850932727E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,   2.6489081850932727E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,  -2.6489081850932727E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,   1.8688820258078589E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,   1.8688820258078589E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,  -1.8688820258078589E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,   1.8688820258078589E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,  -1.8688820258078589E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   9.4599453169961911E-01,  -1.8688820258078589E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,   1.8688820258078589E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -9.4599453169961911E-01,  -1.8688820258078589E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,   9.4599453169961911E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,   9.4599453169961911E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,  -9.4599453169961911E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,   9.4599453169961911E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,  -9.4599453169961911E-01,   1.8688820258078589E-01,   3.0393404638644241E-03],
            [   2.6489081850932727E-01,  -9.4599453169961911E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,   9.4599453169961911E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [  -2.6489081850932727E-01,  -9.4599453169961911E-01,  -1.8688820258078589E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,   9.4599453169961911E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,   9.4599453169961911E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,  -9.4599453169961911E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,   9.4599453169961911E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,  -9.4599453169961911E-01,   2.6489081850932727E-01,   3.0393404638644241E-03],
            [   1.8688820258078589E-01,  -9.4599453169961911E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,   9.4599453169961911E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [  -1.8688820258078589E-01,  -9.4599453169961911E-01,  -2.6489081850932727E-01,   3.0393404638644241E-03],
            [   3.0263892595741360E-01,   2.2292776297762240E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,   2.2292776297762240E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,  -2.2292776297762240E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,   2.2292776297762240E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,  -2.2292776297762240E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,  -2.2292776297762240E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,   2.2292776297762240E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,  -2.2292776297762240E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,   3.0263892595741360E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,   3.0263892595741360E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,  -3.0263892595741360E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,   3.0263892595741360E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,  -3.0263892595741360E-01,   9.2666762811114545E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,  -3.0263892595741360E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,   3.0263892595741360E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,  -3.0263892595741360E-01,  -9.2666762811114545E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,   3.0263892595741360E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,   3.0263892595741360E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,  -3.0263892595741360E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,   3.0263892595741360E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,  -3.0263892595741360E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,  -3.0263892595741360E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,   3.0263892595741360E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,  -3.0263892595741360E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,   2.2292776297762240E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,   2.2292776297762240E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,  -2.2292776297762240E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,   2.2292776297762240E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,  -2.2292776297762240E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   9.2666762811114545E-01,  -2.2292776297762240E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,   2.2292776297762240E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -9.2666762811114545E-01,  -2.2292776297762240E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,   9.2666762811114545E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,   9.2666762811114545E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,  -9.2666762811114545E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,   9.2666762811114545E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,  -9.2666762811114545E-01,   2.2292776297762240E-01,   3.1709985836559191E-03],
            [   3.0263892595741360E-01,  -9.2666762811114545E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,   9.2666762811114545E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [  -3.0263892595741360E-01,  -9.2666762811114545E-01,  -2.2292776297762240E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,   9.2666762811114545E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,   9.2666762811114545E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,  -9.2666762811114545E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,   9.2666762811114545E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,  -9.2666762811114545E-01,   3.0263892595741360E-01,   3.1709985836559191E-03],
            [   2.2292776297762240E-01,  -9.2666762811114545E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,   9.2666762811114545E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [  -2.2292776297762240E-01,  -9.2666762811114545E-01,  -3.0263892595741360E-01,   3.1709985836559191E-03],
            [   3.4002202961513839E-01,   2.5909518407462351E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,   2.5909518407462351E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,  -2.5909518407462351E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,   2.5909518407462351E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,  -2.5909518407462351E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,  -2.5909518407462351E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,   2.5909518407462351E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,  -2.5909518407462351E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,   3.4002202961513839E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,   3.4002202961513839E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,  -3.4002202961513839E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,   3.4002202961513839E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,  -3.4002202961513839E-01,   9.0402140736032288E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,  -3.4002202961513839E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,   3.4002202961513839E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,  -3.4002202961513839E-01,  -9.0402140736032288E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,   3.4002202961513839E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,   3.4002202961513839E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,  -3.4002202961513839E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,   3.4002202961513839E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,  -3.4002202961513839E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,  -3.4002202961513839E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,   3.4002202961513839E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,  -3.4002202961513839E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,   2.5909518407462351E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,   2.5909518407462351E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,  -2.5909518407462351E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,   2.5909518407462351E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,  -2.5909518407462351E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   9.0402140736032288E-01,  -2.5909518407462351E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,   2.5909518407462351E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -9.0402140736032288E-01,  -2.5909518407462351E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,   9.0402140736032288E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,   9.0402140736032288E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,  -9.0402140736032288E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,   9.0402140736032288E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,  -9.0402140736032288E-01,   2.5909518407462351E-01,   3.2768369273255618E-03],
            [   3.4002202961513839E-01,  -9.0402140736032288E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,   9.0402140736032288E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [  -3.4002202961513839E-01,  -9.0402140736032288E-01,  -2.5909518407462351E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,   9.0402140736032288E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,   9.0402140736032288E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,  -9.0402140736032288E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,   9.0402140736032288E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,  -9.0402140736032288E-01,   3.4002202961513839E-01,   3.2768369273255618E-03],
            [   2.5909518407462351E-01,  -9.0402140736032288E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,   9.0402140736032288E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [  -2.5909518407462351E-01,  -9.0402140736032288E-01,  -3.4002202961513839E-01,   3.2768369273255618E-03],
            [   3.7682179533355098E-01,   2.9510472917508468E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,   2.9510472917508468E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,  -2.9510472917508468E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,   2.9510472917508468E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,  -2.9510472917508468E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,  -2.9510472917508468E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,   2.9510472917508468E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,  -2.9510472917508468E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,   3.7682179533355098E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,   3.7682179533355098E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,  -3.7682179533355098E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,   3.7682179533355098E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,  -3.7682179533355098E-01,   8.7801966571375800E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,  -3.7682179533355098E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,   3.7682179533355098E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,  -3.7682179533355098E-01,  -8.7801966571375800E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,   3.7682179533355098E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,   3.7682179533355098E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,  -3.7682179533355098E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,   3.7682179533355098E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,  -3.7682179533355098E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,  -3.7682179533355098E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,   3.7682179533355098E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,  -3.7682179533355098E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,   2.9510472917508468E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,   2.9510472917508468E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,  -2.9510472917508468E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,   2.9510472917508468E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,  -2.9510472917508468E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   8.7801966571375800E-01,  -2.9510472917508468E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,   2.9510472917508468E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -8.7801966571375800E-01,  -2.9510472917508468E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,   8.7801966571375800E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,   8.7801966571375800E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,  -8.7801966571375800E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,   8.7801966571375800E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,  -8.7801966571375800E-01,   2.9510472917508468E-01,   3.3608017203022077E-03],
            [   3.7682179533355098E-01,  -8.7801966571375800E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,   8.7801966571375800E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [  -3.7682179533355098E-01,  -8.7801966571375800E-01,  -2.9510472917508468E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,   8.7801966571375800E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,   8.7801966571375800E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,  -8.7801966571375800E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,   8.7801966571375800E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,  -8.7801966571375800E-01,   3.7682179533355098E-01,   3.3608017203022077E-03],
            [   2.9510472917508468E-01,  -8.7801966571375800E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,   8.7801966571375800E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [  -2.9510472917508468E-01,  -8.7801966571375800E-01,  -3.7682179533355098E-01,   3.3608017203022077E-03],
            [   4.1283729009218839E-01,   3.3070197141699298E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,   3.3070197141699298E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,  -3.3070197141699298E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,   3.3070197141699298E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,  -3.3070197141699298E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,  -3.3070197141699298E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,   3.3070197141699298E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,  -3.3070197141699298E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,   4.1283729009218839E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,   4.1283729009218839E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,  -4.1283729009218839E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,   4.1283729009218839E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,  -4.1283729009218839E-01,   8.4864691009291526E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,  -4.1283729009218839E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,   4.1283729009218839E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,  -4.1283729009218839E-01,  -8.4864691009291526E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,   4.1283729009218839E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,   4.1283729009218839E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,  -4.1283729009218839E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,   4.1283729009218839E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,  -4.1283729009218839E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,  -4.1283729009218839E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,   4.1283729009218839E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,  -4.1283729009218839E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,   3.3070197141699298E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,   3.3070197141699298E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,  -3.3070197141699298E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,   3.3070197141699298E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,  -3.3070197141699298E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   8.4864691009291526E-01,  -3.3070197141699298E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,   3.3070197141699298E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -8.4864691009291526E-01,  -3.3070197141699298E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,   8.4864691009291526E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,   8.4864691009291526E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,  -8.4864691009291526E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,   8.4864691009291526E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,  -8.4864691009291526E-01,   3.3070197141699298E-01,   3.4261359495056671E-03],
            [   4.1283729009218839E-01,  -8.4864691009291526E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,   8.4864691009291526E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [  -4.1283729009218839E-01,  -8.4864691009291526E-01,  -3.3070197141699298E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,   8.4864691009291526E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,   8.4864691009291526E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,  -8.4864691009291526E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,   8.4864691009291526E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,  -8.4864691009291526E-01,   4.1283729009218839E-01,   3.4261359495056671E-03],
            [   3.3070197141699298E-01,  -8.4864691009291526E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,   8.4864691009291526E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [  -3.3070197141699298E-01,  -8.4864691009291526E-01,  -4.1283729009218839E-01,   3.4261359495056671E-03],
            [   4.4788071318156297E-01,   3.6565441010876337E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,   3.6565441010876337E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,  -3.6565441010876337E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,   3.6565441010876337E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,  -3.6565441010876337E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,  -3.6565441010876337E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,   3.6565441010876337E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,  -3.6565441010876337E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,   4.4788071318156297E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,   4.4788071318156297E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,  -4.4788071318156297E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,   4.4788071318156297E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,  -4.4788071318156297E-01,   8.1590423404219858E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,  -4.4788071318156297E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,   4.4788071318156297E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,  -4.4788071318156297E-01,  -8.1590423404219858E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,   4.4788071318156297E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,   4.4788071318156297E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,  -4.4788071318156297E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,   4.4788071318156297E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,  -4.4788071318156297E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,  -4.4788071318156297E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,   4.4788071318156297E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,  -4.4788071318156297E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,   3.6565441010876337E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,   3.6565441010876337E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,  -3.6565441010876337E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,   3.6565441010876337E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,  -3.6565441010876337E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   8.1590423404219858E-01,  -3.6565441010876337E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,   3.6565441010876337E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -8.1590423404219858E-01,  -3.6565441010876337E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,   8.1590423404219858E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,   8.1590423404219858E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,  -8.1590423404219858E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,   8.1590423404219858E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,  -8.1590423404219858E-01,   3.6565441010876337E-01,   3.4755913101958661E-03],
            [   4.4788071318156297E-01,  -8.1590423404219858E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,   8.1590423404219858E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [  -4.4788071318156297E-01,  -8.1590423404219858E-01,  -3.6565441010876337E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,   8.1590423404219858E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,   8.1590423404219858E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,  -8.1590423404219858E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,   8.1590423404219858E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,  -8.1590423404219858E-01,   4.4788071318156297E-01,   3.4755913101958661E-03],
            [   3.6565441010876337E-01,  -8.1590423404219858E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,   8.1590423404219858E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [  -3.6565441010876337E-01,  -8.1590423404219858E-01,  -4.4788071318156297E-01,   3.4755913101958661E-03],
            [   4.8177420340892568E-01,   3.9974489519396950E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,   3.9974489519396950E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,  -3.9974489519396950E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,   3.9974489519396950E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,  -3.9974489519396950E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,  -3.9974489519396950E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,   3.9974489519396950E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,  -3.9974489519396950E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,   4.8177420340892568E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,   4.8177420340892568E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,  -4.8177420340892568E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,   4.8177420340892568E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,  -4.8177420340892568E-01,   7.7980615264055042E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,  -4.8177420340892568E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,   4.8177420340892568E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,  -4.8177420340892568E-01,  -7.7980615264055042E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,   4.8177420340892568E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,   4.8177420340892568E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,  -4.8177420340892568E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,   4.8177420340892568E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,  -4.8177420340892568E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,  -4.8177420340892568E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,   4.8177420340892568E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,  -4.8177420340892568E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,   3.9974489519396950E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,   3.9974489519396950E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,  -3.9974489519396950E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,   3.9974489519396950E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,  -3.9974489519396950E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   7.7980615264055042E-01,  -3.9974489519396950E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,   3.9974489519396950E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -7.7980615264055042E-01,  -3.9974489519396950E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,   7.7980615264055042E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,   7.7980615264055042E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,  -7.7980615264055042E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,   7.7980615264055042E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,  -7.7980615264055042E-01,   3.9974489519396950E-01,   3.5115826582008624E-03],
            [   4.8177420340892568E-01,  -7.7980615264055042E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,   7.7980615264055042E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [  -4.8177420340892568E-01,  -7.7980615264055042E-01,  -3.9974489519396950E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,   7.7980615264055042E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,   7.7980615264055042E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,  -7.7980615264055042E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,   7.7980615264055042E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,  -7.7980615264055042E-01,   4.8177420340892568E-01,   3.5115826582008624E-03],
            [   3.9974489519396950E-01,  -7.7980615264055042E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,   7.7980615264055042E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [  -3.9974489519396950E-01,  -7.7980615264055042E-01,  -4.8177420340892568E-01,   3.5115826582008624E-03],
            [   5.1434728146533437E-01,   4.3276671108120240E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,   4.3276671108120240E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,  -4.3276671108120240E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,   4.3276671108120240E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,  -4.3276671108120240E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,  -4.3276671108120240E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,   4.3276671108120240E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,  -4.3276671108120240E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,   5.1434728146533437E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,   5.1434728146533437E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,  -5.1434728146533437E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,   5.1434728146533437E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,  -5.1434728146533437E-01,   7.4037817892559421E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,  -5.1434728146533437E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,   5.1434728146533437E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,  -5.1434728146533437E-01,  -7.4037817892559421E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,   5.1434728146533437E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,   5.1434728146533437E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,  -5.1434728146533437E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,   5.1434728146533437E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,  -5.1434728146533437E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,  -5.1434728146533437E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,   5.1434728146533437E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,  -5.1434728146533437E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,   4.3276671108120240E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,   4.3276671108120240E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,  -4.3276671108120240E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,   4.3276671108120240E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,  -4.3276671108120240E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   7.4037817892559421E-01,  -4.3276671108120240E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,   4.3276671108120240E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -7.4037817892559421E-01,  -4.3276671108120240E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,   7.4037817892559421E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,   7.4037817892559421E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,  -7.4037817892559421E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,   7.4037817892559421E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,  -7.4037817892559421E-01,   4.3276671108120240E-01,   3.5363011005420633E-03],
            [   5.1434728146533437E-01,  -7.4037817892559421E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,   7.4037817892559421E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [  -5.1434728146533437E-01,  -7.4037817892559421E-01,  -4.3276671108120240E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,   7.4037817892559421E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,   7.4037817892559421E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,  -7.4037817892559421E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,   7.4037817892559421E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,  -7.4037817892559421E-01,   5.1434728146533437E-01,   3.5363011005420633E-03],
            [   4.3276671108120240E-01,  -7.4037817892559421E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,   7.4037817892559421E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [  -4.3276671108120240E-01,  -7.4037817892559421E-01,  -5.1434728146533437E-01,   3.5363011005420633E-03],
            [   5.4543462139056498E-01,   4.6451961235322931E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,   4.6451961235322931E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,  -4.6451961235322931E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,   4.6451961235322931E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,  -4.6451961235322931E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,  -4.6451961235322931E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,   4.6451961235322931E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,  -4.6451961235322931E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,   5.4543462139056498E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,   5.4543462139056498E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,  -5.4543462139056498E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,   5.4543462139056498E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,  -5.4543462139056498E-01,   6.9765507489570855E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,  -5.4543462139056498E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,   5.4543462139056498E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,  -5.4543462139056498E-01,  -6.9765507489570855E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,   5.4543462139056498E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,   5.4543462139056498E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,  -5.4543462139056498E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,   5.4543462139056498E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,  -5.4543462139056498E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,  -5.4543462139056498E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,   5.4543462139056498E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,  -5.4543462139056498E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,   4.6451961235322931E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,   4.6451961235322931E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,  -4.6451961235322931E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,   4.6451961235322931E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,  -4.6451961235322931E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   6.9765507489570855E-01,  -4.6451961235322931E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,   4.6451961235322931E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -6.9765507489570855E-01,  -4.6451961235322931E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,   6.9765507489570855E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,   6.9765507489570855E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,  -6.9765507489570855E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,   6.9765507489570855E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,  -6.9765507489570855E-01,   4.6451961235322931E-01,   3.5517961009191232E-03],
            [   5.4543462139056498E-01,  -6.9765507489570855E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,   6.9765507489570855E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [  -5.4543462139056498E-01,  -6.9765507489570855E-01,  -4.6451961235322931E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,   6.9765507489570855E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,   6.9765507489570855E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,  -6.9765507489570855E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,   6.9765507489570855E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,  -6.9765507489570855E-01,   5.4543462139056498E-01,   3.5517961009191232E-03],
            [   4.6451961235322931E-01,  -6.9765507489570855E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,   6.9765507489570855E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [  -4.6451961235322931E-01,  -6.9765507489570855E-01,  -5.4543462139056498E-01,   3.5517961009191232E-03],
            [   5.7487393131702524E-01,   4.9480635557033448E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,   4.9480635557033448E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,  -4.9480635557033448E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,   4.9480635557033448E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,  -4.9480635557033448E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,  -4.9480635557033448E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,   4.9480635557033448E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,  -4.9480635557033448E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,   5.7487393131702524E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,   5.7487393131702524E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,  -5.7487393131702524E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,   5.7487393131702524E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,  -5.7487393131702524E-01,   6.5167985512773974E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,  -5.7487393131702524E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,   5.7487393131702524E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,  -5.7487393131702524E-01,  -6.5167985512773974E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,   5.7487393131702524E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,   5.7487393131702524E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,  -5.7487393131702524E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,   5.7487393131702524E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,  -5.7487393131702524E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,  -5.7487393131702524E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,   5.7487393131702524E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,  -5.7487393131702524E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,   4.9480635557033448E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,   4.9480635557033448E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,  -4.9480635557033448E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,   4.9480635557033448E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,  -4.9480635557033448E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   6.5167985512773974E-01,  -4.9480635557033448E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,   4.9480635557033448E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -6.5167985512773974E-01,  -4.9480635557033448E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,   6.5167985512773974E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,   6.5167985512773974E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,  -6.5167985512773974E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,   6.5167985512773974E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,  -6.5167985512773974E-01,   4.9480635557033448E-01,   3.5600321140074579E-03],
            [   5.7487393131702524E-01,  -6.5167985512773974E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,   6.5167985512773974E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [  -5.7487393131702524E-01,  -6.5167985512773974E-01,  -4.9480635557033448E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,   6.5167985512773974E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,   6.5167985512773974E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,  -6.5167985512773974E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,   6.5167985512773974E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,  -6.5167985512773974E-01,   5.7487393131702524E-01,   3.5600321140074579E-03],
            [   4.9480635557033448E-01,  -6.5167985512773974E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,   6.5167985512773974E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [  -4.9480635557033448E-01,  -6.5167985512773974E-01,  -5.7487393131702524E-01,   3.5600321140074579E-03],
            [   1.5995987382863419E-01,   2.7923575900489848E-02,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,   2.7923575900489848E-02,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,  -2.7923575900489848E-02,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,   2.7923575900489848E-02,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,  -2.7923575900489848E-02,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,  -2.7923575900489848E-02,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,   2.7923575900489848E-02,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,  -2.7923575900489848E-02,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,   1.5995987382863419E-01,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,   1.5995987382863419E-01,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,  -1.5995987382863419E-01,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,   1.5995987382863419E-01,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,  -1.5995987382863419E-01,   9.8672848984594386E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,  -1.5995987382863419E-01,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,   1.5995987382863419E-01,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,  -1.5995987382863419E-01,  -9.8672848984594386E-01,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,   1.5995987382863419E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,   1.5995987382863419E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,  -1.5995987382863419E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,   1.5995987382863419E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,  -1.5995987382863419E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,  -1.5995987382863419E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,   1.5995987382863419E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,  -1.5995987382863419E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,   2.7923575900489848E-02,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,   2.7923575900489848E-02,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,  -2.7923575900489848E-02,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,   2.7923575900489848E-02,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,  -2.7923575900489848E-02,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   9.8672848984594386E-01,  -2.7923575900489848E-02,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,   2.7923575900489848E-02,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -9.8672848984594386E-01,  -2.7923575900489848E-02,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,   9.8672848984594386E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,   9.8672848984594386E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,  -9.8672848984594386E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,   9.8672848984594386E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,  -9.8672848984594386E-01,   2.7923575900489848E-02,   2.3708915709838890E-03],
            [   1.5995987382863419E-01,  -9.8672848984594386E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,   9.8672848984594386E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [  -1.5995987382863419E-01,  -9.8672848984594386E-01,  -2.7923575900489848E-02,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,   9.8672848984594386E-01,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,   9.8672848984594386E-01,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,  -9.8672848984594386E-01,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,   9.8672848984594386E-01,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,  -9.8672848984594386E-01,   1.5995987382863419E-01,   2.3708915709838890E-03],
            [   2.7923575900489848E-02,  -9.8672848984594386E-01,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,   9.8672848984594386E-01,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [  -2.7923575900489848E-02,  -9.8672848984594386E-01,  -1.5995987382863419E-01,   2.3708915709838890E-03],
            [   1.9980974125009510E-01,   5.8771410381390651E-02,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,   5.8771410381390651E-02,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,  -5.8771410381390651E-02,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,   5.8771410381390651E-02,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,  -5.8771410381390651E-02,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,  -5.8771410381390651E-02,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,   5.8771410381390651E-02,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,  -5.8771410381390651E-02,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,   1.9980974125009510E-01,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,   1.9980974125009510E-01,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,  -1.9980974125009510E-01,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,   1.9980974125009510E-01,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,  -1.9980974125009510E-01,   9.7807054378677216E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,  -1.9980974125009510E-01,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,   1.9980974125009510E-01,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,  -1.9980974125009510E-01,  -9.7807054378677216E-01,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,   1.9980974125009510E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,   1.9980974125009510E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,  -1.9980974125009510E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,   1.9980974125009510E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,  -1.9980974125009510E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,  -1.9980974125009510E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,   1.9980974125009510E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,  -1.9980974125009510E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,   5.8771410381390651E-02,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,   5.8771410381390651E-02,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,  -5.8771410381390651E-02,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,   5.8771410381390651E-02,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,  -5.8771410381390651E-02,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   9.7807054378677216E-01,  -5.8771410381390651E-02,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,   5.8771410381390651E-02,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -9.7807054378677216E-01,  -5.8771410381390651E-02,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,   9.7807054378677216E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,   9.7807054378677216E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,  -9.7807054378677216E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,   9.7807054378677216E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,  -9.7807054378677216E-01,   5.8771410381390651E-02,   2.6161523384745553E-03],
            [   1.9980974125009510E-01,  -9.7807054378677216E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,   9.7807054378677216E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [  -1.9980974125009510E-01,  -9.7807054378677216E-01,  -5.8771410381390651E-02,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,   9.7807054378677216E-01,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,   9.7807054378677216E-01,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,  -9.7807054378677216E-01,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,   9.7807054378677216E-01,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,  -9.7807054378677216E-01,   1.9980974125009510E-01,   2.6161523384745553E-03],
            [   5.8771410381390651E-02,  -9.7807054378677216E-01,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,   9.7807054378677216E-01,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [  -5.8771410381390651E-02,  -9.7807054378677216E-01,  -1.9980974125009510E-01,   2.6161523384745553E-03],
            [   2.3962289525662020E-01,   9.1645739146913777E-02,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,   9.1645739146913777E-02,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,  -9.1645739146913777E-02,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,   9.1645739146913777E-02,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,  -9.1645739146913777E-02,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,  -9.1645739146913777E-02,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,   9.1645739146913777E-02,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,  -9.1645739146913777E-02,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,   2.3962289525662020E-01,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,   2.3962289525662020E-01,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,  -2.3962289525662020E-01,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,   2.3962289525662020E-01,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,  -2.3962289525662020E-01,   9.6653087201860788E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,  -2.3962289525662020E-01,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,   2.3962289525662020E-01,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,  -2.3962289525662020E-01,  -9.6653087201860788E-01,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,   2.3962289525662020E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,   2.3962289525662020E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,  -2.3962289525662020E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,   2.3962289525662020E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,  -2.3962289525662020E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,  -2.3962289525662020E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,   2.3962289525662020E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,  -2.3962289525662020E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,   9.1645739146913777E-02,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,   9.1645739146913777E-02,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,  -9.1645739146913777E-02,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,   9.1645739146913777E-02,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,  -9.1645739146913777E-02,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.6653087201860788E-01,  -9.1645739146913777E-02,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,   9.1645739146913777E-02,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.6653087201860788E-01,  -9.1645739146913777E-02,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,   9.6653087201860788E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,   9.6653087201860788E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,  -9.6653087201860788E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,   9.6653087201860788E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,  -9.6653087201860788E-01,   9.1645739146913777E-02,   2.8213370404769110E-03],
            [   2.3962289525662020E-01,  -9.6653087201860788E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,   9.6653087201860788E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [  -2.3962289525662020E-01,  -9.6653087201860788E-01,  -9.1645739146913777E-02,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,   9.6653087201860788E-01,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,   9.6653087201860788E-01,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,  -9.6653087201860788E-01,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,   9.6653087201860788E-01,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,  -9.6653087201860788E-01,   2.3962289525662020E-01,   2.8213370404769110E-03],
            [   9.1645739146913777E-02,  -9.6653087201860788E-01,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,   9.6653087201860788E-01,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [  -9.1645739146913777E-02,  -9.6653087201860788E-01,  -2.3962289525662020E-01,   2.8213370404769110E-03],
            [   2.7922283410977461E-01,   1.2590496419626870E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,   1.2590496419626870E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,  -1.2590496419626870E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,   1.2590496419626870E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,  -1.2590496419626870E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,  -1.2590496419626870E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,   1.2590496419626870E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,  -1.2590496419626870E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,   2.7922283410977461E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,   2.7922283410977461E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,  -2.7922283410977461E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,   2.7922283410977461E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,  -2.7922283410977461E-01,   9.5193621052171429E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,  -2.7922283410977461E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,   2.7922283410977461E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,  -2.7922283410977461E-01,  -9.5193621052171429E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,   2.7922283410977461E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,   2.7922283410977461E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,  -2.7922283410977461E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,   2.7922283410977461E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,  -2.7922283410977461E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,  -2.7922283410977461E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,   2.7922283410977461E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,  -2.7922283410977461E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,   1.2590496419626870E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,   1.2590496419626870E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,  -1.2590496419626870E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,   1.2590496419626870E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,  -1.2590496419626870E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   9.5193621052171429E-01,  -1.2590496419626870E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,   1.2590496419626870E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -9.5193621052171429E-01,  -1.2590496419626870E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,   9.5193621052171429E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,   9.5193621052171429E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,  -9.5193621052171429E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,   9.5193621052171429E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,  -9.5193621052171429E-01,   1.2590496419626870E-01,   2.9912617795822488E-03],
            [   2.7922283410977461E-01,  -9.5193621052171429E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,   9.5193621052171429E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [  -2.7922283410977461E-01,  -9.5193621052171429E-01,  -1.2590496419626870E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,   9.5193621052171429E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,   9.5193621052171429E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,  -9.5193621052171429E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,   9.5193621052171429E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,  -9.5193621052171429E-01,   2.7922283410977461E-01,   2.9912617795822488E-03],
            [   1.2590496419626870E-01,  -9.5193621052171429E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,   9.5193621052171429E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [  -1.2590496419626870E-01,  -9.5193621052171429E-01,  -2.7922283410977461E-01,   2.9912617795822488E-03],
            [   3.1842511075467411E-01,   1.6105948234008630E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,   1.6105948234008630E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,  -1.6105948234008630E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,   1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,  -1.6105948234008630E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,  -1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,   1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,  -1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,   3.1842511075467411E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,   3.1842511075467411E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,  -3.1842511075467411E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,   3.1842511075467411E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,  -3.1842511075467411E-01,   9.3416555919666455E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,  -3.1842511075467411E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,   3.1842511075467411E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,  -3.1842511075467411E-01,  -9.3416555919666455E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,   3.1842511075467411E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,   3.1842511075467411E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,  -3.1842511075467411E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,   3.1842511075467411E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,  -3.1842511075467411E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,  -3.1842511075467411E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,   3.1842511075467411E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,  -3.1842511075467411E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,   1.6105948234008630E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,   1.6105948234008630E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,   1.6105948234008630E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   9.3416555919666455E-01,  -1.6105948234008630E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,   1.6105948234008630E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -9.3416555919666455E-01,  -1.6105948234008630E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,   9.3416555919666455E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,   9.3416555919666455E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,  -9.3416555919666455E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,   9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,  -9.3416555919666455E-01,   1.6105948234008630E-01,   3.1307831141806678E-03],
            [   3.1842511075467411E-01,  -9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,   9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [  -3.1842511075467411E-01,  -9.3416555919666455E-01,  -1.6105948234008630E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,   9.3416555919666455E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,   9.3416555919666455E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,   9.3416555919666455E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,  -9.3416555919666455E-01,   3.1842511075467411E-01,   3.1307831141806678E-03],
            [   1.6105948234008630E-01,  -9.3416555919666455E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,   9.3416555919666455E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [  -1.6105948234008630E-01,  -9.3416555919666455E-01,  -3.1842511075467411E-01,   3.1307831141806678E-03],
            [   3.5704811644262441E-01,   1.9671516534608979E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,   1.9671516534608979E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,  -1.9671516534608979E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,   1.9671516534608979E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,  -1.9671516534608979E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,  -1.9671516534608979E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,   1.9671516534608979E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,  -1.9671516534608979E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,   3.5704811644262441E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,   3.5704811644262441E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,  -3.5704811644262441E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,   3.5704811644262441E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,  -3.5704811644262441E-01,   9.1313733154856536E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,  -3.5704811644262441E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,   3.5704811644262441E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,  -3.5704811644262441E-01,  -9.1313733154856536E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,   3.5704811644262441E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,   3.5704811644262441E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,  -3.5704811644262441E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,   3.5704811644262441E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,  -3.5704811644262441E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,  -3.5704811644262441E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,   3.5704811644262441E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,  -3.5704811644262441E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,   1.9671516534608979E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,   1.9671516534608979E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,  -1.9671516534608979E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,   1.9671516534608979E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,  -1.9671516534608979E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   9.1313733154856536E-01,  -1.9671516534608979E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,   1.9671516534608979E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -9.1313733154856536E-01,  -1.9671516534608979E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,   9.1313733154856536E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,   9.1313733154856536E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,  -9.1313733154856536E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,   9.1313733154856536E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,  -9.1313733154856536E-01,   1.9671516534608979E-01,   3.2441749602343259E-03],
            [   3.5704811644262441E-01,  -9.1313733154856536E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,   9.1313733154856536E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [  -3.5704811644262441E-01,  -9.1313733154856536E-01,  -1.9671516534608979E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,   9.1313733154856536E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,   9.1313733154856536E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,  -9.1313733154856536E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,   9.1313733154856536E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,  -9.1313733154856536E-01,   3.5704811644262441E-01,   3.2441749602343259E-03],
            [   1.9671516534608979E-01,  -9.1313733154856536E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,   9.1313733154856536E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [  -1.9671516534608979E-01,  -9.1313733154856536E-01,  -3.5704811644262441E-01,   3.2441749602343259E-03],
            [   3.9491647104921440E-01,   2.3254046061751679E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,   2.3254046061751679E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,  -2.3254046061751679E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,   2.3254046061751679E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,  -2.3254046061751679E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,  -2.3254046061751679E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,   2.3254046061751679E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,  -2.3254046061751679E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,   3.9491647104921440E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,   3.9491647104921440E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,  -3.9491647104921440E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,   3.9491647104921440E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,  -3.9491647104921440E-01,   8.8880026725346351E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,  -3.9491647104921440E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,   3.9491647104921440E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,  -3.9491647104921440E-01,  -8.8880026725346351E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,   3.9491647104921440E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,   3.9491647104921440E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,  -3.9491647104921440E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,   3.9491647104921440E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,  -3.9491647104921440E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,  -3.9491647104921440E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,   3.9491647104921440E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,  -3.9491647104921440E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,   2.3254046061751679E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,   2.3254046061751679E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,  -2.3254046061751679E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,   2.3254046061751679E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,  -2.3254046061751679E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   8.8880026725346351E-01,  -2.3254046061751679E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,   2.3254046061751679E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -8.8880026725346351E-01,  -2.3254046061751679E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,   8.8880026725346351E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,   8.8880026725346351E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,  -8.8880026725346351E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,   8.8880026725346351E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,  -8.8880026725346351E-01,   2.3254046061751679E-01,   3.3350714148979075E-03],
            [   3.9491647104921440E-01,  -8.8880026725346351E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,   8.8880026725346351E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [  -3.9491647104921440E-01,  -8.8880026725346351E-01,  -2.3254046061751679E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,   8.8880026725346351E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,   8.8880026725346351E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,  -8.8880026725346351E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,   8.8880026725346351E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,  -8.8880026725346351E-01,   3.9491647104921440E-01,   3.3350714148979075E-03],
            [   2.3254046061751679E-01,  -8.8880026725346351E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,   8.8880026725346351E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [  -2.3254046061751679E-01,  -8.8880026725346351E-01,  -3.9491647104921440E-01,   3.3350714148979075E-03],
            [   4.3186172939705031E-01,   2.6824611411514387E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,   2.6824611411514387E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,  -2.6824611411514387E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,   2.6824611411514387E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,  -2.6824611411514387E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,  -2.6824611411514387E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,   2.6824611411514387E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,  -2.6824611411514387E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,   4.3186172939705031E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,   4.3186172939705031E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,  -4.3186172939705031E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,   4.3186172939705031E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,  -4.3186172939705031E-01,   8.6112685995985172E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,  -4.3186172939705031E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,   4.3186172939705031E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,  -4.3186172939705031E-01,  -8.6112685995985172E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,   4.3186172939705031E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,   4.3186172939705031E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,  -4.3186172939705031E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,   4.3186172939705031E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,  -4.3186172939705031E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,  -4.3186172939705031E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,   4.3186172939705031E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,  -4.3186172939705031E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,   2.6824611411514387E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,   2.6824611411514387E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,  -2.6824611411514387E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,   2.6824611411514387E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,  -2.6824611411514387E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   8.6112685995985172E-01,  -2.6824611411514387E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,   2.6824611411514387E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -8.6112685995985172E-01,  -2.6824611411514387E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,   8.6112685995985172E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,   8.6112685995985172E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,  -8.6112685995985172E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,   8.6112685995985172E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,  -8.6112685995985172E-01,   2.6824611411514387E-01,   3.4065636468254092E-03],
            [   4.3186172939705031E-01,  -8.6112685995985172E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,   8.6112685995985172E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [  -4.3186172939705031E-01,  -8.6112685995985172E-01,  -2.6824611411514387E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,   8.6112685995985172E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,   8.6112685995985172E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,  -8.6112685995985172E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,   8.6112685995985172E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,  -8.6112685995985172E-01,   4.3186172939705031E-01,   3.4065636468254092E-03],
            [   2.6824611411514387E-01,  -8.6112685995985172E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,   8.6112685995985172E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [  -2.6824611411514387E-01,  -8.6112685995985172E-01,  -4.3186172939705031E-01,   3.4065636468254092E-03],
            [   4.6772210099316780E-01,   3.0357201160119729E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,   3.0357201160119729E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,  -3.0357201160119729E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,   3.0357201160119729E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,  -3.0357201160119729E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,  -3.0357201160119729E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,   3.0357201160119729E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,  -3.0357201160119729E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,   4.6772210099316780E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,   4.6772210099316780E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,  -4.6772210099316780E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,   4.6772210099316780E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,  -4.6772210099316780E-01,   8.3010846882497191E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,  -4.6772210099316780E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,   4.6772210099316780E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,  -4.6772210099316780E-01,  -8.3010846882497191E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,   4.6772210099316780E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,   4.6772210099316780E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,  -4.6772210099316780E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,   4.6772210099316780E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,  -4.6772210099316780E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,  -4.6772210099316780E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,   4.6772210099316780E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,  -4.6772210099316780E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,   3.0357201160119729E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,   3.0357201160119729E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,  -3.0357201160119729E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,   3.0357201160119729E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,  -3.0357201160119729E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   8.3010846882497191E-01,  -3.0357201160119729E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,   3.0357201160119729E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -8.3010846882497191E-01,  -3.0357201160119729E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,   8.3010846882497191E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,   8.3010846882497191E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,  -8.3010846882497191E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,   8.3010846882497191E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,  -8.3010846882497191E-01,   3.0357201160119729E-01,   3.4613239656819976E-03],
            [   4.6772210099316780E-01,  -8.3010846882497191E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,   8.3010846882497191E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [  -4.6772210099316780E-01,  -8.3010846882497191E-01,  -3.0357201160119729E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,   8.3010846882497191E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,   8.3010846882497191E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,  -8.3010846882497191E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,   8.3010846882497191E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,  -8.3010846882497191E-01,   4.6772210099316780E-01,   3.4613239656819976E-03],
            [   3.0357201160119729E-01,  -8.3010846882497191E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,   8.3010846882497191E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [  -3.0357201160119729E-01,  -8.3010846882497191E-01,  -4.6772210099316780E-01,   3.4613239656819976E-03],
            [   5.0234179392709555E-01,   3.3827818591974390E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,   3.3827818591974390E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,  -3.3827818591974390E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,   3.3827818591974390E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,  -3.3827818591974390E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,  -3.3827818591974390E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,   3.3827818591974390E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,  -3.3827818591974390E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,   5.0234179392709555E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,   5.0234179392709555E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,  -5.0234179392709555E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,   5.0234179392709555E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,  -5.0234179392709555E-01,   7.9575158875427621E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,  -5.0234179392709555E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,   5.0234179392709555E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,  -5.0234179392709555E-01,  -7.9575158875427621E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,   5.0234179392709555E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,   5.0234179392709555E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,  -5.0234179392709555E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,   5.0234179392709555E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,  -5.0234179392709555E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,  -5.0234179392709555E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,   5.0234179392709555E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,  -5.0234179392709555E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,   3.3827818591974390E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,   3.3827818591974390E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,  -3.3827818591974390E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,   3.3827818591974390E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,  -3.3827818591974390E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   7.9575158875427621E-01,  -3.3827818591974390E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,   3.3827818591974390E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -7.9575158875427621E-01,  -3.3827818591974390E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,   7.9575158875427621E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,   7.9575158875427621E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,  -7.9575158875427621E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,   7.9575158875427621E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,  -7.9575158875427621E-01,   3.3827818591974390E-01,   3.5017196178574505E-03],
            [   5.0234179392709555E-01,  -7.9575158875427621E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,   7.9575158875427621E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [  -5.0234179392709555E-01,  -7.9575158875427621E-01,  -3.3827818591974390E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,   7.9575158875427621E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,   7.9575158875427621E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,  -7.9575158875427621E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,   7.9575158875427621E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,  -7.9575158875427621E-01,   5.0234179392709555E-01,   3.5017196178574505E-03],
            [   3.3827818591974390E-01,  -7.9575158875427621E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,   7.9575158875427621E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [  -3.3827818591974390E-01,  -7.9575158875427621E-01,  -5.0234179392709555E-01,   3.5017196178574505E-03],
            [   5.3557018366361275E-01,   3.7213830656259422E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,   3.7213830656259422E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,  -3.7213830656259422E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,   3.7213830656259422E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,  -3.7213830656259422E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,  -3.7213830656259422E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,   3.7213830656259422E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,  -3.7213830656259422E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,   5.3557018366361275E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,   5.3557018366361275E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,  -5.3557018366361275E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,   5.3557018366361275E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,  -5.3557018366361275E-01,   7.5807496935279994E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,  -5.3557018366361275E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,   5.3557018366361275E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,  -5.3557018366361275E-01,  -7.5807496935279994E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,   5.3557018366361275E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,   5.3557018366361275E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,  -5.3557018366361275E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,   5.3557018366361275E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,  -5.3557018366361275E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,  -5.3557018366361275E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,   5.3557018366361275E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,  -5.3557018366361275E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,   3.7213830656259422E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,   3.7213830656259422E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,  -3.7213830656259422E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,   3.7213830656259422E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,  -3.7213830656259422E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   7.5807496935279994E-01,  -3.7213830656259422E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,   3.7213830656259422E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -7.5807496935279994E-01,  -3.7213830656259422E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,   7.5807496935279994E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,   7.5807496935279994E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,  -7.5807496935279994E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,   7.5807496935279994E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,  -7.5807496935279994E-01,   3.7213830656259422E-01,   3.5299074299659844E-03],
            [   5.3557018366361275E-01,  -7.5807496935279994E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,   7.5807496935279994E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [  -5.3557018366361275E-01,  -7.5807496935279994E-01,  -3.7213830656259422E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,   7.5807496935279994E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,   7.5807496935279994E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,  -7.5807496935279994E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,   7.5807496935279994E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,  -7.5807496935279994E-01,   5.3557018366361275E-01,   3.5299074299659844E-03],
            [   3.7213830656259422E-01,  -7.5807496935279994E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,   7.5807496935279994E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [  -3.7213830656259422E-01,  -7.5807496935279994E-01,  -5.3557018366361275E-01,   3.5299074299659844E-03],
            [   5.6726084513287711E-01,   4.0493463604660551E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,   4.0493463604660551E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,  -4.0493463604660551E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,   4.0493463604660551E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,  -4.0493463604660551E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,  -4.0493463604660551E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,   4.0493463604660551E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,  -4.0493463604660551E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,   5.6726084513287711E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,   5.6726084513287711E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,  -5.6726084513287711E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,   5.6726084513287711E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,  -5.6726084513287711E-01,   7.1710743554152123E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,  -5.6726084513287711E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,   5.6726084513287711E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,  -5.6726084513287711E-01,  -7.1710743554152123E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,   5.6726084513287711E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,   5.6726084513287711E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,  -5.6726084513287711E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,   5.6726084513287711E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,  -5.6726084513287711E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,  -5.6726084513287711E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,   5.6726084513287711E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,  -5.6726084513287711E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,   4.0493463604660551E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,   4.0493463604660551E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,  -4.0493463604660551E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,   4.0493463604660551E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,  -4.0493463604660551E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   7.1710743554152123E-01,  -4.0493463604660551E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,   4.0493463604660551E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -7.1710743554152123E-01,  -4.0493463604660551E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,   7.1710743554152123E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,   7.1710743554152123E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,  -7.1710743554152123E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,   7.1710743554152123E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,  -7.1710743554152123E-01,   4.0493463604660551E-01,   3.5479088864124129E-03],
            [   5.6726084513287711E-01,  -7.1710743554152123E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,   7.1710743554152123E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [  -5.6726084513287711E-01,  -7.1710743554152123E-01,  -4.0493463604660551E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,   7.1710743554152123E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,   7.1710743554152123E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,  -7.1710743554152123E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,   7.1710743554152123E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,  -7.1710743554152123E-01,   5.6726084513287711E-01,   3.5479088864124129E-03],
            [   4.0493463604660551E-01,  -7.1710743554152123E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,   7.1710743554152123E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [  -4.0493463604660551E-01,  -7.1710743554152123E-01,  -5.6726084513287711E-01,   3.5479088864124129E-03],
            [   5.9727042025401622E-01,   4.3645380986338023E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,   4.3645380986338023E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,  -4.3645380986338023E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,   4.3645380986338023E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,  -4.3645380986338023E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,  -4.3645380986338023E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,   4.3645380986338023E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,  -4.3645380986338023E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,   5.9727042025401622E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,   5.9727042025401622E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,  -5.9727042025401622E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,   5.9727042025401622E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,  -5.9727042025401622E-01,   6.7288640716344628E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,  -5.9727042025401622E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,   5.9727042025401622E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,  -5.9727042025401622E-01,  -6.7288640716344628E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,   5.9727042025401622E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,   5.9727042025401622E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,  -5.9727042025401622E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,   5.9727042025401622E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,  -5.9727042025401622E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,  -5.9727042025401622E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,   5.9727042025401622E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,  -5.9727042025401622E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,   4.3645380986338023E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,   4.3645380986338023E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,  -4.3645380986338023E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,   4.3645380986338023E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,  -4.3645380986338023E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   6.7288640716344628E-01,  -4.3645380986338023E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,   4.3645380986338023E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -6.7288640716344628E-01,  -4.3645380986338023E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,   6.7288640716344628E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,   6.7288640716344628E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,  -6.7288640716344628E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,   6.7288640716344628E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,  -6.7288640716344628E-01,   4.3645380986338023E-01,   3.5576666621930102E-03],
            [   5.9727042025401622E-01,  -6.7288640716344628E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,   6.7288640716344628E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [  -5.9727042025401622E-01,  -6.7288640716344628E-01,  -4.3645380986338023E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,   6.7288640716344628E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,   6.7288640716344628E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,  -6.7288640716344628E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,   6.7288640716344628E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,  -6.7288640716344628E-01,   5.9727042025401622E-01,   3.5576666621930102E-03],
            [   4.3645380986338023E-01,  -6.7288640716344628E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,   6.7288640716344628E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [  -4.3645380986338023E-01,  -6.7288640716344628E-01,  -5.9727042025401622E-01,   3.5576666621930102E-03],
            [   2.4616870223335960E-01,   3.0704231668333679E-02,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,   3.0704231668333679E-02,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,  -3.0704231668333679E-02,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,   3.0704231668333679E-02,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,  -3.0704231668333679E-02,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,  -3.0704231668333679E-02,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,   3.0704231668333679E-02,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,  -3.0704231668333679E-02,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,   2.4616870223335960E-01,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,   2.4616870223335960E-01,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,  -2.4616870223335960E-01,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,   2.4616870223335960E-01,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,  -2.4616870223335960E-01,   9.6874053295936824E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,  -2.4616870223335960E-01,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,   2.4616870223335960E-01,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,  -2.4616870223335960E-01,  -9.6874053295936824E-01,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,   2.4616870223335960E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,   2.4616870223335960E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,  -2.4616870223335960E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,   2.4616870223335960E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,  -2.4616870223335960E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,  -2.4616870223335960E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,   2.4616870223335960E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,  -2.4616870223335960E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,   3.0704231668333679E-02,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,   3.0704231668333679E-02,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,  -3.0704231668333679E-02,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,   3.0704231668333679E-02,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,  -3.0704231668333679E-02,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   9.6874053295936824E-01,  -3.0704231668333679E-02,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,   3.0704231668333679E-02,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -9.6874053295936824E-01,  -3.0704231668333679E-02,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,   9.6874053295936824E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,   9.6874053295936824E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,  -9.6874053295936824E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,   9.6874053295936824E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,  -9.6874053295936824E-01,   3.0704231668333679E-02,   2.7918453893973727E-03],
            [   2.4616870223335960E-01,  -9.6874053295936824E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,   9.6874053295936824E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [  -2.4616870223335960E-01,  -9.6874053295936824E-01,  -3.0704231668333679E-02,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,   9.6874053295936824E-01,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,   9.6874053295936824E-01,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,  -9.6874053295936824E-01,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,   9.6874053295936824E-01,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,  -9.6874053295936824E-01,   2.4616870223335960E-01,   2.7918453893973727E-03],
            [   3.0704231668333679E-02,  -9.6874053295936824E-01,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,   9.6874053295936824E-01,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [  -3.0704231668333679E-02,  -9.6874053295936824E-01,  -2.4616870223335960E-01,   2.7918453893973727E-03],
            [   2.8817745662868310E-01,   6.3380346692818848E-02,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,   6.3380346692818848E-02,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,  -6.3380346692818848E-02,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,   6.3380346692818848E-02,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,  -6.3380346692818848E-02,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,  -6.3380346692818848E-02,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,   6.3380346692818848E-02,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,  -6.3380346692818848E-02,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,   2.8817745662868310E-01,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,   2.8817745662868310E-01,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,  -2.8817745662868310E-01,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,   2.8817745662868310E-01,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,  -2.8817745662868310E-01,   9.5547720283851956E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,  -2.8817745662868310E-01,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,   2.8817745662868310E-01,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,  -2.8817745662868310E-01,  -9.5547720283851956E-01,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,   2.8817745662868310E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,   2.8817745662868310E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,  -2.8817745662868310E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,   2.8817745662868310E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,  -2.8817745662868310E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,  -2.8817745662868310E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,   2.8817745662868310E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,  -2.8817745662868310E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,   6.3380346692818848E-02,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,   6.3380346692818848E-02,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,  -6.3380346692818848E-02,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,   6.3380346692818848E-02,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,  -6.3380346692818848E-02,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   9.5547720283851956E-01,  -6.3380346692818848E-02,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,   6.3380346692818848E-02,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -9.5547720283851956E-01,  -6.3380346692818848E-02,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,   9.5547720283851956E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,   9.5547720283851956E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,  -9.5547720283851956E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,   9.5547720283851956E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,  -9.5547720283851956E-01,   6.3380346692818848E-02,   2.9608703173111652E-03],
            [   2.8817745662868310E-01,  -9.5547720283851956E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,   9.5547720283851956E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [  -2.8817745662868310E-01,  -9.5547720283851956E-01,  -6.3380346692818848E-02,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,   9.5547720283851956E-01,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,   9.5547720283851956E-01,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,  -9.5547720283851956E-01,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,   9.5547720283851956E-01,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,  -9.5547720283851956E-01,   2.8817745662868310E-01,   2.9608703173111652E-03],
            [   6.3380346692818848E-02,  -9.5547720283851956E-01,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,   9.5547720283851956E-01,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [  -6.3380346692818848E-02,  -9.5547720283851956E-01,  -2.8817745662868310E-01,   2.9608703173111652E-03],
            [   3.2939636041169779E-01,   9.7428624870679409E-02,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,   9.7428624870679409E-02,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,  -9.7428624870679409E-02,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,   9.7428624870679409E-02,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,  -9.7428624870679409E-02,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,  -9.7428624870679409E-02,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,   9.7428624870679409E-02,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,  -9.7428624870679409E-02,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,   3.2939636041169779E-01,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,   3.2939636041169779E-01,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,  -3.2939636041169779E-01,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,   3.2939636041169779E-01,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,  -3.2939636041169779E-01,   9.3915158563638457E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,  -3.2939636041169779E-01,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,   3.2939636041169779E-01,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,  -3.2939636041169779E-01,  -9.3915158563638457E-01,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,   3.2939636041169779E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,   3.2939636041169779E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,  -3.2939636041169779E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,   3.2939636041169779E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,  -3.2939636041169779E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,  -3.2939636041169779E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,   3.2939636041169779E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,  -3.2939636041169779E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,   9.7428624870679409E-02,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,   9.7428624870679409E-02,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,  -9.7428624870679409E-02,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,   9.7428624870679409E-02,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,  -9.7428624870679409E-02,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.3915158563638457E-01,  -9.7428624870679409E-02,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,   9.7428624870679409E-02,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.3915158563638457E-01,  -9.7428624870679409E-02,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,   9.3915158563638457E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,   9.3915158563638457E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,  -9.3915158563638457E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,   9.3915158563638457E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,  -9.3915158563638457E-01,   9.7428624870679409E-02,   3.1029238512307704E-03],
            [   3.2939636041169779E-01,  -9.3915158563638457E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,   9.3915158563638457E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [  -3.2939636041169779E-01,  -9.3915158563638457E-01,  -9.7428624870679409E-02,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,   9.3915158563638457E-01,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,   9.3915158563638457E-01,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,  -9.3915158563638457E-01,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,   9.3915158563638457E-01,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,  -9.3915158563638457E-01,   3.2939636041169779E-01,   3.1029238512307704E-03],
            [   9.7428624870679409E-02,  -9.3915158563638457E-01,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,   9.3915158563638457E-01,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [  -9.7428624870679409E-02,  -9.3915158563638457E-01,  -3.2939636041169779E-01,   3.1029238512307704E-03],
            [   3.6973038222413768E-01,   1.3237995322822901E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,   1.3237995322822901E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,  -1.3237995322822901E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,   1.3237995322822901E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,  -1.3237995322822901E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,  -1.3237995322822901E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,   1.3237995322822901E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,  -1.3237995322822901E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,   3.6973038222413768E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,   3.6973038222413768E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,  -3.6973038222413768E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,   3.6973038222413768E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,  -3.6973038222413768E-01,   9.1966025924994987E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,  -3.6973038222413768E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,   3.6973038222413768E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,  -3.6973038222413768E-01,  -9.1966025924994987E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,   3.6973038222413768E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,   3.6973038222413768E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,  -3.6973038222413768E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,   3.6973038222413768E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,  -3.6973038222413768E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,  -3.6973038222413768E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,   3.6973038222413768E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,  -3.6973038222413768E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,   1.3237995322822901E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,   1.3237995322822901E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,  -1.3237995322822901E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,   1.3237995322822901E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,  -1.3237995322822901E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   9.1966025924994987E-01,  -1.3237995322822901E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,   1.3237995322822901E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -9.1966025924994987E-01,  -1.3237995322822901E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,   9.1966025924994987E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,   9.1966025924994987E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,  -9.1966025924994987E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,   9.1966025924994987E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,  -9.1966025924994987E-01,   1.3237995322822901E-01,   3.2204169080219387E-03],
            [   3.6973038222413768E-01,  -9.1966025924994987E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,   9.1966025924994987E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [  -3.6973038222413768E-01,  -9.1966025924994987E-01,  -1.3237995322822901E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,   9.1966025924994987E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,   9.1966025924994987E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,  -9.1966025924994987E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,   9.1966025924994987E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,  -9.1966025924994987E-01,   3.6973038222413768E-01,   3.2204169080219387E-03],
            [   1.3237995322822901E-01,  -9.1966025924994987E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,   9.1966025924994987E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [  -1.3237995322822901E-01,  -9.1966025924994987E-01,  -3.6973038222413768E-01,   3.2204169080219387E-03],
            [   4.0906630231351271E-01,   1.6784970181293360E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,   1.6784970181293360E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,  -1.6784970181293360E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,   1.6784970181293360E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,  -1.6784970181293360E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,  -1.6784970181293360E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,   1.6784970181293360E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,  -1.6784970181293360E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,   4.0906630231351271E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,   4.0906630231351271E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,  -4.0906630231351271E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,   4.0906630231351271E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,  -4.0906630231351271E-01,   8.9693435540894462E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,  -4.0906630231351271E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,   4.0906630231351271E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,  -4.0906630231351271E-01,  -8.9693435540894462E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,   4.0906630231351271E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,   4.0906630231351271E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,  -4.0906630231351271E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,   4.0906630231351271E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,  -4.0906630231351271E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,  -4.0906630231351271E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,   4.0906630231351271E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,  -4.0906630231351271E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,   1.6784970181293360E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,   1.6784970181293360E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,  -1.6784970181293360E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,   1.6784970181293360E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,  -1.6784970181293360E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   8.9693435540894462E-01,  -1.6784970181293360E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,   1.6784970181293360E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -8.9693435540894462E-01,  -1.6784970181293360E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,   8.9693435540894462E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,   8.9693435540894462E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,  -8.9693435540894462E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,   8.9693435540894462E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,  -8.9693435540894462E-01,   1.6784970181293360E-01,   3.3159594989511845E-03],
            [   4.0906630231351271E-01,  -8.9693435540894462E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,   8.9693435540894462E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [  -4.0906630231351271E-01,  -8.9693435540894462E-01,  -1.6784970181293360E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,   8.9693435540894462E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,   8.9693435540894462E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,  -8.9693435540894462E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,   8.9693435540894462E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,  -8.9693435540894462E-01,   4.0906630231351271E-01,   3.3159594989511845E-03],
            [   1.6784970181293360E-01,  -8.9693435540894462E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,   8.9693435540894462E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [  -1.6784970181293360E-01,  -8.9693435540894462E-01,  -4.0906630231351271E-01,   3.3159594989511845E-03],
            [   4.4728193554117118E-01,   2.0350951053261140E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,   2.0350951053261140E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,  -2.0350951053261140E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,   2.0350951053261140E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,  -2.0350951053261140E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,  -2.0350951053261140E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,   2.0350951053261140E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,  -2.0350951053261140E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,   4.4728193554117118E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,   4.4728193554117118E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,  -4.4728193554117118E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,   4.4728193554117118E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,  -4.4728193554117118E-01,   8.7093211518540325E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,  -4.4728193554117118E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,   4.4728193554117118E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,  -4.4728193554117118E-01,  -8.7093211518540325E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,   4.4728193554117118E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,   4.4728193554117118E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,  -4.4728193554117118E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,   4.4728193554117118E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,  -4.4728193554117118E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,  -4.4728193554117118E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,   4.4728193554117118E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,  -4.4728193554117118E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,   2.0350951053261140E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,   2.0350951053261140E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,  -2.0350951053261140E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,   2.0350951053261140E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,  -2.0350951053261140E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   8.7093211518540325E-01,  -2.0350951053261140E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,   2.0350951053261140E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -8.7093211518540325E-01,  -2.0350951053261140E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,   8.7093211518540325E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,   8.7093211518540325E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,  -8.7093211518540325E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,   8.7093211518540325E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,  -8.7093211518540325E-01,   2.0350951053261140E-01,   3.3920544407248371E-03],
            [   4.4728193554117118E-01,  -8.7093211518540325E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,   8.7093211518540325E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [  -4.4728193554117118E-01,  -8.7093211518540325E-01,  -2.0350951053261140E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,   8.7093211518540325E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,   8.7093211518540325E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,  -8.7093211518540325E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,   8.7093211518540325E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,  -8.7093211518540325E-01,   4.4728193554117118E-01,   3.3920544407248371E-03],
            [   2.0350951053261140E-01,  -8.7093211518540325E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,   8.7093211518540325E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [  -2.0350951053261140E-01,  -8.7093211518540325E-01,  -4.4728193554117118E-01,   3.3920544407248371E-03],
            [   4.8425133772314372E-01,   2.3906925666720910E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,   2.3906925666720910E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,  -2.3906925666720910E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,   2.3906925666720910E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,  -2.3906925666720910E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,  -2.3906925666720910E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,   2.3906925666720910E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,  -2.3906925666720910E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,   4.8425133772314372E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,   4.8425133772314372E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,  -4.8425133772314372E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,   4.8425133772314372E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,  -4.8425133772314372E-01,   8.4163325292548530E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,  -4.8425133772314372E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,   4.8425133772314372E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,  -4.8425133772314372E-01,  -8.4163325292548530E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,   4.8425133772314372E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,   4.8425133772314372E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,  -4.8425133772314372E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,   4.8425133772314372E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,  -4.8425133772314372E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,  -4.8425133772314372E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,   4.8425133772314372E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,  -4.8425133772314372E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,   2.3906925666720910E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,   2.3906925666720910E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,  -2.3906925666720910E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,   2.3906925666720910E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,  -2.3906925666720910E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   8.4163325292548530E-01,  -2.3906925666720910E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,   2.3906925666720910E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -8.4163325292548530E-01,  -2.3906925666720910E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,   8.4163325292548530E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,   8.4163325292548530E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,  -8.4163325292548530E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,   8.4163325292548530E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,  -8.4163325292548530E-01,   2.3906925666720910E-01,   3.4510185044245522E-03],
            [   4.8425133772314372E-01,  -8.4163325292548530E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,   8.4163325292548530E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [  -4.8425133772314372E-01,  -8.4163325292548530E-01,  -2.3906925666720910E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,   8.4163325292548530E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,   8.4163325292548530E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,  -8.4163325292548530E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,   8.4163325292548530E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,  -8.4163325292548530E-01,   4.8425133772314372E-01,   3.4510185044245522E-03],
            [   2.3906925666720910E-01,  -8.4163325292548530E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,   8.4163325292548530E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [  -2.3906925666720910E-01,  -8.4163325292548530E-01,  -4.8425133772314372E-01,   3.4510185044245522E-03],
            [   5.1984776299629276E-01,   2.7426498180761488E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,   2.7426498180761488E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,  -2.7426498180761488E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,   2.7426498180761488E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,  -2.7426498180761488E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,  -2.7426498180761488E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,   2.7426498180761488E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,  -2.7426498180761488E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,   5.1984776299629276E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,   5.1984776299629276E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,  -5.1984776299629276E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,   5.1984776299629276E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,  -5.1984776299629276E-01,   8.0903462414276117E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,  -5.1984776299629276E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,   5.1984776299629276E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,  -5.1984776299629276E-01,  -8.0903462414276117E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,   5.1984776299629276E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,   5.1984776299629276E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,  -5.1984776299629276E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,   5.1984776299629276E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,  -5.1984776299629276E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,  -5.1984776299629276E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,   5.1984776299629276E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,  -5.1984776299629276E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,   2.7426498180761488E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,   2.7426498180761488E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,  -2.7426498180761488E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,   2.7426498180761488E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,  -2.7426498180761488E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   8.0903462414276117E-01,  -2.7426498180761488E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,   2.7426498180761488E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -8.0903462414276117E-01,  -2.7426498180761488E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,   8.0903462414276117E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,   8.0903462414276117E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,  -8.0903462414276117E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,   8.0903462414276117E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,  -8.0903462414276117E-01,   2.7426498180761488E-01,   3.4949912587369705E-03],
            [   5.1984776299629276E-01,  -8.0903462414276117E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,   8.0903462414276117E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [  -5.1984776299629276E-01,  -8.0903462414276117E-01,  -2.7426498180761488E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,   8.0903462414276117E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,   8.0903462414276117E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,  -8.0903462414276117E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,   8.0903462414276117E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,  -8.0903462414276117E-01,   5.1984776299629276E-01,   3.4949912587369705E-03],
            [   2.7426498180761488E-01,  -8.0903462414276117E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,   8.0903462414276117E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [  -2.7426498180761488E-01,  -8.0903462414276117E-01,  -5.1984776299629276E-01,   3.4949912587369705E-03],
            [   5.5394530118831453E-01,   3.0885038065800940E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,   3.0885038065800940E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,  -3.0885038065800940E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,   3.0885038065800940E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,  -3.0885038065800940E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,  -3.0885038065800940E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,   3.0885038065800940E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,  -3.0885038065800940E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,   5.5394530118831453E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,   5.5394530118831453E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,  -5.5394530118831453E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,   5.5394530118831453E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,  -5.5394530118831453E-01,   7.7314684611578810E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,  -5.5394530118831453E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,   5.5394530118831453E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,  -5.5394530118831453E-01,  -7.7314684611578810E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,   5.5394530118831453E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,   5.5394530118831453E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,  -5.5394530118831453E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,   5.5394530118831453E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,  -5.5394530118831453E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,  -5.5394530118831453E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,   5.5394530118831453E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,  -5.5394530118831453E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,   3.0885038065800940E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,   3.0885038065800940E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,  -3.0885038065800940E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,   3.0885038065800940E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,  -3.0885038065800940E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   7.7314684611578810E-01,  -3.0885038065800940E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,   3.0885038065800940E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -7.7314684611578810E-01,  -3.0885038065800940E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,   7.7314684611578810E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,   7.7314684611578810E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,  -7.7314684611578810E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,   7.7314684611578810E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,  -7.7314684611578810E-01,   3.0885038065800940E-01,   3.5259743738220951E-03],
            [   5.5394530118831453E-01,  -7.7314684611578810E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,   7.7314684611578810E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [  -5.5394530118831453E-01,  -7.7314684611578810E-01,  -3.0885038065800940E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,   7.7314684611578810E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,   7.7314684611578810E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,  -7.7314684611578810E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,   7.7314684611578810E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,  -7.7314684611578810E-01,   5.5394530118831453E-01,   3.5259743738220951E-03],
            [   3.0885038065800940E-01,  -7.7314684611578810E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,   7.7314684611578810E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [  -3.0885038065800940E-01,  -7.7314684611578810E-01,  -5.5394530118831453E-01,   3.5259743738220951E-03],
            [   5.8641967624012514E-01,   3.4259042459066141E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,   3.4259042459066141E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,  -3.4259042459066141E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,   3.4259042459066141E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,  -3.4259042459066141E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,  -3.4259042459066141E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,   3.4259042459066141E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,  -3.4259042459066141E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,   5.8641967624012514E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,   5.8641967624012514E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,  -5.8641967624012514E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,   5.8641967624012514E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,  -5.8641967624012514E-01,   7.3399166500527591E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,  -5.8641967624012514E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,   5.8641967624012514E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,  -5.8641967624012514E-01,  -7.3399166500527591E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,   5.8641967624012514E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,   5.8641967624012514E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,  -5.8641967624012514E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,   5.8641967624012514E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,  -5.8641967624012514E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,  -5.8641967624012514E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,   5.8641967624012514E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,  -5.8641967624012514E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,   3.4259042459066141E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,   3.4259042459066141E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,  -3.4259042459066141E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,   3.4259042459066141E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,  -3.4259042459066141E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   7.3399166500527591E-01,  -3.4259042459066141E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,   3.4259042459066141E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -7.3399166500527591E-01,  -3.4259042459066141E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,   7.3399166500527591E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,   7.3399166500527591E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,  -7.3399166500527591E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,   7.3399166500527591E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,  -7.3399166500527591E-01,   3.4259042459066141E-01,   3.5458777744347713E-03],
            [   5.8641967624012514E-01,  -7.3399166500527591E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,   7.3399166500527591E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [  -5.8641967624012514E-01,  -7.3399166500527591E-01,  -3.4259042459066141E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,   7.3399166500527591E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,   7.3399166500527591E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,  -7.3399166500527591E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,   7.3399166500527591E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,  -7.3399166500527591E-01,   5.8641967624012514E-01,   3.5458777744347713E-03],
            [   3.4259042459066141E-01,  -7.3399166500527591E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,   7.3399166500527591E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [  -3.4259042459066141E-01,  -7.3399166500527591E-01,  -5.8641967624012514E-01,   3.5458777744347713E-03],
            [   6.1714844666683899E-01,   3.7525622947894682E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,   3.7525622947894682E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,  -3.7525622947894682E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,   3.7525622947894682E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,  -3.7525622947894682E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,  -3.7525622947894682E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,   3.7525622947894682E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,  -3.7525622947894682E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,   6.1714844666683899E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,   6.1714844666683899E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,  -6.1714844666683899E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,   6.1714844666683899E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,  -6.1714844666683899E-01,   6.9159999784120285E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,  -6.1714844666683899E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,   6.1714844666683899E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,  -6.1714844666683899E-01,  -6.9159999784120285E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,   6.1714844666683899E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,   6.1714844666683899E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,  -6.1714844666683899E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,   6.1714844666683899E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,  -6.1714844666683899E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,  -6.1714844666683899E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,   6.1714844666683899E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,  -6.1714844666683899E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,   3.7525622947894682E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,   3.7525622947894682E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,  -3.7525622947894682E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,   3.7525622947894682E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,  -3.7525622947894682E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   6.9159999784120285E-01,  -3.7525622947894682E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,   3.7525622947894682E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -6.9159999784120285E-01,  -3.7525622947894682E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,   6.9159999784120285E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,   6.9159999784120285E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,  -6.9159999784120285E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,   6.9159999784120285E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,  -6.9159999784120285E-01,   3.7525622947894682E-01,   3.5565624885417050E-03],
            [   6.1714844666683899E-01,  -6.9159999784120285E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,   6.9159999784120285E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [  -6.1714844666683899E-01,  -6.9159999784120285E-01,  -3.7525622947894682E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,   6.9159999784120285E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,   6.9159999784120285E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,  -6.9159999784120285E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,   6.9159999784120285E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,  -6.9159999784120285E-01,   6.1714844666683899E-01,   3.5565624885417050E-03],
            [   3.7525622947894682E-01,  -6.9159999784120285E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,   6.9159999784120285E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [  -3.7525622947894682E-01,  -6.9159999784120285E-01,  -6.1714844666683899E-01,   3.5565624885417050E-03],
            [   3.3503378305657272E-01,   3.2615899346347468E-02,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,   3.2615899346347468E-02,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,  -3.2615899346347468E-02,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,   3.2615899346347468E-02,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,  -3.2615899346347468E-02,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,  -3.2615899346347468E-02,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,   3.2615899346347468E-02,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,  -3.2615899346347468E-02,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,   3.3503378305657272E-01,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,   3.3503378305657272E-01,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,  -3.3503378305657272E-01,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,   3.3503378305657272E-01,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,  -3.3503378305657272E-01,   9.4164142183775579E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,  -3.3503378305657272E-01,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,   3.3503378305657272E-01,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,  -3.3503378305657272E-01,  -9.4164142183775579E-01,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,   3.3503378305657272E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,   3.3503378305657272E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,  -3.3503378305657272E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,   3.3503378305657272E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,  -3.3503378305657272E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,  -3.3503378305657272E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,   3.3503378305657272E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,  -3.3503378305657272E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,   3.2615899346347468E-02,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,   3.2615899346347468E-02,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,  -3.2615899346347468E-02,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,   3.2615899346347468E-02,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,  -3.2615899346347468E-02,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   9.4164142183775579E-01,  -3.2615899346347468E-02,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,   3.2615899346347468E-02,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -9.4164142183775579E-01,  -3.2615899346347468E-02,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,   9.4164142183775579E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,   9.4164142183775579E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,  -9.4164142183775579E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,   9.4164142183775579E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,  -9.4164142183775579E-01,   3.2615899346347468E-02,   3.0888088161052396E-03],
            [   3.3503378305657272E-01,  -9.4164142183775579E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,   9.4164142183775579E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [  -3.3503378305657272E-01,  -9.4164142183775579E-01,  -3.2615899346347468E-02,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,   9.4164142183775579E-01,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,   9.4164142183775579E-01,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,  -9.4164142183775579E-01,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,   9.4164142183775579E-01,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,  -9.4164142183775579E-01,   3.3503378305657272E-01,   3.0888088161052396E-03],
            [   3.2615899346347468E-02,  -9.4164142183775579E-01,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,   9.4164142183775579E-01,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [  -3.2615899346347468E-02,  -9.4164142183775579E-01,  -3.3503378305657272E-01,   3.0888088161052396E-03],
            [   3.7757732247582843E-01,   6.6584389280815726E-02,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,   6.6584389280815726E-02,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,  -6.6584389280815726E-02,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,   6.6584389280815726E-02,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,  -6.6584389280815726E-02,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,  -6.6584389280815726E-02,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,   6.6584389280815726E-02,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,  -6.6584389280815726E-02,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,   3.7757732247582843E-01,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,   3.7757732247582843E-01,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,  -3.7757732247582843E-01,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,   3.7757732247582843E-01,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,  -3.7757732247582843E-01,   9.2358101142026794E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,  -3.7757732247582843E-01,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,   3.7757732247582843E-01,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,  -3.7757732247582843E-01,  -9.2358101142026794E-01,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,   3.7757732247582843E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,   3.7757732247582843E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,  -3.7757732247582843E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,   3.7757732247582843E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,  -3.7757732247582843E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,  -3.7757732247582843E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,   3.7757732247582843E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,  -3.7757732247582843E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,   6.6584389280815726E-02,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,   6.6584389280815726E-02,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,  -6.6584389280815726E-02,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,   6.6584389280815726E-02,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,  -6.6584389280815726E-02,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   9.2358101142026794E-01,  -6.6584389280815726E-02,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,   6.6584389280815726E-02,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -9.2358101142026794E-01,  -6.6584389280815726E-02,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,   9.2358101142026794E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,   9.2358101142026794E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,  -9.2358101142026794E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,   9.2358101142026794E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,  -9.2358101142026794E-01,   6.6584389280815726E-02,   3.2062773017744054E-03],
            [   3.7757732247582843E-01,  -9.2358101142026794E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,   9.2358101142026794E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [  -3.7757732247582843E-01,  -9.2358101142026794E-01,  -6.6584389280815726E-02,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,   9.2358101142026794E-01,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,   9.2358101142026794E-01,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,  -9.2358101142026794E-01,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,   9.2358101142026794E-01,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,  -9.2358101142026794E-01,   3.7757732247582843E-01,   3.2062773017744054E-03],
            [   6.6584389280815726E-02,  -9.2358101142026794E-01,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,   9.2358101142026794E-01,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [  -6.6584389280815726E-02,  -9.2358101142026794E-01,  -3.7757732247582843E-01,   3.2062773017744054E-03],
            [   4.1881552298489733E-01,   1.0145657971579540E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,   1.0145657971579540E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,  -1.0145657971579540E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,   1.0145657971579540E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,  -1.0145657971579540E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,  -1.0145657971579540E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,   1.0145657971579540E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,  -1.0145657971579540E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,   4.1881552298489733E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,   4.1881552298489733E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,  -4.1881552298489733E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,   4.1881552298489733E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,  -4.1881552298489733E-01,   9.0238579340504876E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,  -4.1881552298489733E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,   4.1881552298489733E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,  -4.1881552298489733E-01,  -9.0238579340504876E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,   4.1881552298489733E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,   4.1881552298489733E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,  -4.1881552298489733E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,   4.1881552298489733E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,  -4.1881552298489733E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,  -4.1881552298489733E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,   4.1881552298489733E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,  -4.1881552298489733E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,   1.0145657971579540E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,   1.0145657971579540E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,  -1.0145657971579540E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,   1.0145657971579540E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,  -1.0145657971579540E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   9.0238579340504876E-01,  -1.0145657971579540E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,   1.0145657971579540E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -9.0238579340504876E-01,  -1.0145657971579540E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,   9.0238579340504876E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,   9.0238579340504876E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,  -9.0238579340504876E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,   9.0238579340504876E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,  -9.0238579340504876E-01,   1.0145657971579540E-01,   3.3037809371428703E-03],
            [   4.1881552298489733E-01,  -9.0238579340504876E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,   9.0238579340504876E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [  -4.1881552298489733E-01,  -9.0238579340504876E-01,  -1.0145657971579540E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,   9.0238579340504876E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,   9.0238579340504876E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,  -9.0238579340504876E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,   9.0238579340504876E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,  -9.0238579340504876E-01,   4.1881552298489733E-01,   3.3037809371428703E-03],
            [   1.0145657971579540E-01,  -9.0238579340504876E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,   9.0238579340504876E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [  -1.0145657971579540E-01,  -9.0238579340504876E-01,  -4.1881552298489733E-01,   3.3037809371428703E-03],
            [   4.5868058920093441E-01,   1.3685733208438219E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,   1.3685733208438219E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,  -1.3685733208438219E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,   1.3685733208438219E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,  -1.3685733208438219E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,  -1.3685733208438219E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,   1.3685733208438219E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,  -1.3685733208438219E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,   4.5868058920093441E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,   4.5868058920093441E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,  -4.5868058920093441E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,   4.5868058920093441E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,  -4.5868058920093441E-01,   8.7799896796353283E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,  -4.5868058920093441E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,   4.5868058920093441E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,  -4.5868058920093441E-01,  -8.7799896796353283E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,   4.5868058920093441E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,   4.5868058920093441E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,  -4.5868058920093441E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,   4.5868058920093441E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,  -4.5868058920093441E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,  -4.5868058920093441E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,   4.5868058920093441E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,  -4.5868058920093441E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,   1.3685733208438219E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,   1.3685733208438219E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,  -1.3685733208438219E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,   1.3685733208438219E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,  -1.3685733208438219E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   8.7799896796353283E-01,  -1.3685733208438219E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,   1.3685733208438219E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -8.7799896796353283E-01,  -1.3685733208438219E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,   8.7799896796353283E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,   8.7799896796353283E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,  -8.7799896796353283E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,   8.7799896796353283E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,  -8.7799896796353283E-01,   1.3685733208438219E-01,   3.3827418710718695E-03],
            [   4.5868058920093441E-01,  -8.7799896796353283E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,   8.7799896796353283E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [  -4.5868058920093441E-01,  -8.7799896796353283E-01,  -1.3685733208438219E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,   8.7799896796353283E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,   8.7799896796353283E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,  -8.7799896796353283E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,   8.7799896796353283E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,  -8.7799896796353283E-01,   4.5868058920093441E-01,   3.3827418710718695E-03],
            [   1.3685733208438219E-01,  -8.7799896796353283E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,   8.7799896796353283E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [  -1.3685733208438219E-01,  -8.7799896796353283E-01,  -4.5868058920093441E-01,   3.3827418710718695E-03],
            [   4.9708957142242349E-01,   1.7246148519516080E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,   1.7246148519516080E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,  -1.7246148519516080E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,   1.7246148519516080E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,  -1.7246148519516080E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,  -1.7246148519516080E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,   1.7246148519516080E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,  -1.7246148519516080E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,   4.9708957142242349E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,   4.9708957142242349E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,  -4.9708957142242349E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,   4.9708957142242349E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,  -4.9708957142242349E-01,   8.5038755524016851E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,  -4.9708957142242349E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,   4.9708957142242349E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,  -4.9708957142242349E-01,  -8.5038755524016851E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,   4.9708957142242349E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,   4.9708957142242349E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,  -4.9708957142242349E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,   4.9708957142242349E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,  -4.9708957142242349E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,  -4.9708957142242349E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,   4.9708957142242349E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,  -4.9708957142242349E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,   1.7246148519516080E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,   1.7246148519516080E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,  -1.7246148519516080E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,   1.7246148519516080E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,  -1.7246148519516080E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   8.5038755524016851E-01,  -1.7246148519516080E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,   1.7246148519516080E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -8.5038755524016851E-01,  -1.7246148519516080E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,   8.5038755524016851E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,   8.5038755524016851E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,  -8.5038755524016851E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,   8.5038755524016851E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,  -8.5038755524016851E-01,   1.7246148519516080E-01,   3.4447883710045698E-03],
            [   4.9708957142242349E-01,  -8.5038755524016851E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,   8.5038755524016851E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [  -4.9708957142242349E-01,  -8.5038755524016851E-01,  -1.7246148519516080E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,   8.5038755524016851E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,   8.5038755524016851E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,  -8.5038755524016851E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,   8.5038755524016851E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,  -8.5038755524016851E-01,   4.9708957142242349E-01,   3.4447883710045698E-03],
            [   1.7246148519516080E-01,  -8.5038755524016851E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,   8.5038755524016851E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [  -1.7246148519516080E-01,  -8.5038755524016851E-01,  -4.9708957142242349E-01,   3.4447883710045698E-03],
            [   5.3395051339607469E-01,   2.0797793814164120E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,   2.0797793814164120E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,  -2.0797793814164120E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,   2.0797793814164120E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,  -2.0797793814164120E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,  -2.0797793814164120E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,   2.0797793814164120E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,  -2.0797793814164120E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,   5.3395051339607469E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,   5.3395051339607469E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,  -5.3395051339607469E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,   5.3395051339607469E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,  -5.3395051339607469E-01,   8.1953769070764515E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,  -5.3395051339607469E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,   5.3395051339607469E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,  -5.3395051339607469E-01,  -8.1953769070764515E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,   5.3395051339607469E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,   5.3395051339607469E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,  -5.3395051339607469E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,   5.3395051339607469E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,  -5.3395051339607469E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,  -5.3395051339607469E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,   5.3395051339607469E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,  -5.3395051339607469E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,   2.0797793814164120E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,   2.0797793814164120E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,  -2.0797793814164120E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,   2.0797793814164120E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,  -2.0797793814164120E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   8.1953769070764515E-01,  -2.0797793814164120E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,   2.0797793814164120E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -8.1953769070764515E-01,  -2.0797793814164120E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,   8.1953769070764515E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,   8.1953769070764515E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,  -8.1953769070764515E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,   8.1953769070764515E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,  -8.1953769070764515E-01,   2.0797793814164120E-01,   3.4916049934035462E-03],
            [   5.3395051339607469E-01,  -8.1953769070764515E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,   8.1953769070764515E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [  -5.3395051339607469E-01,  -8.1953769070764515E-01,  -2.0797793814164120E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,   8.1953769070764515E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,   8.1953769070764515E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,  -8.1953769070764515E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,   8.1953769070764515E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,  -8.1953769070764515E-01,   5.3395051339607469E-01,   3.4916049934035462E-03],
            [   2.0797793814164120E-01,  -8.1953769070764515E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,   8.1953769070764515E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [  -2.0797793814164120E-01,  -8.1953769070764515E-01,  -5.3395051339607469E-01,   3.4916049934035462E-03],
            [   5.6916657925314396E-01,   2.4313857883222881E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,   2.4313857883222881E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,  -2.4313857883222881E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,   2.4313857883222881E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,  -2.4313857883222881E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,  -2.4313857883222881E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,   2.4313857883222881E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,  -2.4313857883222881E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,   5.6916657925314396E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,   5.6916657925314396E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,  -5.6916657925314396E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,   5.6916657925314396E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,  -5.6916657925314396E-01,   7.8545084922273700E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,  -5.6916657925314396E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,   5.6916657925314396E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,  -5.6916657925314396E-01,  -7.8545084922273700E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,   5.6916657925314396E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,   5.6916657925314396E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,  -5.6916657925314396E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,   5.6916657925314396E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,  -5.6916657925314396E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,  -5.6916657925314396E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,   5.6916657925314396E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,  -5.6916657925314396E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,   2.4313857883222881E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,   2.4313857883222881E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,  -2.4313857883222881E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,   2.4313857883222881E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,  -2.4313857883222881E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   7.8545084922273700E-01,  -2.4313857883222881E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,   2.4313857883222881E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -7.8545084922273700E-01,  -2.4313857883222881E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,   7.8545084922273700E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,   7.8545084922273700E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,  -7.8545084922273700E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,   7.8545084922273700E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,  -7.8545084922273700E-01,   2.4313857883222881E-01,   3.5248802370242945E-03],
            [   5.6916657925314396E-01,  -7.8545084922273700E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,   7.8545084922273700E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [  -5.6916657925314396E-01,  -7.8545084922273700E-01,  -2.4313857883222881E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,   7.8545084922273700E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,   7.8545084922273700E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,  -7.8545084922273700E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,   7.8545084922273700E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,  -7.8545084922273700E-01,   5.6916657925314396E-01,   3.5248802370242945E-03],
            [   2.4313857883222881E-01,  -7.8545084922273700E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,   7.8545084922273700E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [  -2.4313857883222881E-01,  -7.8545084922273700E-01,  -5.6916657925314396E-01,   3.5248802370242945E-03],
            [   6.0263876826803775E-01,   2.7769018830498532E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,   2.7769018830498532E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,  -2.7769018830498532E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,   2.7769018830498532E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,  -2.7769018830498532E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,  -2.7769018830498532E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,   2.7769018830498532E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,  -2.7769018830498532E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,   6.0263876826803775E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,   6.0263876826803775E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,  -6.0263876826803775E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,   6.0263876826803775E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,  -6.0263876826803775E-01,   7.4814081181253844E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,  -6.0263876826803775E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,   6.0263876826803775E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,  -6.0263876826803775E-01,  -7.4814081181253844E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,   6.0263876826803775E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,   6.0263876826803775E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,  -6.0263876826803775E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,   6.0263876826803775E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,  -6.0263876826803775E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,  -6.0263876826803775E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,   6.0263876826803775E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,  -6.0263876826803775E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,   2.7769018830498532E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,   2.7769018830498532E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,  -2.7769018830498532E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,   2.7769018830498532E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,  -2.7769018830498532E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   7.4814081181253844E-01,  -2.7769018830498532E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,   2.7769018830498532E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -7.4814081181253844E-01,  -2.7769018830498532E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,   7.4814081181253844E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,   7.4814081181253844E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,  -7.4814081181253844E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,   7.4814081181253844E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,  -7.4814081181253844E-01,   2.7769018830498532E-01,   3.5462999504848524E-03],
            [   6.0263876826803775E-01,  -7.4814081181253844E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,   7.4814081181253844E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [  -6.0263876826803775E-01,  -7.4814081181253844E-01,  -2.7769018830498532E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,   7.4814081181253844E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,   7.4814081181253844E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,  -7.4814081181253844E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,   7.4814081181253844E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,  -7.4814081181253844E-01,   6.0263876826803775E-01,   3.5462999504848524E-03],
            [   2.7769018830498532E-01,  -7.4814081181253844E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,   7.4814081181253844E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [  -2.7769018830498532E-01,  -7.4814081181253844E-01,  -6.0263876826803775E-01,   3.5462999504848524E-03],
            [   6.3426761501633067E-01,   3.1138813563866319E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,   3.1138813563866319E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,  -3.1138813563866319E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,   3.1138813563866319E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,  -3.1138813563866319E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,  -3.1138813563866319E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,   3.1138813563866319E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,  -3.1138813563866319E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,   6.3426761501633067E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,   6.3426761501633067E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,  -6.3426761501633067E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,   6.3426761501633067E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,  -6.3426761501633067E-01,   7.0763127511789170E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,  -6.3426761501633067E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,   6.3426761501633067E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,  -6.3426761501633067E-01,  -7.0763127511789170E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,   6.3426761501633067E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,   6.3426761501633067E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,  -6.3426761501633067E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,   6.3426761501633067E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,  -6.3426761501633067E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,  -6.3426761501633067E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,   6.3426761501633067E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,  -6.3426761501633067E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,   3.1138813563866319E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,   3.1138813563866319E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,  -3.1138813563866319E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,   3.1138813563866319E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,  -3.1138813563866319E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   7.0763127511789170E-01,  -3.1138813563866319E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,   3.1138813563866319E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -7.0763127511789170E-01,  -3.1138813563866319E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,   7.0763127511789170E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,   7.0763127511789170E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,  -7.0763127511789170E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,   7.0763127511789170E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,  -7.0763127511789170E-01,   3.1138813563866319E-01,   3.5575607596540141E-03],
            [   6.3426761501633067E-01,  -7.0763127511789170E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,   7.0763127511789170E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [  -6.3426761501633067E-01,  -7.0763127511789170E-01,  -3.1138813563866319E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,   7.0763127511789170E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,   7.0763127511789170E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,  -7.0763127511789170E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,   7.0763127511789170E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,  -7.0763127511789170E-01,   6.3426761501633067E-01,   3.5575607596540141E-03],
            [   3.1138813563866319E-01,  -7.0763127511789170E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,   7.0763127511789170E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [  -3.1138813563866319E-01,  -7.0763127511789170E-01,  -6.3426761501633067E-01,   3.5575607596540141E-03],
            [   4.2379511195370673E-01,   3.3948778486643509E-02,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,   3.3948778486643509E-02,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,  -3.3948778486643509E-02,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,   3.3948778486643509E-02,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,  -3.3948778486643509E-02,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,  -3.3948778486643509E-02,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,   3.3948778486643509E-02,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,  -3.3948778486643509E-02,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,   4.2379511195370673E-01,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,   4.2379511195370673E-01,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,  -4.2379511195370673E-01,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,   4.2379511195370673E-01,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,  -4.2379511195370673E-01,   9.0512164018070518E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,  -4.2379511195370673E-01,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,   4.2379511195370673E-01,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,  -4.2379511195370673E-01,  -9.0512164018070518E-01,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,   4.2379511195370673E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,   4.2379511195370673E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,  -4.2379511195370673E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,   4.2379511195370673E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,  -4.2379511195370673E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,  -4.2379511195370673E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,   4.2379511195370673E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,  -4.2379511195370673E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,   3.3948778486643509E-02,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,   3.3948778486643509E-02,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,  -3.3948778486643509E-02,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,   3.3948778486643509E-02,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,  -3.3948778486643509E-02,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   9.0512164018070518E-01,  -3.3948778486643509E-02,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,   3.3948778486643509E-02,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -9.0512164018070518E-01,  -3.3948778486643509E-02,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,   9.0512164018070518E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,   9.0512164018070518E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,  -9.0512164018070518E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,   9.0512164018070518E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,  -9.0512164018070518E-01,   3.3948778486643509E-02,   3.2980124275705886E-03],
            [   4.2379511195370673E-01,  -9.0512164018070518E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,   9.0512164018070518E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [  -4.2379511195370673E-01,  -9.0512164018070518E-01,  -3.3948778486643509E-02,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,   9.0512164018070518E-01,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,   9.0512164018070518E-01,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,  -9.0512164018070518E-01,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,   9.0512164018070518E-01,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,  -9.0512164018070518E-01,   4.2379511195370673E-01,   3.2980124275705886E-03],
            [   3.3948778486643509E-02,  -9.0512164018070518E-01,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,   9.0512164018070518E-01,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [  -3.3948778486643509E-02,  -9.0512164018070518E-01,  -4.2379511195370673E-01,   3.2980124275705886E-03],
            [   4.6569186832349291E-01,   6.8802195562914475E-02,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,   6.8802195562914475E-02,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,  -6.8802195562914475E-02,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,   6.8802195562914475E-02,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,  -6.8802195562914475E-02,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,  -6.8802195562914475E-02,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,   6.8802195562914475E-02,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,  -6.8802195562914475E-02,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,   4.6569186832349291E-01,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,   4.6569186832349291E-01,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,  -4.6569186832349291E-01,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,   4.6569186832349291E-01,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,  -4.6569186832349291E-01,   8.8226829347035751E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,  -4.6569186832349291E-01,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,   4.6569186832349291E-01,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,  -4.6569186832349291E-01,  -8.8226829347035751E-01,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,   4.6569186832349291E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,   4.6569186832349291E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,  -4.6569186832349291E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,   4.6569186832349291E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,  -4.6569186832349291E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,  -4.6569186832349291E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,   4.6569186832349291E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,  -4.6569186832349291E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,   6.8802195562914475E-02,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,   6.8802195562914475E-02,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,  -6.8802195562914475E-02,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,   6.8802195562914475E-02,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,  -6.8802195562914475E-02,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   8.8226829347035751E-01,  -6.8802195562914475E-02,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,   6.8802195562914475E-02,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -8.8226829347035751E-01,  -6.8802195562914475E-02,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,   8.8226829347035751E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,   8.8226829347035751E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,  -8.8226829347035751E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,   8.8226829347035751E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,  -8.8226829347035751E-01,   6.8802195562914475E-02,   3.3778833516811576E-03],
            [   4.6569186832349291E-01,  -8.8226829347035751E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,   8.8226829347035751E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [  -4.6569186832349291E-01,  -8.8226829347035751E-01,  -6.8802195562914475E-02,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,   8.8226829347035751E-01,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,   8.8226829347035751E-01,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,  -8.8226829347035751E-01,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,   8.8226829347035751E-01,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,  -8.8226829347035751E-01,   4.6569186832349291E-01,   3.3778833516811576E-03],
            [   6.8802195562914475E-02,  -8.8226829347035751E-01,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,   8.8226829347035751E-01,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [  -6.8802195562914475E-02,  -8.8226829347035751E-01,  -4.6569186832349291E-01,   3.3778833516811576E-03],
            [   5.0588570691859802E-01,   1.0419468597216350E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,   1.0419468597216350E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,  -1.0419468597216350E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,   1.0419468597216350E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,  -1.0419468597216350E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,  -1.0419468597216350E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,   1.0419468597216350E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,  -1.0419468597216350E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,   5.0588570691859802E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,   5.0588570691859802E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,  -5.0588570691859802E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,   5.0588570691859802E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,  -5.0588570691859802E-01,   8.5628448482419239E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,  -5.0588570691859802E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,   5.0588570691859802E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,  -5.0588570691859802E-01,  -8.5628448482419239E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,   5.0588570691859802E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,   5.0588570691859802E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,  -5.0588570691859802E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,   5.0588570691859802E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,  -5.0588570691859802E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,  -5.0588570691859802E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,   5.0588570691859802E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,  -5.0588570691859802E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,   1.0419468597216350E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,   1.0419468597216350E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,  -1.0419468597216350E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,   1.0419468597216350E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,  -1.0419468597216350E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   8.5628448482419239E-01,  -1.0419468597216350E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,   1.0419468597216350E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -8.5628448482419239E-01,  -1.0419468597216350E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,   8.5628448482419239E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,   8.5628448482419239E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,  -8.5628448482419239E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,   8.5628448482419239E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,  -8.5628448482419239E-01,   1.0419468597216350E-01,   3.4418444040486872E-03],
            [   5.0588570691859802E-01,  -8.5628448482419239E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,   8.5628448482419239E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [  -5.0588570691859802E-01,  -8.5628448482419239E-01,  -1.0419468597216350E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,   8.5628448482419239E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,   8.5628448482419239E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,  -8.5628448482419239E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,   8.5628448482419239E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,  -8.5628448482419239E-01,   5.0588570691859802E-01,   3.4418444040486872E-03],
            [   1.0419468597216350E-01,  -8.5628448482419239E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,   8.5628448482419239E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [  -1.0419468597216350E-01,  -8.5628448482419239E-01,  -5.0588570691859802E-01,   3.4418444040486872E-03],
            [   5.4432046667139955E-01,   1.3980397387363930E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,   1.3980397387363930E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,  -1.3980397387363930E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,   1.3980397387363930E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,  -1.3980397387363930E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,  -1.3980397387363930E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,   1.3980397387363930E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,  -1.3980397387363930E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,   5.4432046667139955E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,   5.4432046667139955E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,  -5.4432046667139955E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,   5.4432046667139955E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,  -5.4432046667139955E-01,   8.2714574196556723E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,  -5.4432046667139955E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,   5.4432046667139955E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,  -5.4432046667139955E-01,  -8.2714574196556723E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,   5.4432046667139955E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,   5.4432046667139955E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,  -5.4432046667139955E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,   5.4432046667139955E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,  -5.4432046667139955E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,  -5.4432046667139955E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,   5.4432046667139955E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,  -5.4432046667139955E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,   1.3980397387363930E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,   1.3980397387363930E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,  -1.3980397387363930E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,   1.3980397387363930E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,  -1.3980397387363930E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   8.2714574196556723E-01,  -1.3980397387363930E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,   1.3980397387363930E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -8.2714574196556723E-01,  -1.3980397387363930E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,   8.2714574196556723E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,   8.2714574196556723E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,  -8.2714574196556723E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,   8.2714574196556723E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,  -8.2714574196556723E-01,   1.3980397387363930E-01,   3.4908683792982168E-03],
            [   5.4432046667139955E-01,  -8.2714574196556723E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,   8.2714574196556723E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [  -5.4432046667139955E-01,  -8.2714574196556723E-01,  -1.3980397387363930E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,   8.2714574196556723E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,   8.2714574196556723E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,  -8.2714574196556723E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,   8.2714574196556723E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,  -8.2714574196556723E-01,   5.4432046667139955E-01,   3.4908683792982168E-03],
            [   1.3980397387363930E-01,  -8.2714574196556723E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,   8.2714574196556723E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [  -1.3980397387363930E-01,  -8.2714574196556723E-01,  -5.4432046667139955E-01,   3.4908683792982168E-03],
            [   5.8092988137597423E-01,   1.7533733811961549E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,   1.7533733811961549E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,  -1.7533733811961549E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,   1.7533733811961549E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,  -1.7533733811961549E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,  -1.7533733811961549E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,   1.7533733811961549E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,  -1.7533733811961549E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,   5.8092988137597423E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,   5.8092988137597423E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,  -5.8092988137597423E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,   5.8092988137597423E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,  -5.8092988137597423E-01,   7.9484419277341645E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,  -5.8092988137597423E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,   5.8092988137597423E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,  -5.8092988137597423E-01,  -7.9484419277341645E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,   5.8092988137597423E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,   5.8092988137597423E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,  -5.8092988137597423E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,   5.8092988137597423E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,  -5.8092988137597423E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,  -5.8092988137597423E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,   5.8092988137597423E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,  -5.8092988137597423E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,   1.7533733811961549E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,   1.7533733811961549E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,  -1.7533733811961549E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,   1.7533733811961549E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,  -1.7533733811961549E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   7.9484419277341645E-01,  -1.7533733811961549E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,   1.7533733811961549E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -7.9484419277341645E-01,  -1.7533733811961549E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,   7.9484419277341645E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,   7.9484419277341645E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,  -7.9484419277341645E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,   7.9484419277341645E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,  -7.9484419277341645E-01,   1.7533733811961549E-01,   3.5261382488645777E-03],
            [   5.8092988137597423E-01,  -7.9484419277341645E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,   7.9484419277341645E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [  -5.8092988137597423E-01,  -7.9484419277341645E-01,  -1.7533733811961549E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,   7.9484419277341645E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,   7.9484419277341645E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,  -7.9484419277341645E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,   7.9484419277341645E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,  -7.9484419277341645E-01,   5.8092988137597423E-01,   3.5261382488645777E-03],
            [   1.7533733811961549E-01,  -7.9484419277341645E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,   7.9484419277341645E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [  -1.7533733811961549E-01,  -7.9484419277341645E-01,  -5.8092988137597423E-01,   3.5261382488645777E-03],
            [   6.1564160394471279E-01,   2.1052157935140101E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,   2.1052157935140101E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,  -2.1052157935140101E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,   2.1052157935140101E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,  -2.1052157935140101E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,  -2.1052157935140101E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,   2.1052157935140101E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,  -2.1052157935140101E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,   6.1564160394471279E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,   6.1564160394471279E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,  -6.1564160394471279E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,   6.1564160394471279E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,  -6.1564160394471279E-01,   7.5938533046127066E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,  -6.1564160394471279E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,   6.1564160394471279E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,  -6.1564160394471279E-01,  -7.5938533046127066E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,   6.1564160394471279E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,   6.1564160394471279E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,  -6.1564160394471279E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,   6.1564160394471279E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,  -6.1564160394471279E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,  -6.1564160394471279E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,   6.1564160394471279E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,  -6.1564160394471279E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,   2.1052157935140101E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,   2.1052157935140101E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,  -2.1052157935140101E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,   2.1052157935140101E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,  -2.1052157935140101E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   7.5938533046127066E-01,  -2.1052157935140101E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,   2.1052157935140101E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -7.5938533046127066E-01,  -2.1052157935140101E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,   7.5938533046127066E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,   7.5938533046127066E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,  -7.5938533046127066E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,   7.5938533046127066E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,  -7.5938533046127066E-01,   2.1052157935140101E-01,   3.5489710865804405E-03],
            [   6.1564160394471279E-01,  -7.5938533046127066E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,   7.5938533046127066E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [  -6.1564160394471279E-01,  -7.5938533046127066E-01,  -2.1052157935140101E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,   7.5938533046127066E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,   7.5938533046127066E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,  -7.5938533046127066E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,   7.5938533046127066E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,  -7.5938533046127066E-01,   6.1564160394471279E-01,   3.5489710865804405E-03],
            [   2.1052157935140101E-01,  -7.5938533046127066E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,   7.5938533046127066E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [  -2.1052157935140101E-01,  -7.5938533046127066E-01,  -6.1564160394471279E-01,   3.5489710865804405E-03],
            [   6.4838013510666037E-01,   2.4509533121570509E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,   2.4509533121570509E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,  -2.4509533121570509E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,   2.4509533121570509E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,  -2.4509533121570509E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,  -2.4509533121570509E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,   2.4509533121570509E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,  -2.4509533121570509E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,   6.4838013510666037E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,   6.4838013510666037E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,  -6.4838013510666037E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,   6.4838013510666037E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,  -6.4838013510666037E-01,   7.2078532103208970E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,  -6.4838013510666037E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,   6.4838013510666037E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,  -6.4838013510666037E-01,  -7.2078532103208970E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,   6.4838013510666037E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,   6.4838013510666037E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,  -6.4838013510666037E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,   6.4838013510666037E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,  -6.4838013510666037E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,  -6.4838013510666037E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,   6.4838013510666037E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,  -6.4838013510666037E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,   2.4509533121570509E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,   2.4509533121570509E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,  -2.4509533121570509E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,   2.4509533121570509E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,  -2.4509533121570509E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   7.2078532103208970E-01,  -2.4509533121570509E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,   2.4509533121570509E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -7.2078532103208970E-01,  -2.4509533121570509E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,   7.2078532103208970E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,   7.2078532103208970E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,  -7.2078532103208970E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,   7.2078532103208970E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,  -7.2078532103208970E-01,   2.4509533121570509E-01,   3.5607881998886187E-03],
            [   6.4838013510666037E-01,  -7.2078532103208970E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,   7.2078532103208970E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [  -6.4838013510666037E-01,  -7.2078532103208970E-01,  -2.4509533121570509E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,   7.2078532103208970E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,   7.2078532103208970E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,  -7.2078532103208970E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,   7.2078532103208970E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,  -7.2078532103208970E-01,   6.4838013510666037E-01,   3.5607881998886187E-03],
            [   2.4509533121570509E-01,  -7.2078532103208970E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,   7.2078532103208970E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [  -2.4509533121570509E-01,  -7.2078532103208970E-01,  -6.4838013510666037E-01,   3.5607881998886187E-03],
            [   5.1036165772516884E-01,   3.4855606438007190E-02,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,   3.4855606438007190E-02,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,  -3.4855606438007190E-02,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,   3.4855606438007190E-02,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,  -3.4855606438007190E-02,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,  -3.4855606438007190E-02,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,   3.4855606438007190E-02,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,  -3.4855606438007190E-02,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,   5.1036165772516884E-01,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,   5.1036165772516884E-01,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,  -5.1036165772516884E-01,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,   5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,  -5.1036165772516884E-01,   8.5925320192819554E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,  -5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,   5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,  -5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,   5.1036165772516884E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,   5.1036165772516884E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,   5.1036165772516884E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,  -5.1036165772516884E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,   5.1036165772516884E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,  -5.1036165772516884E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,   3.4855606438007190E-02,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,   3.4855606438007190E-02,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,  -3.4855606438007190E-02,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,   3.4855606438007190E-02,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,  -3.4855606438007190E-02,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   8.5925320192819554E-01,  -3.4855606438007190E-02,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,   3.4855606438007190E-02,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -8.5925320192819554E-01,  -3.4855606438007190E-02,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,   8.5925320192819554E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,   8.5925320192819554E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,   8.5925320192819554E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,  -8.5925320192819554E-01,   3.4855606438007190E-02,   3.4408799171030129E-03],
            [   5.1036165772516884E-01,  -8.5925320192819554E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,   8.5925320192819554E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [  -5.1036165772516884E-01,  -8.5925320192819554E-01,  -3.4855606438007190E-02,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,   8.5925320192819554E-01,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,   8.5925320192819554E-01,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,  -8.5925320192819554E-01,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,   8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,  -8.5925320192819554E-01,   5.1036165772516884E-01,   3.4408799171030129E-03],
            [   3.4855606438007190E-02,  -8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,   8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [  -3.4855606438007190E-02,  -8.5925320192819554E-01,  -5.1036165772516884E-01,   3.4408799171030129E-03],
            [   5.5067387925806810E-01,   7.0263086315120335E-02,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,   7.0263086315120335E-02,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,  -7.0263086315120335E-02,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,   7.0263086315120335E-02,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,  -7.0263086315120335E-02,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,  -7.0263086315120335E-02,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,   7.0263086315120335E-02,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,  -7.0263086315120335E-02,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,   5.5067387925806810E-01,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,   5.5067387925806810E-01,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,  -5.5067387925806810E-01,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,   5.5067387925806810E-01,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,  -5.5067387925806810E-01,   8.3175800411197998E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,  -5.5067387925806810E-01,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,   5.5067387925806810E-01,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,  -5.5067387925806810E-01,  -8.3175800411197998E-01,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,   5.5067387925806810E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,   5.5067387925806810E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,  -5.5067387925806810E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,   5.5067387925806810E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,  -5.5067387925806810E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,  -5.5067387925806810E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,   5.5067387925806810E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,  -5.5067387925806810E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,   7.0263086315120335E-02,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,   7.0263086315120335E-02,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,  -7.0263086315120335E-02,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,   7.0263086315120335E-02,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,  -7.0263086315120335E-02,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   8.3175800411197998E-01,  -7.0263086315120335E-02,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,   7.0263086315120335E-02,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -8.3175800411197998E-01,  -7.0263086315120335E-02,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,   8.3175800411197998E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,   8.3175800411197998E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,  -8.3175800411197998E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,   8.3175800411197998E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,  -8.3175800411197998E-01,   7.0263086315120335E-02,   3.4913966908322346E-03],
            [   5.5067387925806810E-01,  -8.3175800411197998E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,   8.3175800411197998E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [  -5.5067387925806810E-01,  -8.3175800411197998E-01,  -7.0263086315120335E-02,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,   8.3175800411197998E-01,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,   8.3175800411197998E-01,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,  -8.3175800411197998E-01,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,   8.3175800411197998E-01,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,  -8.3175800411197998E-01,   5.5067387925806810E-01,   3.4913966908322346E-03],
            [   7.0263086315120335E-02,  -8.3175800411197998E-01,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,   8.3175800411197998E-01,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [  -7.0263086315120335E-02,  -8.3175800411197998E-01,  -5.5067387925806810E-01,   3.4913966908322346E-03],
            [   5.8895730409952918E-01,   1.0590350612964031E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,   1.0590350612964031E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,  -1.0590350612964031E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,   1.0590350612964031E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,  -1.0590350612964031E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,  -1.0590350612964031E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,   1.0590350612964031E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,  -1.0590350612964031E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,   5.8895730409952918E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,   5.8895730409952918E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,  -5.8895730409952918E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,   5.8895730409952918E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,  -5.8895730409952918E-01,   8.0119519552807106E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,  -5.8895730409952918E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,   5.8895730409952918E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,  -5.8895730409952918E-01,  -8.0119519552807106E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,   5.8895730409952918E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,   5.8895730409952918E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,  -5.8895730409952918E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,   5.8895730409952918E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,  -5.8895730409952918E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,  -5.8895730409952918E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,   5.8895730409952918E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,  -5.8895730409952918E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,   1.0590350612964031E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,   1.0590350612964031E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,  -1.0590350612964031E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,   1.0590350612964031E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,  -1.0590350612964031E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   8.0119519552807106E-01,  -1.0590350612964031E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,   1.0590350612964031E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -8.0119519552807106E-01,  -1.0590350612964031E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,   8.0119519552807106E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,   8.0119519552807106E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,  -8.0119519552807106E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,   8.0119519552807106E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,  -8.0119519552807106E-01,   1.0590350612964031E-01,   3.5284520679922889E-03],
            [   5.8895730409952918E-01,  -8.0119519552807106E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,   8.0119519552807106E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [  -5.8895730409952918E-01,  -8.0119519552807106E-01,  -1.0590350612964031E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,   8.0119519552807106E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,   8.0119519552807106E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,  -8.0119519552807106E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,   8.0119519552807106E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,  -8.0119519552807106E-01,   5.8895730409952918E-01,   3.5284520679922889E-03],
            [   1.0590350612964031E-01,  -8.0119519552807106E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,   8.0119519552807106E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [  -1.0590350612964031E-01,  -8.0119519552807106E-01,  -5.8895730409952918E-01,   3.5284520679922889E-03],
            [   6.2516415895169297E-01,   1.4148239252360259E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,   1.4148239252360259E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,  -1.4148239252360259E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,   1.4148239252360259E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,  -1.4148239252360259E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,  -1.4148239252360259E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,   1.4148239252360259E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,  -1.4148239252360259E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,   6.2516415895169297E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,   6.2516415895169297E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,  -6.2516415895169297E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,   6.2516415895169297E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,  -6.2516415895169297E-01,   7.6756270556093309E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,  -6.2516415895169297E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,   6.2516415895169297E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,  -6.2516415895169297E-01,  -7.6756270556093309E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,   6.2516415895169297E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,   6.2516415895169297E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,  -6.2516415895169297E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,   6.2516415895169297E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,  -6.2516415895169297E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,  -6.2516415895169297E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,   6.2516415895169297E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,  -6.2516415895169297E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,   1.4148239252360259E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,   1.4148239252360259E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,  -1.4148239252360259E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,   1.4148239252360259E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,  -1.4148239252360259E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   7.6756270556093309E-01,  -1.4148239252360259E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,   1.4148239252360259E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -7.6756270556093309E-01,  -1.4148239252360259E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,   7.6756270556093309E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,   7.6756270556093309E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,  -7.6756270556093309E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,   7.6756270556093309E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,  -7.6756270556093309E-01,   1.4148239252360259E-01,   3.5528220421558207E-03],
            [   6.2516415895169297E-01,  -7.6756270556093309E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,   7.6756270556093309E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [  -6.2516415895169297E-01,  -7.6756270556093309E-01,  -1.4148239252360259E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,   7.6756270556093309E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,   7.6756270556093309E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,  -7.6756270556093309E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,   7.6756270556093309E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,  -7.6756270556093309E-01,   6.2516415895169297E-01,   3.5528220421558207E-03],
            [   1.4148239252360259E-01,  -7.6756270556093309E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,   7.6756270556093309E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [  -1.4148239252360259E-01,  -7.6756270556093309E-01,  -6.2516415895169297E-01,   3.5528220421558207E-03],
            [   6.5924149215701777E-01,   1.7672079082145301E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,   1.7672079082145301E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,  -1.7672079082145301E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,   1.7672079082145301E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,  -1.7672079082145301E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,  -1.7672079082145301E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,   1.7672079082145301E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,  -1.7672079082145301E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,   6.5924149215701777E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,   6.5924149215701777E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,  -6.5924149215701777E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,   6.5924149215701777E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,  -6.5924149215701777E-01,   7.3086963072084810E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,  -6.5924149215701777E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,   6.5924149215701777E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,  -6.5924149215701777E-01,  -7.3086963072084810E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,   6.5924149215701777E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,   6.5924149215701777E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,  -6.5924149215701777E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,   6.5924149215701777E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,  -6.5924149215701777E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,  -6.5924149215701777E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,   6.5924149215701777E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,  -6.5924149215701777E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,   1.7672079082145301E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,   1.7672079082145301E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,  -1.7672079082145301E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,   1.7672079082145301E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,  -1.7672079082145301E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   7.3086963072084810E-01,  -1.7672079082145301E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,   1.7672079082145301E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -7.3086963072084810E-01,  -1.7672079082145301E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,   7.3086963072084810E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,   7.3086963072084810E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,  -7.3086963072084810E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,   7.3086963072084810E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,  -7.3086963072084810E-01,   1.7672079082145301E-01,   3.5655095464946500E-03],
            [   6.5924149215701777E-01,  -7.3086963072084810E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,   7.3086963072084810E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [  -6.5924149215701777E-01,  -7.3086963072084810E-01,  -1.7672079082145301E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,   7.3086963072084810E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,   7.3086963072084810E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,  -7.3086963072084810E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,   7.3086963072084810E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,  -7.3086963072084810E-01,   6.5924149215701777E-01,   3.5655095464946500E-03],
            [   1.7672079082145301E-01,  -7.3086963072084810E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,   7.3086963072084810E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [  -1.7672079082145301E-01,  -7.3086963072084810E-01,  -6.5924149215701777E-01,   3.5655095464946500E-03],
            [   5.9303140175333835E-01,   3.5421893395616723E-02,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,   3.5421893395616723E-02,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,  -3.5421893395616723E-02,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,   3.5421893395616723E-02,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,  -3.5421893395616723E-02,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,  -3.5421893395616723E-02,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,   3.5421893395616723E-02,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,  -3.5421893395616723E-02,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,   5.9303140175333835E-01,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,   5.9303140175333835E-01,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,  -5.9303140175333835E-01,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,   5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,  -5.9303140175333835E-01,   8.0439980482515039E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,  -5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,   5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,  -5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,   5.9303140175333835E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,   5.9303140175333835E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,   5.9303140175333835E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,  -5.9303140175333835E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,   5.9303140175333835E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,  -5.9303140175333835E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,   3.5421893395616723E-02,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,   3.5421893395616723E-02,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,  -3.5421893395616723E-02,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,   3.5421893395616723E-02,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,  -3.5421893395616723E-02,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   8.0439980482515039E-01,  -3.5421893395616723E-02,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,   3.5421893395616723E-02,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -8.0439980482515039E-01,  -3.5421893395616723E-02,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,   8.0439980482515039E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,   8.0439980482515039E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,   8.0439980482515039E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,  -8.0439980482515039E-01,   3.5421893395616723E-02,   3.5301874425464020E-03],
            [   5.9303140175333835E-01,  -8.0439980482515039E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,   8.0439980482515039E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [  -5.9303140175333835E-01,  -8.0439980482515039E-01,  -3.5421893395616723E-02,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,   8.0439980482515039E-01,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,   8.0439980482515039E-01,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,  -8.0439980482515039E-01,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,   8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,  -8.0439980482515039E-01,   5.9303140175333835E-01,   3.5301874425464020E-03],
            [   3.5421893395616723E-02,  -8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,   8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [  -3.5421893395616723E-02,  -8.0439980482515039E-01,  -5.9303140175333835E-01,   3.5301874425464020E-03],
            [   6.3098122533901746E-01,   7.1095740403695484E-02,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,   7.1095740403695484E-02,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,  -7.1095740403695484E-02,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,   7.1095740403695484E-02,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,  -7.1095740403695484E-02,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,  -7.1095740403695484E-02,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,   7.1095740403695484E-02,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,  -7.1095740403695484E-02,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,   6.3098122533901746E-01,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,   6.3098122533901746E-01,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,  -6.3098122533901746E-01,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,   6.3098122533901746E-01,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,  -6.3098122533901746E-01,   7.7253355200024965E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,  -6.3098122533901746E-01,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,   6.3098122533901746E-01,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,  -6.3098122533901746E-01,  -7.7253355200024965E-01,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,   6.3098122533901746E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,   6.3098122533901746E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,  -6.3098122533901746E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,   6.3098122533901746E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,  -6.3098122533901746E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,  -6.3098122533901746E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,   6.3098122533901746E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,  -6.3098122533901746E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,   7.1095740403695484E-02,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,   7.1095740403695484E-02,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,  -7.1095740403695484E-02,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,   7.1095740403695484E-02,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,  -7.1095740403695484E-02,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.7253355200024965E-01,  -7.1095740403695484E-02,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,   7.1095740403695484E-02,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.7253355200024965E-01,  -7.1095740403695484E-02,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,   7.7253355200024965E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,   7.7253355200024965E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,  -7.7253355200024965E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,   7.7253355200024965E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,  -7.7253355200024965E-01,   7.1095740403695484E-02,   3.5561959368220247E-03],
            [   6.3098122533901746E-01,  -7.7253355200024965E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,   7.7253355200024965E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [  -6.3098122533901746E-01,  -7.7253355200024965E-01,  -7.1095740403695484E-02,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,   7.7253355200024965E-01,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,   7.7253355200024965E-01,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,  -7.7253355200024965E-01,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,   7.7253355200024965E-01,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,  -7.7253355200024965E-01,   6.3098122533901746E-01,   3.5561959368220247E-03],
            [   7.1095740403695484E-02,  -7.7253355200024965E-01,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,   7.7253355200024965E-01,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [  -7.1095740403695484E-02,  -7.7253355200024965E-01,  -6.3098122533901746E-01,   3.5561959368220247E-03],
            [   6.6662960113532299E-01,   1.0672597922827300E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,   1.0672597922827300E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,  -1.0672597922827300E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,   1.0672597922827300E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,  -1.0672597922827300E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,  -1.0672597922827300E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,   1.0672597922827300E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,  -1.0672597922827300E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,   6.6662960113532299E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,   6.6662960113532299E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,  -6.6662960113532299E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,   6.6662960113532299E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,  -6.6662960113532299E-01,   7.3770898072880087E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,  -6.6662960113532299E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,   6.6662960113532299E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,  -6.6662960113532299E-01,  -7.3770898072880087E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,   6.6662960113532299E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,   6.6662960113532299E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,  -6.6662960113532299E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,   6.6662960113532299E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,  -6.6662960113532299E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,  -6.6662960113532299E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,   6.6662960113532299E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,  -6.6662960113532299E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,   1.0672597922827300E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,   1.0672597922827300E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,  -1.0672597922827300E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,   1.0672597922827300E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,  -1.0672597922827300E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   7.3770898072880087E-01,  -1.0672597922827300E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,   1.0672597922827300E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -7.3770898072880087E-01,  -1.0672597922827300E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,   7.3770898072880087E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,   7.3770898072880087E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,  -7.3770898072880087E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,   7.3770898072880087E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,  -7.3770898072880087E-01,   1.0672597922827300E-01,   3.5702288837752803E-03],
            [   6.6662960113532299E-01,  -7.3770898072880087E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,   7.3770898072880087E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [  -6.6662960113532299E-01,  -7.3770898072880087E-01,  -1.0672597922827300E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,   7.3770898072880087E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,   7.3770898072880087E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,  -7.3770898072880087E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,   7.3770898072880087E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,  -7.3770898072880087E-01,   6.6662960113532299E-01,   3.5702288837752803E-03],
            [   1.0672597922827300E-01,  -7.3770898072880087E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,   7.3770898072880087E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [  -1.0672597922827300E-01,  -7.3770898072880087E-01,  -6.6662960113532299E-01,   3.5702288837752803E-03],
            [   6.7037152710499215E-01,   3.5694552688208092E-02,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,   3.5694552688208092E-02,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,  -3.5694552688208092E-02,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,   3.5694552688208092E-02,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,  -3.5694552688208092E-02,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,  -3.5694552688208092E-02,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,   3.5694552688208092E-02,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,  -3.5694552688208092E-02,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,   6.7037152710499215E-01,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,   6.7037152710499215E-01,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,  -6.7037152710499215E-01,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,   6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,  -6.7037152710499215E-01,   7.4116659028541587E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,  -6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,   6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,  -6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,   6.7037152710499215E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,   6.7037152710499215E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,   6.7037152710499215E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,  -6.7037152710499215E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,   6.7037152710499215E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,  -6.7037152710499215E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,   3.5694552688208092E-02,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,   3.5694552688208092E-02,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,  -3.5694552688208092E-02,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,   3.5694552688208092E-02,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,  -3.5694552688208092E-02,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   7.4116659028541587E-01,  -3.5694552688208092E-02,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,   3.5694552688208092E-02,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -7.4116659028541587E-01,  -3.5694552688208092E-02,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,   7.4116659028541587E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,   7.4116659028541587E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,   7.4116659028541587E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,  -7.4116659028541587E-01,   3.5694552688208092E-02,   3.5731911944035378E-03],
            [   6.7037152710499215E-01,  -7.4116659028541587E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,   7.4116659028541587E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [  -6.7037152710499215E-01,  -7.4116659028541587E-01,  -3.5694552688208092E-02,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,   7.4116659028541587E-01,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,   7.4116659028541587E-01,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,  -7.4116659028541587E-01,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,   7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,  -7.4116659028541587E-01,   6.7037152710499215E-01,   3.5731911944035378E-03],
            [   3.5694552688208092E-02,  -7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,   7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5731911944035378E-03],
            [  -3.5694552688208092E-02,  -7.4116659028541587E-01,  -6.7037152710499215E-01,   3.5731911944035378E-03],
        ])
  
        order = 107
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build4334():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.8209462984774535E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.8209462984774535E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.8209462984774535E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.8209462984774535E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.8209462984774535E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.8209462984774535E-04],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.1998721250626281E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   3.1998721250626281E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.1998721250626281E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1998721250626281E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   3.1998721250626281E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1998721250626281E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1998721250626281E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   3.1998721250626281E-03],
            [   1.4628961518310130E-02,   1.4628961518310130E-02,   9.9978597058059959E-01,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,   1.4628961518310130E-02,   9.9978597058059959E-01,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,  -1.4628961518310130E-02,   9.9978597058059959E-01,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,   1.4628961518310130E-02,  -9.9978597058059959E-01,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,  -1.4628961518310130E-02,   9.9978597058059959E-01,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,   1.4628961518310130E-02,  -9.9978597058059959E-01,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,  -1.4628961518310130E-02,  -9.9978597058059959E-01,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,  -1.4628961518310130E-02,  -9.9978597058059959E-01,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,   9.9978597058059959E-01,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,  -9.9978597058059959E-01,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,   9.9978597058059959E-01,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,  -9.9978597058059959E-01,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,   9.9978597058059959E-01,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,  -9.9978597058059959E-01,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -1.4628961518310130E-02,  -9.9978597058059959E-01,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [   1.4628961518310130E-02,   9.9978597058059959E-01,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [   9.9978597058059959E-01,   1.4628961518310130E-02,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -9.9978597058059959E-01,   1.4628961518310130E-02,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [   9.9978597058059959E-01,  -1.4628961518310130E-02,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [   9.9978597058059959E-01,   1.4628961518310130E-02,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -9.9978597058059959E-01,  -1.4628961518310130E-02,   1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -9.9978597058059959E-01,   1.4628961518310130E-02,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [   9.9978597058059959E-01,  -1.4628961518310130E-02,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [  -9.9978597058059959E-01,  -1.4628961518310130E-02,  -1.4628961518310130E-02,   7.5629859106700575E-04],
            [   3.7698408124931387E-02,   3.7698408124931387E-02,   9.9857781872505669E-01,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,   3.7698408124931387E-02,   9.9857781872505669E-01,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,  -3.7698408124931387E-02,   9.9857781872505669E-01,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,   3.7698408124931387E-02,  -9.9857781872505669E-01,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,  -3.7698408124931387E-02,   9.9857781872505669E-01,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,   3.7698408124931387E-02,  -9.9857781872505669E-01,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,  -3.7698408124931387E-02,  -9.9857781872505669E-01,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,  -3.7698408124931387E-02,  -9.9857781872505669E-01,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,   9.9857781872505669E-01,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,  -9.9857781872505669E-01,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,   9.9857781872505669E-01,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,  -9.9857781872505669E-01,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,   9.9857781872505669E-01,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,  -9.9857781872505669E-01,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -3.7698408124931387E-02,  -9.9857781872505669E-01,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [   3.7698408124931387E-02,   9.9857781872505669E-01,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [   9.9857781872505669E-01,   3.7698408124931387E-02,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -9.9857781872505669E-01,   3.7698408124931387E-02,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [   9.9857781872505669E-01,  -3.7698408124931387E-02,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [   9.9857781872505669E-01,   3.7698408124931387E-02,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -9.9857781872505669E-01,  -3.7698408124931387E-02,   3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -9.9857781872505669E-01,   3.7698408124931387E-02,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [   9.9857781872505669E-01,  -3.7698408124931387E-02,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [  -9.9857781872505669E-01,  -3.7698408124931387E-02,  -3.7698408124931387E-02,   1.2595104667091079E-03],
            [   6.5247019040968912E-02,   6.5247019040968912E-02,   9.9573372595917176E-01,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,   6.5247019040968912E-02,   9.9573372595917176E-01,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,  -6.5247019040968912E-02,   9.9573372595917176E-01,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,   6.5247019040968912E-02,  -9.9573372595917176E-01,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,  -6.5247019040968912E-02,   9.9573372595917176E-01,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,   6.5247019040968912E-02,  -9.9573372595917176E-01,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,  -6.5247019040968912E-02,  -9.9573372595917176E-01,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,  -6.5247019040968912E-02,  -9.9573372595917176E-01,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,   9.9573372595917176E-01,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,  -9.9573372595917176E-01,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,   9.9573372595917176E-01,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,  -9.9573372595917176E-01,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,   9.9573372595917176E-01,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,  -9.9573372595917176E-01,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -6.5247019040968912E-02,  -9.9573372595917176E-01,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [   6.5247019040968912E-02,   9.9573372595917176E-01,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [   9.9573372595917176E-01,   6.5247019040968912E-02,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -9.9573372595917176E-01,   6.5247019040968912E-02,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [   9.9573372595917176E-01,  -6.5247019040968912E-02,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [   9.9573372595917176E-01,   6.5247019040968912E-02,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -9.9573372595917176E-01,  -6.5247019040968912E-02,   6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -9.9573372595917176E-01,   6.5247019040968912E-02,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [   9.9573372595917176E-01,  -6.5247019040968912E-02,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [  -9.9573372595917176E-01,  -6.5247019040968912E-02,  -6.5247019040968912E-02,   1.6527578791802769E-03],
            [   9.5605434161346481E-02,   9.5605434161346481E-02,   9.9081744126637217E-01,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,   9.5605434161346481E-02,   9.9081744126637217E-01,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,  -9.5605434161346481E-02,   9.9081744126637217E-01,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,   9.5605434161346481E-02,  -9.9081744126637217E-01,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,  -9.5605434161346481E-02,   9.9081744126637217E-01,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,   9.5605434161346481E-02,  -9.9081744126637217E-01,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,  -9.5605434161346481E-02,  -9.9081744126637217E-01,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,  -9.5605434161346481E-02,  -9.9081744126637217E-01,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,   9.9081744126637217E-01,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,  -9.9081744126637217E-01,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,   9.9081744126637217E-01,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,  -9.9081744126637217E-01,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,   9.9081744126637217E-01,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,  -9.9081744126637217E-01,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.5605434161346481E-02,  -9.9081744126637217E-01,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.5605434161346481E-02,   9.9081744126637217E-01,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.9081744126637217E-01,   9.5605434161346481E-02,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.9081744126637217E-01,   9.5605434161346481E-02,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.9081744126637217E-01,  -9.5605434161346481E-02,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.9081744126637217E-01,   9.5605434161346481E-02,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.9081744126637217E-01,  -9.5605434161346481E-02,   9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.9081744126637217E-01,   9.5605434161346481E-02,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [   9.9081744126637217E-01,  -9.5605434161346481E-02,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [  -9.9081744126637217E-01,  -9.5605434161346481E-02,  -9.5605434161346481E-02,   1.9656489663328319E-03],
            [   1.2783358989291979E-01,   1.2783358989291979E-01,   9.8352282464118623E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,   1.2783358989291979E-01,   9.8352282464118623E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,  -1.2783358989291979E-01,   9.8352282464118623E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,   1.2783358989291979E-01,  -9.8352282464118623E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,  -1.2783358989291979E-01,   9.8352282464118623E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,   1.2783358989291979E-01,  -9.8352282464118623E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,  -1.2783358989291979E-01,  -9.8352282464118623E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,  -1.2783358989291979E-01,  -9.8352282464118623E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,   9.8352282464118623E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,  -9.8352282464118623E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,   9.8352282464118623E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,  -9.8352282464118623E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,   9.8352282464118623E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,  -9.8352282464118623E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -1.2783358989291979E-01,  -9.8352282464118623E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [   1.2783358989291979E-01,   9.8352282464118623E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [   9.8352282464118623E-01,   1.2783358989291979E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -9.8352282464118623E-01,   1.2783358989291979E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [   9.8352282464118623E-01,  -1.2783358989291979E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [   9.8352282464118623E-01,   1.2783358989291979E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -9.8352282464118623E-01,  -1.2783358989291979E-01,   1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -9.8352282464118623E-01,   1.2783358989291979E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [   9.8352282464118623E-01,  -1.2783358989291979E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [  -9.8352282464118623E-01,  -1.2783358989291979E-01,  -1.2783358989291979E-01,   2.2181137540774522E-03],
            [   1.6130961044660311E-01,   1.6130961044660311E-01,   9.7363156232485104E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,   1.6130961044660311E-01,   9.7363156232485104E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,  -1.6130961044660311E-01,   9.7363156232485104E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,   1.6130961044660311E-01,  -9.7363156232485104E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,  -1.6130961044660311E-01,   9.7363156232485104E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,   1.6130961044660311E-01,  -9.7363156232485104E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,  -1.6130961044660311E-01,  -9.7363156232485104E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,  -1.6130961044660311E-01,  -9.7363156232485104E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,   9.7363156232485104E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,  -9.7363156232485104E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,   9.7363156232485104E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,  -9.7363156232485104E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,   9.7363156232485104E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,  -9.7363156232485104E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -1.6130961044660311E-01,  -9.7363156232485104E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [   1.6130961044660311E-01,   9.7363156232485104E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [   9.7363156232485104E-01,   1.6130961044660311E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -9.7363156232485104E-01,   1.6130961044660311E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [   9.7363156232485104E-01,  -1.6130961044660311E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [   9.7363156232485104E-01,   1.6130961044660311E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -9.7363156232485104E-01,  -1.6130961044660311E-01,   1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -9.7363156232485104E-01,   1.6130961044660311E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [   9.7363156232485104E-01,  -1.6130961044660311E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [  -9.7363156232485104E-01,  -1.6130961044660311E-01,  -1.6130961044660311E-01,   2.4237225207607103E-03],
            [   1.9558062257453709E-01,   1.9558062257453709E-01,   9.6098722163549755E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,   1.9558062257453709E-01,   9.6098722163549755E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,  -1.9558062257453709E-01,   9.6098722163549755E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,   1.9558062257453709E-01,  -9.6098722163549755E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,  -1.9558062257453709E-01,   9.6098722163549755E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,   1.9558062257453709E-01,  -9.6098722163549755E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,  -1.9558062257453709E-01,  -9.6098722163549755E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,  -1.9558062257453709E-01,  -9.6098722163549755E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,   9.6098722163549755E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,  -9.6098722163549755E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,   9.6098722163549755E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,  -9.6098722163549755E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,   9.6098722163549755E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,  -9.6098722163549755E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -1.9558062257453709E-01,  -9.6098722163549755E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [   1.9558062257453709E-01,   9.6098722163549755E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [   9.6098722163549755E-01,   1.9558062257453709E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -9.6098722163549755E-01,   1.9558062257453709E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [   9.6098722163549755E-01,  -1.9558062257453709E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [   9.6098722163549755E-01,   1.9558062257453709E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -9.6098722163549755E-01,  -1.9558062257453709E-01,   1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -9.6098722163549755E-01,   1.9558062257453709E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [   9.6098722163549755E-01,  -1.9558062257453709E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [  -9.6098722163549755E-01,  -1.9558062257453709E-01,  -1.9558062257453709E-01,   2.5920131592423118E-03],
            [   2.3029352184980281E-01,   2.3029352184980281E-01,   9.4547860239564852E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,   2.3029352184980281E-01,   9.4547860239564852E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,  -2.3029352184980281E-01,   9.4547860239564852E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,   2.3029352184980281E-01,  -9.4547860239564852E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,  -2.3029352184980281E-01,   9.4547860239564852E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,   2.3029352184980281E-01,  -9.4547860239564852E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,  -2.3029352184980281E-01,  -9.4547860239564852E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,  -2.3029352184980281E-01,  -9.4547860239564852E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,   9.4547860239564852E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,  -9.4547860239564852E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,   9.4547860239564852E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,  -9.4547860239564852E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,   9.4547860239564852E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,  -9.4547860239564852E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -2.3029352184980281E-01,  -9.4547860239564852E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [   2.3029352184980281E-01,   9.4547860239564852E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [   9.4547860239564852E-01,   2.3029352184980281E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -9.4547860239564852E-01,   2.3029352184980281E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [   9.4547860239564852E-01,  -2.3029352184980281E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [   9.4547860239564852E-01,   2.3029352184980281E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -9.4547860239564852E-01,  -2.3029352184980281E-01,   2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -9.4547860239564852E-01,   2.3029352184980281E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [   9.4547860239564852E-01,  -2.3029352184980281E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [  -9.4547860239564852E-01,  -2.3029352184980281E-01,  -2.3029352184980281E-01,   2.7299126294801361E-03],
            [   2.6515843441130271E-01,   2.6515843441130271E-01,   9.2702859142590299E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,   2.6515843441130271E-01,   9.2702859142590299E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,  -2.6515843441130271E-01,   9.2702859142590299E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,   2.6515843441130271E-01,  -9.2702859142590299E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,  -2.6515843441130271E-01,   9.2702859142590299E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,   2.6515843441130271E-01,  -9.2702859142590299E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,  -2.6515843441130271E-01,  -9.2702859142590299E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,  -2.6515843441130271E-01,  -9.2702859142590299E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,   9.2702859142590299E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,  -9.2702859142590299E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,   9.2702859142590299E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,  -9.2702859142590299E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,   9.2702859142590299E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,  -9.2702859142590299E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -2.6515843441130271E-01,  -9.2702859142590299E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [   2.6515843441130271E-01,   9.2702859142590299E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [   9.2702859142590299E-01,   2.6515843441130271E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -9.2702859142590299E-01,   2.6515843441130271E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [   9.2702859142590299E-01,  -2.6515843441130271E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [   9.2702859142590299E-01,   2.6515843441130271E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -9.2702859142590299E-01,  -2.6515843441130271E-01,   2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -9.2702859142590299E-01,   2.6515843441130271E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [   9.2702859142590299E-01,  -2.6515843441130271E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [  -9.2702859142590299E-01,  -2.6515843441130271E-01,  -2.6515843441130271E-01,   2.8426087747333547E-03],
            [   2.9992768251832091E-01,   2.9992768251832091E-01,   9.0558642355016483E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,   2.9992768251832091E-01,   9.0558642355016483E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,  -2.9992768251832091E-01,   9.0558642355016483E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,   2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,  -2.9992768251832091E-01,   9.0558642355016483E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,   2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,  -2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,  -2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,   9.0558642355016483E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,   9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,  -9.0558642355016483E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,   9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,  -9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -2.9992768251832091E-01,  -9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [   2.9992768251832091E-01,   9.0558642355016483E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [   9.0558642355016483E-01,   2.9992768251832091E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -9.0558642355016483E-01,   2.9992768251832091E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [   9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [   9.0558642355016483E-01,   2.9992768251832091E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -9.0558642355016483E-01,  -2.9992768251832091E-01,   2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -9.0558642355016483E-01,   2.9992768251832091E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [   9.0558642355016483E-01,  -2.9992768251832091E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [  -9.0558642355016483E-01,  -2.9992768251832091E-01,  -2.9992768251832091E-01,   2.9341039041611730E-03],
            [   3.3438286697187980E-01,   3.3438286697187980E-01,   8.8112212351712760E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,   3.3438286697187980E-01,   8.8112212351712760E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,  -3.3438286697187980E-01,   8.8112212351712760E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,   3.3438286697187980E-01,  -8.8112212351712760E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,  -3.3438286697187980E-01,   8.8112212351712760E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,   3.3438286697187980E-01,  -8.8112212351712760E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,  -3.3438286697187980E-01,  -8.8112212351712760E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,  -3.3438286697187980E-01,  -8.8112212351712760E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,   8.8112212351712760E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,  -8.8112212351712760E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,   8.8112212351712760E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,  -8.8112212351712760E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,   8.8112212351712760E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,  -8.8112212351712760E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -3.3438286697187980E-01,  -8.8112212351712760E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [   3.3438286697187980E-01,   8.8112212351712760E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [   8.8112212351712760E-01,   3.3438286697187980E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -8.8112212351712760E-01,   3.3438286697187980E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [   8.8112212351712760E-01,  -3.3438286697187980E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [   8.8112212351712760E-01,   3.3438286697187980E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -8.8112212351712760E-01,  -3.3438286697187980E-01,   3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -8.8112212351712760E-01,   3.3438286697187980E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [   8.8112212351712760E-01,  -3.3438286697187980E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [  -8.8112212351712760E-01,  -3.3438286697187980E-01,  -3.3438286697187980E-01,   3.0075789374600708E-03],
            [   3.6832650137505180E-01,   3.6832650137505180E-01,   8.5362238534941659E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,   3.6832650137505180E-01,   8.5362238534941659E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,  -3.6832650137505180E-01,   8.5362238534941659E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,   3.6832650137505180E-01,  -8.5362238534941659E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,  -3.6832650137505180E-01,   8.5362238534941659E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,   3.6832650137505180E-01,  -8.5362238534941659E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,  -3.6832650137505180E-01,  -8.5362238534941659E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,  -3.6832650137505180E-01,  -8.5362238534941659E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,   8.5362238534941659E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,  -8.5362238534941659E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,   8.5362238534941659E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,  -8.5362238534941659E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,   8.5362238534941659E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,  -8.5362238534941659E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -3.6832650137505180E-01,  -8.5362238534941659E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [   3.6832650137505180E-01,   8.5362238534941659E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [   8.5362238534941659E-01,   3.6832650137505180E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -8.5362238534941659E-01,   3.6832650137505180E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [   8.5362238534941659E-01,  -3.6832650137505180E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [   8.5362238534941659E-01,   3.6832650137505180E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -8.5362238534941659E-01,  -3.6832650137505180E-01,   3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -8.5362238534941659E-01,   3.6832650137505180E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [   8.5362238534941659E-01,  -3.6832650137505180E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [  -8.5362238534941659E-01,  -3.6832650137505180E-01,  -3.6832650137505180E-01,   3.0656405048761475E-03],
            [   4.0157632065181081E-01,   4.0157632065181081E-01,   8.2308742997539952E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,   4.0157632065181081E-01,   8.2308742997539952E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,  -4.0157632065181081E-01,   8.2308742997539952E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,   4.0157632065181081E-01,  -8.2308742997539952E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,  -4.0157632065181081E-01,   8.2308742997539952E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,   4.0157632065181081E-01,  -8.2308742997539952E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,  -4.0157632065181081E-01,  -8.2308742997539952E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,  -4.0157632065181081E-01,  -8.2308742997539952E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,   8.2308742997539952E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,  -8.2308742997539952E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,   8.2308742997539952E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,  -8.2308742997539952E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,   8.2308742997539952E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,  -8.2308742997539952E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -4.0157632065181081E-01,  -8.2308742997539952E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [   4.0157632065181081E-01,   8.2308742997539952E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [   8.2308742997539952E-01,   4.0157632065181081E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -8.2308742997539952E-01,   4.0157632065181081E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [   8.2308742997539952E-01,  -4.0157632065181081E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [   8.2308742997539952E-01,   4.0157632065181081E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -8.2308742997539952E-01,  -4.0157632065181081E-01,   4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -8.2308742997539952E-01,   4.0157632065181081E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [   8.2308742997539952E-01,  -4.0157632065181081E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [  -8.2308742997539952E-01,  -4.0157632065181081E-01,  -4.0157632065181081E-01,   3.1104932312794116E-03],
            [   4.3396120263997701E-01,   4.3396120263997701E-01,   7.8952856136211413E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,   4.3396120263997701E-01,   7.8952856136211413E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,  -4.3396120263997701E-01,   7.8952856136211413E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,   4.3396120263997701E-01,  -7.8952856136211413E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,  -4.3396120263997701E-01,   7.8952856136211413E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,   4.3396120263997701E-01,  -7.8952856136211413E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,  -4.3396120263997701E-01,  -7.8952856136211413E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,  -4.3396120263997701E-01,  -7.8952856136211413E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,   7.8952856136211413E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,  -7.8952856136211413E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,   7.8952856136211413E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,  -7.8952856136211413E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,   7.8952856136211413E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,  -7.8952856136211413E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -4.3396120263997701E-01,  -7.8952856136211413E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [   4.3396120263997701E-01,   7.8952856136211413E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [   7.8952856136211413E-01,   4.3396120263997701E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -7.8952856136211413E-01,   4.3396120263997701E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [   7.8952856136211413E-01,  -4.3396120263997701E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [   7.8952856136211413E-01,   4.3396120263997701E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -7.8952856136211413E-01,  -4.3396120263997701E-01,   4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -7.8952856136211413E-01,   4.3396120263997701E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [   7.8952856136211413E-01,  -4.3396120263997701E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [  -7.8952856136211413E-01,  -4.3396120263997701E-01,  -4.3396120263997701E-01,   3.1440626468185154E-03],
            [   4.6531806511145818E-01,   4.6531806511145818E-01,   7.5296626522166155E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,   4.6531806511145818E-01,   7.5296626522166155E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,  -4.6531806511145818E-01,   7.5296626522166155E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,   4.6531806511145818E-01,  -7.5296626522166155E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,  -4.6531806511145818E-01,   7.5296626522166155E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,   4.6531806511145818E-01,  -7.5296626522166155E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,  -4.6531806511145818E-01,  -7.5296626522166155E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,  -4.6531806511145818E-01,  -7.5296626522166155E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,   7.5296626522166155E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,  -7.5296626522166155E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,   7.5296626522166155E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,  -7.5296626522166155E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,   7.5296626522166155E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,  -7.5296626522166155E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -4.6531806511145818E-01,  -7.5296626522166155E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [   4.6531806511145818E-01,   7.5296626522166155E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [   7.5296626522166155E-01,   4.6531806511145818E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -7.5296626522166155E-01,   4.6531806511145818E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [   7.5296626522166155E-01,  -4.6531806511145818E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [   7.5296626522166155E-01,   4.6531806511145818E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -7.5296626522166155E-01,  -4.6531806511145818E-01,   4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -7.5296626522166155E-01,   4.6531806511145818E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [   7.5296626522166155E-01,  -4.6531806511145818E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [  -7.5296626522166155E-01,  -4.6531806511145818E-01,  -4.6531806511145818E-01,   3.1680843320967592E-03],
            [   4.9548933310808030E-01,   4.9548933310808030E-01,   7.1342879220859856E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,   4.9548933310808030E-01,   7.1342879220859856E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,  -4.9548933310808030E-01,   7.1342879220859856E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,   4.9548933310808030E-01,  -7.1342879220859856E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,  -4.9548933310808030E-01,   7.1342879220859856E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,   4.9548933310808030E-01,  -7.1342879220859856E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,  -4.9548933310808030E-01,  -7.1342879220859856E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,  -4.9548933310808030E-01,  -7.1342879220859856E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,   7.1342879220859856E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,  -7.1342879220859856E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,   7.1342879220859856E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,  -7.1342879220859856E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,   7.1342879220859856E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,  -7.1342879220859856E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -4.9548933310808030E-01,  -7.1342879220859856E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [   4.9548933310808030E-01,   7.1342879220859856E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [   7.1342879220859856E-01,   4.9548933310808030E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -7.1342879220859856E-01,   4.9548933310808030E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [   7.1342879220859856E-01,  -4.9548933310808030E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [   7.1342879220859856E-01,   4.9548933310808030E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -7.1342879220859856E-01,  -4.9548933310808030E-01,   4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -7.1342879220859856E-01,   4.9548933310808030E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [   7.1342879220859856E-01,  -4.9548933310808030E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [  -7.1342879220859856E-01,  -4.9548933310808030E-01,  -4.9548933310808030E-01,   3.1841687768692545E-03],
            [   5.2432070689249299E-01,   5.2432070689249299E-01,   6.7095125951704793E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,   5.2432070689249299E-01,   6.7095125951704793E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,  -5.2432070689249299E-01,   6.7095125951704793E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,   5.2432070689249299E-01,  -6.7095125951704793E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,  -5.2432070689249299E-01,   6.7095125951704793E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,   5.2432070689249299E-01,  -6.7095125951704793E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,  -5.2432070689249299E-01,  -6.7095125951704793E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,  -5.2432070689249299E-01,  -6.7095125951704793E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,   6.7095125951704793E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,  -6.7095125951704793E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,   6.7095125951704793E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,  -6.7095125951704793E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,   6.7095125951704793E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,  -6.7095125951704793E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -5.2432070689249299E-01,  -6.7095125951704793E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [   5.2432070689249299E-01,   6.7095125951704793E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [   6.7095125951704793E-01,   5.2432070689249299E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -6.7095125951704793E-01,   5.2432070689249299E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [   6.7095125951704793E-01,  -5.2432070689249299E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [   6.7095125951704793E-01,   5.2432070689249299E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -6.7095125951704793E-01,  -5.2432070689249299E-01,   5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -6.7095125951704793E-01,   5.2432070689249299E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [   6.7095125951704793E-01,  -5.2432070689249299E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [  -6.7095125951704793E-01,  -5.2432070689249299E-01,  -5.2432070689249299E-01,   3.1938472679177328E-03],
            [   5.5165904790417042E-01,   5.5165904790417042E-01,   6.2557540691025282E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,   5.5165904790417042E-01,   6.2557540691025282E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,  -5.5165904790417042E-01,   6.2557540691025282E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,   5.5165904790417042E-01,  -6.2557540691025282E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,  -5.5165904790417042E-01,   6.2557540691025282E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,   5.5165904790417042E-01,  -6.2557540691025282E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,  -5.5165904790417042E-01,  -6.2557540691025282E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,  -5.5165904790417042E-01,  -6.2557540691025282E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,   6.2557540691025282E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,  -6.2557540691025282E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,   6.2557540691025282E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,  -6.2557540691025282E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,   6.2557540691025282E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,  -6.2557540691025282E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -5.5165904790417042E-01,  -6.2557540691025282E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [   5.5165904790417042E-01,   6.2557540691025282E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [   6.2557540691025282E-01,   5.5165904790417042E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -6.2557540691025282E-01,   5.5165904790417042E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [   6.2557540691025282E-01,  -5.5165904790417042E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [   6.2557540691025282E-01,   5.5165904790417042E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -6.2557540691025282E-01,  -5.5165904790417042E-01,   5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -6.2557540691025282E-01,   5.5165904790417042E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [   6.2557540691025282E-01,  -5.5165904790417042E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [  -6.2557540691025282E-01,  -5.5165904790417042E-01,  -5.5165904790417042E-01,   3.1986009206841628E-03],
            [   6.0123719278041765E-01,   6.0123719278041765E-01,   5.2633418664860243E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,   6.0123719278041765E-01,   5.2633418664860243E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,  -6.0123719278041765E-01,   5.2633418664860243E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,   6.0123719278041765E-01,  -5.2633418664860243E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,  -6.0123719278041765E-01,   5.2633418664860243E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,   6.0123719278041765E-01,  -5.2633418664860243E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,  -6.0123719278041765E-01,  -5.2633418664860243E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,  -6.0123719278041765E-01,  -5.2633418664860243E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,   5.2633418664860243E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,  -5.2633418664860243E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,   5.2633418664860243E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,  -5.2633418664860243E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,   5.2633418664860243E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,  -5.2633418664860243E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -6.0123719278041765E-01,  -5.2633418664860243E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [   6.0123719278041765E-01,   5.2633418664860243E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [   5.2633418664860243E-01,   6.0123719278041765E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -5.2633418664860243E-01,   6.0123719278041765E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [   5.2633418664860243E-01,  -6.0123719278041765E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [   5.2633418664860243E-01,   6.0123719278041765E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -5.2633418664860243E-01,  -6.0123719278041765E-01,   6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -5.2633418664860243E-01,   6.0123719278041765E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [   5.2633418664860243E-01,  -6.0123719278041765E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [  -5.2633418664860243E-01,  -6.0123719278041765E-01,  -6.0123719278041765E-01,   3.1990548877855558E-03],
            [   6.2315744664498185E-01,   6.2315744664498185E-01,   4.7259876574300652E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,   6.2315744664498185E-01,   4.7259876574300652E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,  -6.2315744664498185E-01,   4.7259876574300652E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,   6.2315744664498185E-01,  -4.7259876574300652E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,  -6.2315744664498185E-01,   4.7259876574300652E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,   6.2315744664498185E-01,  -4.7259876574300652E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,  -6.2315744664498185E-01,  -4.7259876574300652E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,  -6.2315744664498185E-01,  -4.7259876574300652E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,   4.7259876574300652E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,  -4.7259876574300652E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,   4.7259876574300652E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,  -4.7259876574300652E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,   4.7259876574300652E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,  -4.7259876574300652E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -6.2315744664498185E-01,  -4.7259876574300652E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [   6.2315744664498185E-01,   4.7259876574300652E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [   4.7259876574300652E-01,   6.2315744664498185E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -4.7259876574300652E-01,   6.2315744664498185E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [   4.7259876574300652E-01,  -6.2315744664498185E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [   4.7259876574300652E-01,   6.2315744664498185E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -4.7259876574300652E-01,  -6.2315744664498185E-01,   6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -4.7259876574300652E-01,   6.2315744664498185E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [   4.7259876574300652E-01,  -6.2315744664498185E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [  -4.7259876574300652E-01,  -6.2315744664498185E-01,  -6.2315744664498185E-01,   3.1974579589355233E-03],
            [   6.4294165141812709E-01,   6.4294165141812709E-01,   4.1623558923218362E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,   6.4294165141812709E-01,   4.1623558923218362E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,  -6.4294165141812709E-01,   4.1623558923218362E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,   6.4294165141812709E-01,  -4.1623558923218362E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,  -6.4294165141812709E-01,   4.1623558923218362E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,   6.4294165141812709E-01,  -4.1623558923218362E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,  -6.4294165141812709E-01,  -4.1623558923218362E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,  -6.4294165141812709E-01,  -4.1623558923218362E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,   4.1623558923218362E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,  -4.1623558923218362E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,   4.1623558923218362E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,  -4.1623558923218362E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,   4.1623558923218362E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,  -4.1623558923218362E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -6.4294165141812709E-01,  -4.1623558923218362E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [   6.4294165141812709E-01,   4.1623558923218362E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [   4.1623558923218362E-01,   6.4294165141812709E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -4.1623558923218362E-01,   6.4294165141812709E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [   4.1623558923218362E-01,  -6.4294165141812709E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [   4.1623558923218362E-01,   6.4294165141812709E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -4.1623558923218362E-01,  -6.4294165141812709E-01,   6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -4.1623558923218362E-01,   6.4294165141812709E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [   4.1623558923218362E-01,  -6.4294165141812709E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [  -4.1623558923218362E-01,  -6.4294165141812709E-01,  -6.4294165141812709E-01,   3.1962332397209542E-03],
            [   6.6041242729435945E-01,   6.6041242729435945E-01,   3.5736655096741327E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,   6.6041242729435945E-01,   3.5736655096741327E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,  -6.6041242729435945E-01,   3.5736655096741327E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,   6.6041242729435945E-01,  -3.5736655096741327E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,  -6.6041242729435945E-01,   3.5736655096741327E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,   6.6041242729435945E-01,  -3.5736655096741327E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,  -6.6041242729435945E-01,  -3.5736655096741327E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,  -6.6041242729435945E-01,  -3.5736655096741327E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,   3.5736655096741327E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,  -3.5736655096741327E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,   3.5736655096741327E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,  -3.5736655096741327E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,   3.5736655096741327E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,  -3.5736655096741327E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -6.6041242729435945E-01,  -3.5736655096741327E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [   6.6041242729435945E-01,   3.5736655096741327E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [   3.5736655096741327E-01,   6.6041242729435945E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -3.5736655096741327E-01,   6.6041242729435945E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [   3.5736655096741327E-01,  -6.6041242729435945E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [   3.5736655096741327E-01,   6.6041242729435945E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -3.5736655096741327E-01,  -6.6041242729435945E-01,   6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -3.5736655096741327E-01,   6.6041242729435945E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [   3.5736655096741327E-01,  -6.6041242729435945E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [  -3.5736655096741327E-01,  -6.6041242729435945E-01,  -6.6041242729435945E-01,   3.1962644728672804E-03],
            [   6.7538514704082497E-01,   6.7538514704082497E-01,   2.9615841421996864E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,   6.7538514704082497E-01,   2.9615841421996864E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,  -6.7538514704082497E-01,   2.9615841421996864E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,   6.7538514704082497E-01,  -2.9615841421996864E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,  -6.7538514704082497E-01,   2.9615841421996864E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,   6.7538514704082497E-01,  -2.9615841421996864E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,  -6.7538514704082497E-01,  -2.9615841421996864E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,  -6.7538514704082497E-01,  -2.9615841421996864E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,   2.9615841421996864E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,  -2.9615841421996864E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,   2.9615841421996864E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,  -2.9615841421996864E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,   2.9615841421996864E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,  -2.9615841421996864E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -6.7538514704082497E-01,  -2.9615841421996864E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [   6.7538514704082497E-01,   2.9615841421996864E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [   2.9615841421996864E-01,   6.7538514704082497E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -2.9615841421996864E-01,   6.7538514704082497E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [   2.9615841421996864E-01,  -6.7538514704082497E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [   2.9615841421996864E-01,   6.7538514704082497E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -2.9615841421996864E-01,  -6.7538514704082497E-01,   6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -2.9615841421996864E-01,   6.7538514704082497E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [   2.9615841421996864E-01,  -6.7538514704082497E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [  -2.9615841421996864E-01,  -6.7538514704082497E-01,  -6.7538514704082497E-01,   3.1980227896840708E-03],
            [   6.8767179706261605E-01,   6.8767179706261605E-01,   2.3284114552489313E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,   6.8767179706261605E-01,   2.3284114552489313E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,  -6.8767179706261605E-01,   2.3284114552489313E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,   6.8767179706261605E-01,  -2.3284114552489313E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,  -6.8767179706261605E-01,   2.3284114552489313E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,   6.8767179706261605E-01,  -2.3284114552489313E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,  -6.8767179706261605E-01,  -2.3284114552489313E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,  -6.8767179706261605E-01,  -2.3284114552489313E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,   2.3284114552489313E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,  -2.3284114552489313E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,   2.3284114552489313E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,  -2.3284114552489313E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,   2.3284114552489313E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,  -2.3284114552489313E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -6.8767179706261605E-01,  -2.3284114552489313E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [   6.8767179706261605E-01,   2.3284114552489313E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [   2.3284114552489313E-01,   6.8767179706261605E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -2.3284114552489313E-01,   6.8767179706261605E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [   2.3284114552489313E-01,  -6.8767179706261605E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [   2.3284114552489313E-01,   6.8767179706261605E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -2.3284114552489313E-01,  -6.8767179706261605E-01,   6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -2.3284114552489313E-01,   6.8767179706261605E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [   2.3284114552489313E-01,  -6.8767179706261605E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [  -2.3284114552489313E-01,  -6.8767179706261605E-01,  -6.8767179706261605E-01,   3.2014229126059251E-03],
            [   6.9708950613192344E-01,   6.9708950613192344E-01,   1.6772728126784303E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,   6.9708950613192344E-01,   1.6772728126784303E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,  -6.9708950613192344E-01,   1.6772728126784303E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,   6.9708950613192344E-01,  -1.6772728126784303E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,  -6.9708950613192344E-01,   1.6772728126784303E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,   6.9708950613192344E-01,  -1.6772728126784303E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,  -6.9708950613192344E-01,  -1.6772728126784303E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,  -6.9708950613192344E-01,  -1.6772728126784303E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,   1.6772728126784303E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,  -1.6772728126784303E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,   1.6772728126784303E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,  -1.6772728126784303E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,   1.6772728126784303E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,  -1.6772728126784303E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -6.9708950613192344E-01,  -1.6772728126784303E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [   6.9708950613192344E-01,   1.6772728126784303E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [   1.6772728126784303E-01,   6.9708950613192344E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -1.6772728126784303E-01,   6.9708950613192344E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [   1.6772728126784303E-01,  -6.9708950613192344E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [   1.6772728126784303E-01,   6.9708950613192344E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -1.6772728126784303E-01,  -6.9708950613192344E-01,   6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -1.6772728126784303E-01,   6.9708950613192344E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [   1.6772728126784303E-01,  -6.9708950613192344E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [  -1.6772728126784303E-01,  -6.9708950613192344E-01,  -6.9708950613192344E-01,   3.2057570137496746E-03],
            [   7.0347469125533102E-01,   7.0347469125533102E-01,   1.0122607137705858E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,   7.0347469125533102E-01,   1.0122607137705858E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,  -7.0347469125533102E-01,   1.0122607137705858E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,   7.0347469125533102E-01,  -1.0122607137705858E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,  -7.0347469125533102E-01,   1.0122607137705858E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,   7.0347469125533102E-01,  -1.0122607137705858E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,  -7.0347469125533102E-01,  -1.0122607137705858E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,  -7.0347469125533102E-01,  -1.0122607137705858E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,   1.0122607137705858E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,  -1.0122607137705858E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,   1.0122607137705858E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,  -1.0122607137705858E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,   1.0122607137705858E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,  -1.0122607137705858E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -7.0347469125533102E-01,  -1.0122607137705858E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [   7.0347469125533102E-01,   1.0122607137705858E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [   1.0122607137705858E-01,   7.0347469125533102E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -1.0122607137705858E-01,   7.0347469125533102E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [   1.0122607137705858E-01,  -7.0347469125533102E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [   1.0122607137705858E-01,   7.0347469125533102E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -1.0122607137705858E-01,  -7.0347469125533102E-01,   7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -1.0122607137705858E-01,   7.0347469125533102E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [   1.0122607137705858E-01,  -7.0347469125533102E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [  -1.0122607137705858E-01,  -7.0347469125533102E-01,  -7.0347469125533102E-01,   3.2098179097600540E-03],
            [   7.0670172175422952E-01,   7.0670172175422952E-01,   3.3843063384025068E-02,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,   7.0670172175422952E-01,   3.3843063384025068E-02,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,  -7.0670172175422952E-01,   3.3843063384025068E-02,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,   7.0670172175422952E-01,  -3.3843063384025068E-02,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,  -7.0670172175422952E-01,   3.3843063384025068E-02,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,   7.0670172175422952E-01,  -3.3843063384025068E-02,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,  -7.0670172175422952E-01,  -3.3843063384025068E-02,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,  -7.0670172175422952E-01,  -3.3843063384025068E-02,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,   3.3843063384025068E-02,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,  -3.3843063384025068E-02,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,   3.3843063384025068E-02,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,  -3.3843063384025068E-02,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,   3.3843063384025068E-02,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,  -3.3843063384025068E-02,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -7.0670172175422952E-01,  -3.3843063384025068E-02,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [   7.0670172175422952E-01,   3.3843063384025068E-02,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [   3.3843063384025068E-02,   7.0670172175422952E-01,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -3.3843063384025068E-02,   7.0670172175422952E-01,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [   3.3843063384025068E-02,  -7.0670172175422952E-01,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [   3.3843063384025068E-02,   7.0670172175422952E-01,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -3.3843063384025068E-02,  -7.0670172175422952E-01,   7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -3.3843063384025068E-02,   7.0670172175422952E-01,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [   3.3843063384025068E-02,  -7.0670172175422952E-01,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [  -3.3843063384025068E-02,  -7.0670172175422952E-01,  -7.0670172175422952E-01,   3.2122856645556688E-03],
            [   4.3822235011311231E-02,   9.9903934442974440E-01,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [  -4.3822235011311231E-02,   9.9903934442974440E-01,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [   4.3822235011311231E-02,  -9.9903934442974440E-01,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [  -4.3822235011311231E-02,  -9.9903934442974440E-01,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [   9.9903934442974440E-01,   4.3822235011311231E-02,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [  -9.9903934442974440E-01,   4.3822235011311231E-02,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [   9.9903934442974440E-01,  -4.3822235011311231E-02,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [  -9.9903934442974440E-01,  -4.3822235011311231E-02,   0.0000000000000000E+00,   1.1361682545917241E-03],
            [   4.3822235011311231E-02,   0.0000000000000000E+00,   9.9903934442974440E-01,   1.1361682545917241E-03],
            [  -4.3822235011311231E-02,   0.0000000000000000E+00,   9.9903934442974440E-01,   1.1361682545917241E-03],
            [   4.3822235011311231E-02,   0.0000000000000000E+00,  -9.9903934442974440E-01,   1.1361682545917241E-03],
            [  -4.3822235011311231E-02,   0.0000000000000000E+00,  -9.9903934442974440E-01,   1.1361682545917241E-03],
            [   9.9903934442974440E-01,   0.0000000000000000E+00,   4.3822235011311231E-02,   1.1361682545917241E-03],
            [  -9.9903934442974440E-01,   0.0000000000000000E+00,   4.3822235011311231E-02,   1.1361682545917241E-03],
            [   9.9903934442974440E-01,   0.0000000000000000E+00,  -4.3822235011311231E-02,   1.1361682545917241E-03],
            [  -9.9903934442974440E-01,   0.0000000000000000E+00,  -4.3822235011311231E-02,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,   4.3822235011311231E-02,   9.9903934442974440E-01,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,  -4.3822235011311231E-02,   9.9903934442974440E-01,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,   4.3822235011311231E-02,  -9.9903934442974440E-01,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,  -4.3822235011311231E-02,  -9.9903934442974440E-01,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,   9.9903934442974440E-01,   4.3822235011311231E-02,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,  -9.9903934442974440E-01,   4.3822235011311231E-02,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,   9.9903934442974440E-01,  -4.3822235011311231E-02,   1.1361682545917241E-03],
            [   0.0000000000000000E+00,  -9.9903934442974440E-01,  -4.3822235011311231E-02,   1.1361682545917241E-03],
            [   1.1174740774000060E-01,   9.9373664361509284E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [  -1.1174740774000060E-01,   9.9373664361509284E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [   1.1174740774000060E-01,  -9.9373664361509284E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [  -1.1174740774000060E-01,  -9.9373664361509284E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [   9.9373664361509284E-01,   1.1174740774000060E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [  -9.9373664361509284E-01,   1.1174740774000060E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [   9.9373664361509284E-01,  -1.1174740774000060E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [  -9.9373664361509284E-01,  -1.1174740774000060E-01,   0.0000000000000000E+00,   1.8075798365225530E-03],
            [   1.1174740774000060E-01,   0.0000000000000000E+00,   9.9373664361509284E-01,   1.8075798365225530E-03],
            [  -1.1174740774000060E-01,   0.0000000000000000E+00,   9.9373664361509284E-01,   1.8075798365225530E-03],
            [   1.1174740774000060E-01,   0.0000000000000000E+00,  -9.9373664361509284E-01,   1.8075798365225530E-03],
            [  -1.1174740774000060E-01,   0.0000000000000000E+00,  -9.9373664361509284E-01,   1.8075798365225530E-03],
            [   9.9373664361509284E-01,   0.0000000000000000E+00,   1.1174740774000060E-01,   1.8075798365225530E-03],
            [  -9.9373664361509284E-01,   0.0000000000000000E+00,   1.1174740774000060E-01,   1.8075798365225530E-03],
            [   9.9373664361509284E-01,   0.0000000000000000E+00,  -1.1174740774000060E-01,   1.8075798365225530E-03],
            [  -9.9373664361509284E-01,   0.0000000000000000E+00,  -1.1174740774000060E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,   1.1174740774000060E-01,   9.9373664361509284E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,  -1.1174740774000060E-01,   9.9373664361509284E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,   1.1174740774000060E-01,  -9.9373664361509284E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,  -1.1174740774000060E-01,  -9.9373664361509284E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,   9.9373664361509284E-01,   1.1174740774000060E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,  -9.9373664361509284E-01,   1.1174740774000060E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,   9.9373664361509284E-01,  -1.1174740774000060E-01,   1.8075798365225530E-03],
            [   0.0000000000000000E+00,  -9.9373664361509284E-01,  -1.1174740774000060E-01,   1.8075798365225530E-03],
            [   1.8971532529114399E-01,   9.8183913924312238E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [  -1.8971532529114399E-01,   9.8183913924312238E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [   1.8971532529114399E-01,  -9.8183913924312238E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [  -1.8971532529114399E-01,  -9.8183913924312238E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [   9.8183913924312238E-01,   1.8971532529114399E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [  -9.8183913924312238E-01,   1.8971532529114399E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [   9.8183913924312238E-01,  -1.8971532529114399E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [  -9.8183913924312238E-01,  -1.8971532529114399E-01,   0.0000000000000000E+00,   2.2651173187624458E-03],
            [   1.8971532529114399E-01,   0.0000000000000000E+00,   9.8183913924312238E-01,   2.2651173187624458E-03],
            [  -1.8971532529114399E-01,   0.0000000000000000E+00,   9.8183913924312238E-01,   2.2651173187624458E-03],
            [   1.8971532529114399E-01,   0.0000000000000000E+00,  -9.8183913924312238E-01,   2.2651173187624458E-03],
            [  -1.8971532529114399E-01,   0.0000000000000000E+00,  -9.8183913924312238E-01,   2.2651173187624458E-03],
            [   9.8183913924312238E-01,   0.0000000000000000E+00,   1.8971532529114399E-01,   2.2651173187624458E-03],
            [  -9.8183913924312238E-01,   0.0000000000000000E+00,   1.8971532529114399E-01,   2.2651173187624458E-03],
            [   9.8183913924312238E-01,   0.0000000000000000E+00,  -1.8971532529114399E-01,   2.2651173187624458E-03],
            [  -9.8183913924312238E-01,   0.0000000000000000E+00,  -1.8971532529114399E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,   1.8971532529114399E-01,   9.8183913924312238E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,  -1.8971532529114399E-01,   9.8183913924312238E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,   1.8971532529114399E-01,  -9.8183913924312238E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,  -1.8971532529114399E-01,  -9.8183913924312238E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,   9.8183913924312238E-01,   1.8971532529114399E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,  -9.8183913924312238E-01,   1.8971532529114399E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,   9.8183913924312238E-01,  -1.8971532529114399E-01,   2.2651173187624458E-03],
            [   0.0000000000000000E+00,  -9.8183913924312238E-01,  -1.8971532529114399E-01,   2.2651173187624458E-03],
            [   2.7240230099103308E-01,   9.6218344738141826E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [  -2.7240230099103308E-01,   9.6218344738141826E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [   2.7240230099103308E-01,  -9.6218344738141826E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [  -2.7240230099103308E-01,  -9.6218344738141826E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [   9.6218344738141826E-01,   2.7240230099103308E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [  -9.6218344738141826E-01,   2.7240230099103308E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [   9.6218344738141826E-01,  -2.7240230099103308E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [  -9.6218344738141826E-01,  -2.7240230099103308E-01,   0.0000000000000000E+00,   2.5887380568205554E-03],
            [   2.7240230099103308E-01,   0.0000000000000000E+00,   9.6218344738141826E-01,   2.5887380568205554E-03],
            [  -2.7240230099103308E-01,   0.0000000000000000E+00,   9.6218344738141826E-01,   2.5887380568205554E-03],
            [   2.7240230099103308E-01,   0.0000000000000000E+00,  -9.6218344738141826E-01,   2.5887380568205554E-03],
            [  -2.7240230099103308E-01,   0.0000000000000000E+00,  -9.6218344738141826E-01,   2.5887380568205554E-03],
            [   9.6218344738141826E-01,   0.0000000000000000E+00,   2.7240230099103308E-01,   2.5887380568205554E-03],
            [  -9.6218344738141826E-01,   0.0000000000000000E+00,   2.7240230099103308E-01,   2.5887380568205554E-03],
            [   9.6218344738141826E-01,   0.0000000000000000E+00,  -2.7240230099103308E-01,   2.5887380568205554E-03],
            [  -9.6218344738141826E-01,   0.0000000000000000E+00,  -2.7240230099103308E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,   2.7240230099103308E-01,   9.6218344738141826E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,  -2.7240230099103308E-01,   9.6218344738141826E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,   2.7240230099103308E-01,  -9.6218344738141826E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,  -2.7240230099103308E-01,  -9.6218344738141826E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,   9.6218344738141826E-01,   2.7240230099103308E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,  -9.6218344738141826E-01,   2.7240230099103308E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,   9.6218344738141826E-01,  -2.7240230099103308E-01,   2.5887380568205554E-03],
            [   0.0000000000000000E+00,  -9.6218344738141826E-01,  -2.7240230099103308E-01,   2.5887380568205554E-03],
            [   3.5671633087099019E-01,   9.3421274840902180E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [  -3.5671633087099019E-01,   9.3421274840902180E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [   3.5671633087099019E-01,  -9.3421274840902180E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [  -3.5671633087099019E-01,  -9.3421274840902180E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [   9.3421274840902180E-01,   3.5671633087099019E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [  -9.3421274840902180E-01,   3.5671633087099019E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [   9.3421274840902180E-01,  -3.5671633087099019E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [  -9.3421274840902180E-01,  -3.5671633087099019E-01,   0.0000000000000000E+00,   2.8211530290595021E-03],
            [   3.5671633087099019E-01,   0.0000000000000000E+00,   9.3421274840902180E-01,   2.8211530290595021E-03],
            [  -3.5671633087099019E-01,   0.0000000000000000E+00,   9.3421274840902180E-01,   2.8211530290595021E-03],
            [   3.5671633087099019E-01,   0.0000000000000000E+00,  -9.3421274840902180E-01,   2.8211530290595021E-03],
            [  -3.5671633087099019E-01,   0.0000000000000000E+00,  -9.3421274840902180E-01,   2.8211530290595021E-03],
            [   9.3421274840902180E-01,   0.0000000000000000E+00,   3.5671633087099019E-01,   2.8211530290595021E-03],
            [  -9.3421274840902180E-01,   0.0000000000000000E+00,   3.5671633087099019E-01,   2.8211530290595021E-03],
            [   9.3421274840902180E-01,   0.0000000000000000E+00,  -3.5671633087099019E-01,   2.8211530290595021E-03],
            [  -9.3421274840902180E-01,   0.0000000000000000E+00,  -3.5671633087099019E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,   3.5671633087099019E-01,   9.3421274840902180E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,  -3.5671633087099019E-01,   9.3421274840902180E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,   3.5671633087099019E-01,  -9.3421274840902180E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,  -3.5671633087099019E-01,  -9.3421274840902180E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,   9.3421274840902180E-01,   3.5671633087099019E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,  -9.3421274840902180E-01,   3.5671633087099019E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,   9.3421274840902180E-01,  -3.5671633087099019E-01,   2.8211530290595021E-03],
            [   0.0000000000000000E+00,  -9.3421274840902180E-01,  -3.5671633087099019E-01,   2.8211530290595021E-03],
            [   4.4047844830280869E-01,   8.9776318513333453E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [  -4.4047844830280869E-01,   8.9776318513333453E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [   4.4047844830280869E-01,  -8.9776318513333453E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [  -4.4047844830280869E-01,  -8.9776318513333453E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [   8.9776318513333453E-01,   4.4047844830280869E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [  -8.9776318513333453E-01,   4.4047844830280869E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [   8.9776318513333453E-01,  -4.4047844830280869E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [  -8.9776318513333453E-01,  -4.4047844830280869E-01,   0.0000000000000000E+00,   2.9871015019101812E-03],
            [   4.4047844830280869E-01,   0.0000000000000000E+00,   8.9776318513333453E-01,   2.9871015019101812E-03],
            [  -4.4047844830280869E-01,   0.0000000000000000E+00,   8.9776318513333453E-01,   2.9871015019101812E-03],
            [   4.4047844830280869E-01,   0.0000000000000000E+00,  -8.9776318513333453E-01,   2.9871015019101812E-03],
            [  -4.4047844830280869E-01,   0.0000000000000000E+00,  -8.9776318513333453E-01,   2.9871015019101812E-03],
            [   8.9776318513333453E-01,   0.0000000000000000E+00,   4.4047844830280869E-01,   2.9871015019101812E-03],
            [  -8.9776318513333453E-01,   0.0000000000000000E+00,   4.4047844830280869E-01,   2.9871015019101812E-03],
            [   8.9776318513333453E-01,   0.0000000000000000E+00,  -4.4047844830280869E-01,   2.9871015019101812E-03],
            [  -8.9776318513333453E-01,   0.0000000000000000E+00,  -4.4047844830280869E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,   4.4047844830280869E-01,   8.9776318513333453E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,  -4.4047844830280869E-01,   8.9776318513333453E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,   4.4047844830280869E-01,  -8.9776318513333453E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,  -4.4047844830280869E-01,  -8.9776318513333453E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,   8.9776318513333453E-01,   4.4047844830280869E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,  -8.9776318513333453E-01,   4.4047844830280869E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,   8.9776318513333453E-01,  -4.4047844830280869E-01,   2.9871015019101812E-03],
            [   0.0000000000000000E+00,  -8.9776318513333453E-01,  -4.4047844830280869E-01,   2.9871015019101812E-03],
            [   5.2198331541614107E-01,   8.5295569546558125E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [  -5.2198331541614107E-01,   8.5295569546558125E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [   5.2198331541614107E-01,  -8.5295569546558125E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [  -5.2198331541614107E-01,  -8.5295569546558125E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [   8.5295569546558125E-01,   5.2198331541614107E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [  -8.5295569546558125E-01,   5.2198331541614107E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [   8.5295569546558125E-01,  -5.2198331541614107E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [  -8.5295569546558125E-01,  -5.2198331541614107E-01,   0.0000000000000000E+00,   3.1015297519945001E-03],
            [   5.2198331541614107E-01,   0.0000000000000000E+00,   8.5295569546558125E-01,   3.1015297519945001E-03],
            [  -5.2198331541614107E-01,   0.0000000000000000E+00,   8.5295569546558125E-01,   3.1015297519945001E-03],
            [   5.2198331541614107E-01,   0.0000000000000000E+00,  -8.5295569546558125E-01,   3.1015297519945001E-03],
            [  -5.2198331541614107E-01,   0.0000000000000000E+00,  -8.5295569546558125E-01,   3.1015297519945001E-03],
            [   8.5295569546558125E-01,   0.0000000000000000E+00,   5.2198331541614107E-01,   3.1015297519945001E-03],
            [  -8.5295569546558125E-01,   0.0000000000000000E+00,   5.2198331541614107E-01,   3.1015297519945001E-03],
            [   8.5295569546558125E-01,   0.0000000000000000E+00,  -5.2198331541614107E-01,   3.1015297519945001E-03],
            [  -8.5295569546558125E-01,   0.0000000000000000E+00,  -5.2198331541614107E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,   5.2198331541614107E-01,   8.5295569546558125E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,  -5.2198331541614107E-01,   8.5295569546558125E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,   5.2198331541614107E-01,  -8.5295569546558125E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,  -5.2198331541614107E-01,  -8.5295569546558125E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,   8.5295569546558125E-01,   5.2198331541614107E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,  -8.5295569546558125E-01,   5.2198331541614107E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,   8.5295569546558125E-01,  -5.2198331541614107E-01,   3.1015297519945001E-03],
            [   0.0000000000000000E+00,  -8.5295569546558125E-01,  -5.2198331541614107E-01,   3.1015297519945001E-03],
            [   5.9981798689775534E-01,   8.0013647747988859E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [  -5.9981798689775534E-01,   8.0013647747988859E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [   5.9981798689775534E-01,  -8.0013647747988859E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [  -5.9981798689775534E-01,  -8.0013647747988859E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [   8.0013647747988859E-01,   5.9981798689775534E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [  -8.0013647747988859E-01,   5.9981798689775534E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [   8.0013647747988859E-01,  -5.9981798689775534E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [  -8.0013647747988859E-01,  -5.9981798689775534E-01,   0.0000000000000000E+00,   3.1735248983229725E-03],
            [   5.9981798689775534E-01,   0.0000000000000000E+00,   8.0013647747988859E-01,   3.1735248983229725E-03],
            [  -5.9981798689775534E-01,   0.0000000000000000E+00,   8.0013647747988859E-01,   3.1735248983229725E-03],
            [   5.9981798689775534E-01,   0.0000000000000000E+00,  -8.0013647747988859E-01,   3.1735248983229725E-03],
            [  -5.9981798689775534E-01,   0.0000000000000000E+00,  -8.0013647747988859E-01,   3.1735248983229725E-03],
            [   8.0013647747988859E-01,   0.0000000000000000E+00,   5.9981798689775534E-01,   3.1735248983229725E-03],
            [  -8.0013647747988859E-01,   0.0000000000000000E+00,   5.9981798689775534E-01,   3.1735248983229725E-03],
            [   8.0013647747988859E-01,   0.0000000000000000E+00,  -5.9981798689775534E-01,   3.1735248983229725E-03],
            [  -8.0013647747988859E-01,   0.0000000000000000E+00,  -5.9981798689775534E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,   5.9981798689775534E-01,   8.0013647747988859E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,  -5.9981798689775534E-01,   8.0013647747988859E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,   5.9981798689775534E-01,  -8.0013647747988859E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,  -5.9981798689775534E-01,  -8.0013647747988859E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,   8.0013647747988859E-01,   5.9981798689775534E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,  -8.0013647747988859E-01,   5.9981798689775534E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,   8.0013647747988859E-01,  -5.9981798689775534E-01,   3.1735248983229725E-03],
            [   0.0000000000000000E+00,  -8.0013647747988859E-01,  -5.9981798689775534E-01,   3.1735248983229725E-03],
            [   6.7278031545482220E-01,   7.3984231234534703E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [  -6.7278031545482220E-01,   7.3984231234534703E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [   6.7278031545482220E-01,  -7.3984231234534703E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [  -6.7278031545482220E-01,  -7.3984231234534703E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [   7.3984231234534703E-01,   6.7278031545482220E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [  -7.3984231234534703E-01,   6.7278031545482220E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [   7.3984231234534703E-01,  -6.7278031545482220E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [  -7.3984231234534703E-01,  -6.7278031545482220E-01,   0.0000000000000000E+00,   3.2083218533266009E-03],
            [   6.7278031545482220E-01,   0.0000000000000000E+00,   7.3984231234534703E-01,   3.2083218533266009E-03],
            [  -6.7278031545482220E-01,   0.0000000000000000E+00,   7.3984231234534703E-01,   3.2083218533266009E-03],
            [   6.7278031545482220E-01,   0.0000000000000000E+00,  -7.3984231234534703E-01,   3.2083218533266009E-03],
            [  -6.7278031545482220E-01,   0.0000000000000000E+00,  -7.3984231234534703E-01,   3.2083218533266009E-03],
            [   7.3984231234534703E-01,   0.0000000000000000E+00,   6.7278031545482220E-01,   3.2083218533266009E-03],
            [  -7.3984231234534703E-01,   0.0000000000000000E+00,   6.7278031545482220E-01,   3.2083218533266009E-03],
            [   7.3984231234534703E-01,   0.0000000000000000E+00,  -6.7278031545482220E-01,   3.2083218533266009E-03],
            [  -7.3984231234534703E-01,   0.0000000000000000E+00,  -6.7278031545482220E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,   6.7278031545482220E-01,   7.3984231234534703E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,  -6.7278031545482220E-01,   7.3984231234534703E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,   6.7278031545482220E-01,  -7.3984231234534703E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,  -6.7278031545482220E-01,  -7.3984231234534703E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,   7.3984231234534703E-01,   6.7278031545482220E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,  -7.3984231234534703E-01,   6.7278031545482220E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,   7.3984231234534703E-01,  -6.7278031545482220E-01,   3.2083218533266009E-03],
            [   0.0000000000000000E+00,  -7.3984231234534703E-01,  -6.7278031545482220E-01,   3.2083218533266009E-03],
            [   7.4765639431660855E-02,   2.1931685094611849E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,   2.1931685094611849E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,  -2.1931685094611849E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,   2.1931685094611849E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,  -2.1931685094611849E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,  -2.1931685094611849E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,   2.1931685094611849E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,  -2.1931685094611849E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,   7.4765639431660855E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,   7.4765639431660855E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,  -7.4765639431660855E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,   7.4765639431660855E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,  -7.4765639431660855E-02,   9.9695992915928455E-01,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,  -7.4765639431660855E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,   7.4765639431660855E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,  -7.4765639431660855E-02,  -9.9695992915928455E-01,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,   7.4765639431660855E-02,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,   7.4765639431660855E-02,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,  -7.4765639431660855E-02,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,   7.4765639431660855E-02,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,  -7.4765639431660855E-02,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,  -7.4765639431660855E-02,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,   7.4765639431660855E-02,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,  -7.4765639431660855E-02,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,   2.1931685094611849E-02,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,   2.1931685094611849E-02,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,  -2.1931685094611849E-02,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,   2.1931685094611849E-02,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,  -2.1931685094611849E-02,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   9.9695992915928455E-01,  -2.1931685094611849E-02,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,   2.1931685094611849E-02,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -9.9695992915928455E-01,  -2.1931685094611849E-02,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,   9.9695992915928455E-01,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,   9.9695992915928455E-01,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,  -9.9695992915928455E-01,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,   9.9695992915928455E-01,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,  -9.9695992915928455E-01,   2.1931685094611849E-02,   1.5241496243925277E-03],
            [   7.4765639431660855E-02,  -9.9695992915928455E-01,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,   9.9695992915928455E-01,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [  -7.4765639431660855E-02,  -9.9695992915928455E-01,  -2.1931685094611849E-02,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,   9.9695992915928455E-01,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,   9.9695992915928455E-01,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,  -9.9695992915928455E-01,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,   9.9695992915928455E-01,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,  -9.9695992915928455E-01,   7.4765639431660855E-02,   1.5241496243925277E-03],
            [   2.1931685094611849E-02,  -9.9695992915928455E-01,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,   9.9695992915928455E-01,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [  -2.1931685094611849E-02,  -9.9695992915928455E-01,  -7.4765639431660855E-02,   1.5241496243925277E-03],
            [   1.0753414820014159E-01,   4.8264192815338870E-02,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,   4.8264192815338870E-02,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,  -4.8264192815338870E-02,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,   4.8264192815338870E-02,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,  -4.8264192815338870E-02,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,  -4.8264192815338870E-02,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,   4.8264192815338870E-02,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,  -4.8264192815338870E-02,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,   1.0753414820014159E-01,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,   1.0753414820014159E-01,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,  -1.0753414820014159E-01,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,   1.0753414820014159E-01,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,  -1.0753414820014159E-01,   9.9302919124402067E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,  -1.0753414820014159E-01,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,   1.0753414820014159E-01,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,  -1.0753414820014159E-01,  -9.9302919124402067E-01,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,   1.0753414820014159E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,   1.0753414820014159E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,  -1.0753414820014159E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,   1.0753414820014159E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,  -1.0753414820014159E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,  -1.0753414820014159E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,   1.0753414820014159E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,  -1.0753414820014159E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,   4.8264192815338870E-02,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,   4.8264192815338870E-02,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,  -4.8264192815338870E-02,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,   4.8264192815338870E-02,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,  -4.8264192815338870E-02,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   9.9302919124402067E-01,  -4.8264192815338870E-02,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,   4.8264192815338870E-02,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -9.9302919124402067E-01,  -4.8264192815338870E-02,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,   9.9302919124402067E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,   9.9302919124402067E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,  -9.9302919124402067E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,   9.9302919124402067E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,  -9.9302919124402067E-01,   4.8264192815338870E-02,   1.8508666493889554E-03],
            [   1.0753414820014159E-01,  -9.9302919124402067E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,   9.9302919124402067E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [  -1.0753414820014159E-01,  -9.9302919124402067E-01,  -4.8264192815338870E-02,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,   9.9302919124402067E-01,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,   9.9302919124402067E-01,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,  -9.9302919124402067E-01,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,   9.9302919124402067E-01,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,  -9.9302919124402067E-01,   1.0753414820014159E-01,   1.8508666493889554E-03],
            [   4.8264192815338870E-02,  -9.9302919124402067E-01,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,   9.9302919124402067E-01,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [  -4.8264192815338870E-02,  -9.9302919124402067E-01,  -1.0753414820014159E-01,   1.8508666493889554E-03],
            [   1.4163448852032590E-01,   7.7511918835757421E-02,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,   7.7511918835757421E-02,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,  -7.7511918835757421E-02,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,   7.7511918835757421E-02,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,  -7.7511918835757421E-02,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,  -7.7511918835757421E-02,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,   7.7511918835757421E-02,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,  -7.7511918835757421E-02,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,   1.4163448852032590E-01,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,   1.4163448852032590E-01,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,  -1.4163448852032590E-01,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,   1.4163448852032590E-01,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,  -1.4163448852032590E-01,   9.8687971612551884E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,  -1.4163448852032590E-01,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,   1.4163448852032590E-01,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,  -1.4163448852032590E-01,  -9.8687971612551884E-01,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,   1.4163448852032590E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,   1.4163448852032590E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,  -1.4163448852032590E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,   1.4163448852032590E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,  -1.4163448852032590E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,  -1.4163448852032590E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,   1.4163448852032590E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,  -1.4163448852032590E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,   7.7511918835757421E-02,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,   7.7511918835757421E-02,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,  -7.7511918835757421E-02,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,   7.7511918835757421E-02,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,  -7.7511918835757421E-02,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   9.8687971612551884E-01,  -7.7511918835757421E-02,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,   7.7511918835757421E-02,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -9.8687971612551884E-01,  -7.7511918835757421E-02,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,   9.8687971612551884E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,   9.8687971612551884E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,  -9.8687971612551884E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,   9.8687971612551884E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,  -9.8687971612551884E-01,   7.7511918835757421E-02,   2.1197539557874117E-03],
            [   1.4163448852032590E-01,  -9.8687971612551884E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,   9.8687971612551884E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [  -1.4163448852032590E-01,  -9.8687971612551884E-01,  -7.7511918835757421E-02,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,   9.8687971612551884E-01,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,   9.8687971612551884E-01,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,  -9.8687971612551884E-01,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,   9.8687971612551884E-01,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,  -9.8687971612551884E-01,   1.4163448852032590E-01,   2.1197539557874117E-03],
            [   7.7511918835757421E-02,  -9.8687971612551884E-01,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,   9.8687971612551884E-01,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [  -7.7511918835757421E-02,  -9.8687971612551884E-01,  -1.4163448852032590E-01,   2.1197539557874117E-03],
            [   1.7663253153885861E-01,   1.0875581392476801E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,   1.0875581392476801E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,  -1.0875581392476801E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,   1.0875581392476801E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,  -1.0875581392476801E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,  -1.0875581392476801E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,   1.0875581392476801E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,  -1.0875581392476801E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,   1.7663253153885861E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,   1.7663253153885861E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,  -1.7663253153885861E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,   1.7663253153885861E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,  -1.7663253153885861E-01,   9.7825003027842294E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,  -1.7663253153885861E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,   1.7663253153885861E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,  -1.7663253153885861E-01,  -9.7825003027842294E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,   1.7663253153885861E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,   1.7663253153885861E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,  -1.7663253153885861E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,   1.7663253153885861E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,  -1.7663253153885861E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,  -1.7663253153885861E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,   1.7663253153885861E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,  -1.7663253153885861E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,   1.0875581392476801E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,   1.0875581392476801E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,  -1.0875581392476801E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,   1.0875581392476801E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,  -1.0875581392476801E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   9.7825003027842294E-01,  -1.0875581392476801E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,   1.0875581392476801E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -9.7825003027842294E-01,  -1.0875581392476801E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,   9.7825003027842294E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,   9.7825003027842294E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,  -9.7825003027842294E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,   9.7825003027842294E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,  -9.7825003027842294E-01,   1.0875581392476801E-01,   2.3407358621399454E-03],
            [   1.7663253153885861E-01,  -9.7825003027842294E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,   9.7825003027842294E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [  -1.7663253153885861E-01,  -9.7825003027842294E-01,  -1.0875581392476801E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,   9.7825003027842294E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,   9.7825003027842294E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,  -9.7825003027842294E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,   9.7825003027842294E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,  -9.7825003027842294E-01,   1.7663253153885861E-01,   2.3407358621399454E-03],
            [   1.0875581392476801E-01,  -9.7825003027842294E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,   9.7825003027842294E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [  -1.0875581392476801E-01,  -9.7825003027842294E-01,  -1.7663253153885861E-01,   2.3407358621399454E-03],
            [   2.1217441744815141E-01,   1.4136613742530960E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,   1.4136613742530960E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,  -1.4136613742530960E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,   1.4136613742530960E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,  -1.4136613742530960E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,  -1.4136613742530960E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,   1.4136613742530960E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,  -1.4136613742530960E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,   2.1217441744815141E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,   2.1217441744815141E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,  -2.1217441744815141E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,   2.1217441744815141E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,  -2.1217441744815141E-01,   9.6695275570732309E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,  -2.1217441744815141E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,   2.1217441744815141E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,  -2.1217441744815141E-01,  -9.6695275570732309E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,   2.1217441744815141E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,   2.1217441744815141E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,  -2.1217441744815141E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,   2.1217441744815141E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,  -2.1217441744815141E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,  -2.1217441744815141E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,   2.1217441744815141E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,  -2.1217441744815141E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,   1.4136613742530960E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,   1.4136613742530960E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,  -1.4136613742530960E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,   1.4136613742530960E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,  -1.4136613742530960E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   9.6695275570732309E-01,  -1.4136613742530960E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,   1.4136613742530960E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -9.6695275570732309E-01,  -1.4136613742530960E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,   9.6695275570732309E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,   9.6695275570732309E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,  -9.6695275570732309E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,   9.6695275570732309E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,  -9.6695275570732309E-01,   1.4136613742530960E-01,   2.5226121388297433E-03],
            [   2.1217441744815141E-01,  -9.6695275570732309E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,   9.6695275570732309E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [  -2.1217441744815141E-01,  -9.6695275570732309E-01,  -1.4136613742530960E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,   9.6695275570732309E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,   9.6695275570732309E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,  -9.6695275570732309E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,   9.6695275570732309E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,  -9.6695275570732309E-01,   2.1217441744815141E-01,   2.5226121388297433E-03],
            [   1.4136613742530960E-01,  -9.6695275570732309E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,   9.6695275570732309E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [  -1.4136613742530960E-01,  -9.6695275570732309E-01,  -2.1217441744815141E-01,   2.5226121388297433E-03],
            [   2.4796694434081451E-01,   1.7487682142588801E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,   1.7487682142588801E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,  -1.7487682142588801E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,   1.7487682142588801E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,  -1.7487682142588801E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,  -1.7487682142588801E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,   1.7487682142588801E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,  -1.7487682142588801E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,   2.4796694434081451E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,   2.4796694434081451E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,  -2.4796694434081451E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,   2.4796694434081451E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,  -2.4796694434081451E-01,   9.5285386699234076E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,  -2.4796694434081451E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,   2.4796694434081451E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,  -2.4796694434081451E-01,  -9.5285386699234076E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,   2.4796694434081451E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,   2.4796694434081451E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,  -2.4796694434081451E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,   2.4796694434081451E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,  -2.4796694434081451E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,  -2.4796694434081451E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,   2.4796694434081451E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,  -2.4796694434081451E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,   1.7487682142588801E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,   1.7487682142588801E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,  -1.7487682142588801E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,   1.7487682142588801E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,  -1.7487682142588801E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   9.5285386699234076E-01,  -1.7487682142588801E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,   1.7487682142588801E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -9.5285386699234076E-01,  -1.7487682142588801E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,   9.5285386699234076E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,   9.5285386699234076E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,  -9.5285386699234076E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,   9.5285386699234076E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,  -9.5285386699234076E-01,   1.7487682142588801E-01,   2.6723243200394036E-03],
            [   2.4796694434081451E-01,  -9.5285386699234076E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,   9.5285386699234076E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [  -2.4796694434081451E-01,  -9.5285386699234076E-01,  -1.7487682142588801E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,   9.5285386699234076E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,   9.5285386699234076E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,  -9.5285386699234076E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,   9.5285386699234076E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,  -9.5285386699234076E-01,   2.4796694434081451E-01,   2.6723243200394036E-03],
            [   1.7487682142588801E-01,  -9.5285386699234076E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,   9.5285386699234076E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [  -1.7487682142588801E-01,  -9.5285386699234076E-01,  -2.4796694434081451E-01,   2.6723243200394036E-03],
            [   2.8376004522941128E-01,   2.0892164066120730E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,   2.0892164066120730E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,  -2.0892164066120730E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,   2.0892164066120730E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,  -2.0892164066120730E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,  -2.0892164066120730E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,   2.0892164066120730E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,  -2.0892164066120730E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,   2.8376004522941128E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,   2.8376004522941128E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,  -2.8376004522941128E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,   2.8376004522941128E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,  -2.8376004522941128E-01,   9.3585895560967514E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,  -2.8376004522941128E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,   2.8376004522941128E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,  -2.8376004522941128E-01,  -9.3585895560967514E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,   2.8376004522941128E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,   2.8376004522941128E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,  -2.8376004522941128E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,   2.8376004522941128E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,  -2.8376004522941128E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,  -2.8376004522941128E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,   2.8376004522941128E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,  -2.8376004522941128E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,   2.0892164066120730E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,   2.0892164066120730E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,  -2.0892164066120730E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,   2.0892164066120730E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,  -2.0892164066120730E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   9.3585895560967514E-01,  -2.0892164066120730E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,   2.0892164066120730E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -9.3585895560967514E-01,  -2.0892164066120730E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,   9.3585895560967514E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,   9.3585895560967514E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,  -9.3585895560967514E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,   9.3585895560967514E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,  -9.3585895560967514E-01,   2.0892164066120730E-01,   2.7952566978554447E-03],
            [   2.8376004522941128E-01,  -9.3585895560967514E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,   9.3585895560967514E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [  -2.8376004522941128E-01,  -9.3585895560967514E-01,  -2.0892164066120730E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,   9.3585895560967514E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,   9.3585895560967514E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,  -9.3585895560967514E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,   9.3585895560967514E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,  -9.3585895560967514E-01,   2.8376004522941128E-01,   2.7952566978554447E-03],
            [   2.0892164066120730E-01,  -9.3585895560967514E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,   9.3585895560967514E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [  -2.0892164066120730E-01,  -9.3585895560967514E-01,  -2.8376004522941128E-01,   2.7952566978554447E-03],
            [   3.1933449331939839E-01,   2.4319876855459721E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,   2.4319876855459721E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,  -2.4319876855459721E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,   2.4319876855459721E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,  -2.4319876855459721E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,  -2.4319876855459721E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,   2.4319876855459721E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,  -2.4319876855459721E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,   3.1933449331939839E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,   3.1933449331939839E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,  -3.1933449331939839E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,   3.1933449331939839E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,  -3.1933449331939839E-01,   9.1590383793822516E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,  -3.1933449331939839E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,   3.1933449331939839E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,  -3.1933449331939839E-01,  -9.1590383793822516E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,   3.1933449331939839E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,   3.1933449331939839E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,  -3.1933449331939839E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,   3.1933449331939839E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,  -3.1933449331939839E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,  -3.1933449331939839E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,   3.1933449331939839E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,  -3.1933449331939839E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,   2.4319876855459721E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,   2.4319876855459721E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,  -2.4319876855459721E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,   2.4319876855459721E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,  -2.4319876855459721E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   9.1590383793822516E-01,  -2.4319876855459721E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,   2.4319876855459721E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -9.1590383793822516E-01,  -2.4319876855459721E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,   9.1590383793822516E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,   9.1590383793822516E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,  -9.1590383793822516E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,   9.1590383793822516E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,  -9.1590383793822516E-01,   2.4319876855459721E-01,   2.8956241985430048E-03],
            [   3.1933449331939839E-01,  -9.1590383793822516E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,   9.1590383793822516E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [  -3.1933449331939839E-01,  -9.1590383793822516E-01,  -2.4319876855459721E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,   9.1590383793822516E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,   9.1590383793822516E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,  -9.1590383793822516E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,   9.1590383793822516E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,  -9.1590383793822516E-01,   3.1933449331939839E-01,   2.8956241985430048E-03],
            [   2.4319876855459721E-01,  -9.1590383793822516E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,   9.1590383793822516E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [  -2.4319876855459721E-01,  -9.1590383793822516E-01,  -3.1933449331939839E-01,   2.8956241985430048E-03],
            [   3.5449354424387453E-01,   2.7744970543777697E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,   2.7744970543777697E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,  -2.7744970543777697E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,   2.7744970543777697E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,  -2.7744970543777697E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,  -2.7744970543777697E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,   2.7744970543777697E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,  -2.7744970543777697E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,   3.5449354424387453E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,   3.5449354424387453E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,  -3.5449354424387453E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,   3.5449354424387453E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,  -3.5449354424387453E-01,   8.9294792011735324E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,  -3.5449354424387453E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,   3.5449354424387453E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,  -3.5449354424387453E-01,  -8.9294792011735324E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,   3.5449354424387453E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,   3.5449354424387453E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,  -3.5449354424387453E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,   3.5449354424387453E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,  -3.5449354424387453E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,  -3.5449354424387453E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,   3.5449354424387453E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,  -3.5449354424387453E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,   2.7744970543777697E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,   2.7744970543777697E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,  -2.7744970543777697E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,   2.7744970543777697E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,  -2.7744970543777697E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   8.9294792011735324E-01,  -2.7744970543777697E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,   2.7744970543777697E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -8.9294792011735324E-01,  -2.7744970543777697E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,   8.9294792011735324E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,   8.9294792011735324E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,  -8.9294792011735324E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,   8.9294792011735324E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,  -8.9294792011735324E-01,   2.7744970543777697E-01,   2.9767900919751154E-03],
            [   3.5449354424387453E-01,  -8.9294792011735324E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,   8.9294792011735324E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [  -3.5449354424387453E-01,  -8.9294792011735324E-01,  -2.7744970543777697E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,   8.9294792011735324E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,   8.9294792011735324E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,  -8.9294792011735324E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,   8.9294792011735324E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,  -8.9294792011735324E-01,   3.5449354424387453E-01,   2.9767900919751154E-03],
            [   2.7744970543777697E-01,  -8.9294792011735324E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,   8.9294792011735324E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [  -2.7744970543777697E-01,  -8.9294792011735324E-01,  -3.5449354424387453E-01,   2.9767900919751154E-03],
            [   3.8905719322881538E-01,   3.1144603561569151E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,   3.1144603561569151E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,  -3.1144603561569151E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,   3.1144603561569151E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,  -3.1144603561569151E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,  -3.1144603561569151E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,   3.1144603561569151E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,  -3.1144603561569151E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,   3.8905719322881538E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,   3.8905719322881538E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,  -3.8905719322881538E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,   3.8905719322881538E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,  -3.8905719322881538E-01,   8.6696935776080675E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,  -3.8905719322881538E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,   3.8905719322881538E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,  -3.8905719322881538E-01,  -8.6696935776080675E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,   3.8905719322881538E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,   3.8905719322881538E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,  -3.8905719322881538E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,   3.8905719322881538E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,  -3.8905719322881538E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,  -3.8905719322881538E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,   3.8905719322881538E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,  -3.8905719322881538E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,   3.1144603561569151E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,   3.1144603561569151E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,  -3.1144603561569151E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,   3.1144603561569151E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,  -3.1144603561569151E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   8.6696935776080675E-01,  -3.1144603561569151E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,   3.1144603561569151E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -8.6696935776080675E-01,  -3.1144603561569151E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,   8.6696935776080675E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,   8.6696935776080675E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,  -8.6696935776080675E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,   8.6696935776080675E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,  -8.6696935776080675E-01,   3.1144603561569151E-01,   3.0415041373415236E-03],
            [   3.8905719322881538E-01,  -8.6696935776080675E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,   8.6696935776080675E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [  -3.8905719322881538E-01,  -8.6696935776080675E-01,  -3.1144603561569151E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,   8.6696935776080675E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,   8.6696935776080675E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,  -8.6696935776080675E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,   8.6696935776080675E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,  -8.6696935776080675E-01,   3.8905719322881538E-01,   3.0415041373415236E-03],
            [   3.1144603561569151E-01,  -8.6696935776080675E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,   8.6696935776080675E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [  -3.1144603561569151E-01,  -8.6696935776080675E-01,  -3.8905719322881538E-01,   3.0415041373415236E-03],
            [   4.2285812142590901E-01,   3.4498068519130121E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,   3.4498068519130121E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,  -3.4498068519130121E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,   3.4498068519130121E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,  -3.4498068519130121E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,  -3.4498068519130121E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,   3.4498068519130121E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,  -3.4498068519130121E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,   4.2285812142590901E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,   4.2285812142590901E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,  -4.2285812142590901E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,   4.2285812142590901E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,  -4.2285812142590901E-01,   8.3796141676636371E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,  -4.2285812142590901E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,   4.2285812142590901E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,  -4.2285812142590901E-01,  -8.3796141676636371E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,   4.2285812142590901E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,   4.2285812142590901E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,  -4.2285812142590901E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,   4.2285812142590901E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,  -4.2285812142590901E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,  -4.2285812142590901E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,   4.2285812142590901E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,  -4.2285812142590901E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,   3.4498068519130121E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,   3.4498068519130121E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,  -3.4498068519130121E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,   3.4498068519130121E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,  -3.4498068519130121E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   8.3796141676636371E-01,  -3.4498068519130121E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,   3.4498068519130121E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -8.3796141676636371E-01,  -3.4498068519130121E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,   8.3796141676636371E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,   8.3796141676636371E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,  -8.3796141676636371E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,   8.3796141676636371E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,  -8.3796141676636371E-01,   3.4498068519130121E-01,   3.0920775255601799E-03],
            [   4.2285812142590901E-01,  -8.3796141676636371E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,   8.3796141676636371E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [  -4.2285812142590901E-01,  -8.3796141676636371E-01,  -3.4498068519130121E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,   8.3796141676636371E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,   8.3796141676636371E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,  -8.3796141676636371E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,   8.3796141676636371E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,  -8.3796141676636371E-01,   4.2285812142590901E-01,   3.0920775255601799E-03],
            [   3.4498068519130121E-01,  -8.3796141676636371E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,   8.3796141676636371E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [  -3.4498068519130121E-01,  -8.3796141676636371E-01,  -4.2285812142590901E-01,   3.0920775255601799E-03],
            [   4.5573872113040520E-01,   3.7786186412482559E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,   3.7786186412482559E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,  -3.7786186412482559E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,   3.7786186412482559E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,  -3.7786186412482559E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,  -3.7786186412482559E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,   3.7786186412482559E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,  -3.7786186412482559E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,   4.5573872113040520E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,   4.5573872113040520E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,  -4.5573872113040520E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,   4.5573872113040520E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,  -4.5573872113040520E-01,   8.0592966796274135E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,  -4.5573872113040520E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,   4.5573872113040520E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,  -4.5573872113040520E-01,  -8.0592966796274135E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,   4.5573872113040520E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,   4.5573872113040520E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,  -4.5573872113040520E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,   4.5573872113040520E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,  -4.5573872113040520E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,  -4.5573872113040520E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,   4.5573872113040520E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,  -4.5573872113040520E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,   3.7786186412482559E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,   3.7786186412482559E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,  -3.7786186412482559E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,   3.7786186412482559E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,  -3.7786186412482559E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   8.0592966796274135E-01,  -3.7786186412482559E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,   3.7786186412482559E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -8.0592966796274135E-01,  -3.7786186412482559E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,   8.0592966796274135E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,   8.0592966796274135E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,  -8.0592966796274135E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,   8.0592966796274135E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,  -8.0592966796274135E-01,   3.7786186412482559E-01,   3.1305115177218093E-03],
            [   4.5573872113040520E-01,  -8.0592966796274135E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,   8.0592966796274135E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [  -4.5573872113040520E-01,  -8.0592966796274135E-01,  -3.7786186412482559E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,   8.0592966796274135E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,   8.0592966796274135E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,  -8.0592966796274135E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,   8.0592966796274135E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,  -8.0592966796274135E-01,   4.5573872113040520E-01,   3.1305115177218093E-03],
            [   3.7786186412482559E-01,  -8.0592966796274135E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,   8.0592966796274135E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [  -3.7786186412482559E-01,  -8.0592966796274135E-01,  -4.5573872113040520E-01,   3.1305115177218093E-03],
            [   4.8754879505416432E-01,   4.0990863916989778E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,   4.0990863916989778E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,  -4.0990863916989778E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,   4.0990863916989778E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,  -4.0990863916989778E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,  -4.0990863916989778E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,   4.0990863916989778E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,  -4.0990863916989778E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,   4.8754879505416432E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,   4.8754879505416432E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,  -4.8754879505416432E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,   4.8754879505416432E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,  -4.8754879505416432E-01,   7.7088979755547093E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,  -4.8754879505416432E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,   4.8754879505416432E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,  -4.8754879505416432E-01,  -7.7088979755547093E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,   4.8754879505416432E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,   4.8754879505416432E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,  -4.8754879505416432E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,   4.8754879505416432E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,  -4.8754879505416432E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,  -4.8754879505416432E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,   4.8754879505416432E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,  -4.8754879505416432E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,   4.0990863916989778E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,   4.0990863916989778E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,  -4.0990863916989778E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,   4.0990863916989778E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,  -4.0990863916989778E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   7.7088979755547093E-01,  -4.0990863916989778E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,   4.0990863916989778E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -7.7088979755547093E-01,  -4.0990863916989778E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,   7.7088979755547093E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,   7.7088979755547093E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,  -7.7088979755547093E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,   7.7088979755547093E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,  -7.7088979755547093E-01,   4.0990863916989778E-01,   3.1585926838031755E-03],
            [   4.8754879505416432E-01,  -7.7088979755547093E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,   7.7088979755547093E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [  -4.8754879505416432E-01,  -7.7088979755547093E-01,  -4.0990863916989778E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,   7.7088979755547093E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,   7.7088979755547093E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,  -7.7088979755547093E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,   7.7088979755547093E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,  -7.7088979755547093E-01,   4.8754879505416432E-01,   3.1585926838031755E-03],
            [   4.0990863916989778E-01,  -7.7088979755547093E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,   7.7088979755547093E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [  -4.0990863916989778E-01,  -7.7088979755547093E-01,  -4.8754879505416432E-01,   3.1585926838031755E-03],
            [   5.1814365299629972E-01,   4.4094749258539728E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,   4.4094749258539728E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,  -4.4094749258539728E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,   4.4094749258539728E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,  -4.4094749258539728E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,  -4.4094749258539728E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,   4.4094749258539728E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,  -4.4094749258539728E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,   5.1814365299629972E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,   5.1814365299629972E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,  -5.1814365299629972E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,   5.1814365299629972E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,  -5.1814365299629972E-01,   7.3286592473814827E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,  -5.1814365299629972E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,   5.1814365299629972E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,  -5.1814365299629972E-01,  -7.3286592473814827E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,   5.1814365299629972E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,   5.1814365299629972E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,  -5.1814365299629972E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,   5.1814365299629972E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,  -5.1814365299629972E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,  -5.1814365299629972E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,   5.1814365299629972E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,  -5.1814365299629972E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,   4.4094749258539728E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,   4.4094749258539728E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,  -4.4094749258539728E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,   4.4094749258539728E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,  -4.4094749258539728E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   7.3286592473814827E-01,  -4.4094749258539728E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,   4.4094749258539728E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -7.3286592473814827E-01,  -4.4094749258539728E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,   7.3286592473814827E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,   7.3286592473814827E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,  -7.3286592473814827E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,   7.3286592473814827E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,  -7.3286592473814827E-01,   4.4094749258539728E-01,   3.1779636215672168E-03],
            [   5.1814365299629972E-01,  -7.3286592473814827E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,   7.3286592473814827E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [  -5.1814365299629972E-01,  -7.3286592473814827E-01,  -4.4094749258539728E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,   7.3286592473814827E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,   7.3286592473814827E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,  -7.3286592473814827E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,   7.3286592473814827E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,  -7.3286592473814827E-01,   5.1814365299629972E-01,   3.1779636215672168E-03],
            [   4.4094749258539728E-01,  -7.3286592473814827E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,   7.3286592473814827E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [  -4.4094749258539728E-01,  -7.3286592473814827E-01,  -5.1814365299629972E-01,   3.1779636215672168E-03],
            [   5.4738240956006612E-01,   4.7080945177112909E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,   4.7080945177112909E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,  -4.7080945177112909E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,   4.7080945177112909E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,  -4.7080945177112909E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,  -4.7080945177112909E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,   4.7080945177112909E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,  -4.7080945177112909E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,   5.4738240956006612E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,   5.4738240956006612E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,  -5.4738240956006612E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,   5.4738240956006612E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,  -5.4738240956006612E-01,   6.9188941155880168E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,  -5.4738240956006612E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,   5.4738240956006612E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,  -5.4738240956006612E-01,  -6.9188941155880168E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,   5.4738240956006612E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,   5.4738240956006612E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,  -5.4738240956006612E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,   5.4738240956006612E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,  -5.4738240956006612E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,  -5.4738240956006612E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,   5.4738240956006612E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,  -5.4738240956006612E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,   4.7080945177112909E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,   4.7080945177112909E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,  -4.7080945177112909E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,   4.7080945177112909E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,  -4.7080945177112909E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   6.9188941155880168E-01,  -4.7080945177112909E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,   4.7080945177112909E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -6.9188941155880168E-01,  -4.7080945177112909E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,   6.9188941155880168E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,   6.9188941155880168E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,  -6.9188941155880168E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,   6.9188941155880168E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,  -6.9188941155880168E-01,   4.7080945177112909E-01,   3.1901747054407540E-03],
            [   5.4738240956006612E-01,  -6.9188941155880168E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,   6.9188941155880168E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [  -5.4738240956006612E-01,  -6.9188941155880168E-01,  -4.7080945177112909E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,   6.9188941155880168E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,   6.9188941155880168E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,  -6.9188941155880168E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,   6.9188941155880168E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,  -6.9188941155880168E-01,   5.4738240956006612E-01,   3.1901747054407540E-03],
            [   4.7080945177112909E-01,  -6.9188941155880168E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,   6.9188941155880168E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [  -4.7080945177112909E-01,  -6.9188941155880168E-01,  -5.4738240956006612E-01,   3.1901747054407540E-03],
            [   5.7512633989761741E-01,   4.9932751403546372E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,   4.9932751403546372E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,  -4.9932751403546372E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,   4.9932751403546372E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,  -4.9932751403546372E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,  -4.9932751403546372E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,   4.9932751403546372E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,  -4.9932751403546372E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,   5.7512633989761741E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,   5.7512633989761741E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,  -5.7512633989761741E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,   5.7512633989761741E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,  -5.7512633989761741E-01,   6.4799824604942724E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,  -5.7512633989761741E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,   5.7512633989761741E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,  -5.7512633989761741E-01,  -6.4799824604942724E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,   5.7512633989761741E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,   5.7512633989761741E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,  -5.7512633989761741E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,   5.7512633989761741E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,  -5.7512633989761741E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,  -5.7512633989761741E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,   5.7512633989761741E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,  -5.7512633989761741E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,   4.9932751403546372E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,   4.9932751403546372E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,  -4.9932751403546372E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,   4.9932751403546372E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,  -4.9932751403546372E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   6.4799824604942724E-01,  -4.9932751403546372E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,   4.9932751403546372E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -6.4799824604942724E-01,  -4.9932751403546372E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,   6.4799824604942724E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,   6.4799824604942724E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,  -6.4799824604942724E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,   6.4799824604942724E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,  -6.4799824604942724E-01,   4.9932751403546372E-01,   3.1967196228774417E-03],
            [   5.7512633989761741E-01,  -6.4799824604942724E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,   6.4799824604942724E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [  -5.7512633989761741E-01,  -6.4799824604942724E-01,  -4.9932751403546372E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,   6.4799824604942724E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,   6.4799824604942724E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,  -6.4799824604942724E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,   6.4799824604942724E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,  -6.4799824604942724E-01,   5.7512633989761741E-01,   3.1967196228774417E-03],
            [   4.9932751403546372E-01,  -6.4799824604942724E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,   6.4799824604942724E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [  -4.9932751403546372E-01,  -6.4799824604942724E-01,  -5.7512633989761741E-01,   3.1967196228774417E-03],
            [   1.4895157468400280E-01,   2.5993819932670172E-02,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,   2.5993819932670172E-02,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,  -2.5993819932670172E-02,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,   2.5993819932670172E-02,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,  -2.5993819932670172E-02,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,  -2.5993819932670172E-02,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,   2.5993819932670172E-02,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,  -2.5993819932670172E-02,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,   1.4895157468400280E-01,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,   1.4895157468400280E-01,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,  -1.4895157468400280E-01,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,   1.4895157468400280E-01,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,  -1.4895157468400280E-01,   9.8850278184963336E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,  -1.4895157468400280E-01,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,   1.4895157468400280E-01,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,  -1.4895157468400280E-01,  -9.8850278184963336E-01,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,   1.4895157468400280E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,   1.4895157468400280E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,  -1.4895157468400280E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,   1.4895157468400280E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,  -1.4895157468400280E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,  -1.4895157468400280E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,   1.4895157468400280E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,  -1.4895157468400280E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,   2.5993819932670172E-02,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,   2.5993819932670172E-02,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,  -2.5993819932670172E-02,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,   2.5993819932670172E-02,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,  -2.5993819932670172E-02,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   9.8850278184963336E-01,  -2.5993819932670172E-02,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,   2.5993819932670172E-02,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -9.8850278184963336E-01,  -2.5993819932670172E-02,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,   9.8850278184963336E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,   9.8850278184963336E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,  -9.8850278184963336E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,   9.8850278184963336E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,  -9.8850278184963336E-01,   2.5993819932670172E-02,   2.0641464297803881E-03],
            [   1.4895157468400280E-01,  -9.8850278184963336E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,   9.8850278184963336E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [  -1.4895157468400280E-01,  -9.8850278184963336E-01,  -2.5993819932670172E-02,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,   9.8850278184963336E-01,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,   9.8850278184963336E-01,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,  -9.8850278184963336E-01,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,   9.8850278184963336E-01,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,  -9.8850278184963336E-01,   1.4895157468400280E-01,   2.0641464297803881E-03],
            [   2.5993819932670172E-02,  -9.8850278184963336E-01,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,   9.8850278184963336E-01,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [  -2.5993819932670172E-02,  -9.8850278184963336E-01,  -1.4895157468400280E-01,   2.0641464297803881E-03],
            [   1.8636564443517670E-01,   5.4792865324621902E-02,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,   5.4792865324621902E-02,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,  -5.4792865324621902E-02,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,   5.4792865324621902E-02,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,  -5.4792865324621902E-02,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,  -5.4792865324621902E-02,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,   5.4792865324621902E-02,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,  -5.4792865324621902E-02,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,   1.8636564443517670E-01,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,   1.8636564443517670E-01,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,  -1.8636564443517670E-01,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,   1.8636564443517670E-01,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,  -1.8636564443517670E-01,   9.8095136907176961E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,  -1.8636564443517670E-01,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,   1.8636564443517670E-01,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,  -1.8636564443517670E-01,  -9.8095136907176961E-01,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,   1.8636564443517670E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,   1.8636564443517670E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,  -1.8636564443517670E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,   1.8636564443517670E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,  -1.8636564443517670E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,  -1.8636564443517670E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,   1.8636564443517670E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,  -1.8636564443517670E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,   5.4792865324621902E-02,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,   5.4792865324621902E-02,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,  -5.4792865324621902E-02,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,   5.4792865324621902E-02,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,  -5.4792865324621902E-02,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   9.8095136907176961E-01,  -5.4792865324621902E-02,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,   5.4792865324621902E-02,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -9.8095136907176961E-01,  -5.4792865324621902E-02,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,   9.8095136907176961E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,   9.8095136907176961E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,  -9.8095136907176961E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,   9.8095136907176961E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,  -9.8095136907176961E-01,   5.4792865324621902E-02,   2.2848761395987062E-03],
            [   1.8636564443517670E-01,  -9.8095136907176961E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,   9.8095136907176961E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [  -1.8636564443517670E-01,  -9.8095136907176961E-01,  -5.4792865324621902E-02,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,   9.8095136907176961E-01,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,   9.8095136907176961E-01,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,  -9.8095136907176961E-01,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,   9.8095136907176961E-01,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,  -9.8095136907176961E-01,   1.8636564443517670E-01,   2.2848761395987062E-03],
            [   5.4792865324621902E-02,  -9.8095136907176961E-01,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,   9.8095136907176961E-01,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [  -5.4792865324621902E-02,  -9.8095136907176961E-01,  -1.8636564443517670E-01,   2.2848761395987062E-03],
            [   2.2386028803563479E-01,   8.5567632514252534E-02,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,   8.5567632514252534E-02,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,  -8.5567632514252534E-02,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,   8.5567632514252534E-02,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,  -8.5567632514252534E-02,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,  -8.5567632514252534E-02,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,   8.5567632514252534E-02,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,  -8.5567632514252534E-02,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,   2.2386028803563479E-01,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,   2.2386028803563479E-01,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,  -2.2386028803563479E-01,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,   2.2386028803563479E-01,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,  -2.2386028803563479E-01,   9.7085774020013271E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,  -2.2386028803563479E-01,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,   2.2386028803563479E-01,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,  -2.2386028803563479E-01,  -9.7085774020013271E-01,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,   2.2386028803563479E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,   2.2386028803563479E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,  -2.2386028803563479E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,   2.2386028803563479E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,  -2.2386028803563479E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,  -2.2386028803563479E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,   2.2386028803563479E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,  -2.2386028803563479E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,   8.5567632514252534E-02,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,   8.5567632514252534E-02,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,  -8.5567632514252534E-02,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,   8.5567632514252534E-02,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,  -8.5567632514252534E-02,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   9.7085774020013271E-01,  -8.5567632514252534E-02,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,   8.5567632514252534E-02,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -9.7085774020013271E-01,  -8.5567632514252534E-02,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,   9.7085774020013271E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,   9.7085774020013271E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,  -9.7085774020013271E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,   9.7085774020013271E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,  -9.7085774020013271E-01,   8.5567632514252534E-02,   2.4712592788989707E-03],
            [   2.2386028803563479E-01,  -9.7085774020013271E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,   9.7085774020013271E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [  -2.2386028803563479E-01,  -9.7085774020013271E-01,  -8.5567632514252534E-02,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,   9.7085774020013271E-01,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,   9.7085774020013271E-01,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,  -9.7085774020013271E-01,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,   9.7085774020013271E-01,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,  -9.7085774020013271E-01,   2.2386028803563479E-01,   2.4712592788989707E-03],
            [   8.5567632514252534E-02,  -9.7085774020013271E-01,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,   9.7085774020013271E-01,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [  -8.5567632514252534E-02,  -9.7085774020013271E-01,  -2.2386028803563479E-01,   2.4712592788989707E-03],
            [   2.6127233757281598E-01,   1.1772578022670110E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,   1.1772578022670110E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,  -1.1772578022670110E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,   1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,  -1.1772578022670110E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,  -1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,   1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,  -1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,   2.6127233757281598E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,   2.6127233757281598E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,  -2.6127233757281598E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,   2.6127233757281598E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,  -2.6127233757281598E-01,   9.5805918725789119E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,  -2.6127233757281598E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,   2.6127233757281598E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,  -2.6127233757281598E-01,  -9.5805918725789119E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,   2.6127233757281598E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,   2.6127233757281598E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,  -2.6127233757281598E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,   2.6127233757281598E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,  -2.6127233757281598E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,  -2.6127233757281598E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,   2.6127233757281598E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,  -2.6127233757281598E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,   1.1772578022670110E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,   1.1772578022670110E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,   1.1772578022670110E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   9.5805918725789119E-01,  -1.1772578022670110E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,   1.1772578022670110E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -9.5805918725789119E-01,  -1.1772578022670110E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,   9.5805918725789119E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,   9.5805918725789119E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,  -9.5805918725789119E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,   9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,  -9.5805918725789119E-01,   1.1772578022670110E-01,   2.6272233397750559E-03],
            [   2.6127233757281598E-01,  -9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,   9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [  -2.6127233757281598E-01,  -9.5805918725789119E-01,  -1.1772578022670110E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,   9.5805918725789119E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,   9.5805918725789119E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,   9.5805918725789119E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,  -9.5805918725789119E-01,   2.6127233757281598E-01,   2.6272233397750559E-03],
            [   1.1772578022670110E-01,  -9.5805918725789119E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,   9.5805918725789119E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [  -1.1772578022670110E-01,  -9.5805918725789119E-01,  -2.6127233757281598E-01,   2.6272233397750559E-03],
            [   2.9843329902061899E-01,   1.5081684561927000E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,   1.5081684561927000E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,  -1.5081684561927000E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,   1.5081684561927000E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,  -1.5081684561927000E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,  -1.5081684561927000E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,   1.5081684561927000E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,  -1.5081684561927000E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,   2.9843329902061899E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,   2.9843329902061899E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,  -2.9843329902061899E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,   2.9843329902061899E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,  -2.9843329902061899E-01,   9.4243930579805679E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,  -2.9843329902061899E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,   2.9843329902061899E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,  -2.9843329902061899E-01,  -9.4243930579805679E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,   2.9843329902061899E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,   2.9843329902061899E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,  -2.9843329902061899E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,   2.9843329902061899E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,  -2.9843329902061899E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,  -2.9843329902061899E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,   2.9843329902061899E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,  -2.9843329902061899E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,   1.5081684561927000E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,   1.5081684561927000E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,  -1.5081684561927000E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,   1.5081684561927000E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,  -1.5081684561927000E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   9.4243930579805679E-01,  -1.5081684561927000E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,   1.5081684561927000E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -9.4243930579805679E-01,  -1.5081684561927000E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,   9.4243930579805679E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,   9.4243930579805679E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,  -9.4243930579805679E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,   9.4243930579805679E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,  -9.4243930579805679E-01,   1.5081684561927000E-01,   2.7568360327254204E-03],
            [   2.9843329902061899E-01,  -9.4243930579805679E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,   9.4243930579805679E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [  -2.9843329902061899E-01,  -9.4243930579805679E-01,  -1.5081684561927000E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,   9.4243930579805679E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,   9.4243930579805679E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,  -9.4243930579805679E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,   9.4243930579805679E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,  -9.4243930579805679E-01,   2.9843329902061899E-01,   2.7568360327254204E-03],
            [   1.5081684561927000E-01,  -9.4243930579805679E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,   9.4243930579805679E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [  -1.5081684561927000E-01,  -9.4243930579805679E-01,  -2.9843329902061899E-01,   2.7568360327254204E-03],
            [   3.3517865846633332E-01,   1.8448018921777271E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,   1.8448018921777271E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,  -1.8448018921777271E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,   1.8448018921777271E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,  -1.8448018921777271E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,  -1.8448018921777271E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,   1.8448018921777271E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,  -1.8448018921777271E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,   3.3517865846633332E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,   3.3517865846633332E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,  -3.3517865846633332E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,   3.3517865846633332E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,  -3.3517865846633332E-01,   9.2391683970738614E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,  -3.3517865846633332E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,   3.3517865846633332E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,  -3.3517865846633332E-01,  -9.2391683970738614E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,   3.3517865846633332E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,   3.3517865846633332E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,  -3.3517865846633332E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,   3.3517865846633332E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,  -3.3517865846633332E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,  -3.3517865846633332E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,   3.3517865846633332E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,  -3.3517865846633332E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,   1.8448018921777271E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,   1.8448018921777271E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,  -1.8448018921777271E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,   1.8448018921777271E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,  -1.8448018921777271E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   9.2391683970738614E-01,  -1.8448018921777271E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,   1.8448018921777271E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -9.2391683970738614E-01,  -1.8448018921777271E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,   9.2391683970738614E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,   9.2391683970738614E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,  -9.2391683970738614E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,   9.2391683970738614E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,  -9.2391683970738614E-01,   1.8448018921777271E-01,   2.8637135402651216E-03],
            [   3.3517865846633332E-01,  -9.2391683970738614E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,   9.2391683970738614E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [  -3.3517865846633332E-01,  -9.2391683970738614E-01,  -1.8448018921777271E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,   9.2391683970738614E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,   9.2391683970738614E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,  -9.2391683970738614E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,   9.2391683970738614E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,  -9.2391683970738614E-01,   3.3517865846633332E-01,   2.8637135402651216E-03],
            [   1.8448018921777271E-01,  -9.2391683970738614E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,   9.2391683970738614E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [  -1.8448018921777271E-01,  -9.2391683970738614E-01,  -3.3517865846633332E-01,   2.8637135402651216E-03],
            [   3.7135055222091201E-01,   2.1841452360875979E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,   2.1841452360875979E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,  -2.1841452360875979E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,   2.1841452360875979E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,  -2.1841452360875979E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,  -2.1841452360875979E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,   2.1841452360875979E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,  -2.1841452360875979E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,   3.7135055222091201E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,   3.7135055222091201E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,  -3.7135055222091201E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,   3.7135055222091201E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,  -3.7135055222091201E-01,   9.0243773372016212E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,  -3.7135055222091201E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,   3.7135055222091201E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,  -3.7135055222091201E-01,  -9.0243773372016212E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,   3.7135055222091201E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,   3.7135055222091201E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,  -3.7135055222091201E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,   3.7135055222091201E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,  -3.7135055222091201E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,  -3.7135055222091201E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,   3.7135055222091201E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,  -3.7135055222091201E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,   2.1841452360875979E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,   2.1841452360875979E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,  -2.1841452360875979E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,   2.1841452360875979E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,  -2.1841452360875979E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   9.0243773372016212E-01,  -2.1841452360875979E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,   2.1841452360875979E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -9.0243773372016212E-01,  -2.1841452360875979E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,   9.0243773372016212E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,   9.0243773372016212E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,  -9.0243773372016212E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,   9.0243773372016212E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,  -9.0243773372016212E-01,   2.1841452360875979E-01,   2.9509396901687204E-03],
            [   3.7135055222091201E-01,  -9.0243773372016212E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,   9.0243773372016212E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [  -3.7135055222091201E-01,  -9.0243773372016212E-01,  -2.1841452360875979E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,   9.0243773372016212E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,   9.0243773372016212E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,  -9.0243773372016212E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,   9.0243773372016212E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,  -9.0243773372016212E-01,   3.7135055222091201E-01,   2.9509396901687204E-03],
            [   2.1841452360875979E-01,  -9.0243773372016212E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,   9.0243773372016212E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [  -2.1841452360875979E-01,  -9.0243773372016212E-01,  -3.7135055222091201E-01,   2.9509396901687204E-03],
            [   4.0679810989546628E-01,   2.5235906414862291E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,   2.5235906414862291E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,  -2.5235906414862291E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,   2.5235906414862291E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,  -2.5235906414862291E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,  -2.5235906414862291E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,   2.5235906414862291E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,  -2.5235906414862291E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,   4.0679810989546628E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,   4.0679810989546628E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,  -4.0679810989546628E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,   4.0679810989546628E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,  -4.0679810989546628E-01,   8.7796936195262953E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,  -4.0679810989546628E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,   4.0679810989546628E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,  -4.0679810989546628E-01,  -8.7796936195262953E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,   4.0679810989546628E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,   4.0679810989546628E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,  -4.0679810989546628E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,   4.0679810989546628E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,  -4.0679810989546628E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,  -4.0679810989546628E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,   4.0679810989546628E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,  -4.0679810989546628E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,   2.5235906414862291E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,   2.5235906414862291E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,  -2.5235906414862291E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,   2.5235906414862291E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,  -2.5235906414862291E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   8.7796936195262953E-01,  -2.5235906414862291E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,   2.5235906414862291E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -8.7796936195262953E-01,  -2.5235906414862291E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,   8.7796936195262953E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,   8.7796936195262953E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,  -8.7796936195262953E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,   8.7796936195262953E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,  -8.7796936195262953E-01,   2.5235906414862291E-01,   3.0211311177351717E-03],
            [   4.0679810989546628E-01,  -8.7796936195262953E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,   8.7796936195262953E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [  -4.0679810989546628E-01,  -8.7796936195262953E-01,  -2.5235906414862291E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,   8.7796936195262953E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,   8.7796936195262953E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,  -8.7796936195262953E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,   8.7796936195262953E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,  -8.7796936195262953E-01,   4.0679810989546628E-01,   3.0211311177351717E-03],
            [   2.5235906414862291E-01,  -8.7796936195262953E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,   8.7796936195262953E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [  -2.5235906414862291E-01,  -8.7796936195262953E-01,  -4.0679810989546628E-01,   3.0211311177351717E-03],
            [   4.4137699936875341E-01,   2.8608129769013729E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,   2.8608129769013729E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,  -2.8608129769013729E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,   2.8608129769013729E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,  -2.8608129769013729E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,  -2.8608129769013729E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,   2.8608129769013729E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,  -2.8608129769013729E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,   4.4137699936875341E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,   4.4137699936875341E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,  -4.4137699936875341E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,   4.4137699936875341E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,  -4.4137699936875341E-01,   8.5049622899820221E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,  -4.4137699936875341E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,   4.4137699936875341E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,  -4.4137699936875341E-01,  -8.5049622899820221E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,   4.4137699936875341E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,   4.4137699936875341E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,  -4.4137699936875341E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,   4.4137699936875341E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,  -4.4137699936875341E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,  -4.4137699936875341E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,   4.4137699936875341E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,  -4.4137699936875341E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,   2.8608129769013729E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,   2.8608129769013729E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,  -2.8608129769013729E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,   2.8608129769013729E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,  -2.8608129769013729E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   8.5049622899820221E-01,  -2.8608129769013729E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,   2.8608129769013729E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -8.5049622899820221E-01,  -2.8608129769013729E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,   8.5049622899820221E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,   8.5049622899820221E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,  -8.5049622899820221E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,   8.5049622899820221E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,  -8.5049622899820221E-01,   2.8608129769013729E-01,   3.0765332954153222E-03],
            [   4.4137699936875341E-01,  -8.5049622899820221E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,   8.5049622899820221E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [  -4.4137699936875341E-01,  -8.5049622899820221E-01,  -2.8608129769013729E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,   8.5049622899820221E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,   8.5049622899820221E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,  -8.5049622899820221E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,   8.5049622899820221E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,  -8.5049622899820221E-01,   4.4137699936875341E-01,   3.0765332954153222E-03],
            [   2.8608129769013729E-01,  -8.5049622899820221E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,   8.5049622899820221E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [  -2.8608129769013729E-01,  -8.5049622899820221E-01,  -4.4137699936875341E-01,   3.0765332954153222E-03],
            [   4.7494871825163942E-01,   3.1936867578089961E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,   3.1936867578089961E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,  -3.1936867578089961E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,   3.1936867578089961E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,  -3.1936867578089961E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,  -3.1936867578089961E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,   3.1936867578089961E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,  -3.1936867578089961E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,   4.7494871825163942E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,   4.7494871825163942E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,  -4.7494871825163942E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,   4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,  -4.7494871825163942E-01,   8.2001668517236859E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,  -4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,   4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,  -4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,   4.7494871825163942E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,   4.7494871825163942E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,   4.7494871825163942E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,  -4.7494871825163942E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,   4.7494871825163942E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,  -4.7494871825163942E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,   3.1936867578089961E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,   3.1936867578089961E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,  -3.1936867578089961E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,   3.1936867578089961E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,  -3.1936867578089961E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   8.2001668517236859E-01,  -3.1936867578089961E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,   3.1936867578089961E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -8.2001668517236859E-01,  -3.1936867578089961E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,   8.2001668517236859E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,   8.2001668517236859E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,   8.2001668517236859E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,  -8.2001668517236859E-01,   3.1936867578089961E-01,   3.1191119890752166E-03],
            [   4.7494871825163942E-01,  -8.2001668517236859E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,   8.2001668517236859E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [  -4.7494871825163942E-01,  -8.2001668517236859E-01,  -3.1936867578089961E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,   8.2001668517236859E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,   8.2001668517236859E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,  -8.2001668517236859E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,   8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,  -8.2001668517236859E-01,   4.7494871825163942E-01,   3.1191119890752166E-03],
            [   3.1936867578089961E-01,  -8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,   8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [  -3.1936867578089961E-01,  -8.2001668517236859E-01,  -4.7494871825163942E-01,   3.1191119890752166E-03],
            [   5.0737981050754255E-01,   3.5202269495476018E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,   3.5202269495476018E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,  -3.5202269495476018E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,   3.5202269495476018E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,  -3.5202269495476018E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,  -3.5202269495476018E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,   3.5202269495476018E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,  -3.5202269495476018E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,   5.0737981050754255E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,   5.0737981050754255E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,  -5.0737981050754255E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,   5.0737981050754255E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,  -5.0737981050754255E-01,   7.8654036776640912E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,  -5.0737981050754255E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,   5.0737981050754255E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,  -5.0737981050754255E-01,  -7.8654036776640912E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,   5.0737981050754255E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,   5.0737981050754255E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,  -5.0737981050754255E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,   5.0737981050754255E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,  -5.0737981050754255E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,  -5.0737981050754255E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,   5.0737981050754255E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,  -5.0737981050754255E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,   3.5202269495476018E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,   3.5202269495476018E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,  -3.5202269495476018E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,   3.5202269495476018E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,  -3.5202269495476018E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   7.8654036776640912E-01,  -3.5202269495476018E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,   3.5202269495476018E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -7.8654036776640912E-01,  -3.5202269495476018E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,   7.8654036776640912E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,   7.8654036776640912E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,  -7.8654036776640912E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,   7.8654036776640912E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,  -7.8654036776640912E-01,   3.5202269495476018E-01,   3.1506308871933203E-03],
            [   5.0737981050754255E-01,  -7.8654036776640912E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,   7.8654036776640912E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [  -5.0737981050754255E-01,  -7.8654036776640912E-01,  -3.5202269495476018E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,   7.8654036776640912E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,   7.8654036776640912E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,  -7.8654036776640912E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,   7.8654036776640912E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,  -7.8654036776640912E-01,   5.0737981050754255E-01,   3.1506308871933203E-03],
            [   3.5202269495476018E-01,  -7.8654036776640912E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,   7.8654036776640912E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [  -3.5202269495476018E-01,  -7.8654036776640912E-01,  -5.0737981050754255E-01,   3.1506308871933203E-03],
            [   5.3854104488786536E-01,   3.8385443956678900E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,   3.8385443956678900E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,  -3.8385443956678900E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,   3.8385443956678900E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,  -3.8385443956678900E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,  -3.8385443956678900E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,   3.8385443956678900E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,  -3.8385443956678900E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,   5.3854104488786536E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,   5.3854104488786536E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,  -5.3854104488786536E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,   5.3854104488786536E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,  -5.3854104488786536E-01,   7.5008620317664321E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,  -5.3854104488786536E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,   5.3854104488786536E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,  -5.3854104488786536E-01,  -7.5008620317664321E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,   5.3854104488786536E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,   5.3854104488786536E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,  -5.3854104488786536E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,   5.3854104488786536E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,  -5.3854104488786536E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,  -5.3854104488786536E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,   5.3854104488786536E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,  -5.3854104488786536E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,   3.8385443956678900E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,   3.8385443956678900E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,  -3.8385443956678900E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,   3.8385443956678900E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,  -3.8385443956678900E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   7.5008620317664321E-01,  -3.8385443956678900E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,   3.8385443956678900E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -7.5008620317664321E-01,  -3.8385443956678900E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,   7.5008620317664321E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,   7.5008620317664321E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,  -7.5008620317664321E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,   7.5008620317664321E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,  -7.5008620317664321E-01,   3.8385443956678900E-01,   3.1727144875130790E-03],
            [   5.3854104488786536E-01,  -7.5008620317664321E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,   7.5008620317664321E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [  -5.3854104488786536E-01,  -7.5008620317664321E-01,  -3.8385443956678900E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,   7.5008620317664321E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,   7.5008620317664321E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,  -7.5008620317664321E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,   7.5008620317664321E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,  -7.5008620317664321E-01,   5.3854104488786536E-01,   3.1727144875130790E-03],
            [   3.8385443956678900E-01,  -7.5008620317664321E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,   7.5008620317664321E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [  -3.8385443956678900E-01,  -7.5008620317664321E-01,  -5.3854104488786536E-01,   3.1727144875130790E-03],
            [   5.6830653536705300E-01,   4.1468100376409628E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,   4.1468100376409628E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,  -4.1468100376409628E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,   4.1468100376409628E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,  -4.1468100376409628E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,  -4.1468100376409628E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,   4.1468100376409628E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,  -4.1468100376409628E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,   5.6830653536705300E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,   5.6830653536705300E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,  -5.6830653536705300E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,   5.6830653536705300E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,  -5.6830653536705300E-01,   7.1068090376504278E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,  -5.6830653536705300E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,   5.6830653536705300E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,  -5.6830653536705300E-01,  -7.1068090376504278E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,   5.6830653536705300E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,   5.6830653536705300E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,  -5.6830653536705300E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,   5.6830653536705300E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,  -5.6830653536705300E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,  -5.6830653536705300E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,   5.6830653536705300E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,  -5.6830653536705300E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,   4.1468100376409628E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,   4.1468100376409628E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,  -4.1468100376409628E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,   4.1468100376409628E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,  -4.1468100376409628E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   7.1068090376504278E-01,  -4.1468100376409628E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,   4.1468100376409628E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -7.1068090376504278E-01,  -4.1468100376409628E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,   7.1068090376504278E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,   7.1068090376504278E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,  -7.1068090376504278E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,   7.1068090376504278E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,  -7.1068090376504278E-01,   4.1468100376409628E-01,   3.1868974211817220E-03],
            [   5.6830653536705300E-01,  -7.1068090376504278E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,   7.1068090376504278E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [  -5.6830653536705300E-01,  -7.1068090376504278E-01,  -4.1468100376409628E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,   7.1068090376504278E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,   7.1068090376504278E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,  -7.1068090376504278E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,   7.1068090376504278E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,  -7.1068090376504278E-01,   5.6830653536705300E-01,   3.1868974211817220E-03],
            [   4.1468100376409628E-01,  -7.1068090376504278E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,   7.1068090376504278E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [  -4.1468100376409628E-01,  -7.1068090376504278E-01,  -5.6830653536705300E-01,   3.1868974211817220E-03],
            [   5.9655276206635099E-01,   4.4432240946811208E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,   4.4432240946811208E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,  -4.4432240946811208E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,   4.4432240946811208E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,  -4.4432240946811208E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,  -4.4432240946811208E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,   4.4432240946811208E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,  -4.4432240946811208E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,   5.9655276206635099E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,   5.9655276206635099E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,  -5.9655276206635099E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,   5.9655276206635099E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,  -5.9655276206635099E-01,   6.6835798679708991E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,  -5.9655276206635099E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,   5.9655276206635099E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,  -5.9655276206635099E-01,  -6.6835798679708991E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,   5.9655276206635099E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,   5.9655276206635099E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,  -5.9655276206635099E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,   5.9655276206635099E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,  -5.9655276206635099E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,  -5.9655276206635099E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,   5.9655276206635099E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,  -5.9655276206635099E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,   4.4432240946811208E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,   4.4432240946811208E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,  -4.4432240946811208E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,   4.4432240946811208E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,  -4.4432240946811208E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   6.6835798679708991E-01,  -4.4432240946811208E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,   4.4432240946811208E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -6.6835798679708991E-01,  -4.4432240946811208E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,   6.6835798679708991E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,   6.6835798679708991E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,  -6.6835798679708991E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,   6.6835798679708991E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,  -6.6835798679708991E-01,   4.4432240946811208E-01,   3.1946611756383790E-03],
            [   5.9655276206635099E-01,  -6.6835798679708991E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,   6.6835798679708991E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [  -5.9655276206635099E-01,  -6.6835798679708991E-01,  -4.4432240946811208E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,   6.6835798679708991E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,   6.6835798679708991E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,  -6.6835798679708991E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,   6.6835798679708991E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,  -6.6835798679708991E-01,   5.9655276206635099E-01,   3.1946611756383790E-03],
            [   4.4432240946811208E-01,  -6.6835798679708991E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,   6.6835798679708991E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [  -4.4432240946811208E-01,  -6.6835798679708991E-01,  -5.9655276206635099E-01,   3.1946611756383790E-03],
            [   2.2992277008561571E-01,   2.8657576640575839E-02,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,   2.8657576640575839E-02,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,  -2.8657576640575839E-02,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,   2.8657576640575839E-02,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,  -2.8657576640575839E-02,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,  -2.8657576640575839E-02,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,   2.8657576640575839E-02,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,  -2.8657576640575839E-02,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,   2.2992277008561571E-01,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,   2.2992277008561571E-01,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,  -2.2992277008561571E-01,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,   2.2992277008561571E-01,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,  -2.2992277008561571E-01,   9.7278685388796582E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,  -2.2992277008561571E-01,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,   2.2992277008561571E-01,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,  -2.2992277008561571E-01,  -9.7278685388796582E-01,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,   2.2992277008561571E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,   2.2992277008561571E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,  -2.2992277008561571E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,   2.2992277008561571E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,  -2.2992277008561571E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,  -2.2992277008561571E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,   2.2992277008561571E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,  -2.2992277008561571E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,   2.8657576640575839E-02,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,   2.8657576640575839E-02,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,  -2.8657576640575839E-02,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,   2.8657576640575839E-02,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,  -2.8657576640575839E-02,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   9.7278685388796582E-01,  -2.8657576640575839E-02,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,   2.8657576640575839E-02,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -9.7278685388796582E-01,  -2.8657576640575839E-02,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,   9.7278685388796582E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,   9.7278685388796582E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,  -9.7278685388796582E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,   9.7278685388796582E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,  -9.7278685388796582E-01,   2.8657576640575839E-02,   2.4439291363070859E-03],
            [   2.2992277008561571E-01,  -9.7278685388796582E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,   9.7278685388796582E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [  -2.2992277008561571E-01,  -9.7278685388796582E-01,  -2.8657576640575839E-02,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,   9.7278685388796582E-01,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,   9.7278685388796582E-01,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,  -9.7278685388796582E-01,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,   9.7278685388796582E-01,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,  -9.7278685388796582E-01,   2.2992277008561571E-01,   2.4439291363070859E-03],
            [   2.8657576640575839E-02,  -9.7278685388796582E-01,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,   9.7278685388796582E-01,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [  -2.8657576640575839E-02,  -9.7278685388796582E-01,  -2.2992277008561571E-01,   2.4439291363070859E-03],
            [   2.6957529985532669E-01,   5.9234216844859931E-02,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,   5.9234216844859931E-02,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,  -5.9234216844859931E-02,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,   5.9234216844859931E-02,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,  -5.9234216844859931E-02,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,  -5.9234216844859931E-02,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,   5.9234216844859931E-02,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,  -5.9234216844859931E-02,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,   2.6957529985532669E-01,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,   2.6957529985532669E-01,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,  -2.6957529985532669E-01,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,   2.6957529985532669E-01,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,  -2.6957529985532669E-01,   9.6115579656093564E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,  -2.6957529985532669E-01,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,   2.6957529985532669E-01,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,  -2.6957529985532669E-01,  -9.6115579656093564E-01,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,   2.6957529985532669E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,   2.6957529985532669E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,  -2.6957529985532669E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,   2.6957529985532669E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,  -2.6957529985532669E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,  -2.6957529985532669E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,   2.6957529985532669E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,  -2.6957529985532669E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,   5.9234216844859931E-02,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,   5.9234216844859931E-02,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,  -5.9234216844859931E-02,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,   5.9234216844859931E-02,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,  -5.9234216844859931E-02,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   9.6115579656093564E-01,  -5.9234216844859931E-02,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,   5.9234216844859931E-02,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -9.6115579656093564E-01,  -5.9234216844859931E-02,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,   9.6115579656093564E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,   9.6115579656093564E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,  -9.6115579656093564E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,   9.6115579656093564E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,  -9.6115579656093564E-01,   5.9234216844859931E-02,   2.5985524829758642E-03],
            [   2.6957529985532669E-01,  -9.6115579656093564E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,   9.6115579656093564E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [  -2.6957529985532669E-01,  -9.6115579656093564E-01,  -5.9234216844859931E-02,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,   9.6115579656093564E-01,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,   9.6115579656093564E-01,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,  -9.6115579656093564E-01,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,   9.6115579656093564E-01,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,  -9.6115579656093564E-01,   2.6957529985532669E-01,   2.5985524829758642E-03],
            [   5.9234216844859931E-02,  -9.6115579656093564E-01,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,   9.6115579656093564E-01,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [  -5.9234216844859931E-02,  -9.6115579656093564E-01,  -2.6957529985532669E-01,   2.5985524829758642E-03],
            [   3.0861787166113891E-01,   9.1178177760577156E-02,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,   9.1178177760577156E-02,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,  -9.1178177760577156E-02,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,   9.1178177760577156E-02,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,  -9.1178177760577156E-02,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,  -9.1178177760577156E-02,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,   9.1178177760577156E-02,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,  -9.1178177760577156E-02,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,   3.0861787166113891E-01,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,   3.0861787166113891E-01,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,  -3.0861787166113891E-01,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,   3.0861787166113891E-01,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,  -3.0861787166113891E-01,   9.4680597230457375E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,  -3.0861787166113891E-01,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,   3.0861787166113891E-01,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,  -3.0861787166113891E-01,  -9.4680597230457375E-01,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,   3.0861787166113891E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,   3.0861787166113891E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,  -3.0861787166113891E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,   3.0861787166113891E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,  -3.0861787166113891E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,  -3.0861787166113891E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,   3.0861787166113891E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,  -3.0861787166113891E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,   9.1178177760577156E-02,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,   9.1178177760577156E-02,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,  -9.1178177760577156E-02,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,   9.1178177760577156E-02,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,  -9.1178177760577156E-02,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.4680597230457375E-01,  -9.1178177760577156E-02,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,   9.1178177760577156E-02,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.4680597230457375E-01,  -9.1178177760577156E-02,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,   9.4680597230457375E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,   9.4680597230457375E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,  -9.4680597230457375E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,   9.4680597230457375E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,  -9.4680597230457375E-01,   9.1178177760577156E-02,   2.7299695409331482E-03],
            [   3.0861787166113891E-01,  -9.4680597230457375E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,   9.4680597230457375E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [  -3.0861787166113891E-01,  -9.4680597230457375E-01,  -9.1178177760577156E-02,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,   9.4680597230457375E-01,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,   9.4680597230457375E-01,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,  -9.4680597230457375E-01,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,   9.4680597230457375E-01,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,  -9.4680597230457375E-01,   3.0861787166113891E-01,   2.7299695409331482E-03],
            [   9.1178177760577156E-02,  -9.4680597230457375E-01,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,   9.4680597230457375E-01,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [  -9.1178177760577156E-02,  -9.4680597230457375E-01,  -3.0861787166113891E-01,   2.7299695409331482E-03],
            [   3.4696498716590768E-01,   1.2405938140826051E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,   1.2405938140826051E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,  -1.2405938140826051E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,   1.2405938140826051E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,  -1.2405938140826051E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,  -1.2405938140826051E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,   1.2405938140826051E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,  -1.2405938140826051E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,   3.4696498716590768E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,   3.4696498716590768E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,  -3.4696498716590768E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,   3.4696498716590768E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,  -3.4696498716590768E-01,   9.2963679335833149E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,  -3.4696498716590768E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,   3.4696498716590768E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,  -3.4696498716590768E-01,  -9.2963679335833149E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,   3.4696498716590768E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,   3.4696498716590768E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,  -3.4696498716590768E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,   3.4696498716590768E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,  -3.4696498716590768E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,  -3.4696498716590768E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,   3.4696498716590768E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,  -3.4696498716590768E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,   1.2405938140826051E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,   1.2405938140826051E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,  -1.2405938140826051E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,   1.2405938140826051E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,  -1.2405938140826051E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   9.2963679335833149E-01,  -1.2405938140826051E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,   1.2405938140826051E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -9.2963679335833149E-01,  -1.2405938140826051E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,   9.2963679335833149E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,   9.2963679335833149E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,  -9.2963679335833149E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,   9.2963679335833149E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,  -9.2963679335833149E-01,   1.2405938140826051E-01,   2.8401580847142605E-03],
            [   3.4696498716590768E-01,  -9.2963679335833149E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,   9.2963679335833149E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [  -3.4696498716590768E-01,  -9.2963679335833149E-01,  -1.2405938140826051E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,   9.2963679335833149E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,   9.2963679335833149E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,  -9.2963679335833149E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,   9.2963679335833149E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,  -9.2963679335833149E-01,   3.4696498716590768E-01,   2.8401580847142605E-03],
            [   1.2405938140826051E-01,  -9.2963679335833149E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,   9.2963679335833149E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [  -1.2405938140826051E-01,  -9.2963679335833149E-01,  -3.4696498716590768E-01,   2.8401580847142605E-03],
            [   3.8451535663196551E-01,   1.5752720582591750E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,   1.5752720582591750E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,  -1.5752720582591750E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,   1.5752720582591750E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,  -1.5752720582591750E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,  -1.5752720582591750E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,   1.5752720582591750E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,  -1.5752720582591750E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,   3.8451535663196551E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,   3.8451535663196551E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,  -3.8451535663196551E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,   3.8451535663196551E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,  -3.8451535663196551E-01,   9.0957853973083125E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,  -3.8451535663196551E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,   3.8451535663196551E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,  -3.8451535663196551E-01,  -9.0957853973083125E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,   3.8451535663196551E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,   3.8451535663196551E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,  -3.8451535663196551E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,   3.8451535663196551E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,  -3.8451535663196551E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,  -3.8451535663196551E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,   3.8451535663196551E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,  -3.8451535663196551E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,   1.5752720582591750E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,   1.5752720582591750E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,  -1.5752720582591750E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,   1.5752720582591750E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,  -1.5752720582591750E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   9.0957853973083125E-01,  -1.5752720582591750E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,   1.5752720582591750E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -9.0957853973083125E-01,  -1.5752720582591750E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,   9.0957853973083125E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,   9.0957853973083125E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,  -9.0957853973083125E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,   9.0957853973083125E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,  -9.0957853973083125E-01,   1.5752720582591750E-01,   2.9313007354633759E-03],
            [   3.8451535663196551E-01,  -9.0957853973083125E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,   9.0957853973083125E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [  -3.8451535663196551E-01,  -9.0957853973083125E-01,  -1.5752720582591750E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,   9.0957853973083125E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,   9.0957853973083125E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,  -9.0957853973083125E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,   9.0957853973083125E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,  -9.0957853973083125E-01,   3.8451535663196551E-01,   2.9313007354633759E-03],
            [   1.5752720582591750E-01,  -9.0957853973083125E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,   9.0957853973083125E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [  -1.5752720582591750E-01,  -9.0957853973083125E-01,  -3.8451535663196551E-01,   2.9313007354633759E-03],
            [   4.2116000334032150E-01,   1.9128451635254129E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,   1.9128451635254129E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,  -1.9128451635254129E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,   1.9128451635254129E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,  -1.9128451635254129E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,  -1.9128451635254129E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,   1.9128451635254129E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,  -1.9128451635254129E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,   4.2116000334032150E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,   4.2116000334032150E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,  -4.2116000334032150E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,   4.2116000334032150E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,  -4.2116000334032150E-01,   8.8658585900642173E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,  -4.2116000334032150E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,   4.2116000334032150E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,  -4.2116000334032150E-01,  -8.8658585900642173E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,   4.2116000334032150E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,   4.2116000334032150E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,  -4.2116000334032150E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,   4.2116000334032150E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,  -4.2116000334032150E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,  -4.2116000334032150E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,   4.2116000334032150E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,  -4.2116000334032150E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,   1.9128451635254129E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,   1.9128451635254129E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,  -1.9128451635254129E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,   1.9128451635254129E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,  -1.9128451635254129E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   8.8658585900642173E-01,  -1.9128451635254129E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,   1.9128451635254129E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -8.8658585900642173E-01,  -1.9128451635254129E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,   8.8658585900642173E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,   8.8658585900642173E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,  -8.8658585900642173E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,   8.8658585900642173E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,  -8.8658585900642173E-01,   1.9128451635254129E-01,   3.0054984596381670E-03],
            [   4.2116000334032150E-01,  -8.8658585900642173E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,   8.8658585900642173E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [  -4.2116000334032150E-01,  -8.8658585900642173E-01,  -1.9128451635254129E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,   8.8658585900642173E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,   8.8658585900642173E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,  -8.8658585900642173E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,   8.8658585900642173E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,  -8.8658585900642173E-01,   4.2116000334032150E-01,   3.0054984596381670E-03],
            [   1.9128451635254129E-01,  -8.8658585900642173E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,   8.8658585900642173E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [  -1.9128451635254129E-01,  -8.8658585900642173E-01,  -4.2116000334032150E-01,   3.0054984596381670E-03],
            [   4.5678678343298817E-01,   2.2507101778581709E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,   2.2507101778581709E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,  -2.2507101778581709E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,   2.2507101778581709E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,  -2.2507101778581709E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,  -2.2507101778581709E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,   2.2507101778581709E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,  -2.2507101778581709E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,   4.5678678343298817E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,   4.5678678343298817E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,  -4.5678678343298817E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,   4.5678678343298817E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,  -4.5678678343298817E-01,   8.6063283195204721E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,  -4.5678678343298817E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,   4.5678678343298817E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,  -4.5678678343298817E-01,  -8.6063283195204721E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,   4.5678678343298817E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,   4.5678678343298817E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,  -4.5678678343298817E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,   4.5678678343298817E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,  -4.5678678343298817E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,  -4.5678678343298817E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,   4.5678678343298817E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,  -4.5678678343298817E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,   2.2507101778581709E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,   2.2507101778581709E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,  -2.2507101778581709E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,   2.2507101778581709E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,  -2.2507101778581709E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   8.6063283195204721E-01,  -2.2507101778581709E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,   2.2507101778581709E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -8.6063283195204721E-01,  -2.2507101778581709E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,   8.6063283195204721E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,   8.6063283195204721E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,  -8.6063283195204721E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,   8.6063283195204721E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,  -8.6063283195204721E-01,   2.2507101778581709E-01,   3.0646883859155728E-03],
            [   4.5678678343298817E-01,  -8.6063283195204721E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,   8.6063283195204721E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [  -4.5678678343298817E-01,  -8.6063283195204721E-01,  -2.2507101778581709E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,   8.6063283195204721E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,   8.6063283195204721E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,  -8.6063283195204721E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,   8.6063283195204721E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,  -8.6063283195204721E-01,   4.5678678343298817E-01,   3.0646883859155728E-03],
            [   2.2507101778581709E-01,  -8.6063283195204721E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,   8.6063283195204721E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [  -2.2507101778581709E-01,  -8.6063283195204721E-01,  -4.5678678343298817E-01,   3.0646883859155728E-03],
            [   4.9128293192320610E-01,   2.5865213034409101E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,   2.5865213034409101E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,  -2.5865213034409101E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,   2.5865213034409101E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,  -2.5865213034409101E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,  -2.5865213034409101E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,   2.5865213034409101E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,  -2.5865213034409101E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,   4.9128293192320610E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,   4.9128293192320610E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,  -4.9128293192320610E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,   4.9128293192320610E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,  -4.9128293192320610E-01,   8.3170917769939390E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,  -4.9128293192320610E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,   4.9128293192320610E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,  -4.9128293192320610E-01,  -8.3170917769939390E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,   4.9128293192320610E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,   4.9128293192320610E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,  -4.9128293192320610E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,   4.9128293192320610E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,  -4.9128293192320610E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,  -4.9128293192320610E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,   4.9128293192320610E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,  -4.9128293192320610E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,   2.5865213034409101E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,   2.5865213034409101E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,  -2.5865213034409101E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,   2.5865213034409101E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,  -2.5865213034409101E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   8.3170917769939390E-01,  -2.5865213034409101E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,   2.5865213034409101E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -8.3170917769939390E-01,  -2.5865213034409101E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,   8.3170917769939390E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,   8.3170917769939390E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,  -8.3170917769939390E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,   8.3170917769939390E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,  -8.3170917769939390E-01,   2.5865213034409101E-01,   3.1106423164392670E-03],
            [   4.9128293192320610E-01,  -8.3170917769939390E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,   8.3170917769939390E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [  -4.9128293192320610E-01,  -8.3170917769939390E-01,  -2.5865213034409101E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,   8.3170917769939390E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,   8.3170917769939390E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,  -8.3170917769939390E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,   8.3170917769939390E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,  -8.3170917769939390E-01,   4.9128293192320610E-01,   3.1106423164392670E-03],
            [   2.5865213034409101E-01,  -8.3170917769939390E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,   8.3170917769939390E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [  -2.5865213034409101E-01,  -8.3170917769939390E-01,  -4.9128293192320610E-01,   3.1106423164392670E-03],
            [   5.2453647933038117E-01,   2.9181122428654072E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,   2.9181122428654072E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,  -2.9181122428654072E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,   2.9181122428654072E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,  -2.9181122428654072E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,  -2.9181122428654072E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,   2.9181122428654072E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,  -2.9181122428654072E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,   5.2453647933038117E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,   5.2453647933038117E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,  -5.2453647933038117E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,   5.2453647933038117E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,  -5.2453647933038117E-01,   7.9981728615483105E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,  -5.2453647933038117E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,   5.2453647933038117E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,  -5.2453647933038117E-01,  -7.9981728615483105E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,   5.2453647933038117E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,   5.2453647933038117E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,  -5.2453647933038117E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,   5.2453647933038117E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,  -5.2453647933038117E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,  -5.2453647933038117E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,   5.2453647933038117E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,  -5.2453647933038117E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,   2.9181122428654072E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,   2.9181122428654072E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,  -2.9181122428654072E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,   2.9181122428654072E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,  -2.9181122428654072E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   7.9981728615483105E-01,  -2.9181122428654072E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,   2.9181122428654072E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -7.9981728615483105E-01,  -2.9181122428654072E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,   7.9981728615483105E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,   7.9981728615483105E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,  -7.9981728615483105E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,   7.9981728615483105E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,  -7.9981728615483105E-01,   2.9181122428654072E-01,   3.1449946662297783E-03],
            [   5.2453647933038117E-01,  -7.9981728615483105E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,   7.9981728615483105E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [  -5.2453647933038117E-01,  -7.9981728615483105E-01,  -2.9181122428654072E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,   7.9981728615483105E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,   7.9981728615483105E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,  -7.9981728615483105E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,   7.9981728615483105E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,  -7.9981728615483105E-01,   5.2453647933038117E-01,   3.1449946662297783E-03],
            [   2.9181122428654072E-01,  -7.9981728615483105E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,   7.9981728615483105E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [  -2.9181122428654072E-01,  -7.9981728615483105E-01,  -5.2453647933038117E-01,   3.1449946662297783E-03],
            [   5.5643697889157562E-01,   3.2434392390678901E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,   3.2434392390678901E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,  -3.2434392390678901E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,   3.2434392390678901E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,  -3.2434392390678901E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,  -3.2434392390678901E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,   3.2434392390678901E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,  -3.2434392390678901E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,   5.5643697889157562E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,   5.5643697889157562E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,  -5.5643697889157562E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,   5.5643697889157562E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,  -5.5643697889157562E-01,   7.6496987362036895E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,  -5.5643697889157562E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,   5.5643697889157562E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,  -5.5643697889157562E-01,  -7.6496987362036895E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,   5.5643697889157562E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,   5.5643697889157562E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,  -5.5643697889157562E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,   5.5643697889157562E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,  -5.5643697889157562E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,  -5.5643697889157562E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,   5.5643697889157562E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,  -5.5643697889157562E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,   3.2434392390678901E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,   3.2434392390678901E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,  -3.2434392390678901E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,   3.2434392390678901E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,  -3.2434392390678901E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   7.6496987362036895E-01,  -3.2434392390678901E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,   3.2434392390678901E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -7.6496987362036895E-01,  -3.2434392390678901E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,   7.6496987362036895E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,   7.6496987362036895E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,  -7.6496987362036895E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,   7.6496987362036895E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,  -7.6496987362036895E-01,   3.2434392390678901E-01,   3.1692785056610293E-03],
            [   5.5643697889157562E-01,  -7.6496987362036895E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,   7.6496987362036895E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [  -5.5643697889157562E-01,  -7.6496987362036895E-01,  -3.2434392390678901E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,   7.6496987362036895E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,   7.6496987362036895E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,  -7.6496987362036895E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,   7.6496987362036895E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,  -7.6496987362036895E-01,   5.5643697889157562E-01,   3.1692785056610293E-03],
            [   3.2434392390678901E-01,  -7.6496987362036895E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,   7.6496987362036895E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [  -3.2434392390678901E-01,  -7.6496987362036895E-01,  -5.5643697889157562E-01,   3.1692785056610293E-03],
            [   5.8687576977752876E-01,   3.5605367878353511E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,   3.5605367878353511E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,  -3.5605367878353511E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,   3.5605367878353511E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,  -3.5605367878353511E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,  -3.5605367878353511E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,   3.5605367878353511E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,  -3.5605367878353511E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,   5.8687576977752876E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,   5.8687576977752876E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,  -5.8687576977752876E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,   5.8687576977752876E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,  -5.8687576977752876E-01,   7.2718815218122490E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,  -5.8687576977752876E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,   5.8687576977752876E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,  -5.8687576977752876E-01,  -7.2718815218122490E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,   5.8687576977752876E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,   5.8687576977752876E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,  -5.8687576977752876E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,   5.8687576977752876E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,  -5.8687576977752876E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,  -5.8687576977752876E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,   5.8687576977752876E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,  -5.8687576977752876E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,   3.5605367878353511E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,   3.5605367878353511E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,  -3.5605367878353511E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,   3.5605367878353511E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,  -3.5605367878353511E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   7.2718815218122490E-01,  -3.5605367878353511E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,   3.5605367878353511E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -7.2718815218122490E-01,  -3.5605367878353511E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,   7.2718815218122490E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,   7.2718815218122490E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,  -7.2718815218122490E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,   7.2718815218122490E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,  -7.2718815218122490E-01,   3.5605367878353511E-01,   3.1849607944823537E-03],
            [   5.8687576977752876E-01,  -7.2718815218122490E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,   7.2718815218122490E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [  -5.8687576977752876E-01,  -7.2718815218122490E-01,  -3.5605367878353511E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,   7.2718815218122490E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,   7.2718815218122490E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,  -7.2718815218122490E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,   7.2718815218122490E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,  -7.2718815218122490E-01,   5.8687576977752876E-01,   3.1849607944823537E-03],
            [   3.5605367878353511E-01,  -7.2718815218122490E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,   7.2718815218122490E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [  -3.5605367878353511E-01,  -7.2718815218122490E-01,  -5.8687576977752876E-01,   3.1849607944823537E-03],
            [   6.1574588535196173E-01,   3.8674808212425810E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,   3.8674808212425810E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,  -3.8674808212425810E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,   3.8674808212425810E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,  -3.8674808212425810E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,  -3.8674808212425810E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,   3.8674808212425810E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,  -3.8674808212425810E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,   6.1574588535196173E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,   6.1574588535196173E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,  -6.1574588535196173E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,   6.1574588535196173E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,  -6.1574588535196173E-01,   6.8650049209402386E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,  -6.1574588535196173E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,   6.1574588535196173E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,  -6.1574588535196173E-01,  -6.8650049209402386E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,   6.1574588535196173E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,   6.1574588535196173E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,  -6.1574588535196173E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,   6.1574588535196173E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,  -6.1574588535196173E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,  -6.1574588535196173E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,   6.1574588535196173E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,  -6.1574588535196173E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,   3.8674808212425810E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,   3.8674808212425810E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,  -3.8674808212425810E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,   3.8674808212425810E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,  -3.8674808212425810E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   6.8650049209402386E-01,  -3.8674808212425810E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,   3.8674808212425810E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -6.8650049209402386E-01,  -3.8674808212425810E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,   6.8650049209402386E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,   6.8650049209402386E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,  -6.8650049209402386E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,   6.8650049209402386E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,  -6.8650049209402386E-01,   3.8674808212425810E-01,   3.1934728078006655E-03],
            [   6.1574588535196173E-01,  -6.8650049209402386E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,   6.8650049209402386E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [  -6.1574588535196173E-01,  -6.8650049209402386E-01,  -3.8674808212425810E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,   6.8650049209402386E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,   6.8650049209402386E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,  -6.8650049209402386E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,   6.8650049209402386E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,  -6.8650049209402386E-01,   6.1574588535196173E-01,   3.1934728078006655E-03],
            [   3.8674808212425810E-01,  -6.8650049209402386E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,   6.8650049209402386E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [  -3.8674808212425810E-01,  -6.8650049209402386E-01,  -6.1574588535196173E-01,   3.1934728078006655E-03],
            [   3.1384611106721128E-01,   3.0513746375072780E-02,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,   3.0513746375072780E-02,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,  -3.0513746375072780E-02,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,   3.0513746375072780E-02,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,  -3.0513746375072780E-02,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,  -3.0513746375072780E-02,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,   3.0513746375072780E-02,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,  -3.0513746375072780E-02,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,   3.1384611106721128E-01,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,   3.1384611106721128E-01,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,  -3.1384611106721128E-01,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,   3.1384611106721128E-01,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,  -3.1384611106721128E-01,   9.4898341916502704E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,  -3.1384611106721128E-01,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,   3.1384611106721128E-01,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,  -3.1384611106721128E-01,  -9.4898341916502704E-01,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,   3.1384611106721128E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,   3.1384611106721128E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,  -3.1384611106721128E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,   3.1384611106721128E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,  -3.1384611106721128E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,  -3.1384611106721128E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,   3.1384611106721128E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,  -3.1384611106721128E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,   3.0513746375072780E-02,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,   3.0513746375072780E-02,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,  -3.0513746375072780E-02,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,   3.0513746375072780E-02,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,  -3.0513746375072780E-02,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   9.4898341916502704E-01,  -3.0513746375072780E-02,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,   3.0513746375072780E-02,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -9.4898341916502704E-01,  -3.0513746375072780E-02,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,   9.4898341916502704E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,   9.4898341916502704E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,  -9.4898341916502704E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,   9.4898341916502704E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,  -9.4898341916502704E-01,   3.0513746375072780E-02,   2.7162326330516149E-03],
            [   3.1384611106721128E-01,  -9.4898341916502704E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,   9.4898341916502704E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [  -3.1384611106721128E-01,  -9.4898341916502704E-01,  -3.0513746375072780E-02,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,   9.4898341916502704E-01,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,   9.4898341916502704E-01,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,  -9.4898341916502704E-01,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,   9.4898341916502704E-01,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,  -9.4898341916502704E-01,   3.1384611106721128E-01,   2.7162326330516149E-03],
            [   3.0513746375072780E-02,  -9.4898341916502704E-01,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,   9.4898341916502704E-01,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [  -3.0513746375072780E-02,  -9.4898341916502704E-01,  -3.1384611106721128E-01,   2.7162326330516149E-03],
            [   3.5424958720505689E-01,   6.2371112337307549E-02,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,   6.2371112337307549E-02,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,  -6.2371112337307549E-02,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,   6.2371112337307549E-02,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,  -6.2371112337307549E-02,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,  -6.2371112337307549E-02,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,   6.2371112337307549E-02,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,  -6.2371112337307549E-02,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,   3.5424958720505689E-01,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,   3.5424958720505689E-01,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,  -3.5424958720505689E-01,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,   3.5424958720505689E-01,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,  -3.5424958720505689E-01,   9.3306863322633116E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,  -3.5424958720505689E-01,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,   3.5424958720505689E-01,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,  -3.5424958720505689E-01,  -9.3306863322633116E-01,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,   3.5424958720505689E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,   3.5424958720505689E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,  -3.5424958720505689E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,   3.5424958720505689E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,  -3.5424958720505689E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,  -3.5424958720505689E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,   3.5424958720505689E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,  -3.5424958720505689E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,   6.2371112337307549E-02,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,   6.2371112337307549E-02,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,  -6.2371112337307549E-02,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,   6.2371112337307549E-02,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,  -6.2371112337307549E-02,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   9.3306863322633116E-01,  -6.2371112337307549E-02,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,   6.2371112337307549E-02,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -9.3306863322633116E-01,  -6.2371112337307549E-02,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,   9.3306863322633116E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,   9.3306863322633116E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,  -9.3306863322633116E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,   9.3306863322633116E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,  -9.3306863322633116E-01,   6.2371112337307549E-02,   2.8258984229467725E-03],
            [   3.5424958720505689E-01,  -9.3306863322633116E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,   9.3306863322633116E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [  -3.5424958720505689E-01,  -9.3306863322633116E-01,  -6.2371112337307549E-02,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,   9.3306863322633116E-01,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,   9.3306863322633116E-01,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,  -9.3306863322633116E-01,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,   9.3306863322633116E-01,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,  -9.3306863322633116E-01,   3.5424958720505689E-01,   2.8258984229467725E-03],
            [   6.2371112337307549E-02,  -9.3306863322633116E-01,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,   9.3306863322633116E-01,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [  -6.2371112337307549E-02,  -9.3306863322633116E-01,  -3.5424958720505689E-01,   2.8258984229467725E-03],
            [   3.9357515531201809E-01,   9.5162239524019074E-02,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,   9.5162239524019074E-02,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,  -9.5162239524019074E-02,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,   9.5162239524019074E-02,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,  -9.5162239524019074E-02,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,  -9.5162239524019074E-02,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,   9.5162239524019074E-02,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,  -9.5162239524019074E-02,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,   3.9357515531201809E-01,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,   3.9357515531201809E-01,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,  -3.9357515531201809E-01,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,   3.9357515531201809E-01,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,  -3.9357515531201809E-01,   9.1435373094327888E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,  -3.9357515531201809E-01,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,   3.9357515531201809E-01,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,  -3.9357515531201809E-01,  -9.1435373094327888E-01,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,   3.9357515531201809E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,   3.9357515531201809E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,  -3.9357515531201809E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,   3.9357515531201809E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,  -3.9357515531201809E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,  -3.9357515531201809E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,   3.9357515531201809E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,  -3.9357515531201809E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,   9.5162239524019074E-02,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,   9.5162239524019074E-02,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,  -9.5162239524019074E-02,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,   9.5162239524019074E-02,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,  -9.5162239524019074E-02,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.1435373094327888E-01,  -9.5162239524019074E-02,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,   9.5162239524019074E-02,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.1435373094327888E-01,  -9.5162239524019074E-02,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,   9.1435373094327888E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,   9.1435373094327888E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,  -9.1435373094327888E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,   9.1435373094327888E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,  -9.1435373094327888E-01,   9.5162239524019074E-02,   2.9183998414220539E-03],
            [   3.9357515531201809E-01,  -9.1435373094327888E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,   9.1435373094327888E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [  -3.9357515531201809E-01,  -9.1435373094327888E-01,  -9.5162239524019074E-02,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,   9.1435373094327888E-01,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,   9.1435373094327888E-01,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,  -9.1435373094327888E-01,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,   9.1435373094327888E-01,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,  -9.1435373094327888E-01,   3.9357515531201809E-01,   2.9183998414220539E-03],
            [   9.5162239524019074E-02,  -9.1435373094327888E-01,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,   9.1435373094327888E-01,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [  -9.5162239524019074E-02,  -9.1435373094327888E-01,  -3.9357515531201809E-01,   2.9183998414220539E-03],
            [   4.3176346681111472E-01,   1.2854673415085169E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,   1.2854673415085169E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,  -1.2854673415085169E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,   1.2854673415085169E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,  -1.2854673415085169E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,  -1.2854673415085169E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,   1.2854673415085169E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,  -1.2854673415085169E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,   4.3176346681111472E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,   4.3176346681111472E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,  -4.3176346681111472E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,   4.3176346681111472E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,  -4.3176346681111472E-01,   8.9277995377718788E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,  -4.3176346681111472E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,   4.3176346681111472E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,  -4.3176346681111472E-01,  -8.9277995377718788E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,   4.3176346681111472E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,   4.3176346681111472E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,  -4.3176346681111472E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,   4.3176346681111472E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,  -4.3176346681111472E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,  -4.3176346681111472E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,   4.3176346681111472E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,  -4.3176346681111472E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,   1.2854673415085169E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,   1.2854673415085169E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,  -1.2854673415085169E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,   1.2854673415085169E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,  -1.2854673415085169E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   8.9277995377718788E-01,  -1.2854673415085169E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,   1.2854673415085169E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -8.9277995377718788E-01,  -1.2854673415085169E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,   8.9277995377718788E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,   8.9277995377718788E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,  -8.9277995377718788E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,   8.9277995377718788E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,  -8.9277995377718788E-01,   1.2854673415085169E-01,   2.9948997181008302E-03],
            [   4.3176346681111472E-01,  -8.9277995377718788E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,   8.9277995377718788E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [  -4.3176346681111472E-01,  -8.9277995377718788E-01,  -1.2854673415085169E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,   8.9277995377718788E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,   8.9277995377718788E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,  -8.9277995377718788E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,   8.9277995377718788E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,  -8.9277995377718788E-01,   4.3176346681111472E-01,   2.9948997181008302E-03],
            [   1.2854673415085169E-01,  -8.9277995377718788E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,   8.9277995377718788E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [  -1.2854673415085169E-01,  -8.9277995377718788E-01,  -4.3176346681111472E-01,   2.9948997181008302E-03],
            [   4.6874138422508210E-01,   1.6223189316560330E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,   1.6223189316560330E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,  -1.6223189316560330E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,   1.6223189316560330E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,  -1.6223189316560330E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,  -1.6223189316560330E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,   1.6223189316560330E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,  -1.6223189316560330E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,   4.6874138422508210E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,   4.6874138422508210E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,  -4.6874138422508210E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,   4.6874138422508210E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,  -4.6874138422508210E-01,   8.6831004114582144E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,  -4.6874138422508210E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,   4.6874138422508210E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,  -4.6874138422508210E-01,  -8.6831004114582144E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,   4.6874138422508210E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,   4.6874138422508210E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,  -4.6874138422508210E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,   4.6874138422508210E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,  -4.6874138422508210E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,  -4.6874138422508210E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,   4.6874138422508210E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,  -4.6874138422508210E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,   1.6223189316560330E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,   1.6223189316560330E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,  -1.6223189316560330E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,   1.6223189316560330E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,  -1.6223189316560330E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   8.6831004114582144E-01,  -1.6223189316560330E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,   1.6223189316560330E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -8.6831004114582144E-01,  -1.6223189316560330E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,   8.6831004114582144E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,   8.6831004114582144E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,  -8.6831004114582144E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,   8.6831004114582144E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,  -8.6831004114582144E-01,   1.6223189316560330E-01,   3.0567403409079469E-03],
            [   4.6874138422508210E-01,  -8.6831004114582144E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,   8.6831004114582144E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [  -4.6874138422508210E-01,  -8.6831004114582144E-01,  -1.6223189316560330E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,   8.6831004114582144E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,   8.6831004114582144E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,  -8.6831004114582144E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,   8.6831004114582144E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,  -8.6831004114582144E-01,   4.6874138422508210E-01,   3.0567403409079469E-03],
            [   1.6223189316560330E-01,  -8.6831004114582144E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,   8.6831004114582144E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [  -1.6223189316560330E-01,  -8.6831004114582144E-01,  -4.6874138422508210E-01,   3.0567403409079469E-03],
            [   5.0442742370602833E-01,   1.9595811538364530E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,   1.9595811538364530E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,  -1.9595811538364530E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,   1.9595811538364530E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,  -1.9595811538364530E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,  -1.9595811538364530E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,   1.9595811538364530E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,  -1.9595811538364530E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,   5.0442742370602833E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,   5.0442742370602833E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,  -5.0442742370602833E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,   5.0442742370602833E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,  -5.0442742370602833E-01,   8.4092412929383165E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,  -5.0442742370602833E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,   5.0442742370602833E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,  -5.0442742370602833E-01,  -8.4092412929383165E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,   5.0442742370602833E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,   5.0442742370602833E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,  -5.0442742370602833E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,   5.0442742370602833E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,  -5.0442742370602833E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,  -5.0442742370602833E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,   5.0442742370602833E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,  -5.0442742370602833E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,   1.9595811538364530E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,   1.9595811538364530E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,  -1.9595811538364530E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,   1.9595811538364530E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,  -1.9595811538364530E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   8.4092412929383165E-01,  -1.9595811538364530E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,   1.9595811538364530E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -8.4092412929383165E-01,  -1.9595811538364530E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,   8.4092412929383165E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,   8.4092412929383165E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,  -8.4092412929383165E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,   8.4092412929383165E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,  -8.4092412929383165E-01,   1.9595811538364530E-01,   3.1053037697030359E-03],
            [   5.0442742370602833E-01,  -8.4092412929383165E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,   8.4092412929383165E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [  -5.0442742370602833E-01,  -8.4092412929383165E-01,  -1.9595811538364530E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,   8.4092412929383165E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,   8.4092412929383165E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,  -8.4092412929383165E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,   8.4092412929383165E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,  -8.4092412929383165E-01,   5.0442742370602833E-01,   3.1053037697030359E-03],
            [   1.9595811538364530E-01,  -8.4092412929383165E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,   8.4092412929383165E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [  -1.9595811538364530E-01,  -8.4092412929383165E-01,  -5.0442742370602833E-01,   3.1053037697030359E-03],
            [   5.3873540779257267E-01,   2.2948880811838371E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,   2.2948880811838371E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,  -2.2948880811838371E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,   2.2948880811838371E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,  -2.2948880811838371E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,  -2.2948880811838371E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,   2.2948880811838371E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,  -2.2948880811838371E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,   5.3873540779257267E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,   5.3873540779257267E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,  -5.3873540779257267E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,   5.3873540779257267E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,  -5.3873540779257267E-01,   8.1061646130520570E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,  -5.3873540779257267E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,   5.3873540779257267E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,  -5.3873540779257267E-01,  -8.1061646130520570E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,   5.3873540779257267E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,   5.3873540779257267E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,  -5.3873540779257267E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,   5.3873540779257267E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,  -5.3873540779257267E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,  -5.3873540779257267E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,   5.3873540779257267E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,  -5.3873540779257267E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,   2.2948880811838371E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,   2.2948880811838371E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,  -2.2948880811838371E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,   2.2948880811838371E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,  -2.2948880811838371E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   8.1061646130520570E-01,  -2.2948880811838371E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,   2.2948880811838371E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -8.1061646130520570E-01,  -2.2948880811838371E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,   8.1061646130520570E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,   8.1061646130520570E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,  -8.1061646130520570E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,   8.1061646130520570E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,  -8.1061646130520570E-01,   2.2948880811838371E-01,   3.1419592805775600E-03],
            [   5.3873540779257267E-01,  -8.1061646130520570E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,   8.1061646130520570E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [  -5.3873540779257267E-01,  -8.1061646130520570E-01,  -2.2948880811838371E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,   8.1061646130520570E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,   8.1061646130520570E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,  -8.1061646130520570E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,   8.1061646130520570E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,  -8.1061646130520570E-01,   5.3873540779257267E-01,   3.1419592805775600E-03],
            [   2.2948880811838371E-01,  -8.1061646130520570E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,   8.1061646130520570E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [  -2.2948880811838371E-01,  -8.1061646130520570E-01,  -5.3873540779257267E-01,   3.1419592805775600E-03],
            [   5.7157688983561050E-01,   2.6260311527139452E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,   2.6260311527139452E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,  -2.6260311527139452E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,   2.6260311527139452E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,  -2.6260311527139452E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,  -2.6260311527139452E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,   2.6260311527139452E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,  -2.6260311527139452E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,   5.7157688983561050E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,   5.7157688983561050E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,  -5.7157688983561050E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,   5.7157688983561050E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,  -5.7157688983561050E-01,   7.7739273398688835E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,  -5.7157688983561050E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,   5.7157688983561050E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,  -5.7157688983561050E-01,  -7.7739273398688835E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,   5.7157688983561050E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,   5.7157688983561050E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,  -5.7157688983561050E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,   5.7157688983561050E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,  -5.7157688983561050E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,  -5.7157688983561050E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,   5.7157688983561050E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,  -5.7157688983561050E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,   2.6260311527139452E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,   2.6260311527139452E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,  -2.6260311527139452E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,   2.6260311527139452E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,  -2.6260311527139452E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   7.7739273398688835E-01,  -2.6260311527139452E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,   2.6260311527139452E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -7.7739273398688835E-01,  -2.6260311527139452E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,   7.7739273398688835E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,   7.7739273398688835E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,  -7.7739273398688835E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,   7.7739273398688835E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,  -7.7739273398688835E-01,   2.6260311527139452E-01,   3.1680523316313658E-03],
            [   5.7157688983561050E-01,  -7.7739273398688835E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,   7.7739273398688835E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [  -5.7157688983561050E-01,  -7.7739273398688835E-01,  -2.6260311527139452E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,   7.7739273398688835E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,   7.7739273398688835E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,  -7.7739273398688835E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,   7.7739273398688835E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,  -7.7739273398688835E-01,   5.7157688983561050E-01,   3.1680523316313658E-03],
            [   2.6260311527139452E-01,  -7.7739273398688835E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,   7.7739273398688835E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [  -2.6260311527139452E-01,  -7.7739273398688835E-01,  -5.7157688983561050E-01,   3.1680523316313658E-03],
            [   6.0286272001361108E-01,   2.9509040752867127E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,   2.9509040752867127E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,  -2.9509040752867127E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,   2.9509040752867127E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,  -2.9509040752867127E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,  -2.9509040752867127E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,   2.9509040752867127E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,  -2.9509040752867127E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,   6.0286272001361108E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,   6.0286272001361108E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,  -6.0286272001361108E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,   6.0286272001361108E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,  -6.0286272001361108E-01,   7.4126796248209270E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,  -6.0286272001361108E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,   6.0286272001361108E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,  -6.0286272001361108E-01,  -7.4126796248209270E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,   6.0286272001361108E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,   6.0286272001361108E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,  -6.0286272001361108E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,   6.0286272001361108E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,  -6.0286272001361108E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,  -6.0286272001361108E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,   6.0286272001361108E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,  -6.0286272001361108E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,   2.9509040752867127E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,   2.9509040752867127E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,  -2.9509040752867127E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,   2.9509040752867127E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,  -2.9509040752867127E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   7.4126796248209270E-01,  -2.9509040752867127E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,   2.9509040752867127E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -7.4126796248209270E-01,  -2.9509040752867127E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,   7.4126796248209270E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,   7.4126796248209270E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,  -7.4126796248209270E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,   7.4126796248209270E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,  -7.4126796248209270E-01,   2.9509040752867127E-01,   3.1849124335549036E-03],
            [   6.0286272001361108E-01,  -7.4126796248209270E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,   7.4126796248209270E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [  -6.0286272001361108E-01,  -7.4126796248209270E-01,  -2.9509040752867127E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,   7.4126796248209270E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,   7.4126796248209270E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,  -7.4126796248209270E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,   7.4126796248209270E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,  -7.4126796248209270E-01,   6.0286272001361108E-01,   3.1849124335549036E-03],
            [   2.9509040752867127E-01,  -7.4126796248209270E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,   7.4126796248209270E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [  -2.9509040752867127E-01,  -7.4126796248209270E-01,  -6.0286272001361108E-01,   3.1849124335549036E-03],
            [   6.3250398126534635E-01,   3.2674584511132859E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,   3.2674584511132859E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,  -3.2674584511132859E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,   3.2674584511132859E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,  -3.2674584511132859E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,  -3.2674584511132859E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,   3.2674584511132859E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,  -3.2674584511132859E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,   6.3250398126534635E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,   6.3250398126534635E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,  -6.3250398126534635E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,   6.3250398126534635E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,  -6.3250398126534635E-01,   7.0226481215134939E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,  -6.3250398126534635E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,   6.3250398126534635E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,  -6.3250398126534635E-01,  -7.0226481215134939E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,   6.3250398126534635E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,   6.3250398126534635E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,  -6.3250398126534635E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,   6.3250398126534635E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,  -6.3250398126534635E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,  -6.3250398126534635E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,   6.3250398126534635E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,  -6.3250398126534635E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,   3.2674584511132859E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,   3.2674584511132859E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,  -3.2674584511132859E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,   3.2674584511132859E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,  -3.2674584511132859E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   7.0226481215134939E-01,  -3.2674584511132859E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,   3.2674584511132859E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -7.0226481215134939E-01,  -3.2674584511132859E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,   7.0226481215134939E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,   7.0226481215134939E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,  -7.0226481215134939E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,   7.0226481215134939E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,  -7.0226481215134939E-01,   3.2674584511132859E-01,   3.1938683947913740E-03],
            [   6.3250398126534635E-01,  -7.0226481215134939E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,   7.0226481215134939E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [  -6.3250398126534635E-01,  -7.0226481215134939E-01,  -3.2674584511132859E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,   7.0226481215134939E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,   7.0226481215134939E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,  -7.0226481215134939E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,   7.0226481215134939E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,  -7.0226481215134939E-01,   6.3250398126534635E-01,   3.1938683947913740E-03],
            [   3.2674584511132859E-01,  -7.0226481215134939E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,   7.0226481215134939E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [  -3.2674584511132859E-01,  -7.0226481215134939E-01,  -6.3250398126534635E-01,   3.1938683947913740E-03],
            [   3.9819867084234067E-01,   3.1832914587498207E-02,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,   3.1832914587498207E-02,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,  -3.1832914587498207E-02,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,   3.1832914587498207E-02,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,  -3.1832914587498207E-02,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,  -3.1832914587498207E-02,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,   3.1832914587498207E-02,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,  -3.1832914587498207E-02,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,   3.9819867084234067E-01,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,   3.9819867084234067E-01,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,  -3.9819867084234067E-01,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,   3.9819867084234067E-01,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,  -3.9819867084234067E-01,   9.1674668479807353E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,  -3.9819867084234067E-01,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,   3.9819867084234067E-01,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,  -3.9819867084234067E-01,  -9.1674668479807353E-01,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,   3.9819867084234067E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,   3.9819867084234067E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,  -3.9819867084234067E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,   3.9819867084234067E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,  -3.9819867084234067E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,  -3.9819867084234067E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,   3.9819867084234067E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,  -3.9819867084234067E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,   3.1832914587498207E-02,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,   3.1832914587498207E-02,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,  -3.1832914587498207E-02,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,   3.1832914587498207E-02,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,  -3.1832914587498207E-02,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   9.1674668479807353E-01,  -3.1832914587498207E-02,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,   3.1832914587498207E-02,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -9.1674668479807353E-01,  -3.1832914587498207E-02,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,   9.1674668479807353E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,   9.1674668479807353E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,  -9.1674668479807353E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,   9.1674668479807353E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,  -9.1674668479807353E-01,   3.1832914587498207E-02,   2.9121068197358979E-03],
            [   3.9819867084234067E-01,  -9.1674668479807353E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,   9.1674668479807353E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [  -3.9819867084234067E-01,  -9.1674668479807353E-01,  -3.1832914587498207E-02,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,   9.1674668479807353E-01,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,   9.1674668479807353E-01,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,  -9.1674668479807353E-01,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,   9.1674668479807353E-01,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,  -9.1674668479807353E-01,   3.9819867084234067E-01,   2.9121068197358979E-03],
            [   3.1832914587498207E-02,  -9.1674668479807353E-01,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,   9.1674668479807353E-01,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [  -3.1832914587498207E-02,  -9.1674668479807353E-01,  -3.9819867084234067E-01,   2.9121068197358979E-03],
            [   4.3827911821332999E-01,   6.4595481938809082E-02,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,   6.4595481938809082E-02,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,  -6.4595481938809082E-02,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,   6.4595481938809082E-02,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,  -6.4595481938809082E-02,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,  -6.4595481938809082E-02,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,   6.4595481938809082E-02,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,  -6.4595481938809082E-02,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,   4.3827911821332999E-01,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,   4.3827911821332999E-01,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,  -4.3827911821332999E-01,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,   4.3827911821332999E-01,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,  -4.3827911821332999E-01,   8.9651482879606559E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,  -4.3827911821332999E-01,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,   4.3827911821332999E-01,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,  -4.3827911821332999E-01,  -8.9651482879606559E-01,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,   4.3827911821332999E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,   4.3827911821332999E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,  -4.3827911821332999E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,   4.3827911821332999E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,  -4.3827911821332999E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,  -4.3827911821332999E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,   4.3827911821332999E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,  -4.3827911821332999E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,   6.4595481938809082E-02,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,   6.4595481938809082E-02,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,  -6.4595481938809082E-02,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,   6.4595481938809082E-02,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,  -6.4595481938809082E-02,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   8.9651482879606559E-01,  -6.4595481938809082E-02,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,   6.4595481938809082E-02,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -8.9651482879606559E-01,  -6.4595481938809082E-02,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,   8.9651482879606559E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,   8.9651482879606559E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,  -8.9651482879606559E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,   8.9651482879606559E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,  -8.9651482879606559E-01,   6.4595481938809082E-02,   2.9889750044978631E-03],
            [   4.3827911821332999E-01,  -8.9651482879606559E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,   8.9651482879606559E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [  -4.3827911821332999E-01,  -8.9651482879606559E-01,  -6.4595481938809082E-02,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,   8.9651482879606559E-01,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,   8.9651482879606559E-01,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,  -8.9651482879606559E-01,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,   8.9651482879606559E-01,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,  -8.9651482879606559E-01,   4.3827911821332999E-01,   2.9889750044978631E-03],
            [   6.4595481938809082E-02,  -8.9651482879606559E-01,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,   8.9651482879606559E-01,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [  -6.4595481938809082E-02,  -8.9651482879606559E-01,  -4.3827911821332999E-01,   2.9889750044978631E-03],
            [   4.7692330572181663E-01,   9.7957570370879515E-02,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,   9.7957570370879515E-02,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,  -9.7957570370879515E-02,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,   9.7957570370879515E-02,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,  -9.7957570370879515E-02,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,  -9.7957570370879515E-02,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,   9.7957570370879515E-02,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,  -9.7957570370879515E-02,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,   4.7692330572181663E-01,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,   4.7692330572181663E-01,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,  -4.7692330572181663E-01,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,   4.7692330572181663E-01,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,  -4.7692330572181663E-01,   8.7346921804171707E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,  -4.7692330572181663E-01,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,   4.7692330572181663E-01,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,  -4.7692330572181663E-01,  -8.7346921804171707E-01,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,   4.7692330572181663E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,   4.7692330572181663E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,  -4.7692330572181663E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,   4.7692330572181663E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,  -4.7692330572181663E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,  -4.7692330572181663E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,   4.7692330572181663E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,  -4.7692330572181663E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,   9.7957570370879515E-02,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,   9.7957570370879515E-02,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,  -9.7957570370879515E-02,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,   9.7957570370879515E-02,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,  -9.7957570370879515E-02,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   8.7346921804171707E-01,  -9.7957570370879515E-02,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,   9.7957570370879515E-02,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -8.7346921804171707E-01,  -9.7957570370879515E-02,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,   8.7346921804171707E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,   8.7346921804171707E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,  -8.7346921804171707E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,   8.7346921804171707E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,  -8.7346921804171707E-01,   9.7957570370879515E-02,   3.0522262262840196E-03],
            [   4.7692330572181663E-01,  -8.7346921804171707E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,   8.7346921804171707E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [  -4.7692330572181663E-01,  -8.7346921804171707E-01,  -9.7957570370879515E-02,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,   8.7346921804171707E-01,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,   8.7346921804171707E-01,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,  -8.7346921804171707E-01,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,   8.7346921804171707E-01,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,  -8.7346921804171707E-01,   4.7692330572181663E-01,   3.0522262262840196E-03],
            [   9.7957570370879515E-02,  -8.7346921804171707E-01,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,   8.7346921804171707E-01,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [  -9.7957570370879515E-02,  -8.7346921804171707E-01,  -4.7692330572181663E-01,   3.0522262262840196E-03],
            [   5.1408239111942378E-01,   1.3163072351266550E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,   1.3163072351266550E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,  -1.3163072351266550E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,   1.3163072351266550E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,  -1.3163072351266550E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,  -1.3163072351266550E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,   1.3163072351266550E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,  -1.3163072351266550E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,   5.1408239111942378E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,   5.1408239111942378E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,  -5.1408239111942378E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,   5.1408239111942378E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,  -5.1408239111942378E-01,   8.4758046683985588E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,  -5.1408239111942378E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,   5.1408239111942378E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,  -5.1408239111942378E-01,  -8.4758046683985588E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,   5.1408239111942378E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,   5.1408239111942378E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,  -5.1408239111942378E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,   5.1408239111942378E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,  -5.1408239111942378E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,  -5.1408239111942378E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,   5.1408239111942378E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,  -5.1408239111942378E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,   1.3163072351266550E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,   1.3163072351266550E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,  -1.3163072351266550E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,   1.3163072351266550E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,  -1.3163072351266550E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   8.4758046683985588E-01,  -1.3163072351266550E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,   1.3163072351266550E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -8.4758046683985588E-01,  -1.3163072351266550E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,   8.4758046683985588E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,   8.4758046683985588E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,  -8.4758046683985588E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,   8.4758046683985588E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,  -8.4758046683985588E-01,   1.3163072351266550E-01,   3.1026402420083190E-03],
            [   5.1408239111942378E-01,  -8.4758046683985588E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,   8.4758046683985588E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [  -5.1408239111942378E-01,  -8.4758046683985588E-01,  -1.3163072351266550E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,   8.4758046683985588E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,   8.4758046683985588E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,  -8.4758046683985588E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,   8.4758046683985588E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,  -8.4758046683985588E-01,   5.1408239111942378E-01,   3.1026402420083190E-03],
            [   1.3163072351266550E-01,  -8.4758046683985588E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,   8.4758046683985588E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [  -1.3163072351266550E-01,  -8.4758046683985588E-01,  -5.1408239111942378E-01,   3.1026402420083190E-03],
            [   5.4969778338629827E-01,   1.6535564863587041E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,   1.6535564863587041E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,  -1.6535564863587041E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,   1.6535564863587041E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,  -1.6535564863587041E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,  -1.6535564863587041E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,   1.6535564863587041E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,  -1.6535564863587041E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,   5.4969778338629827E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,   5.4969778338629827E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,  -5.4969778338629827E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,   5.4969778338629827E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,  -5.4969778338629827E-01,   8.1883444993747112E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,  -5.4969778338629827E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,   5.4969778338629827E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,  -5.4969778338629827E-01,  -8.1883444993747112E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,   5.4969778338629827E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,   5.4969778338629827E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,  -5.4969778338629827E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,   5.4969778338629827E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,  -5.4969778338629827E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,  -5.4969778338629827E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,   5.4969778338629827E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,  -5.4969778338629827E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,   1.6535564863587041E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,   1.6535564863587041E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,  -1.6535564863587041E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,   1.6535564863587041E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,  -1.6535564863587041E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   8.1883444993747112E-01,  -1.6535564863587041E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,   1.6535564863587041E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -8.1883444993747112E-01,  -1.6535564863587041E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,   8.1883444993747112E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,   8.1883444993747112E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,  -8.1883444993747112E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,   8.1883444993747112E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,  -8.1883444993747112E-01,   1.6535564863587041E-01,   3.1411623487214721E-03],
            [   5.4969778338629827E-01,  -8.1883444993747112E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,   8.1883444993747112E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [  -5.4969778338629827E-01,  -8.1883444993747112E-01,  -1.6535564863587041E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,   8.1883444993747112E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,   8.1883444993747112E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,  -8.1883444993747112E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,   8.1883444993747112E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,  -8.1883444993747112E-01,   5.4969778338629827E-01,   3.1411623487214721E-03],
            [   1.6535564863587041E-01,  -8.1883444993747112E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,   8.1883444993747112E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [  -1.6535564863587041E-01,  -8.1883444993747112E-01,  -5.4969778338629827E-01,   3.1411623487214721E-03],
            [   5.8370473065127271E-01,   1.9889317241265100E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,   1.9889317241265100E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,  -1.9889317241265100E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,   1.9889317241265100E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,  -1.9889317241265100E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,  -1.9889317241265100E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,   1.9889317241265100E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,  -1.9889317241265100E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,   5.8370473065127271E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,   5.8370473065127271E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,  -5.8370473065127271E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,   5.8370473065127271E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,  -5.8370473065127271E-01,   7.8722950489863930E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,  -5.8370473065127271E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,   5.8370473065127271E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,  -5.8370473065127271E-01,  -7.8722950489863930E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,   5.8370473065127271E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,   5.8370473065127271E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,  -5.8370473065127271E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,   5.8370473065127271E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,  -5.8370473065127271E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,  -5.8370473065127271E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,   5.8370473065127271E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,  -5.8370473065127271E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,   1.9889317241265100E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,   1.9889317241265100E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,  -1.9889317241265100E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,   1.9889317241265100E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,  -1.9889317241265100E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   7.8722950489863930E-01,  -1.9889317241265100E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,   1.9889317241265100E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -7.8722950489863930E-01,  -1.9889317241265100E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,   7.8722950489863930E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,   7.8722950489863930E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,  -7.8722950489863930E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,   7.8722950489863930E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,  -7.8722950489863930E-01,   1.9889317241265100E-01,   3.1688317302593330E-03],
            [   5.8370473065127271E-01,  -7.8722950489863930E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,   7.8722950489863930E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [  -5.8370473065127271E-01,  -7.8722950489863930E-01,  -1.9889317241265100E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,   7.8722950489863930E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,   7.8722950489863930E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,  -7.8722950489863930E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,   7.8722950489863930E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,  -7.8722950489863930E-01,   5.8370473065127271E-01,   3.1688317302593330E-03],
            [   1.9889317241265100E-01,  -7.8722950489863930E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,   7.8722950489863930E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [  -1.9889317241265100E-01,  -7.8722950489863930E-01,  -5.8370473065127271E-01,   3.1688317302593330E-03],
            [   6.1603495669268793E-01,   2.3201745814389499E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,   2.3201745814389499E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,  -2.3201745814389499E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,   2.3201745814389499E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,  -2.3201745814389499E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,  -2.3201745814389499E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,   2.3201745814389499E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,  -2.3201745814389499E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,   6.1603495669268793E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,   6.1603495669268793E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,  -6.1603495669268793E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,   6.1603495669268793E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,  -6.1603495669268793E-01,   7.5277409044751542E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,  -6.1603495669268793E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,   6.1603495669268793E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,  -6.1603495669268793E-01,  -7.5277409044751542E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,   6.1603495669268793E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,   6.1603495669268793E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,  -6.1603495669268793E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,   6.1603495669268793E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,  -6.1603495669268793E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,  -6.1603495669268793E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,   6.1603495669268793E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,  -6.1603495669268793E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,   2.3201745814389499E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,   2.3201745814389499E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,  -2.3201745814389499E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,   2.3201745814389499E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,  -2.3201745814389499E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   7.5277409044751542E-01,  -2.3201745814389499E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,   2.3201745814389499E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -7.5277409044751542E-01,  -2.3201745814389499E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,   7.5277409044751542E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,   7.5277409044751542E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,  -7.5277409044751542E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,   7.5277409044751542E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,  -7.5277409044751542E-01,   2.3201745814389499E-01,   3.1867507390971779E-03],
            [   6.1603495669268793E-01,  -7.5277409044751542E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,   7.5277409044751542E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [  -6.1603495669268793E-01,  -7.5277409044751542E-01,  -2.3201745814389499E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,   7.5277409044751542E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,   7.5277409044751542E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,  -7.5277409044751542E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,   7.5277409044751542E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,  -7.5277409044751542E-01,   6.1603495669268793E-01,   3.1867507390971779E-03],
            [   2.3201745814389499E-01,  -7.5277409044751542E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,   7.5277409044751542E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [  -2.3201745814389499E-01,  -7.5277409044751542E-01,  -6.1603495669268793E-01,   3.1867507390971779E-03],
            [   6.4661853532094404E-01,   2.6451065621686620E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,   2.6451065621686620E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,  -2.6451065621686620E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,   2.6451065621686620E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,  -2.6451065621686620E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,  -2.6451065621686620E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,   2.6451065621686620E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,  -2.6451065621686620E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,   6.4661853532094404E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,   6.4661853532094404E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,  -6.4661853532094404E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,   6.4661853532094404E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,  -6.4661853532094404E-01,   7.1548485834930142E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,  -6.4661853532094404E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,   6.4661853532094404E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,  -6.4661853532094404E-01,  -7.1548485834930142E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,   6.4661853532094404E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,   6.4661853532094404E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,  -6.4661853532094404E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,   6.4661853532094404E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,  -6.4661853532094404E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,  -6.4661853532094404E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,   6.4661853532094404E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,  -6.4661853532094404E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,   2.6451065621686620E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,   2.6451065621686620E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,  -2.6451065621686620E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,   2.6451065621686620E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,  -2.6451065621686620E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   7.1548485834930142E-01,  -2.6451065621686620E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,   2.6451065621686620E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -7.1548485834930142E-01,  -2.6451065621686620E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,   7.1548485834930142E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,   7.1548485834930142E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,  -7.1548485834930142E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,   7.1548485834930142E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,  -7.1548485834930142E-01,   2.6451065621686620E-01,   3.1960763441631732E-03],
            [   6.4661853532094404E-01,  -7.1548485834930142E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,   7.1548485834930142E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [  -6.4661853532094404E-01,  -7.1548485834930142E-01,  -2.6451065621686620E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,   7.1548485834930142E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,   7.1548485834930142E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,  -7.1548485834930142E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,   7.1548485834930142E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,  -7.1548485834930142E-01,   6.4661853532094404E-01,   3.1960763441631732E-03],
            [   2.6451065621686620E-01,  -7.1548485834930142E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,   7.1548485834930142E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [  -2.6451065621686620E-01,  -7.1548485834930142E-01,  -6.4661853532094404E-01,   3.1960763441631732E-03],
            [   4.8108351587954040E-01,   3.2759178077439922E-02,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,   3.2759178077439922E-02,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,  -3.2759178077439922E-02,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,   3.2759178077439922E-02,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,  -3.2759178077439922E-02,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,  -3.2759178077439922E-02,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,   3.2759178077439922E-02,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,  -3.2759178077439922E-02,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,   4.8108351587954040E-01,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,   4.8108351587954040E-01,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,  -4.8108351587954040E-01,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,   4.8108351587954040E-01,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,  -4.8108351587954040E-01,   8.7606249035138495E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,  -4.8108351587954040E-01,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,   4.8108351587954040E-01,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,  -4.8108351587954040E-01,  -8.7606249035138495E-01,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,   4.8108351587954040E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,   4.8108351587954040E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,  -4.8108351587954040E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,   4.8108351587954040E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,  -4.8108351587954040E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,  -4.8108351587954040E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,   4.8108351587954040E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,  -4.8108351587954040E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,   3.2759178077439922E-02,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,   3.2759178077439922E-02,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,  -3.2759178077439922E-02,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,   3.2759178077439922E-02,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,  -3.2759178077439922E-02,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   8.7606249035138495E-01,  -3.2759178077439922E-02,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,   3.2759178077439922E-02,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -8.7606249035138495E-01,  -3.2759178077439922E-02,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,   8.7606249035138495E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,   8.7606249035138495E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,  -8.7606249035138495E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,   8.7606249035138495E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,  -8.7606249035138495E-01,   3.2759178077439922E-02,   3.0503020993824766E-03],
            [   4.8108351587954040E-01,  -8.7606249035138495E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,   8.7606249035138495E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [  -4.8108351587954040E-01,  -8.7606249035138495E-01,  -3.2759178077439922E-02,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,   8.7606249035138495E-01,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,   8.7606249035138495E-01,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,  -8.7606249035138495E-01,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,   8.7606249035138495E-01,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,  -8.7606249035138495E-01,   4.8108351587954040E-01,   3.0503020993824766E-03],
            [   3.2759178077439922E-02,  -8.7606249035138495E-01,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,   8.7606249035138495E-01,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [  -3.2759178077439922E-02,  -8.7606249035138495E-01,  -4.8108351587954040E-01,   3.0503020993824766E-03],
            [   5.1999250413243414E-01,   6.6125461839671815E-02,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,   6.6125461839671815E-02,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,  -6.6125461839671815E-02,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,   6.6125461839671815E-02,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,  -6.6125461839671815E-02,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,  -6.6125461839671815E-02,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,   6.6125461839671815E-02,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,  -6.6125461839671815E-02,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,   5.1999250413243414E-01,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,   5.1999250413243414E-01,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,  -5.1999250413243414E-01,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,   5.1999250413243414E-01,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,  -5.1999250413243414E-01,   8.5160743241388548E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,  -5.1999250413243414E-01,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,   5.1999250413243414E-01,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,  -5.1999250413243414E-01,  -8.5160743241388548E-01,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,   5.1999250413243414E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,   5.1999250413243414E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,  -5.1999250413243414E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,   5.1999250413243414E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,  -5.1999250413243414E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,  -5.1999250413243414E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,   5.1999250413243414E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,  -5.1999250413243414E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,   6.6125461839671815E-02,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,   6.6125461839671815E-02,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,  -6.6125461839671815E-02,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,   6.6125461839671815E-02,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,  -6.6125461839671815E-02,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   8.5160743241388548E-01,  -6.6125461839671815E-02,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,   6.6125461839671815E-02,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -8.5160743241388548E-01,  -6.6125461839671815E-02,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,   8.5160743241388548E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,   8.5160743241388548E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,  -8.5160743241388548E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,   8.5160743241388548E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,  -8.5160743241388548E-01,   6.6125461839671815E-02,   3.1017045299299630E-03],
            [   5.1999250413243414E-01,  -8.5160743241388548E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,   8.5160743241388548E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [  -5.1999250413243414E-01,  -8.5160743241388548E-01,  -6.6125461839671815E-02,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,   8.5160743241388548E-01,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,   8.5160743241388548E-01,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,  -8.5160743241388548E-01,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,   8.5160743241388548E-01,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,  -8.5160743241388548E-01,   5.1999250413243414E-01,   3.1017045299299630E-03],
            [   6.6125461839671815E-02,  -8.5160743241388548E-01,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,   8.5160743241388548E-01,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [  -6.6125461839671815E-02,  -8.5160743241388548E-01,  -5.1999250413243414E-01,   3.1017045299299630E-03],
            [   5.5717176922074940E-01,   9.9814983314741423E-02,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,   9.9814983314741423E-02,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,  -9.9814983314741423E-02,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,   9.9814983314741423E-02,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,  -9.9814983314741423E-02,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,  -9.9814983314741423E-02,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,   9.9814983314741423E-02,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,  -9.9814983314741423E-02,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,   5.5717176922074940E-01,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,   5.5717176922074940E-01,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,  -5.5717176922074940E-01,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,   5.5717176922074940E-01,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,  -5.5717176922074940E-01,   8.2437648479884351E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,  -5.5717176922074940E-01,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,   5.5717176922074940E-01,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,  -5.5717176922074940E-01,  -8.2437648479884351E-01,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,   5.5717176922074940E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,   5.5717176922074940E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,  -5.5717176922074940E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,   5.5717176922074940E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,  -5.5717176922074940E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,  -5.5717176922074940E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,   5.5717176922074940E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,  -5.5717176922074940E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,   9.9814983314741423E-02,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,   9.9814983314741423E-02,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,  -9.9814983314741423E-02,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,   9.9814983314741423E-02,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,  -9.9814983314741423E-02,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   8.2437648479884351E-01,  -9.9814983314741423E-02,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,   9.9814983314741423E-02,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -8.2437648479884351E-01,  -9.9814983314741423E-02,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,   8.2437648479884351E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,   8.2437648479884351E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,  -8.2437648479884351E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,   8.2437648479884351E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,  -8.2437648479884351E-01,   9.9814983314741423E-02,   3.1416692537118199E-03],
            [   5.5717176922074940E-01,  -8.2437648479884351E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,   8.2437648479884351E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [  -5.5717176922074940E-01,  -8.2437648479884351E-01,  -9.9814983314741423E-02,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,   8.2437648479884351E-01,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,   8.2437648479884351E-01,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,  -8.2437648479884351E-01,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,   8.2437648479884351E-01,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,  -8.2437648479884351E-01,   5.5717176922074940E-01,   3.1416692537118199E-03],
            [   9.9814983314741423E-02,  -8.2437648479884351E-01,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,   8.2437648479884351E-01,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [  -9.9814983314741423E-02,  -8.2437648479884351E-01,  -5.5717176922074940E-01,   3.1416692537118199E-03],
            [   5.9257892508363785E-01,   1.3356870014103739E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,   1.3356870014103739E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,  -1.3356870014103739E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,   1.3356870014103739E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,  -1.3356870014103739E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,  -1.3356870014103739E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,   1.3356870014103739E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,  -1.3356870014103739E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,   5.9257892508363785E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,   5.9257892508363785E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,  -5.9257892508363785E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,   5.9257892508363785E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,  -5.9257892508363785E-01,   7.9436113946325071E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,  -5.9257892508363785E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,   5.9257892508363785E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,  -5.9257892508363785E-01,  -7.9436113946325071E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,   5.9257892508363785E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,   5.9257892508363785E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,  -5.9257892508363785E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,   5.9257892508363785E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,  -5.9257892508363785E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,  -5.9257892508363785E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,   5.9257892508363785E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,  -5.9257892508363785E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,   1.3356870014103739E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,   1.3356870014103739E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,  -1.3356870014103739E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,   1.3356870014103739E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,  -1.3356870014103739E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   7.9436113946325071E-01,  -1.3356870014103739E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,   1.3356870014103739E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -7.9436113946325071E-01,  -1.3356870014103739E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,   7.9436113946325071E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,   7.9436113946325071E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,  -7.9436113946325071E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,   7.9436113946325071E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,  -7.9436113946325071E-01,   1.3356870014103739E-01,   3.1707948448249862E-03],
            [   5.9257892508363785E-01,  -7.9436113946325071E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,   7.9436113946325071E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [  -5.9257892508363785E-01,  -7.9436113946325071E-01,  -1.3356870014103739E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,   7.9436113946325071E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,   7.9436113946325071E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,  -7.9436113946325071E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,   7.9436113946325071E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,  -7.9436113946325071E-01,   5.9257892508363785E-01,   3.1707948448249862E-03],
            [   1.3356870014103739E-01,  -7.9436113946325071E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,   7.9436113946325071E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [  -1.3356870014103739E-01,  -7.9436113946325071E-01,  -5.9257892508363785E-01,   3.1707948448249862E-03],
            [   6.2616585238596700E-01,   1.6714444028964631E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,   1.6714444028964631E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,  -1.6714444028964631E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,   1.6714444028964631E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,  -1.6714444028964631E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,  -1.6714444028964631E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,   1.6714444028964631E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,  -1.6714444028964631E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,   6.2616585238596700E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,   6.2616585238596700E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,  -6.2616585238596700E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,   6.2616585238596700E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,  -6.2616585238596700E-01,   7.6156356358876320E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,  -6.2616585238596700E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,   6.2616585238596700E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,  -6.2616585238596700E-01,  -7.6156356358876320E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,   6.2616585238596700E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,   6.2616585238596700E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,  -6.2616585238596700E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,   6.2616585238596700E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,  -6.2616585238596700E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,  -6.2616585238596700E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,   6.2616585238596700E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,  -6.2616585238596700E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,   1.6714444028964631E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,   1.6714444028964631E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,  -1.6714444028964631E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,   1.6714444028964631E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,  -1.6714444028964631E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   7.6156356358876320E-01,  -1.6714444028964631E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,   1.6714444028964631E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -7.6156356358876320E-01,  -1.6714444028964631E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,   7.6156356358876320E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,   7.6156356358876320E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,  -7.6156356358876320E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,   7.6156356358876320E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,  -7.6156356358876320E-01,   1.6714444028964631E-01,   3.1898465871552429E-03],
            [   6.2616585238596700E-01,  -7.6156356358876320E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,   7.6156356358876320E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [  -6.2616585238596700E-01,  -7.6156356358876320E-01,  -1.6714444028964631E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,   7.6156356358876320E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,   7.6156356358876320E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,  -7.6156356358876320E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,   7.6156356358876320E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,  -7.6156356358876320E-01,   6.2616585238596700E-01,   3.1898465871552429E-03],
            [   1.6714444028964631E-01,  -7.6156356358876320E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,   7.6156356358876320E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [  -1.6714444028964631E-01,  -7.6156356358876320E-01,  -6.2616585238596700E-01,   3.1898465871552429E-03],
            [   6.5788111266693305E-01,   2.0031063821560760E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,   2.0031063821560760E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,  -2.0031063821560760E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,   2.0031063821560760E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,  -2.0031063821560760E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,  -2.0031063821560760E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,   2.0031063821560760E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,  -2.0031063821560760E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,   6.5788111266693305E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,   6.5788111266693305E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,  -6.5788111266693305E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,   6.5788111266693305E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,  -6.5788111266693305E-01,   7.2599455219290321E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,  -6.5788111266693305E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,   6.5788111266693305E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,  -6.5788111266693305E-01,  -7.2599455219290321E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,   6.5788111266693305E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,   6.5788111266693305E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,  -6.5788111266693305E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,   6.5788111266693305E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,  -6.5788111266693305E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,  -6.5788111266693305E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,   6.5788111266693305E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,  -6.5788111266693305E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,   2.0031063821560760E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,   2.0031063821560760E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,  -2.0031063821560760E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,   2.0031063821560760E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,  -2.0031063821560760E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   7.2599455219290321E-01,  -2.0031063821560760E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,   2.0031063821560760E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -7.2599455219290321E-01,  -2.0031063821560760E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,   7.2599455219290321E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,   7.2599455219290321E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,  -7.2599455219290321E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,   7.2599455219290321E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,  -7.2599455219290321E-01,   2.0031063821560760E-01,   3.1997195661059327E-03],
            [   6.5788111266693305E-01,  -7.2599455219290321E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,   7.2599455219290321E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [  -6.5788111266693305E-01,  -7.2599455219290321E-01,  -2.0031063821560760E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,   7.2599455219290321E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,   7.2599455219290321E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,  -7.2599455219290321E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,   7.2599455219290321E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,  -7.2599455219290321E-01,   6.5788111266693305E-01,   3.1997195661059327E-03],
            [   2.0031063821560760E-01,  -7.2599455219290321E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,   7.2599455219290321E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [  -2.0031063821560760E-01,  -7.2599455219290321E-01,  -6.5788111266693305E-01,   3.1997195661059327E-03],
            [   5.6096246129980998E-01,   3.3375009402313353E-02,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,   3.3375009402313353E-02,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,  -3.3375009402313353E-02,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,   3.3375009402313353E-02,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,  -3.3375009402313353E-02,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,  -3.3375009402313353E-02,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,   3.3375009402313353E-02,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,  -3.3375009402313353E-02,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,   5.6096246129980998E-01,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,   5.6096246129980998E-01,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,  -5.6096246129980998E-01,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,   5.6096246129980998E-01,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,  -5.6096246129980998E-01,   8.2716819677732689E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,  -5.6096246129980998E-01,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,   5.6096246129980998E-01,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,  -5.6096246129980998E-01,  -8.2716819677732689E-01,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,   5.6096246129980998E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,   5.6096246129980998E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,  -5.6096246129980998E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,   5.6096246129980998E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,  -5.6096246129980998E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,  -5.6096246129980998E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,   5.6096246129980998E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,  -5.6096246129980998E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,   3.3375009402313353E-02,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,   3.3375009402313353E-02,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,  -3.3375009402313353E-02,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,   3.3375009402313353E-02,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,  -3.3375009402313353E-02,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   8.2716819677732689E-01,  -3.3375009402313353E-02,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,   3.3375009402313353E-02,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -8.2716819677732689E-01,  -3.3375009402313353E-02,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,   8.2716819677732689E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,   8.2716819677732689E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,  -8.2716819677732689E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,   8.2716819677732689E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,  -8.2716819677732689E-01,   3.3375009402313353E-02,   3.1423257254468350E-03],
            [   5.6096246129980998E-01,  -8.2716819677732689E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,   8.2716819677732689E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [  -5.6096246129980998E-01,  -8.2716819677732689E-01,  -3.3375009402313353E-02,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,   8.2716819677732689E-01,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,   8.2716819677732689E-01,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,  -8.2716819677732689E-01,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,   8.2716819677732689E-01,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,  -8.2716819677732689E-01,   5.6096246129980998E-01,   3.1423257254468350E-03],
            [   3.3375009402313353E-02,  -8.2716819677732689E-01,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,   8.2716819677732689E-01,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [  -3.3375009402313353E-02,  -8.2716819677732689E-01,  -5.6096246129980998E-01,   3.1423257254468350E-03],
            [   5.9799596599846705E-01,   6.7087503359018030E-02,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,   6.7087503359018030E-02,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,  -6.7087503359018030E-02,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,   6.7087503359018030E-02,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,  -6.7087503359018030E-02,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,  -6.7087503359018030E-02,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,   6.7087503359018030E-02,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,  -6.7087503359018030E-02,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,   5.9799596599846705E-01,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,   5.9799596599846705E-01,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,  -5.9799596599846705E-01,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,   5.9799596599846705E-01,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,  -5.9799596599846705E-01,   7.9868647887804767E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,  -5.9799596599846705E-01,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,   5.9799596599846705E-01,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,  -5.9799596599846705E-01,  -7.9868647887804767E-01,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,   5.9799596599846705E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,   5.9799596599846705E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,  -5.9799596599846705E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,   5.9799596599846705E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,  -5.9799596599846705E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,  -5.9799596599846705E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,   5.9799596599846705E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,  -5.9799596599846705E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,   6.7087503359018030E-02,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,   6.7087503359018030E-02,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,  -6.7087503359018030E-02,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,   6.7087503359018030E-02,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,  -6.7087503359018030E-02,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   7.9868647887804767E-01,  -6.7087503359018030E-02,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,   6.7087503359018030E-02,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -7.9868647887804767E-01,  -6.7087503359018030E-02,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,   7.9868647887804767E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,   7.9868647887804767E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,  -7.9868647887804767E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,   7.9868647887804767E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,  -7.9868647887804767E-01,   6.7087503359018030E-02,   3.1727291521224171E-03],
            [   5.9799596599846705E-01,  -7.9868647887804767E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,   7.9868647887804767E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [  -5.9799596599846705E-01,  -7.9868647887804767E-01,  -6.7087503359018030E-02,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,   7.9868647887804767E-01,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,   7.9868647887804767E-01,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,  -7.9868647887804767E-01,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,   7.9868647887804767E-01,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,  -7.9868647887804767E-01,   5.9799596599846705E-01,   3.1727291521224171E-03],
            [   6.7087503359018030E-02,  -7.9868647887804767E-01,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,   7.9868647887804767E-01,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [  -6.7087503359018030E-02,  -7.9868647887804767E-01,  -5.9799596599846705E-01,   3.1727291521224171E-03],
            [   6.3305237110540025E-01,   1.0087921264248501E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,   1.0087921264248501E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,  -1.0087921264248501E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,   1.0087921264248501E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,  -1.0087921264248501E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,  -1.0087921264248501E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,   1.0087921264248501E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,  -1.0087921264248501E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,   6.3305237110540025E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,   6.3305237110540025E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,  -6.3305237110540025E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,   6.3305237110540025E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,  -6.3305237110540025E-01,   7.6750770673294411E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,  -6.3305237110540025E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,   6.3305237110540025E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,  -6.3305237110540025E-01,  -7.6750770673294411E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,   6.3305237110540025E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,   6.3305237110540025E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,  -6.3305237110540025E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,   6.3305237110540025E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,  -6.3305237110540025E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,  -6.3305237110540025E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,   6.3305237110540025E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,  -6.3305237110540025E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,   1.0087921264248501E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,   1.0087921264248501E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,  -1.0087921264248501E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,   1.0087921264248501E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,  -1.0087921264248501E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   7.6750770673294411E-01,  -1.0087921264248501E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,   1.0087921264248501E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -7.6750770673294411E-01,  -1.0087921264248501E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,   7.6750770673294411E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,   7.6750770673294411E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,  -7.6750770673294411E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,   7.6750770673294411E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,  -7.6750770673294411E-01,   1.0087921264248501E-01,   3.1930534415051406E-03],
            [   6.3305237110540025E-01,  -7.6750770673294411E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,   7.6750770673294411E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [  -6.3305237110540025E-01,  -7.6750770673294411E-01,  -1.0087921264248501E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,   7.6750770673294411E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,   7.6750770673294411E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,  -7.6750770673294411E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,   7.6750770673294411E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,  -7.6750770673294411E-01,   6.3305237110540025E-01,   3.1930534415051406E-03],
            [   1.0087921264248501E-01,  -7.6750770673294411E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,   7.6750770673294411E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [  -1.0087921264248501E-01,  -7.6750770673294411E-01,  -6.3305237110540025E-01,   3.1930534415051406E-03],
            [   6.6609609981039719E-01,   1.3450503431717939E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,   1.3450503431717939E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,  -1.3450503431717939E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,   1.3450503431717939E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,  -1.3450503431717939E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,  -1.3450503431717939E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,   1.3450503431717939E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,  -1.3450503431717939E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,   6.6609609981039719E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,   6.6609609981039719E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,  -6.6609609981039719E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,   6.6609609981039719E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,  -6.6609609981039719E-01,   7.3363777271942032E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,  -6.6609609981039719E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,   6.6609609981039719E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,  -6.6609609981039719E-01,  -7.3363777271942032E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,   6.6609609981039719E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,   6.6609609981039719E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,  -6.6609609981039719E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,   6.6609609981039719E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,  -6.6609609981039719E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,  -6.6609609981039719E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,   6.6609609981039719E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,  -6.6609609981039719E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,   1.3450503431717939E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,   1.3450503431717939E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,  -1.3450503431717939E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,   1.3450503431717939E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,  -1.3450503431717939E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   7.3363777271942032E-01,  -1.3450503431717939E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,   1.3450503431717939E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -7.3363777271942032E-01,  -1.3450503431717939E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,   7.3363777271942032E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,   7.3363777271942032E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,  -7.3363777271942032E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,   7.3363777271942032E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,  -7.3363777271942032E-01,   1.3450503431717939E-01,   3.2038264542690181E-03],
            [   6.6609609981039719E-01,  -7.3363777271942032E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,   7.3363777271942032E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [  -6.6609609981039719E-01,  -7.3363777271942032E-01,  -1.3450503431717939E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,   7.3363777271942032E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,   7.3363777271942032E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,  -7.3363777271942032E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,   7.3363777271942032E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,  -7.3363777271942032E-01,   6.6609609981039719E-01,   3.2038264542690181E-03],
            [   1.3450503431717939E-01,  -7.3363777271942032E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,   7.3363777271942032E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [  -1.3450503431717939E-01,  -7.3363777271942032E-01,  -6.6609609981039719E-01,   3.2038264542690181E-03],
            [   6.3653843645858188E-01,   3.3727994607370519E-02,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,   3.3727994607370519E-02,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,  -3.3727994607370519E-02,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,   3.3727994607370519E-02,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,  -3.3727994607370519E-02,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,  -3.3727994607370519E-02,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,   3.3727994607370519E-02,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,  -3.3727994607370519E-02,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,   6.3653843645858188E-01,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,   6.3653843645858188E-01,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,  -6.3653843645858188E-01,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,   6.3653843645858188E-01,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,  -6.3653843645858188E-01,   7.7050713253715508E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,  -6.3653843645858188E-01,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,   6.3653843645858188E-01,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,  -6.3653843645858188E-01,  -7.7050713253715508E-01,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,   6.3653843645858188E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,   6.3653843645858188E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,  -6.3653843645858188E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,   6.3653843645858188E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,  -6.3653843645858188E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,  -6.3653843645858188E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,   6.3653843645858188E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,  -6.3653843645858188E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,   3.3727994607370519E-02,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,   3.3727994607370519E-02,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,  -3.3727994607370519E-02,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,   3.3727994607370519E-02,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,  -3.3727994607370519E-02,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   7.7050713253715508E-01,  -3.3727994607370519E-02,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,   3.3727994607370519E-02,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -7.7050713253715508E-01,  -3.3727994607370519E-02,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,   7.7050713253715508E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,   7.7050713253715508E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,  -7.7050713253715508E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,   7.7050713253715508E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,  -7.7050713253715508E-01,   3.3727994607370519E-02,   3.1950870737845571E-03],
            [   6.3653843645858188E-01,  -7.7050713253715508E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,   7.7050713253715508E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [  -6.3653843645858188E-01,  -7.7050713253715508E-01,  -3.3727994607370519E-02,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,   7.7050713253715508E-01,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,   7.7050713253715508E-01,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,  -7.7050713253715508E-01,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,   7.7050713253715508E-01,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,  -7.7050713253715508E-01,   6.3653843645858188E-01,   3.1950870737845571E-03],
            [   3.3727994607370519E-02,  -7.7050713253715508E-01,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,   7.7050713253715508E-01,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [  -3.3727994607370519E-02,  -7.7050713253715508E-01,  -6.3653843645858188E-01,   3.1950870737845571E-03],
            [   6.7109943028992747E-01,   6.7552493096780283E-02,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,   6.7552493096780283E-02,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,  -6.7552493096780283E-02,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,   6.7552493096780283E-02,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,  -6.7552493096780283E-02,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,  -6.7552493096780283E-02,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,   6.7552493096780283E-02,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,  -6.7552493096780283E-02,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,   6.7109943028992747E-01,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,   6.7109943028992747E-01,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,  -6.7109943028992747E-01,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,   6.7109943028992747E-01,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,  -6.7109943028992747E-01,   7.3828328935507148E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,  -6.7109943028992747E-01,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,   6.7109943028992747E-01,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,  -6.7109943028992747E-01,  -7.3828328935507148E-01,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,   6.7109943028992747E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,   6.7109943028992747E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,  -6.7109943028992747E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,   6.7109943028992747E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,  -6.7109943028992747E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,  -6.7109943028992747E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,   6.7109943028992747E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,  -6.7109943028992747E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,   6.7552493096780283E-02,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,   6.7552493096780283E-02,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,  -6.7552493096780283E-02,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,   6.7552493096780283E-02,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,  -6.7552493096780283E-02,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   7.3828328935507148E-01,  -6.7552493096780283E-02,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,   6.7552493096780283E-02,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -7.3828328935507148E-01,  -6.7552493096780283E-02,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,   7.3828328935507148E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,   7.3828328935507148E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,  -7.3828328935507148E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,   7.3828328935507148E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,  -7.3828328935507148E-01,   6.7552493096780283E-02,   3.2070811977316931E-03],
            [   6.7109943028992747E-01,  -7.3828328935507148E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,   7.3828328935507148E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [  -6.7109943028992747E-01,  -7.3828328935507148E-01,  -6.7552493096780283E-02,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,   7.3828328935507148E-01,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,   7.3828328935507148E-01,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,  -7.3828328935507148E-01,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,   7.3828328935507148E-01,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,  -7.3828328935507148E-01,   6.7109943028992747E-01,   3.2070811977316931E-03],
            [   6.7552493096780283E-02,  -7.3828328935507148E-01,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,   7.3828328935507148E-01,  -6.7109943028992747E-01,   3.2070811977316931E-03],
            [  -6.7552493096780283E-02,  -7.3828328935507148E-01,  -6.7109943028992747E-01,   3.2070811977316931E-03],
        ])
  
        order = 113
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build4802():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.2173699027151388E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.2173699027151388E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.2173699027151388E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.2173699027151388E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.2173699027151388E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.2173699027151388E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   2.9001900293292786E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   2.9001900293292786E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   2.9001900293292786E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   2.9001900293292786E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.9001900293292786E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.9001900293292786E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.9001900293292786E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.9001900293292786E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.9001900293292786E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.9001900293292786E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.9001900293292786E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.9001900293292786E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.8868859588886300E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.8868859588886300E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.8868859588886300E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.8868859588886300E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.8868859588886300E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.8868859588886300E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.8868859588886300E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.8868859588886300E-03],
            [   2.3357286088870641E-02,   2.3357286088870641E-02,   9.9945428828592520E-01,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,   2.3357286088870641E-02,   9.9945428828592520E-01,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,  -2.3357286088870641E-02,   9.9945428828592520E-01,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,   2.3357286088870641E-02,  -9.9945428828592520E-01,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,  -2.3357286088870641E-02,   9.9945428828592520E-01,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,   2.3357286088870641E-02,  -9.9945428828592520E-01,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,  -2.3357286088870641E-02,  -9.9945428828592520E-01,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,  -2.3357286088870641E-02,  -9.9945428828592520E-01,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,   9.9945428828592520E-01,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,  -9.9945428828592520E-01,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,   9.9945428828592520E-01,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,  -9.9945428828592520E-01,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,   9.9945428828592520E-01,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,  -9.9945428828592520E-01,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -2.3357286088870641E-02,  -9.9945428828592520E-01,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [   2.3357286088870641E-02,   9.9945428828592520E-01,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [   9.9945428828592520E-01,   2.3357286088870641E-02,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -9.9945428828592520E-01,   2.3357286088870641E-02,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [   9.9945428828592520E-01,  -2.3357286088870641E-02,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [   9.9945428828592520E-01,   2.3357286088870641E-02,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -9.9945428828592520E-01,  -2.3357286088870641E-02,   2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -9.9945428828592520E-01,   2.3357286088870641E-02,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [   9.9945428828592520E-01,  -2.3357286088870641E-02,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [  -9.9945428828592520E-01,  -2.3357286088870641E-02,  -2.3357286088870641E-02,   9.2818555308547617E-04],
            [   4.3529878365506529E-02,   4.3529878365506529E-02,   9.9810335105086612E-01,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,   4.3529878365506529E-02,   9.9810335105086612E-01,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,  -4.3529878365506529E-02,   9.9810335105086612E-01,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,   4.3529878365506529E-02,  -9.9810335105086612E-01,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,  -4.3529878365506529E-02,   9.9810335105086612E-01,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,   4.3529878365506529E-02,  -9.9810335105086612E-01,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,  -4.3529878365506529E-02,  -9.9810335105086612E-01,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,  -4.3529878365506529E-02,  -9.9810335105086612E-01,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,   9.9810335105086612E-01,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,  -9.9810335105086612E-01,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,   9.9810335105086612E-01,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,  -9.9810335105086612E-01,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,   9.9810335105086612E-01,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,  -9.9810335105086612E-01,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -4.3529878365506529E-02,  -9.9810335105086612E-01,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [   4.3529878365506529E-02,   9.9810335105086612E-01,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [   9.9810335105086612E-01,   4.3529878365506529E-02,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -9.9810335105086612E-01,   4.3529878365506529E-02,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [   9.9810335105086612E-01,  -4.3529878365506529E-02,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [   9.9810335105086612E-01,   4.3529878365506529E-02,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -9.9810335105086612E-01,  -4.3529878365506529E-02,   4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -9.9810335105086612E-01,   4.3529878365506529E-02,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [   9.9810335105086612E-01,  -4.3529878365506529E-02,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [  -9.9810335105086612E-01,  -4.3529878365506529E-02,  -4.3529878365506529E-02,   1.0377280828499421E-03],
            [   6.4392005210888004E-02,   6.4392005210888004E-02,   9.9584503780951883E-01,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,   6.4392005210888004E-02,   9.9584503780951883E-01,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,  -6.4392005210888004E-02,   9.9584503780951883E-01,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,   6.4392005210888004E-02,  -9.9584503780951883E-01,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,  -6.4392005210888004E-02,   9.9584503780951883E-01,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,   6.4392005210888004E-02,  -9.9584503780951883E-01,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,  -6.4392005210888004E-02,  -9.9584503780951883E-01,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,  -6.4392005210888004E-02,  -9.9584503780951883E-01,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,   9.9584503780951883E-01,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,  -9.9584503780951883E-01,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,   9.9584503780951883E-01,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,  -9.9584503780951883E-01,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,   9.9584503780951883E-01,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,  -9.9584503780951883E-01,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -6.4392005210888004E-02,  -9.9584503780951883E-01,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [   6.4392005210888004E-02,   9.9584503780951883E-01,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [   9.9584503780951883E-01,   6.4392005210888004E-02,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -9.9584503780951883E-01,   6.4392005210888004E-02,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [   9.9584503780951883E-01,  -6.4392005210888004E-02,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [   9.9584503780951883E-01,   6.4392005210888004E-02,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -9.9584503780951883E-01,  -6.4392005210888004E-02,   6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -9.9584503780951883E-01,   6.4392005210888004E-02,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [   9.9584503780951883E-01,  -6.4392005210888004E-02,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [  -9.9584503780951883E-01,  -6.4392005210888004E-02,  -6.4392005210888004E-02,   1.2196975567957578E-03],
            [   9.0039436319931804E-02,   9.0039436319931804E-02,   9.9185976822047672E-01,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,   9.0039436319931804E-02,   9.9185976822047672E-01,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,  -9.0039436319931804E-02,   9.9185976822047672E-01,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,   9.0039436319931804E-02,  -9.9185976822047672E-01,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,  -9.0039436319931804E-02,   9.9185976822047672E-01,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,   9.0039436319931804E-02,  -9.9185976822047672E-01,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,  -9.0039436319931804E-02,  -9.9185976822047672E-01,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,  -9.0039436319931804E-02,  -9.9185976822047672E-01,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,   9.9185976822047672E-01,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,  -9.9185976822047672E-01,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,   9.9185976822047672E-01,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,  -9.9185976822047672E-01,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,   9.9185976822047672E-01,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,  -9.9185976822047672E-01,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.0039436319931804E-02,  -9.9185976822047672E-01,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.0039436319931804E-02,   9.9185976822047672E-01,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.9185976822047672E-01,   9.0039436319931804E-02,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.9185976822047672E-01,   9.0039436319931804E-02,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.9185976822047672E-01,  -9.0039436319931804E-02,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.9185976822047672E-01,   9.0039436319931804E-02,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.9185976822047672E-01,  -9.0039436319931804E-02,   9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.9185976822047672E-01,   9.0039436319931804E-02,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [   9.9185976822047672E-01,  -9.0039436319931804E-02,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [  -9.9185976822047672E-01,  -9.0039436319931804E-02,  -9.0039436319931804E-02,   1.6366363768733300E-03],
            [   1.1967066155484730E-01,   1.1967066155484730E-01,   9.8557489087641148E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,   1.1967066155484730E-01,   9.8557489087641148E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,  -1.1967066155484730E-01,   9.8557489087641148E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,   1.1967066155484730E-01,  -9.8557489087641148E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,  -1.1967066155484730E-01,   9.8557489087641148E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,   1.1967066155484730E-01,  -9.8557489087641148E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,  -1.1967066155484730E-01,  -9.8557489087641148E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,  -1.1967066155484730E-01,  -9.8557489087641148E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,   9.8557489087641148E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,  -9.8557489087641148E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,   9.8557489087641148E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,  -9.8557489087641148E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,   9.8557489087641148E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,  -9.8557489087641148E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -1.1967066155484730E-01,  -9.8557489087641148E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [   1.1967066155484730E-01,   9.8557489087641148E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [   9.8557489087641148E-01,   1.1967066155484730E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -9.8557489087641148E-01,   1.1967066155484730E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [   9.8557489087641148E-01,  -1.1967066155484730E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [   9.8557489087641148E-01,   1.1967066155484730E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -9.8557489087641148E-01,  -1.1967066155484730E-01,   1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -9.8557489087641148E-01,   1.1967066155484730E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [   9.8557489087641148E-01,  -1.1967066155484730E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [  -9.8557489087641148E-01,  -1.1967066155484730E-01,  -1.1967066155484730E-01,   1.9376803191222896E-03],
            [   1.5117154128381341E-01,   1.5117154128381341E-01,   9.7687989548959020E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,   1.5117154128381341E-01,   9.7687989548959020E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,  -1.5117154128381341E-01,   9.7687989548959020E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,   1.5117154128381341E-01,  -9.7687989548959020E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,  -1.5117154128381341E-01,   9.7687989548959020E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,   1.5117154128381341E-01,  -9.7687989548959020E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,  -1.5117154128381341E-01,  -9.7687989548959020E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,  -1.5117154128381341E-01,  -9.7687989548959020E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,   9.7687989548959020E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,  -9.7687989548959020E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,   9.7687989548959020E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,  -9.7687989548959020E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,   9.7687989548959020E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,  -9.7687989548959020E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -1.5117154128381341E-01,  -9.7687989548959020E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [   1.5117154128381341E-01,   9.7687989548959020E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [   9.7687989548959020E-01,   1.5117154128381341E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -9.7687989548959020E-01,   1.5117154128381341E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [   9.7687989548959020E-01,  -1.5117154128381341E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [   9.7687989548959020E-01,   1.5117154128381341E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -9.7687989548959020E-01,  -1.5117154128381341E-01,   1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -9.7687989548959020E-01,   1.5117154128381341E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [   9.7687989548959020E-01,  -1.5117154128381341E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [  -9.7687989548959020E-01,  -1.5117154128381341E-01,  -1.5117154128381341E-01,   2.1418873168243999E-03],
            [   1.8359828285038010E-01,   1.8359828285038010E-01,   9.6570354719695606E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,   1.8359828285038010E-01,   9.6570354719695606E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,  -1.8359828285038010E-01,   9.6570354719695606E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,   1.8359828285038010E-01,  -9.6570354719695606E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,  -1.8359828285038010E-01,   9.6570354719695606E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,   1.8359828285038010E-01,  -9.6570354719695606E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,  -1.8359828285038010E-01,  -9.6570354719695606E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,  -1.8359828285038010E-01,  -9.6570354719695606E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,   9.6570354719695606E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,  -9.6570354719695606E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,   9.6570354719695606E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,  -9.6570354719695606E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,   9.6570354719695606E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,  -9.6570354719695606E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -1.8359828285038010E-01,  -9.6570354719695606E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [   1.8359828285038010E-01,   9.6570354719695606E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [   9.6570354719695606E-01,   1.8359828285038010E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -9.6570354719695606E-01,   1.8359828285038010E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [   9.6570354719695606E-01,  -1.8359828285038010E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [   9.6570354719695606E-01,   1.8359828285038010E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -9.6570354719695606E-01,  -1.8359828285038010E-01,   1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -9.6570354719695606E-01,   1.8359828285038010E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [   9.6570354719695606E-01,  -1.8359828285038010E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [  -9.6570354719695606E-01,  -1.8359828285038010E-01,  -1.8359828285038010E-01,   2.2963470130962730E-03],
            [   2.1650812591554050E-01,   2.1650812591554050E-01,   9.5197083086882495E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,   2.1650812591554050E-01,   9.5197083086882495E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,  -2.1650812591554050E-01,   9.5197083086882495E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,   2.1650812591554050E-01,  -9.5197083086882495E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,  -2.1650812591554050E-01,   9.5197083086882495E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,   2.1650812591554050E-01,  -9.5197083086882495E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,  -2.1650812591554050E-01,  -9.5197083086882495E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,  -2.1650812591554050E-01,  -9.5197083086882495E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,   9.5197083086882495E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,  -9.5197083086882495E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,   9.5197083086882495E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,  -9.5197083086882495E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,   9.5197083086882495E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,  -9.5197083086882495E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -2.1650812591554050E-01,  -9.5197083086882495E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [   2.1650812591554050E-01,   9.5197083086882495E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [   9.5197083086882495E-01,   2.1650812591554050E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -9.5197083086882495E-01,   2.1650812591554050E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [   9.5197083086882495E-01,  -2.1650812591554050E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [   9.5197083086882495E-01,   2.1650812591554050E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -9.5197083086882495E-01,  -2.1650812591554050E-01,   2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -9.5197083086882495E-01,   2.1650812591554050E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [   9.5197083086882495E-01,  -2.1650812591554050E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [  -9.5197083086882495E-01,  -2.1650812591554050E-01,  -2.1650812591554050E-01,   2.4207363968882008E-03],
            [   2.4962087204175629E-01,   2.4962087204175629E-01,   9.3561682353526876E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,   2.4962087204175629E-01,   9.3561682353526876E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,  -2.4962087204175629E-01,   9.3561682353526876E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,   2.4962087204175629E-01,  -9.3561682353526876E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,  -2.4962087204175629E-01,   9.3561682353526876E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,   2.4962087204175629E-01,  -9.3561682353526876E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,  -2.4962087204175629E-01,  -9.3561682353526876E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,  -2.4962087204175629E-01,  -9.3561682353526876E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,   9.3561682353526876E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,  -9.3561682353526876E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,   9.3561682353526876E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,  -9.3561682353526876E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,   9.3561682353526876E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,  -9.3561682353526876E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -2.4962087204175629E-01,  -9.3561682353526876E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [   2.4962087204175629E-01,   9.3561682353526876E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [   9.3561682353526876E-01,   2.4962087204175629E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -9.3561682353526876E-01,   2.4962087204175629E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [   9.3561682353526876E-01,  -2.4962087204175629E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [   9.3561682353526876E-01,   2.4962087204175629E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -9.3561682353526876E-01,  -2.4962087204175629E-01,   2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -9.3561682353526876E-01,   2.4962087204175629E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [   9.3561682353526876E-01,  -2.4962087204175629E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [  -9.3561682353526876E-01,  -2.4962087204175629E-01,  -2.4962087204175629E-01,   2.5233400866920197E-03],
            [   2.8272006735679001E-01,   2.8272006735679001E-01,   9.1659081766486417E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,   2.8272006735679001E-01,   9.1659081766486417E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,  -2.8272006735679001E-01,   9.1659081766486417E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,   2.8272006735679001E-01,  -9.1659081766486417E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,  -2.8272006735679001E-01,   9.1659081766486417E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,   2.8272006735679001E-01,  -9.1659081766486417E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,  -2.8272006735679001E-01,  -9.1659081766486417E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,  -2.8272006735679001E-01,  -9.1659081766486417E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,   9.1659081766486417E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,  -9.1659081766486417E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,   9.1659081766486417E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,  -9.1659081766486417E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,   9.1659081766486417E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,  -9.1659081766486417E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -2.8272006735679001E-01,  -9.1659081766486417E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [   2.8272006735679001E-01,   9.1659081766486417E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [   9.1659081766486417E-01,   2.8272006735679001E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -9.1659081766486417E-01,   2.8272006735679001E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [   9.1659081766486417E-01,  -2.8272006735679001E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [   9.1659081766486417E-01,   2.8272006735679001E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -9.1659081766486417E-01,  -2.8272006735679001E-01,   2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -9.1659081766486417E-01,   2.8272006735679001E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [   9.1659081766486417E-01,  -2.8272006735679001E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [  -9.1659081766486417E-01,  -2.8272006735679001E-01,  -2.8272006735679001E-01,   2.6083211025506284E-03],
            [   3.1561908239943459E-01,   3.1561908239943459E-01,   8.9485707777872436E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,   3.1561908239943459E-01,   8.9485707777872436E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,  -3.1561908239943459E-01,   8.9485707777872436E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,   3.1561908239943459E-01,  -8.9485707777872436E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,  -3.1561908239943459E-01,   8.9485707777872436E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,   3.1561908239943459E-01,  -8.9485707777872436E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,  -3.1561908239943459E-01,  -8.9485707777872436E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,  -3.1561908239943459E-01,  -8.9485707777872436E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,   8.9485707777872436E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,  -8.9485707777872436E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,   8.9485707777872436E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,  -8.9485707777872436E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,   8.9485707777872436E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,  -8.9485707777872436E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -3.1561908239943459E-01,  -8.9485707777872436E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [   3.1561908239943459E-01,   8.9485707777872436E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [   8.9485707777872436E-01,   3.1561908239943459E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -8.9485707777872436E-01,   3.1561908239943459E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [   8.9485707777872436E-01,  -3.1561908239943459E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [   8.9485707777872436E-01,   3.1561908239943459E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -8.9485707777872436E-01,  -3.1561908239943459E-01,   3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -8.9485707777872436E-01,   3.1561908239943459E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [   8.9485707777872436E-01,  -3.1561908239943459E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [  -8.9485707777872436E-01,  -3.1561908239943459E-01,  -3.1561908239943459E-01,   2.6782789114634061E-03],
            [   3.4814767937491148E-01,   3.4814767937491148E-01,   8.7039438571932870E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,   3.4814767937491148E-01,   8.7039438571932870E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,  -3.4814767937491148E-01,   8.7039438571932870E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,   3.4814767937491148E-01,  -8.7039438571932870E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,  -3.4814767937491148E-01,   8.7039438571932870E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,   3.4814767937491148E-01,  -8.7039438571932870E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,  -3.4814767937491148E-01,  -8.7039438571932870E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,  -3.4814767937491148E-01,  -8.7039438571932870E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,   8.7039438571932870E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,  -8.7039438571932870E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,   8.7039438571932870E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,  -8.7039438571932870E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,   8.7039438571932870E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,  -8.7039438571932870E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -3.4814767937491148E-01,  -8.7039438571932870E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [   3.4814767937491148E-01,   8.7039438571932870E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [   8.7039438571932870E-01,   3.4814767937491148E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -8.7039438571932870E-01,   3.4814767937491148E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [   8.7039438571932870E-01,  -3.4814767937491148E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [   8.7039438571932870E-01,   3.4814767937491148E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -8.7039438571932870E-01,  -3.4814767937491148E-01,   3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -8.7039438571932870E-01,   3.4814767937491148E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [   8.7039438571932870E-01,  -3.4814767937491148E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [  -8.7039438571932870E-01,  -3.4814767937491148E-01,  -3.4814767937491148E-01,   2.7351488903245660E-03],
            [   3.8014660869472261E-01,   3.8014660869472261E-01,   8.4319458714806927E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,   3.8014660869472261E-01,   8.4319458714806927E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,  -3.8014660869472261E-01,   8.4319458714806927E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,   3.8014660869472261E-01,  -8.4319458714806927E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,  -3.8014660869472261E-01,   8.4319458714806927E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,   3.8014660869472261E-01,  -8.4319458714806927E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,  -3.8014660869472261E-01,  -8.4319458714806927E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,  -3.8014660869472261E-01,  -8.4319458714806927E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,   8.4319458714806927E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,  -8.4319458714806927E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,   8.4319458714806927E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,  -8.4319458714806927E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,   8.4319458714806927E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,  -8.4319458714806927E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -3.8014660869472261E-01,  -8.4319458714806927E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [   3.8014660869472261E-01,   8.4319458714806927E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [   8.4319458714806927E-01,   3.8014660869472261E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -8.4319458714806927E-01,   3.8014660869472261E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [   8.4319458714806927E-01,  -3.8014660869472261E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [   8.4319458714806927E-01,   3.8014660869472261E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -8.4319458714806927E-01,  -3.8014660869472261E-01,   3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -8.4319458714806927E-01,   3.8014660869472261E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [   8.4319458714806927E-01,  -3.8014660869472261E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [  -8.4319458714806927E-01,  -3.8014660869472261E-01,  -3.8014660869472261E-01,   2.7805385368564082E-03],
            [   4.1146521196340108E-01,   4.1146521196340108E-01,   8.1326057244146954E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,   4.1146521196340108E-01,   8.1326057244146954E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,  -4.1146521196340108E-01,   8.1326057244146954E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,   4.1146521196340108E-01,  -8.1326057244146954E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,  -4.1146521196340108E-01,   8.1326057244146954E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,   4.1146521196340108E-01,  -8.1326057244146954E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,  -4.1146521196340108E-01,  -8.1326057244146954E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,  -4.1146521196340108E-01,  -8.1326057244146954E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,   8.1326057244146954E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,  -8.1326057244146954E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,   8.1326057244146954E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,  -8.1326057244146954E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,   8.1326057244146954E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,  -8.1326057244146954E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -4.1146521196340108E-01,  -8.1326057244146954E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [   4.1146521196340108E-01,   8.1326057244146954E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [   8.1326057244146954E-01,   4.1146521196340108E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -8.1326057244146954E-01,   4.1146521196340108E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [   8.1326057244146954E-01,  -4.1146521196340108E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [   8.1326057244146954E-01,   4.1146521196340108E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -8.1326057244146954E-01,  -4.1146521196340108E-01,   4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -8.1326057244146954E-01,   4.1146521196340108E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [   8.1326057244146954E-01,  -4.1146521196340108E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [  -8.1326057244146954E-01,  -4.1146521196340108E-01,  -4.1146521196340108E-01,   2.8158717186367722E-03],
            [   4.4195987865197511E-01,   4.4195987865197511E-01,   7.8060420913793627E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,   4.4195987865197511E-01,   7.8060420913793627E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,  -4.4195987865197511E-01,   7.8060420913793627E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,   4.4195987865197511E-01,  -7.8060420913793627E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,  -4.4195987865197511E-01,   7.8060420913793627E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,   4.4195987865197511E-01,  -7.8060420913793627E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,  -4.4195987865197511E-01,  -7.8060420913793627E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,  -4.4195987865197511E-01,  -7.8060420913793627E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,   7.8060420913793627E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,  -7.8060420913793627E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,   7.8060420913793627E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,  -7.8060420913793627E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,   7.8060420913793627E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,  -7.8060420913793627E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -4.4195987865197511E-01,  -7.8060420913793627E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [   4.4195987865197511E-01,   7.8060420913793627E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [   7.8060420913793627E-01,   4.4195987865197511E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -7.8060420913793627E-01,   4.4195987865197511E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [   7.8060420913793627E-01,  -4.4195987865197511E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [   7.8060420913793627E-01,   4.4195987865197511E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -7.8060420913793627E-01,  -4.4195987865197511E-01,   4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -7.8060420913793627E-01,   4.4195987865197511E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [   7.8060420913793627E-01,  -4.4195987865197511E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [  -7.8060420913793627E-01,  -4.4195987865197511E-01,  -4.4195987865197511E-01,   2.8424625365000189E-03],
            [   4.7149259493295431E-01,   4.7149259493295431E-01,   7.4524456780762793E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,   4.7149259493295431E-01,   7.4524456780762793E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,  -4.7149259493295431E-01,   7.4524456780762793E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,   4.7149259493295431E-01,  -7.4524456780762793E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,  -4.7149259493295431E-01,   7.4524456780762793E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,   4.7149259493295431E-01,  -7.4524456780762793E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,  -4.7149259493295431E-01,  -7.4524456780762793E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,  -4.7149259493295431E-01,  -7.4524456780762793E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,   7.4524456780762793E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,  -7.4524456780762793E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,   7.4524456780762793E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,  -7.4524456780762793E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,   7.4524456780762793E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,  -7.4524456780762793E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -4.7149259493295431E-01,  -7.4524456780762793E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [   4.7149259493295431E-01,   7.4524456780762793E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [   7.4524456780762793E-01,   4.7149259493295431E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -7.4524456780762793E-01,   4.7149259493295431E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [   7.4524456780762793E-01,  -4.7149259493295431E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [   7.4524456780762793E-01,   4.7149259493295431E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -7.4524456780762793E-01,  -4.7149259493295431E-01,   4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -7.4524456780762793E-01,   4.7149259493295431E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [   7.4524456780762793E-01,  -4.7149259493295431E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [  -7.4524456780762793E-01,  -4.7149259493295431E-01,  -4.7149259493295431E-01,   2.8615590877300433E-03],
            [   4.9992939728794661E-01,   4.9992939728794661E-01,   7.0720661440248200E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,   4.9992939728794661E-01,   7.0720661440248200E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,  -4.9992939728794661E-01,   7.0720661440248200E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,   4.9992939728794661E-01,  -7.0720661440248200E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,  -4.9992939728794661E-01,   7.0720661440248200E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,   4.9992939728794661E-01,  -7.0720661440248200E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,  -4.9992939728794661E-01,  -7.0720661440248200E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,  -4.9992939728794661E-01,  -7.0720661440248200E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,   7.0720661440248200E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,  -7.0720661440248200E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,   7.0720661440248200E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,  -7.0720661440248200E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,   7.0720661440248200E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,  -7.0720661440248200E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -4.9992939728794661E-01,  -7.0720661440248200E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [   4.9992939728794661E-01,   7.0720661440248200E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [   7.0720661440248200E-01,   4.9992939728794661E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -7.0720661440248200E-01,   4.9992939728794661E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [   7.0720661440248200E-01,  -4.9992939728794661E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [   7.0720661440248200E-01,   4.9992939728794661E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -7.0720661440248200E-01,  -4.9992939728794661E-01,   4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -7.0720661440248200E-01,   4.9992939728794661E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [   7.0720661440248200E-01,  -4.9992939728794661E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [  -7.0720661440248200E-01,  -4.9992939728794661E-01,  -4.9992939728794661E-01,   2.8743710093975900E-03],
            [   5.2713872214312485E-01,   5.2713872214312485E-01,   6.6652046872892567E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,   5.2713872214312485E-01,   6.6652046872892567E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,  -5.2713872214312485E-01,   6.6652046872892567E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,   5.2713872214312485E-01,  -6.6652046872892567E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,  -5.2713872214312485E-01,   6.6652046872892567E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,   5.2713872214312485E-01,  -6.6652046872892567E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,  -5.2713872214312485E-01,  -6.6652046872892567E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,  -5.2713872214312485E-01,  -6.6652046872892567E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,   6.6652046872892567E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,  -6.6652046872892567E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,   6.6652046872892567E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,  -6.6652046872892567E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,   6.6652046872892567E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,  -6.6652046872892567E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -5.2713872214312485E-01,  -6.6652046872892567E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [   5.2713872214312485E-01,   6.6652046872892567E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [   6.6652046872892567E-01,   5.2713872214312485E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -6.6652046872892567E-01,   5.2713872214312485E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [   6.6652046872892567E-01,  -5.2713872214312485E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [   6.6652046872892567E-01,   5.2713872214312485E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -6.6652046872892567E-01,  -5.2713872214312485E-01,   5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -6.6652046872892567E-01,   5.2713872214312485E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [   6.6652046872892567E-01,  -5.2713872214312485E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [  -6.6652046872892567E-01,  -5.2713872214312485E-01,  -5.2713872214312485E-01,   2.8820855570408943E-03],
            [   5.5298967808377608E-01,   5.5298967808377608E-01,   6.2322133457191864E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,   5.5298967808377608E-01,   6.2322133457191864E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,  -5.5298967808377608E-01,   6.2322133457191864E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,   5.5298967808377608E-01,  -6.2322133457191864E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,  -5.5298967808377608E-01,   6.2322133457191864E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,   5.5298967808377608E-01,  -6.2322133457191864E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,  -5.5298967808377608E-01,  -6.2322133457191864E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,  -5.5298967808377608E-01,  -6.2322133457191864E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,   6.2322133457191864E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,  -6.2322133457191864E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,   6.2322133457191864E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,  -6.2322133457191864E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,   6.2322133457191864E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,  -6.2322133457191864E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -5.5298967808377608E-01,  -6.2322133457191864E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [   5.5298967808377608E-01,   6.2322133457191864E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [   6.2322133457191864E-01,   5.5298967808377608E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -6.2322133457191864E-01,   5.5298967808377608E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [   6.2322133457191864E-01,  -5.5298967808377608E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [   6.2322133457191864E-01,   5.5298967808377608E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -6.2322133457191864E-01,  -5.5298967808377608E-01,   5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -6.2322133457191864E-01,   5.5298967808377608E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [   6.2322133457191864E-01,  -5.5298967808377608E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [  -6.2322133457191864E-01,  -5.5298967808377608E-01,  -5.5298967808377608E-01,   2.8858736873164930E-03],
            [   6.0008560994817117E-01,   6.0008560994817117E-01,   5.2895606761456349E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,   6.0008560994817117E-01,   5.2895606761456349E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,  -6.0008560994817117E-01,   5.2895606761456349E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,   6.0008560994817117E-01,  -5.2895606761456349E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,  -6.0008560994817117E-01,   5.2895606761456349E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,   6.0008560994817117E-01,  -5.2895606761456349E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,  -6.0008560994817117E-01,  -5.2895606761456349E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,  -6.0008560994817117E-01,  -5.2895606761456349E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,   5.2895606761456349E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,  -5.2895606761456349E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,   5.2895606761456349E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,  -5.2895606761456349E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,   5.2895606761456349E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,  -5.2895606761456349E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -6.0008560994817117E-01,  -5.2895606761456349E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [   6.0008560994817117E-01,   5.2895606761456349E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [   5.2895606761456349E-01,   6.0008560994817117E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -5.2895606761456349E-01,   6.0008560994817117E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [   5.2895606761456349E-01,  -6.0008560994817117E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [   5.2895606761456349E-01,   6.0008560994817117E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -5.2895606761456349E-01,  -6.0008560994817117E-01,   6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -5.2895606761456349E-01,   6.0008560994817117E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [   5.2895606761456349E-01,  -6.0008560994817117E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [  -5.2895606761456349E-01,  -6.0008560994817117E-01,  -6.0008560994817117E-01,   2.8862362521691804E-03],
            [   6.2105621927851751E-01,   6.2105621927851751E-01,   4.7809867704371239E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,   6.2105621927851751E-01,   4.7809867704371239E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,  -6.2105621927851751E-01,   4.7809867704371239E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,   6.2105621927851751E-01,  -4.7809867704371239E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,  -6.2105621927851751E-01,   4.7809867704371239E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,   6.2105621927851751E-01,  -4.7809867704371239E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,  -6.2105621927851751E-01,  -4.7809867704371239E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,  -6.2105621927851751E-01,  -4.7809867704371239E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,   4.7809867704371239E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,  -4.7809867704371239E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,   4.7809867704371239E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,  -4.7809867704371239E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,   4.7809867704371239E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,  -4.7809867704371239E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -6.2105621927851751E-01,  -4.7809867704371239E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [   6.2105621927851751E-01,   4.7809867704371239E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [   4.7809867704371239E-01,   6.2105621927851751E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -4.7809867704371239E-01,   6.2105621927851751E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [   4.7809867704371239E-01,  -6.2105621927851751E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [   4.7809867704371239E-01,   6.2105621927851751E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -4.7809867704371239E-01,  -6.2105621927851751E-01,   6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -4.7809867704371239E-01,   6.2105621927851751E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [   4.7809867704371239E-01,  -6.2105621927851751E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [  -4.7809867704371239E-01,  -6.2105621927851751E-01,  -6.2105621927851751E-01,   2.8849690738381880E-03],
            [   6.4011658799342397E-01,   6.4011658799342397E-01,   4.2485468992505454E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,   6.4011658799342397E-01,   4.2485468992505454E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,  -6.4011658799342397E-01,   4.2485468992505454E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,   6.4011658799342397E-01,  -4.2485468992505454E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,  -6.4011658799342397E-01,   4.2485468992505454E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,   6.4011658799342397E-01,  -4.2485468992505454E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,  -6.4011658799342397E-01,  -4.2485468992505454E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,  -6.4011658799342397E-01,  -4.2485468992505454E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,   4.2485468992505454E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,  -4.2485468992505454E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,   4.2485468992505454E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,  -4.2485468992505454E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,   4.2485468992505454E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,  -4.2485468992505454E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -6.4011658799342397E-01,  -4.2485468992505454E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [   6.4011658799342397E-01,   4.2485468992505454E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [   4.2485468992505454E-01,   6.4011658799342397E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -4.2485468992505454E-01,   6.4011658799342397E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [   4.2485468992505454E-01,  -6.4011658799342397E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [   4.2485468992505454E-01,   6.4011658799342397E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -4.2485468992505454E-01,  -6.4011658799342397E-01,   6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -4.2485468992505454E-01,   6.4011658799342397E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [   4.2485468992505454E-01,  -6.4011658799342397E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [  -4.2485468992505454E-01,  -6.4011658799342397E-01,  -6.4011658799342397E-01,   2.8840045894194680E-03],
            [   6.5711440292443335E-01,   6.5711440292443335E-01,   3.6932549727649583E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,   6.5711440292443335E-01,   3.6932549727649583E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,  -6.5711440292443335E-01,   3.6932549727649583E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,   6.5711440292443335E-01,  -3.6932549727649583E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,  -6.5711440292443335E-01,   3.6932549727649583E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,   6.5711440292443335E-01,  -3.6932549727649583E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,  -6.5711440292443335E-01,  -3.6932549727649583E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,  -6.5711440292443335E-01,  -3.6932549727649583E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,   3.6932549727649583E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,  -3.6932549727649583E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,   3.6932549727649583E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,  -3.6932549727649583E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,   3.6932549727649583E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,  -3.6932549727649583E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -6.5711440292443335E-01,  -3.6932549727649583E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [   6.5711440292443335E-01,   3.6932549727649583E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [   3.6932549727649583E-01,   6.5711440292443335E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -3.6932549727649583E-01,   6.5711440292443335E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [   3.6932549727649583E-01,  -6.5711440292443335E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [   3.6932549727649583E-01,   6.5711440292443335E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -3.6932549727649583E-01,  -6.5711440292443335E-01,   6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -3.6932549727649583E-01,   6.5711440292443335E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [   3.6932549727649583E-01,  -6.5711440292443335E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [  -3.6932549727649583E-01,  -6.5711440292443335E-01,  -6.5711440292443335E-01,   2.8840569995488121E-03],
            [   6.7189108217188631E-01,   6.7189108217188631E-01,   3.1164843557409849E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,   6.7189108217188631E-01,   3.1164843557409849E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,  -6.7189108217188631E-01,   3.1164843557409849E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,   6.7189108217188631E-01,  -3.1164843557409849E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,  -6.7189108217188631E-01,   3.1164843557409849E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,   6.7189108217188631E-01,  -3.1164843557409849E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,  -6.7189108217188631E-01,  -3.1164843557409849E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,  -6.7189108217188631E-01,  -3.1164843557409849E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,   3.1164843557409849E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,  -3.1164843557409849E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,   3.1164843557409849E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,  -3.1164843557409849E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,   3.1164843557409849E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,  -3.1164843557409849E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -6.7189108217188631E-01,  -3.1164843557409849E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [   6.7189108217188631E-01,   3.1164843557409849E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [   3.1164843557409849E-01,   6.7189108217188631E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -3.1164843557409849E-01,   6.7189108217188631E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [   3.1164843557409849E-01,  -6.7189108217188631E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [   3.1164843557409849E-01,   6.7189108217188631E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -3.1164843557409849E-01,  -6.7189108217188631E-01,   6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -3.1164843557409849E-01,   6.7189108217188631E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [   3.1164843557409849E-01,  -6.7189108217188631E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [  -3.1164843557409849E-01,  -6.7189108217188631E-01,  -6.7189108217188631E-01,   2.8855306641799093E-03],
            [   6.8428455910990105E-01,   6.8428455910990105E-01,   2.5201048455875136E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,   6.8428455910990105E-01,   2.5201048455875136E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,  -6.8428455910990105E-01,   2.5201048455875136E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,   6.8428455910990105E-01,  -2.5201048455875136E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,  -6.8428455910990105E-01,   2.5201048455875136E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,   6.8428455910990105E-01,  -2.5201048455875136E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,  -6.8428455910990105E-01,  -2.5201048455875136E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,  -6.8428455910990105E-01,  -2.5201048455875136E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,   2.5201048455875136E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,  -2.5201048455875136E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,   2.5201048455875136E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,  -2.5201048455875136E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,   2.5201048455875136E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,  -2.5201048455875136E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -6.8428455910990105E-01,  -2.5201048455875136E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [   6.8428455910990105E-01,   2.5201048455875136E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [   2.5201048455875136E-01,   6.8428455910990105E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -2.5201048455875136E-01,   6.8428455910990105E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [   2.5201048455875136E-01,  -6.8428455910990105E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [   2.5201048455875136E-01,   6.8428455910990105E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -2.5201048455875136E-01,  -6.8428455910990105E-01,   6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -2.5201048455875136E-01,   6.8428455910990105E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [   2.5201048455875136E-01,  -6.8428455910990105E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [  -2.5201048455875136E-01,  -6.8428455910990105E-01,  -6.8428455910990105E-01,   2.8884182094345763E-03],
            [   6.9413534762698159E-01,   6.9413534762698159E-01,   1.9066262966176362E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,   6.9413534762698159E-01,   1.9066262966176362E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,  -6.9413534762698159E-01,   1.9066262966176362E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,   6.9413534762698159E-01,  -1.9066262966176362E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,  -6.9413534762698159E-01,   1.9066262966176362E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,   6.9413534762698159E-01,  -1.9066262966176362E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,  -6.9413534762698159E-01,  -1.9066262966176362E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,  -6.9413534762698159E-01,  -1.9066262966176362E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,   1.9066262966176362E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,  -1.9066262966176362E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,   1.9066262966176362E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,  -1.9066262966176362E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,   1.9066262966176362E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,  -1.9066262966176362E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -6.9413534762698159E-01,  -1.9066262966176362E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [   6.9413534762698159E-01,   1.9066262966176362E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [   1.9066262966176362E-01,   6.9413534762698159E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -1.9066262966176362E-01,   6.9413534762698159E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [   1.9066262966176362E-01,  -6.9413534762698159E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [   1.9066262966176362E-01,   6.9413534762698159E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -1.9066262966176362E-01,  -6.9413534762698159E-01,   6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -1.9066262966176362E-01,   6.9413534762698159E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [   1.9066262966176362E-01,  -6.9413534762698159E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [  -1.9066262966176362E-01,  -6.9413534762698159E-01,  -6.9413534762698159E-01,   2.8922504643183835E-03],
            [   7.0129652422129907E-01,   7.0129652422129907E-01,   1.2793111517629235E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,   7.0129652422129907E-01,   1.2793111517629235E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,  -7.0129652422129907E-01,   1.2793111517629235E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,   7.0129652422129907E-01,  -1.2793111517629235E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,  -7.0129652422129907E-01,   1.2793111517629235E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,   7.0129652422129907E-01,  -1.2793111517629235E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,  -7.0129652422129907E-01,  -1.2793111517629235E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,  -7.0129652422129907E-01,  -1.2793111517629235E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,   1.2793111517629235E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,  -1.2793111517629235E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,   1.2793111517629235E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,  -1.2793111517629235E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,   1.2793111517629235E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,  -1.2793111517629235E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -7.0129652422129907E-01,  -1.2793111517629235E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [   7.0129652422129907E-01,   1.2793111517629235E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [   1.2793111517629235E-01,   7.0129652422129907E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -1.2793111517629235E-01,   7.0129652422129907E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [   1.2793111517629235E-01,  -7.0129652422129907E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [   1.2793111517629235E-01,   7.0129652422129907E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -1.2793111517629235E-01,  -7.0129652422129907E-01,   7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -1.2793111517629235E-01,   7.0129652422129907E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [   1.2793111517629235E-01,  -7.0129652422129907E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [  -1.2793111517629235E-01,  -7.0129652422129907E-01,  -7.0129652422129907E-01,   2.8961593780543722E-03],
            [   7.0564714282426444E-01,   7.0564714282426444E-01,   6.4220087573159890E-02,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,   7.0564714282426444E-01,   6.4220087573159890E-02,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,  -7.0564714282426444E-01,   6.4220087573159890E-02,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,   7.0564714282426444E-01,  -6.4220087573159890E-02,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,  -7.0564714282426444E-01,   6.4220087573159890E-02,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,   7.0564714282426444E-01,  -6.4220087573159890E-02,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,  -7.0564714282426444E-01,  -6.4220087573159890E-02,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,  -7.0564714282426444E-01,  -6.4220087573159890E-02,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,   6.4220087573159890E-02,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,  -6.4220087573159890E-02,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,   6.4220087573159890E-02,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,  -6.4220087573159890E-02,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,   6.4220087573159890E-02,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,  -6.4220087573159890E-02,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -7.0564714282426444E-01,  -6.4220087573159890E-02,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [   7.0564714282426444E-01,   6.4220087573159890E-02,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [   6.4220087573159890E-02,   7.0564714282426444E-01,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -6.4220087573159890E-02,   7.0564714282426444E-01,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [   6.4220087573159890E-02,  -7.0564714282426444E-01,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [   6.4220087573159890E-02,   7.0564714282426444E-01,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -6.4220087573159890E-02,  -7.0564714282426444E-01,   7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -6.4220087573159890E-02,   7.0564714282426444E-01,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [   6.4220087573159890E-02,  -7.0564714282426444E-01,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [  -6.4220087573159890E-02,  -7.0564714282426444E-01,  -7.0564714282426444E-01,   2.8990968814270940E-03],
            [   4.5955576435858951E-02,   9.9894348438460112E-01,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [  -4.5955576435858951E-02,   9.9894348438460112E-01,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [   4.5955576435858951E-02,  -9.9894348438460112E-01,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [  -4.5955576435858951E-02,  -9.9894348438460112E-01,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [   9.9894348438460112E-01,   4.5955576435858951E-02,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [  -9.9894348438460112E-01,   4.5955576435858951E-02,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [   9.9894348438460112E-01,  -4.5955576435858951E-02,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [  -9.9894348438460112E-01,  -4.5955576435858951E-02,   0.0000000000000000E+00,   1.1702149510108809E-03],
            [   4.5955576435858951E-02,   0.0000000000000000E+00,   9.9894348438460112E-01,   1.1702149510108809E-03],
            [  -4.5955576435858951E-02,   0.0000000000000000E+00,   9.9894348438460112E-01,   1.1702149510108809E-03],
            [   4.5955576435858951E-02,   0.0000000000000000E+00,  -9.9894348438460112E-01,   1.1702149510108809E-03],
            [  -4.5955576435858951E-02,   0.0000000000000000E+00,  -9.9894348438460112E-01,   1.1702149510108809E-03],
            [   9.9894348438460112E-01,   0.0000000000000000E+00,   4.5955576435858951E-02,   1.1702149510108809E-03],
            [  -9.9894348438460112E-01,   0.0000000000000000E+00,   4.5955576435858951E-02,   1.1702149510108809E-03],
            [   9.9894348438460112E-01,   0.0000000000000000E+00,  -4.5955576435858951E-02,   1.1702149510108809E-03],
            [  -9.9894348438460112E-01,   0.0000000000000000E+00,  -4.5955576435858951E-02,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,   4.5955576435858951E-02,   9.9894348438460112E-01,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,  -4.5955576435858951E-02,   9.9894348438460112E-01,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,   4.5955576435858951E-02,  -9.9894348438460112E-01,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,  -4.5955576435858951E-02,  -9.9894348438460112E-01,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,   9.9894348438460112E-01,   4.5955576435858951E-02,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,  -9.9894348438460112E-01,   4.5955576435858951E-02,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,   9.9894348438460112E-01,  -4.5955576435858951E-02,   1.1702149510108809E-03],
            [   0.0000000000000000E+00,  -9.9894348438460112E-01,  -4.5955576435858951E-02,   1.1702149510108809E-03],
            [   1.0493167424350230E-01,   9.9447943354322599E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [  -1.0493167424350230E-01,   9.9447943354322599E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [   1.0493167424350230E-01,  -9.9447943354322599E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [  -1.0493167424350230E-01,  -9.9447943354322599E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [   9.9447943354322599E-01,   1.0493167424350230E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [  -9.9447943354322599E-01,   1.0493167424350230E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [   9.9447943354322599E-01,  -1.0493167424350230E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [  -9.9447943354322599E-01,  -1.0493167424350230E-01,   0.0000000000000000E+00,   1.5078631710283708E-03],
            [   1.0493167424350230E-01,   0.0000000000000000E+00,   9.9447943354322599E-01,   1.5078631710283708E-03],
            [  -1.0493167424350230E-01,   0.0000000000000000E+00,   9.9447943354322599E-01,   1.5078631710283708E-03],
            [   1.0493167424350230E-01,   0.0000000000000000E+00,  -9.9447943354322599E-01,   1.5078631710283708E-03],
            [  -1.0493167424350230E-01,   0.0000000000000000E+00,  -9.9447943354322599E-01,   1.5078631710283708E-03],
            [   9.9447943354322599E-01,   0.0000000000000000E+00,   1.0493167424350230E-01,   1.5078631710283708E-03],
            [  -9.9447943354322599E-01,   0.0000000000000000E+00,   1.0493167424350230E-01,   1.5078631710283708E-03],
            [   9.9447943354322599E-01,   0.0000000000000000E+00,  -1.0493167424350230E-01,   1.5078631710283708E-03],
            [  -9.9447943354322599E-01,   0.0000000000000000E+00,  -1.0493167424350230E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,   1.0493167424350230E-01,   9.9447943354322599E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,  -1.0493167424350230E-01,   9.9447943354322599E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,   1.0493167424350230E-01,  -9.9447943354322599E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,  -1.0493167424350230E-01,  -9.9447943354322599E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,   9.9447943354322599E-01,   1.0493167424350230E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,  -9.9447943354322599E-01,   1.0493167424350230E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,   9.9447943354322599E-01,  -1.0493167424350230E-01,   1.5078631710283708E-03],
            [   0.0000000000000000E+00,  -9.9447943354322599E-01,  -1.0493167424350230E-01,   1.5078631710283708E-03],
            [   1.7735488795492740E-01,   9.8414696245961919E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [  -1.7735488795492740E-01,   9.8414696245961919E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [   1.7735488795492740E-01,  -9.8414696245961919E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [  -1.7735488795492740E-01,  -9.8414696245961919E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [   9.8414696245961919E-01,   1.7735488795492740E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [  -9.8414696245961919E-01,   1.7735488795492740E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [   9.8414696245961919E-01,  -1.7735488795492740E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [  -9.8414696245961919E-01,  -1.7735488795492740E-01,   0.0000000000000000E+00,   2.0081552075388439E-03],
            [   1.7735488795492740E-01,   0.0000000000000000E+00,   9.8414696245961919E-01,   2.0081552075388439E-03],
            [  -1.7735488795492740E-01,   0.0000000000000000E+00,   9.8414696245961919E-01,   2.0081552075388439E-03],
            [   1.7735488795492740E-01,   0.0000000000000000E+00,  -9.8414696245961919E-01,   2.0081552075388439E-03],
            [  -1.7735488795492740E-01,   0.0000000000000000E+00,  -9.8414696245961919E-01,   2.0081552075388439E-03],
            [   9.8414696245961919E-01,   0.0000000000000000E+00,   1.7735488795492740E-01,   2.0081552075388439E-03],
            [  -9.8414696245961919E-01,   0.0000000000000000E+00,   1.7735488795492740E-01,   2.0081552075388439E-03],
            [   9.8414696245961919E-01,   0.0000000000000000E+00,  -1.7735488795492740E-01,   2.0081552075388439E-03],
            [  -9.8414696245961919E-01,   0.0000000000000000E+00,  -1.7735488795492740E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,   1.7735488795492740E-01,   9.8414696245961919E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,  -1.7735488795492740E-01,   9.8414696245961919E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,   1.7735488795492740E-01,  -9.8414696245961919E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,  -1.7735488795492740E-01,  -9.8414696245961919E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,   9.8414696245961919E-01,   1.7735488795492740E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,  -9.8414696245961919E-01,   1.7735488795492740E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,   9.8414696245961919E-01,  -1.7735488795492740E-01,   2.0081552075388439E-03],
            [   0.0000000000000000E+00,  -9.8414696245961919E-01,  -1.7735488795492740E-01,   2.0081552075388439E-03],
            [   2.5590714112361268E-01,   9.6670136811837570E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [  -2.5590714112361268E-01,   9.6670136811837570E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [   2.5590714112361268E-01,  -9.6670136811837570E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [  -2.5590714112361268E-01,  -9.6670136811837570E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [   9.6670136811837570E-01,   2.5590714112361268E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [  -9.6670136811837570E-01,   2.5590714112361268E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [   9.6670136811837570E-01,  -2.5590714112361268E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [  -9.6670136811837570E-01,  -2.5590714112361268E-01,   0.0000000000000000E+00,   2.2899116146493032E-03],
            [   2.5590714112361268E-01,   0.0000000000000000E+00,   9.6670136811837570E-01,   2.2899116146493032E-03],
            [  -2.5590714112361268E-01,   0.0000000000000000E+00,   9.6670136811837570E-01,   2.2899116146493032E-03],
            [   2.5590714112361268E-01,   0.0000000000000000E+00,  -9.6670136811837570E-01,   2.2899116146493032E-03],
            [  -2.5590714112361268E-01,   0.0000000000000000E+00,  -9.6670136811837570E-01,   2.2899116146493032E-03],
            [   9.6670136811837570E-01,   0.0000000000000000E+00,   2.5590714112361268E-01,   2.2899116146493032E-03],
            [  -9.6670136811837570E-01,   0.0000000000000000E+00,   2.5590714112361268E-01,   2.2899116146493032E-03],
            [   9.6670136811837570E-01,   0.0000000000000000E+00,  -2.5590714112361268E-01,   2.2899116146493032E-03],
            [  -9.6670136811837570E-01,   0.0000000000000000E+00,  -2.5590714112361268E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,   2.5590714112361268E-01,   9.6670136811837570E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,  -2.5590714112361268E-01,   9.6670136811837570E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,   2.5590714112361268E-01,  -9.6670136811837570E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,  -2.5590714112361268E-01,  -9.6670136811837570E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,   9.6670136811837570E-01,   2.5590714112361268E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,  -9.6670136811837570E-01,   2.5590714112361268E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,   9.6670136811837570E-01,  -2.5590714112361268E-01,   2.2899116146493032E-03],
            [   0.0000000000000000E+00,  -9.6670136811837570E-01,  -2.5590714112361268E-01,   2.2899116146493032E-03],
            [   3.3581568379858978E-01,   9.4192771830692268E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [  -3.3581568379858978E-01,   9.4192771830692268E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [   3.3581568379858978E-01,  -9.4192771830692268E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [  -3.3581568379858978E-01,  -9.4192771830692268E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [   9.4192771830692268E-01,   3.3581568379858978E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [  -9.4192771830692268E-01,   3.3581568379858978E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [   9.4192771830692268E-01,  -3.3581568379858978E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [  -9.4192771830692268E-01,  -3.3581568379858978E-01,   0.0000000000000000E+00,   2.4989228170020999E-03],
            [   3.3581568379858978E-01,   0.0000000000000000E+00,   9.4192771830692268E-01,   2.4989228170020999E-03],
            [  -3.3581568379858978E-01,   0.0000000000000000E+00,   9.4192771830692268E-01,   2.4989228170020999E-03],
            [   3.3581568379858978E-01,   0.0000000000000000E+00,  -9.4192771830692268E-01,   2.4989228170020999E-03],
            [  -3.3581568379858978E-01,   0.0000000000000000E+00,  -9.4192771830692268E-01,   2.4989228170020999E-03],
            [   9.4192771830692268E-01,   0.0000000000000000E+00,   3.3581568379858978E-01,   2.4989228170020999E-03],
            [  -9.4192771830692268E-01,   0.0000000000000000E+00,   3.3581568379858978E-01,   2.4989228170020999E-03],
            [   9.4192771830692268E-01,   0.0000000000000000E+00,  -3.3581568379858978E-01,   2.4989228170020999E-03],
            [  -9.4192771830692268E-01,   0.0000000000000000E+00,  -3.3581568379858978E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,   3.3581568379858978E-01,   9.4192771830692268E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,  -3.3581568379858978E-01,   9.4192771830692268E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,   3.3581568379858978E-01,  -9.4192771830692268E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,  -3.3581568379858978E-01,  -9.4192771830692268E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,   9.4192771830692268E-01,   3.3581568379858978E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,  -9.4192771830692268E-01,   3.3581568379858978E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,   9.4192771830692268E-01,  -3.3581568379858978E-01,   2.4989228170020999E-03],
            [   0.0000000000000000E+00,  -9.4192771830692268E-01,  -3.3581568379858978E-01,   2.4989228170020999E-03],
            [   4.1558357437638932E-01,   9.0955499707744125E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [  -4.1558357437638932E-01,   9.0955499707744125E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [   4.1558357437638932E-01,  -9.0955499707744125E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [  -4.1558357437638932E-01,  -9.0955499707744125E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [   9.0955499707744125E-01,   4.1558357437638932E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [  -9.0955499707744125E-01,   4.1558357437638932E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [   9.0955499707744125E-01,  -4.1558357437638932E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [  -9.0955499707744125E-01,  -4.1558357437638932E-01,   0.0000000000000000E+00,   2.6547967175779008E-03],
            [   4.1558357437638932E-01,   0.0000000000000000E+00,   9.0955499707744125E-01,   2.6547967175779008E-03],
            [  -4.1558357437638932E-01,   0.0000000000000000E+00,   9.0955499707744125E-01,   2.6547967175779008E-03],
            [   4.1558357437638932E-01,   0.0000000000000000E+00,  -9.0955499707744125E-01,   2.6547967175779008E-03],
            [  -4.1558357437638932E-01,   0.0000000000000000E+00,  -9.0955499707744125E-01,   2.6547967175779008E-03],
            [   9.0955499707744125E-01,   0.0000000000000000E+00,   4.1558357437638932E-01,   2.6547967175779008E-03],
            [  -9.0955499707744125E-01,   0.0000000000000000E+00,   4.1558357437638932E-01,   2.6547967175779008E-03],
            [   9.0955499707744125E-01,   0.0000000000000000E+00,  -4.1558357437638932E-01,   2.6547967175779008E-03],
            [  -9.0955499707744125E-01,   0.0000000000000000E+00,  -4.1558357437638932E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,   4.1558357437638932E-01,   9.0955499707744125E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,  -4.1558357437638932E-01,   9.0955499707744125E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,   4.1558357437638932E-01,  -9.0955499707744125E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,  -4.1558357437638932E-01,  -9.0955499707744125E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,   9.0955499707744125E-01,   4.1558357437638932E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,  -9.0955499707744125E-01,   4.1558357437638932E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,   9.0955499707744125E-01,  -4.1558357437638932E-01,   2.6547967175779008E-03],
            [   0.0000000000000000E+00,  -9.0955499707744125E-01,  -4.1558357437638932E-01,   2.6547967175779008E-03],
            [   4.9378942961674721E-01,   8.6958150808234613E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [  -4.9378942961674721E-01,   8.6958150808234613E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [   4.9378942961674721E-01,  -8.6958150808234613E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [  -4.9378942961674721E-01,  -8.6958150808234613E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [   8.6958150808234613E-01,   4.9378942961674721E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [  -8.6958150808234613E-01,   4.9378942961674721E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [   8.6958150808234613E-01,  -4.9378942961674721E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [  -8.6958150808234613E-01,  -4.9378942961674721E-01,   0.0000000000000000E+00,   2.7666057301504185E-03],
            [   4.9378942961674721E-01,   0.0000000000000000E+00,   8.6958150808234613E-01,   2.7666057301504185E-03],
            [  -4.9378942961674721E-01,   0.0000000000000000E+00,   8.6958150808234613E-01,   2.7666057301504185E-03],
            [   4.9378942961674721E-01,   0.0000000000000000E+00,  -8.6958150808234613E-01,   2.7666057301504185E-03],
            [  -4.9378942961674721E-01,   0.0000000000000000E+00,  -8.6958150808234613E-01,   2.7666057301504185E-03],
            [   8.6958150808234613E-01,   0.0000000000000000E+00,   4.9378942961674721E-01,   2.7666057301504185E-03],
            [  -8.6958150808234613E-01,   0.0000000000000000E+00,   4.9378942961674721E-01,   2.7666057301504185E-03],
            [   8.6958150808234613E-01,   0.0000000000000000E+00,  -4.9378942961674721E-01,   2.7666057301504185E-03],
            [  -8.6958150808234613E-01,   0.0000000000000000E+00,  -4.9378942961674721E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,   4.9378942961674721E-01,   8.6958150808234613E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,  -4.9378942961674721E-01,   8.6958150808234613E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,   4.9378942961674721E-01,  -8.6958150808234613E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,  -4.9378942961674721E-01,  -8.6958150808234613E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,   8.6958150808234613E-01,   4.9378942961674721E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,  -8.6958150808234613E-01,   4.9378942961674721E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,   8.6958150808234613E-01,  -4.9378942961674721E-01,   2.7666057301504185E-03],
            [   0.0000000000000000E+00,  -8.6958150808234613E-01,  -4.9378942961674721E-01,   2.7666057301504185E-03],
            [   5.6915696947933159E-01,   8.2222888789746573E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [  -5.6915696947933159E-01,   8.2222888789746573E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [   5.6915696947933159E-01,  -8.2222888789746573E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [  -5.6915696947933159E-01,  -8.2222888789746573E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [   8.2222888789746573E-01,   5.6915696947933159E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [  -8.2222888789746573E-01,   5.6915696947933159E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [   8.2222888789746573E-01,  -5.6915696947933159E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [  -8.2222888789746573E-01,  -5.6915696947933159E-01,   0.0000000000000000E+00,   2.8420387666994234E-03],
            [   5.6915696947933159E-01,   0.0000000000000000E+00,   8.2222888789746573E-01,   2.8420387666994234E-03],
            [  -5.6915696947933159E-01,   0.0000000000000000E+00,   8.2222888789746573E-01,   2.8420387666994234E-03],
            [   5.6915696947933159E-01,   0.0000000000000000E+00,  -8.2222888789746573E-01,   2.8420387666994234E-03],
            [  -5.6915696947933159E-01,   0.0000000000000000E+00,  -8.2222888789746573E-01,   2.8420387666994234E-03],
            [   8.2222888789746573E-01,   0.0000000000000000E+00,   5.6915696947933159E-01,   2.8420387666994234E-03],
            [  -8.2222888789746573E-01,   0.0000000000000000E+00,   5.6915696947933159E-01,   2.8420387666994234E-03],
            [   8.2222888789746573E-01,   0.0000000000000000E+00,  -5.6915696947933159E-01,   2.8420387666994234E-03],
            [  -8.2222888789746573E-01,   0.0000000000000000E+00,  -5.6915696947933159E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,   5.6915696947933159E-01,   8.2222888789746573E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,  -5.6915696947933159E-01,   8.2222888789746573E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,   5.6915696947933159E-01,  -8.2222888789746573E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,  -5.6915696947933159E-01,  -8.2222888789746573E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,   8.2222888789746573E-01,   5.6915696947933159E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,  -8.2222888789746573E-01,   5.6915696947933159E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,   8.2222888789746573E-01,  -5.6915696947933159E-01,   2.8420387666994234E-03],
            [   0.0000000000000000E+00,  -8.2222888789746573E-01,  -5.6915696947933159E-01,   2.8420387666994234E-03],
            [   6.4058408548942514E-01,   7.6788803182344023E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [  -6.4058408548942514E-01,   7.6788803182344023E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [   6.4058408548942514E-01,  -7.6788803182344023E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [  -6.4058408548942514E-01,  -7.6788803182344023E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [   7.6788803182344023E-01,   6.4058408548942514E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [  -7.6788803182344023E-01,   6.4058408548942514E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [   7.6788803182344023E-01,  -6.4058408548942514E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [  -7.6788803182344023E-01,  -6.4058408548942514E-01,   0.0000000000000000E+00,   2.8858148026351155E-03],
            [   6.4058408548942514E-01,   0.0000000000000000E+00,   7.6788803182344023E-01,   2.8858148026351155E-03],
            [  -6.4058408548942514E-01,   0.0000000000000000E+00,   7.6788803182344023E-01,   2.8858148026351155E-03],
            [   6.4058408548942514E-01,   0.0000000000000000E+00,  -7.6788803182344023E-01,   2.8858148026351155E-03],
            [  -6.4058408548942514E-01,   0.0000000000000000E+00,  -7.6788803182344023E-01,   2.8858148026351155E-03],
            [   7.6788803182344023E-01,   0.0000000000000000E+00,   6.4058408548942514E-01,   2.8858148026351155E-03],
            [  -7.6788803182344023E-01,   0.0000000000000000E+00,   6.4058408548942514E-01,   2.8858148026351155E-03],
            [   7.6788803182344023E-01,   0.0000000000000000E+00,  -6.4058408548942514E-01,   2.8858148026351155E-03],
            [  -7.6788803182344023E-01,   0.0000000000000000E+00,  -6.4058408548942514E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,   6.4058408548942514E-01,   7.6788803182344023E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,  -6.4058408548942514E-01,   7.6788803182344023E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,   6.4058408548942514E-01,  -7.6788803182344023E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,  -6.4058408548942514E-01,  -7.6788803182344023E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,   7.6788803182344023E-01,   6.4058408548942514E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,  -7.6788803182344023E-01,   6.4058408548942514E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,   7.6788803182344023E-01,  -6.4058408548942514E-01,   2.8858148026351155E-03],
            [   0.0000000000000000E+00,  -7.6788803182344023E-01,  -6.4058408548942514E-01,   2.8858148026351155E-03],
            [   7.3451338941433478E-02,   2.1778440814860672E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,   2.1778440814860672E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,  -2.1778440814860672E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,   2.1778440814860672E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,  -2.1778440814860672E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,  -2.1778440814860672E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,   2.1778440814860672E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,  -2.1778440814860672E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,   7.3451338941433478E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,   7.3451338941433478E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,  -7.3451338941433478E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,   7.3451338941433478E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,  -7.3451338941433478E-02,   9.9706098124607423E-01,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,  -7.3451338941433478E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,   7.3451338941433478E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,  -7.3451338941433478E-02,  -9.9706098124607423E-01,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,   7.3451338941433478E-02,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,   7.3451338941433478E-02,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,  -7.3451338941433478E-02,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,   7.3451338941433478E-02,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,  -7.3451338941433478E-02,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,  -7.3451338941433478E-02,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,   7.3451338941433478E-02,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,  -7.3451338941433478E-02,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,   2.1778440814860672E-02,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,   2.1778440814860672E-02,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,  -2.1778440814860672E-02,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,   2.1778440814860672E-02,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,  -2.1778440814860672E-02,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   9.9706098124607423E-01,  -2.1778440814860672E-02,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,   2.1778440814860672E-02,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -9.9706098124607423E-01,  -2.1778440814860672E-02,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,   9.9706098124607423E-01,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,   9.9706098124607423E-01,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,  -9.9706098124607423E-01,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,   9.9706098124607423E-01,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,  -9.9706098124607423E-01,   2.1778440814860672E-02,   1.2641856680331142E-03],
            [   7.3451338941433478E-02,  -9.9706098124607423E-01,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,   9.9706098124607423E-01,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [  -7.3451338941433478E-02,  -9.9706098124607423E-01,  -2.1778440814860672E-02,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,   9.9706098124607423E-01,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,   9.9706098124607423E-01,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,  -9.9706098124607423E-01,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,   9.9706098124607423E-01,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,  -9.9706098124607423E-01,   7.3451338941433478E-02,   1.2641856680331142E-03],
            [   2.1778440814860672E-02,  -9.9706098124607423E-01,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,   9.9706098124607423E-01,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [  -2.1778440814860672E-02,  -9.9706098124607423E-01,  -7.3451338941433478E-02,   1.2641856680331142E-03],
            [   1.0098598340449309E-01,   4.5903621857751882E-02,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,   4.5903621857751882E-02,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,  -4.5903621857751882E-02,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,   4.5903621857751882E-02,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,  -4.5903621857751882E-02,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,  -4.5903621857751882E-02,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,   4.5903621857751882E-02,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,  -4.5903621857751882E-02,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,   1.0098598340449309E-01,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,   1.0098598340449309E-01,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,  -1.0098598340449309E-01,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,   1.0098598340449309E-01,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,  -1.0098598340449309E-01,   9.9382829938383621E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,  -1.0098598340449309E-01,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,   1.0098598340449309E-01,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,  -1.0098598340449309E-01,  -9.9382829938383621E-01,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,   1.0098598340449309E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,   1.0098598340449309E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,  -1.0098598340449309E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,   1.0098598340449309E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,  -1.0098598340449309E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,  -1.0098598340449309E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,   1.0098598340449309E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,  -1.0098598340449309E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,   4.5903621857751882E-02,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,   4.5903621857751882E-02,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,  -4.5903621857751882E-02,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,   4.5903621857751882E-02,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,  -4.5903621857751882E-02,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   9.9382829938383621E-01,  -4.5903621857751882E-02,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,   4.5903621857751882E-02,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -9.9382829938383621E-01,  -4.5903621857751882E-02,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,   9.9382829938383621E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,   9.9382829938383621E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,  -9.9382829938383621E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,   9.9382829938383621E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,  -9.9382829938383621E-01,   4.5903621857751882E-02,   1.5427440276574017E-03],
            [   1.0098598340449309E-01,  -9.9382829938383621E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,   9.9382829938383621E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [  -1.0098598340449309E-01,  -9.9382829938383621E-01,  -4.5903621857751882E-02,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,   9.9382829938383621E-01,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,   9.9382829938383621E-01,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,  -9.9382829938383621E-01,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,   9.9382829938383621E-01,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,  -9.9382829938383621E-01,   1.0098598340449309E-01,   1.5427440276574017E-03],
            [   4.5903621857751882E-02,  -9.9382829938383621E-01,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,   9.9382829938383621E-01,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [  -4.5903621857751882E-02,  -9.9382829938383621E-01,  -1.0098598340449309E-01,   1.5427440276574017E-03],
            [   1.3242896197487580E-01,   7.2550630956908765E-02,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,   7.2550630956908765E-02,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,  -7.2550630956908765E-02,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,   7.2550630956908765E-02,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,  -7.2550630956908765E-02,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,  -7.2550630956908765E-02,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,   7.2550630956908765E-02,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,  -7.2550630956908765E-02,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,   1.3242896197487580E-01,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,   1.3242896197487580E-01,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,  -1.3242896197487580E-01,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,   1.3242896197487580E-01,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,  -1.3242896197487580E-01,   9.8853375055078996E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,  -1.3242896197487580E-01,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,   1.3242896197487580E-01,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,  -1.3242896197487580E-01,  -9.8853375055078996E-01,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,   1.3242896197487580E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,   1.3242896197487580E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,  -1.3242896197487580E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,   1.3242896197487580E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,  -1.3242896197487580E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,  -1.3242896197487580E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,   1.3242896197487580E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,  -1.3242896197487580E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,   7.2550630956908765E-02,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,   7.2550630956908765E-02,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,  -7.2550630956908765E-02,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,   7.2550630956908765E-02,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,  -7.2550630956908765E-02,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   9.8853375055078996E-01,  -7.2550630956908765E-02,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,   7.2550630956908765E-02,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -9.8853375055078996E-01,  -7.2550630956908765E-02,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,   9.8853375055078996E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,   9.8853375055078996E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,  -9.8853375055078996E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,   9.8853375055078996E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,  -9.8853375055078996E-01,   7.2550630956908765E-02,   1.8445726557453873E-03],
            [   1.3242896197487580E-01,  -9.8853375055078996E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,   9.8853375055078996E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [  -1.3242896197487580E-01,  -9.8853375055078996E-01,  -7.2550630956908765E-02,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,   9.8853375055078996E-01,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,   9.8853375055078996E-01,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,  -9.8853375055078996E-01,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,   9.8853375055078996E-01,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,  -9.8853375055078996E-01,   1.3242896197487580E-01,   1.8445726557453873E-03],
            [   7.2550630956908765E-02,  -9.8853375055078996E-01,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,   9.8853375055078996E-01,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [  -7.2550630956908765E-02,  -9.8853375055078996E-01,  -1.3242896197487580E-01,   1.8445726557453873E-03],
            [   1.6542721096071270E-01,   1.0178254519606840E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,   1.0178254519606840E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,  -1.0178254519606840E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,   1.0178254519606840E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,  -1.0178254519606840E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,  -1.0178254519606840E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,   1.0178254519606840E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,  -1.0178254519606840E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,   1.6542721096071270E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,   1.6542721096071270E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,  -1.6542721096071270E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,   1.6542721096071270E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,  -1.6542721096071270E-01,   9.8095573364304778E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,  -1.6542721096071270E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,   1.6542721096071270E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,  -1.6542721096071270E-01,  -9.8095573364304778E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,   1.6542721096071270E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,   1.6542721096071270E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,  -1.6542721096071270E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,   1.6542721096071270E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,  -1.6542721096071270E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,  -1.6542721096071270E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,   1.6542721096071270E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,  -1.6542721096071270E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,   1.0178254519606840E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,   1.0178254519606840E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,  -1.0178254519606840E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,   1.0178254519606840E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,  -1.0178254519606840E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   9.8095573364304778E-01,  -1.0178254519606840E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,   1.0178254519606840E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -9.8095573364304778E-01,  -1.0178254519606840E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,   9.8095573364304778E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,   9.8095573364304778E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,  -9.8095573364304778E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,   9.8095573364304778E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,  -9.8095573364304778E-01,   1.0178254519606840E-01,   2.0661361565777955E-03],
            [   1.6542721096071270E-01,  -9.8095573364304778E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,   9.8095573364304778E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [  -1.6542721096071270E-01,  -9.8095573364304778E-01,  -1.0178254519606840E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,   9.8095573364304778E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,   9.8095573364304778E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,  -9.8095573364304778E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,   9.8095573364304778E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,  -9.8095573364304778E-01,   1.6542721096071270E-01,   2.0661361565777955E-03],
            [   1.0178254519606840E-01,  -9.8095573364304778E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,   9.8095573364304778E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [  -1.0178254519606840E-01,  -9.8095573364304778E-01,  -1.6542721096071270E-01,   2.0661361565777955E-03],
            [   1.9907671867764609E-01,   1.3256523209803639E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,   1.3256523209803639E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,  -1.3256523209803639E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,   1.3256523209803639E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,  -1.3256523209803639E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,  -1.3256523209803639E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,   1.3256523209803639E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,  -1.3256523209803639E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,   1.9907671867764609E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,   1.9907671867764609E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,  -1.9907671867764609E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,   1.9907671867764609E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,  -1.9907671867764609E-01,   9.7097627124422314E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,  -1.9907671867764609E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,   1.9907671867764609E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,  -1.9907671867764609E-01,  -9.7097627124422314E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,   1.9907671867764609E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,   1.9907671867764609E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,  -1.9907671867764609E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,   1.9907671867764609E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,  -1.9907671867764609E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,  -1.9907671867764609E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,   1.9907671867764609E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,  -1.9907671867764609E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,   1.3256523209803639E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,   1.3256523209803639E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,  -1.3256523209803639E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,   1.3256523209803639E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,  -1.3256523209803639E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   9.7097627124422314E-01,  -1.3256523209803639E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,   1.3256523209803639E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -9.7097627124422314E-01,  -1.3256523209803639E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,   9.7097627124422314E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,   9.7097627124422314E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,  -9.7097627124422314E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,   9.7097627124422314E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,  -9.7097627124422314E-01,   1.3256523209803639E-01,   2.2338795844908761E-03],
            [   1.9907671867764609E-01,  -9.7097627124422314E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,   9.7097627124422314E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [  -1.9907671867764609E-01,  -9.7097627124422314E-01,  -1.3256523209803639E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,   9.7097627124422314E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,   9.7097627124422314E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,  -9.7097627124422314E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,   9.7097627124422314E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,  -9.7097627124422314E-01,   1.9907671867764609E-01,   2.2338795844908761E-03],
            [   1.3256523209803639E-01,  -9.7097627124422314E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,   9.7097627124422314E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [  -1.3256523209803639E-01,  -9.7097627124422314E-01,  -1.9907671867764609E-01,   2.2338795844908761E-03],
            [   2.3301259455232781E-01,   1.6427653744967649E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,   1.6427653744967649E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,  -1.6427653744967649E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,   1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,  -1.6427653744967649E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,  -1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,   1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,  -1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,   2.3301259455232781E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,   2.3301259455232781E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,  -2.3301259455232781E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,   2.3301259455232781E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,  -2.3301259455232781E-01,   9.5849796558132427E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,  -2.3301259455232781E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,   2.3301259455232781E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,  -2.3301259455232781E-01,  -9.5849796558132427E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,   2.3301259455232781E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,   2.3301259455232781E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,  -2.3301259455232781E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,   2.3301259455232781E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,  -2.3301259455232781E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,  -2.3301259455232781E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,   2.3301259455232781E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,  -2.3301259455232781E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,   1.6427653744967649E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,   1.6427653744967649E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,   1.6427653744967649E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   9.5849796558132427E-01,  -1.6427653744967649E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,   1.6427653744967649E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -9.5849796558132427E-01,  -1.6427653744967649E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,   9.5849796558132427E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,   9.5849796558132427E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,  -9.5849796558132427E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,   9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,  -9.5849796558132427E-01,   1.6427653744967649E-01,   2.3685417843772533E-03],
            [   2.3301259455232781E-01,  -9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,   9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [  -2.3301259455232781E-01,  -9.5849796558132427E-01,  -1.6427653744967649E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,   9.5849796558132427E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,   9.5849796558132427E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,   9.5849796558132427E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,  -9.5849796558132427E-01,   2.3301259455232781E-01,   2.3685417843772533E-03],
            [   1.6427653744967649E-01,  -9.5849796558132427E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,   9.5849796558132427E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [  -1.6427653744967649E-01,  -9.5849796558132427E-01,  -2.3301259455232781E-01,   2.3685417843772533E-03],
            [   2.6700806111082870E-01,   1.9653603743378889E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,   1.9653603743378889E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,  -1.9653603743378889E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,   1.9653603743378889E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,  -1.9653603743378889E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,  -1.9653603743378889E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,   1.9653603743378889E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,  -1.9653603743378889E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,   2.6700806111082870E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,   2.6700806111082870E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,  -2.6700806111082870E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,   2.6700806111082870E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,  -2.6700806111082870E-01,   9.4344066124566639E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,  -2.6700806111082870E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,   2.6700806111082870E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,  -2.6700806111082870E-01,  -9.4344066124566639E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,   2.6700806111082870E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,   2.6700806111082870E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,  -2.6700806111082870E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,   2.6700806111082870E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,  -2.6700806111082870E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,  -2.6700806111082870E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,   2.6700806111082870E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,  -2.6700806111082870E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,   1.9653603743378889E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,   1.9653603743378889E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,  -1.9653603743378889E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,   1.9653603743378889E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,  -1.9653603743378889E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   9.4344066124566639E-01,  -1.9653603743378889E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,   1.9653603743378889E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -9.4344066124566639E-01,  -1.9653603743378889E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,   9.4344066124566639E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,   9.4344066124566639E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,  -9.4344066124566639E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,   9.4344066124566639E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,  -9.4344066124566639E-01,   1.9653603743378889E-01,   2.4796832672856306E-03],
            [   2.6700806111082870E-01,  -9.4344066124566639E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,   9.4344066124566639E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [  -2.6700806111082870E-01,  -9.4344066124566639E-01,  -1.9653603743378889E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,   9.4344066124566639E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,   9.4344066124566639E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,  -9.4344066124566639E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,   9.4344066124566639E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,  -9.4344066124566639E-01,   2.6700806111082870E-01,   2.4796832672856306E-03],
            [   1.9653603743378889E-01,  -9.4344066124566639E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,   9.4344066124566639E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [  -1.9653603743378889E-01,  -9.4344066124566639E-01,  -2.6700806111082870E-01,   2.4796832672856306E-03],
            [   3.0087533762943158E-01,   2.2907267705422379E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,   2.2907267705422379E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,  -2.2907267705422379E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,   2.2907267705422379E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,  -2.2907267705422379E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,  -2.2907267705422379E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,   2.2907267705422379E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,  -2.2907267705422379E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,   3.0087533762943158E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,   3.0087533762943158E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,  -3.0087533762943158E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,   3.0087533762943158E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,  -3.0087533762943158E-01,   9.2574280436500667E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,  -3.0087533762943158E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,   3.0087533762943158E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,  -3.0087533762943158E-01,  -9.2574280436500667E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,   3.0087533762943158E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,   3.0087533762943158E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,  -3.0087533762943158E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,   3.0087533762943158E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,  -3.0087533762943158E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,  -3.0087533762943158E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,   3.0087533762943158E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,  -3.0087533762943158E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,   2.2907267705422379E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,   2.2907267705422379E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,  -2.2907267705422379E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,   2.2907267705422379E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,  -2.2907267705422379E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   9.2574280436500667E-01,  -2.2907267705422379E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,   2.2907267705422379E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -9.2574280436500667E-01,  -2.2907267705422379E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,   9.2574280436500667E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,   9.2574280436500667E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,  -9.2574280436500667E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,   9.2574280436500667E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,  -9.2574280436500667E-01,   2.2907267705422379E-01,   2.5720442432925674E-03],
            [   3.0087533762943158E-01,  -9.2574280436500667E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,   9.2574280436500667E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [  -3.0087533762943158E-01,  -9.2574280436500667E-01,  -2.2907267705422379E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,   9.2574280436500667E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,   9.2574280436500667E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,  -9.2574280436500667E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,   9.2574280436500667E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,  -9.2574280436500667E-01,   3.0087533762943158E-01,   2.5720442432925674E-03],
            [   2.2907267705422379E-01,  -9.2574280436500667E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,   9.2574280436500667E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [  -2.2907267705422379E-01,  -9.2574280436500667E-01,  -3.0087533762943158E-01,   2.5720442432925674E-03],
            [   3.3444755961678602E-01,   2.6166454953708229E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,   2.6166454953708229E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,  -2.6166454953708229E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,   2.6166454953708229E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,  -2.6166454953708229E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,  -2.6166454953708229E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,   2.6166454953708229E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,  -2.6166454953708229E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,   3.3444755961678602E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,   3.3444755961678602E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,  -3.3444755961678602E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,   3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,  -3.3444755961678602E-01,   9.0535986954466463E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,  -3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,   3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,  -3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,   3.3444755961678602E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,   3.3444755961678602E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,   3.3444755961678602E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,  -3.3444755961678602E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,   3.3444755961678602E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,  -3.3444755961678602E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,   2.6166454953708229E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,   2.6166454953708229E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,  -2.6166454953708229E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,   2.6166454953708229E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,  -2.6166454953708229E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   9.0535986954466463E-01,  -2.6166454953708229E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,   2.6166454953708229E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -9.0535986954466463E-01,  -2.6166454953708229E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,   9.0535986954466463E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,   9.0535986954466463E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,   9.0535986954466463E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,  -9.0535986954466463E-01,   2.6166454953708229E-01,   2.6484884289156149E-03],
            [   3.3444755961678602E-01,  -9.0535986954466463E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,   9.0535986954466463E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [  -3.3444755961678602E-01,  -9.0535986954466463E-01,  -2.6166454953708229E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,   9.0535986954466463E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,   9.0535986954466463E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,  -9.0535986954466463E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,   9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,  -9.0535986954466463E-01,   3.3444755961678602E-01,   2.6484884289156149E-03],
            [   2.6166454953708229E-01,  -9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,   9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [  -2.6166454953708229E-01,  -9.0535986954466463E-01,  -3.3444755961678602E-01,   2.6484884289156149E-03],
            [   3.6757097240707859E-01,   2.9411507288431410E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,   2.9411507288431410E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,  -2.9411507288431410E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,   2.9411507288431410E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,  -2.9411507288431410E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,  -2.9411507288431410E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,   2.9411507288431410E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,  -2.9411507288431410E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,   3.6757097240707859E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,   3.6757097240707859E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,  -3.6757097240707859E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,   3.6757097240707859E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,  -3.6757097240707859E-01,   8.8226294501467606E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,  -3.6757097240707859E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,   3.6757097240707859E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,  -3.6757097240707859E-01,  -8.8226294501467606E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,   3.6757097240707859E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,   3.6757097240707859E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,  -3.6757097240707859E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,   3.6757097240707859E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,  -3.6757097240707859E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,  -3.6757097240707859E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,   3.6757097240707859E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,  -3.6757097240707859E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,   2.9411507288431410E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,   2.9411507288431410E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,  -2.9411507288431410E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,   2.9411507288431410E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,  -2.9411507288431410E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   8.8226294501467606E-01,  -2.9411507288431410E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,   2.9411507288431410E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -8.8226294501467606E-01,  -2.9411507288431410E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,   8.8226294501467606E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,   8.8226294501467606E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,  -8.8226294501467606E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,   8.8226294501467606E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,  -8.8226294501467606E-01,   2.9411507288431410E-01,   2.7110893577727540E-03],
            [   3.6757097240707859E-01,  -8.8226294501467606E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,   8.8226294501467606E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [  -3.6757097240707859E-01,  -8.8226294501467606E-01,  -2.9411507288431410E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,   8.8226294501467606E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,   8.8226294501467606E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,  -8.8226294501467606E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,   8.8226294501467606E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,  -8.8226294501467606E-01,   3.6757097240707859E-01,   2.7110893577727540E-03],
            [   2.9411507288431410E-01,  -8.8226294501467606E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,   8.8226294501467606E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [  -2.9411507288431410E-01,  -8.8226294501467606E-01,  -3.6757097240707859E-01,   2.7110893577727540E-03],
            [   4.0010008875878122E-01,   3.2624404009190661E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,   3.2624404009190661E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,  -3.2624404009190661E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,   3.2624404009190661E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,  -3.2624404009190661E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,  -3.2624404009190661E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,   3.2624404009190661E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,  -3.2624404009190661E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,   4.0010008875878122E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,   4.0010008875878122E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,  -4.0010008875878122E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,   4.0010008875878122E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,  -4.0010008875878122E-01,   8.5643723954515527E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,  -4.0010008875878122E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,   4.0010008875878122E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,  -4.0010008875878122E-01,  -8.5643723954515527E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,   4.0010008875878122E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,   4.0010008875878122E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,  -4.0010008875878122E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,   4.0010008875878122E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,  -4.0010008875878122E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,  -4.0010008875878122E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,   4.0010008875878122E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,  -4.0010008875878122E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,   3.2624404009190661E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,   3.2624404009190661E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,  -3.2624404009190661E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,   3.2624404009190661E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,  -3.2624404009190661E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   8.5643723954515527E-01,  -3.2624404009190661E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,   3.2624404009190661E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -8.5643723954515527E-01,  -3.2624404009190661E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,   8.5643723954515527E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,   8.5643723954515527E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,  -8.5643723954515527E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,   8.5643723954515527E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,  -8.5643723954515527E-01,   3.2624404009190661E-01,   2.7615325973907841E-03],
            [   4.0010008875878122E-01,  -8.5643723954515527E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,   8.5643723954515527E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [  -4.0010008875878122E-01,  -8.5643723954515527E-01,  -3.2624404009190661E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,   8.5643723954515527E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,   8.5643723954515527E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,  -8.5643723954515527E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,   8.5643723954515527E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,  -8.5643723954515527E-01,   4.0010008875878122E-01,   2.7615325973907841E-03],
            [   3.2624404009190661E-01,  -8.5643723954515527E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,   8.5643723954515527E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [  -3.2624404009190661E-01,  -8.5643723954515527E-01,  -4.0010008875878122E-01,   2.7615325973907841E-03],
            [   4.3189563504360279E-01,   3.5788353506119158E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,   3.5788353506119158E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,  -3.5788353506119158E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,   3.5788353506119158E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,  -3.5788353506119158E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,  -3.5788353506119158E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,   3.5788353506119158E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,  -3.5788353506119158E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,   4.3189563504360279E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,   4.3189563504360279E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,  -4.3189563504360279E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,   4.3189563504360279E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,  -4.3189563504360279E-01,   8.2788014577134772E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,  -4.3189563504360279E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,   4.3189563504360279E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,  -4.3189563504360279E-01,  -8.2788014577134772E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,   4.3189563504360279E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,   4.3189563504360279E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,  -4.3189563504360279E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,   4.3189563504360279E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,  -4.3189563504360279E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,  -4.3189563504360279E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,   4.3189563504360279E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,  -4.3189563504360279E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,   3.5788353506119158E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,   3.5788353506119158E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,  -3.5788353506119158E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,   3.5788353506119158E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,  -3.5788353506119158E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   8.2788014577134772E-01,  -3.5788353506119158E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,   3.5788353506119158E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -8.2788014577134772E-01,  -3.5788353506119158E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,   8.2788014577134772E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,   8.2788014577134772E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,  -8.2788014577134772E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,   8.2788014577134772E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,  -8.2788014577134772E-01,   3.5788353506119158E-01,   2.8012860531115408E-03],
            [   4.3189563504360279E-01,  -8.2788014577134772E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,   8.2788014577134772E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [  -4.3189563504360279E-01,  -8.2788014577134772E-01,  -3.5788353506119158E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,   8.2788014577134772E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,   8.2788014577134772E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,  -8.2788014577134772E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,   8.2788014577134772E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,  -8.2788014577134772E-01,   4.3189563504360279E-01,   2.8012860531115408E-03],
            [   3.5788353506119158E-01,  -8.2788014577134772E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,   8.2788014577134772E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [  -3.5788353506119158E-01,  -8.2788014577134772E-01,  -4.3189563504360279E-01,   2.8012860531115408E-03],
            [   4.6282390567955312E-01,   3.8887518540436777E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,   3.8887518540436777E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,  -3.8887518540436777E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,   3.8887518540436777E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,  -3.8887518540436777E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,  -3.8887518540436777E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,   3.8887518540436777E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,  -3.8887518540436777E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,   4.6282390567955312E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,   4.6282390567955312E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,  -4.6282390567955312E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,   4.6282390567955312E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,  -4.6282390567955312E-01,   7.9659909773250603E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,  -4.6282390567955312E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,   4.6282390567955312E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,  -4.6282390567955312E-01,  -7.9659909773250603E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,   4.6282390567955312E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,   4.6282390567955312E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,  -4.6282390567955312E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,   4.6282390567955312E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,  -4.6282390567955312E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,  -4.6282390567955312E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,   4.6282390567955312E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,  -4.6282390567955312E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,   3.8887518540436777E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,   3.8887518540436777E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,  -3.8887518540436777E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,   3.8887518540436777E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,  -3.8887518540436777E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   7.9659909773250603E-01,  -3.8887518540436777E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,   3.8887518540436777E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -7.9659909773250603E-01,  -3.8887518540436777E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,   7.9659909773250603E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,   7.9659909773250603E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,  -7.9659909773250603E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,   7.9659909773250603E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,  -7.9659909773250603E-01,   3.8887518540436777E-01,   2.8316872431812319E-03],
            [   4.6282390567955312E-01,  -7.9659909773250603E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,   7.9659909773250603E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [  -4.6282390567955312E-01,  -7.9659909773250603E-01,  -3.8887518540436777E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,   7.9659909773250603E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,   7.9659909773250603E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,  -7.9659909773250603E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,   7.9659909773250603E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,  -7.9659909773250603E-01,   4.6282390567955312E-01,   2.8316872431812319E-03],
            [   3.8887518540436777E-01,  -7.9659909773250603E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,   7.9659909773250603E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [  -3.8887518540436777E-01,  -7.9659909773250603E-01,  -4.6282390567955312E-01,   2.8316872431812319E-03],
            [   4.9275632297736360E-01,   4.1906780032228402E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,   4.1906780032228402E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,  -4.1906780032228402E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,   4.1906780032228402E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,  -4.1906780032228402E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,  -4.1906780032228402E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,   4.1906780032228402E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,  -4.1906780032228402E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,   4.9275632297736360E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,   4.9275632297736360E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,  -4.9275632297736360E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,   4.9275632297736360E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,  -4.9275632297736360E-01,   7.6260958877978346E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,  -4.9275632297736360E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,   4.9275632297736360E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,  -4.9275632297736360E-01,  -7.6260958877978346E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,   4.9275632297736360E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,   4.9275632297736360E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,  -4.9275632297736360E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,   4.9275632297736360E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,  -4.9275632297736360E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,  -4.9275632297736360E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,   4.9275632297736360E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,  -4.9275632297736360E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,   4.1906780032228402E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,   4.1906780032228402E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,  -4.1906780032228402E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,   4.1906780032228402E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,  -4.1906780032228402E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   7.6260958877978346E-01,  -4.1906780032228402E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,   4.1906780032228402E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -7.6260958877978346E-01,  -4.1906780032228402E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,   7.6260958877978346E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,   7.6260958877978346E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,  -7.6260958877978346E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,   7.6260958877978346E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,  -7.6260958877978346E-01,   4.1906780032228402E-01,   2.8539950609481599E-03],
            [   4.9275632297736360E-01,  -7.6260958877978346E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,   7.6260958877978346E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [  -4.9275632297736360E-01,  -7.6260958877978346E-01,  -4.1906780032228402E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,   7.6260958877978346E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,   7.6260958877978346E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,  -7.6260958877978346E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,   7.6260958877978346E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,  -7.6260958877978346E-01,   4.9275632297736360E-01,   2.8539950609481599E-03],
            [   4.1906780032228402E-01,  -7.6260958877978346E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,   7.6260958877978346E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [  -4.1906780032228402E-01,  -7.6260958877978346E-01,  -4.9275632297736360E-01,   2.8539950609481599E-03],
            [   5.2156871367079694E-01,   4.4831518368838519E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,   4.4831518368838519E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,  -4.4831518368838519E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,   4.4831518368838519E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,  -4.4831518368838519E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,  -4.4831518368838519E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,   4.4831518368838519E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,  -4.4831518368838519E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,   5.2156871367079694E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,   5.2156871367079694E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,  -5.2156871367079694E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,   5.2156871367079694E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,  -5.2156871367079694E-01,   7.2593358717877199E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,  -5.2156871367079694E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,   5.2156871367079694E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,  -5.2156871367079694E-01,  -7.2593358717877199E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,   5.2156871367079694E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,   5.2156871367079694E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,  -5.2156871367079694E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,   5.2156871367079694E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,  -5.2156871367079694E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,  -5.2156871367079694E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,   5.2156871367079694E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,  -5.2156871367079694E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,   4.4831518368838519E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,   4.4831518368838519E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,  -4.4831518368838519E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,   4.4831518368838519E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,  -4.4831518368838519E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   7.2593358717877199E-01,  -4.4831518368838519E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,   4.4831518368838519E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -7.2593358717877199E-01,  -4.4831518368838519E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,   7.2593358717877199E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,   7.2593358717877199E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,  -7.2593358717877199E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,   7.2593358717877199E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,  -7.2593358717877199E-01,   4.4831518368838519E-01,   2.8694227757652389E-03],
            [   5.2156871367079694E-01,  -7.2593358717877199E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,   7.2593358717877199E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [  -5.2156871367079694E-01,  -7.2593358717877199E-01,  -4.4831518368838519E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,   7.2593358717877199E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,   7.2593358717877199E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,  -7.2593358717877199E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,   7.2593358717877199E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,  -7.2593358717877199E-01,   5.2156871367079694E-01,   2.8694227757652389E-03],
            [   4.4831518368838519E-01,  -7.2593358717877199E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,   7.2593358717877199E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [  -4.4831518368838519E-01,  -7.2593358717877199E-01,  -5.2156871367079694E-01,   2.8694227757652389E-03],
            [   5.4914023469849049E-01,   4.7647406760878802E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,   4.7647406760878802E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,  -4.7647406760878802E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,   4.7647406760878802E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,  -4.7647406760878802E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,  -4.7647406760878802E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,   4.7647406760878802E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,  -4.7647406760878802E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,   5.4914023469849049E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,   5.4914023469849049E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,  -5.4914023469849049E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,   5.4914023469849049E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,  -5.4914023469849049E-01,   6.8659847475189095E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,  -5.4914023469849049E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,   5.4914023469849049E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,  -5.4914023469849049E-01,  -6.8659847475189095E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,   5.4914023469849049E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,   5.4914023469849049E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,  -5.4914023469849049E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,   5.4914023469849049E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,  -5.4914023469849049E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,  -5.4914023469849049E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,   5.4914023469849049E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,  -5.4914023469849049E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,   4.7647406760878802E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,   4.7647406760878802E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,  -4.7647406760878802E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,   4.7647406760878802E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,  -4.7647406760878802E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   6.8659847475189095E-01,  -4.7647406760878802E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,   4.7647406760878802E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -6.8659847475189095E-01,  -4.7647406760878802E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,   6.8659847475189095E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,   6.8659847475189095E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,  -6.8659847475189095E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,   6.8659847475189095E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,  -6.8659847475189095E-01,   4.7647406760878802E-01,   2.8791586721967797E-03],
            [   5.4914023469849049E-01,  -6.8659847475189095E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,   6.8659847475189095E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [  -5.4914023469849049E-01,  -6.8659847475189095E-01,  -4.7647406760878802E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,   6.8659847475189095E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,   6.8659847475189095E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,  -6.8659847475189095E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,   6.8659847475189095E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,  -6.8659847475189095E-01,   5.4914023469849049E-01,   2.8791586721967797E-03],
            [   4.7647406760878802E-01,  -6.8659847475189095E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,   6.8659847475189095E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [  -4.7647406760878802E-01,  -6.8659847475189095E-01,  -5.4914023469849049E-01,   2.8791586721967797E-03],
            [   5.7535201601260755E-01,   5.0340213109982768E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,   5.0340213109982768E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,  -5.0340213109982768E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,   5.0340213109982768E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,  -5.0340213109982768E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,  -5.0340213109982768E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,   5.0340213109982768E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,  -5.0340213109982768E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,   5.7535201601260755E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,   5.7535201601260755E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,  -5.7535201601260755E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,   5.7535201601260755E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,  -5.7535201601260755E-01,   6.4463660466527972E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,  -5.7535201601260755E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,   5.7535201601260755E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,  -5.7535201601260755E-01,  -6.4463660466527972E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,   5.7535201601260755E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,   5.7535201601260755E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,  -5.7535201601260755E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,   5.7535201601260755E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,  -5.7535201601260755E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,  -5.7535201601260755E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,   5.7535201601260755E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,  -5.7535201601260755E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,   5.0340213109982768E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,   5.0340213109982768E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,  -5.0340213109982768E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,   5.0340213109982768E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,  -5.0340213109982768E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   6.4463660466527972E-01,  -5.0340213109982768E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,   5.0340213109982768E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -6.4463660466527972E-01,  -5.0340213109982768E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,   6.4463660466527972E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,   6.4463660466527972E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,  -6.4463660466527972E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,   6.4463660466527972E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,  -6.4463660466527972E-01,   5.0340213109982768E-01,   2.8843765251466858E-03],
            [   5.7535201601260755E-01,  -6.4463660466527972E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,   6.4463660466527972E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [  -5.7535201601260755E-01,  -6.4463660466527972E-01,  -5.0340213109982768E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,   6.4463660466527972E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,   6.4463660466527972E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,  -6.4463660466527972E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,   6.4463660466527972E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,  -6.4463660466527972E-01,   5.7535201601260755E-01,   2.8843765251466858E-03],
            [   5.0340213109982768E-01,  -6.4463660466527972E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,   6.4463660466527972E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [  -5.0340213109982768E-01,  -6.4463660466527972E-01,  -5.7535201601260755E-01,   2.8843765251466858E-03],
            [   1.3883263564177539E-01,   2.4354365103728060E-02,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,   2.4354365103728060E-02,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,  -2.4354365103728060E-02,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,   2.4354365103728060E-02,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,  -2.4354365103728060E-02,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,  -2.4354365103728060E-02,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,   2.4354365103728060E-02,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,  -2.4354365103728060E-02,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,   1.3883263564177539E-01,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,   1.3883263564177539E-01,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,  -1.3883263564177539E-01,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,   1.3883263564177539E-01,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,  -1.3883263564177539E-01,   9.9001634541110095E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,  -1.3883263564177539E-01,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,   1.3883263564177539E-01,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,  -1.3883263564177539E-01,  -9.9001634541110095E-01,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,   1.3883263564177539E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,   1.3883263564177539E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,  -1.3883263564177539E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,   1.3883263564177539E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,  -1.3883263564177539E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,  -1.3883263564177539E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,   1.3883263564177539E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,  -1.3883263564177539E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,   2.4354365103728060E-02,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,   2.4354365103728060E-02,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,  -2.4354365103728060E-02,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,   2.4354365103728060E-02,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,  -2.4354365103728060E-02,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   9.9001634541110095E-01,  -2.4354365103728060E-02,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,   2.4354365103728060E-02,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -9.9001634541110095E-01,  -2.4354365103728060E-02,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,   9.9001634541110095E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,   9.9001634541110095E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,  -9.9001634541110095E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,   9.9001634541110095E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,  -9.9001634541110095E-01,   2.4354365103728060E-02,   1.8073013547918748E-03],
            [   1.3883263564177539E-01,  -9.9001634541110095E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,   9.9001634541110095E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [  -1.3883263564177539E-01,  -9.9001634541110095E-01,  -2.4354365103728060E-02,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,   9.9001634541110095E-01,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,   9.9001634541110095E-01,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,  -9.9001634541110095E-01,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,   9.9001634541110095E-01,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,  -9.9001634541110095E-01,   1.3883263564177539E-01,   1.8073013547918748E-03],
            [   2.4354365103728060E-02,  -9.9001634541110095E-01,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,   9.9001634541110095E-01,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [  -2.4354365103728060E-02,  -9.9001634541110095E-01,  -1.3883263564177539E-01,   1.8073013547918748E-03],
            [   1.7436869005372441E-01,   5.1188970573426522E-02,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,   5.1188970573426522E-02,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,  -5.1188970573426522E-02,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,   5.1188970573426522E-02,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,  -5.1188970573426522E-02,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,  -5.1188970573426522E-02,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,   5.1188970573426522E-02,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,  -5.1188970573426522E-02,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,   1.7436869005372441E-01,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,   1.7436869005372441E-01,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,  -1.7436869005372441E-01,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,   1.7436869005372441E-01,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,  -1.7436869005372441E-01,   9.8334899665407760E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,  -1.7436869005372441E-01,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,   1.7436869005372441E-01,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,  -1.7436869005372441E-01,  -9.8334899665407760E-01,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,   1.7436869005372441E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,   1.7436869005372441E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,  -1.7436869005372441E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,   1.7436869005372441E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,  -1.7436869005372441E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,  -1.7436869005372441E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,   1.7436869005372441E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,  -1.7436869005372441E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,   5.1188970573426522E-02,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,   5.1188970573426522E-02,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,  -5.1188970573426522E-02,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,   5.1188970573426522E-02,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,  -5.1188970573426522E-02,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   9.8334899665407760E-01,  -5.1188970573426522E-02,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,   5.1188970573426522E-02,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -9.8334899665407760E-01,  -5.1188970573426522E-02,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,   9.8334899665407760E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,   9.8334899665407760E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,  -9.8334899665407760E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,   9.8334899665407760E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,  -9.8334899665407760E-01,   5.1188970573426522E-02,   2.0203431879171436E-03],
            [   1.7436869005372441E-01,  -9.8334899665407760E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,   9.8334899665407760E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [  -1.7436869005372441E-01,  -9.8334899665407760E-01,  -5.1188970573426522E-02,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,   9.8334899665407760E-01,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,   9.8334899665407760E-01,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,  -9.8334899665407760E-01,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,   9.8334899665407760E-01,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,  -9.8334899665407760E-01,   1.7436869005372441E-01,   2.0203431879171436E-03],
            [   5.1188970573426522E-02,  -9.8334899665407760E-01,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,   9.8334899665407760E-01,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [  -5.1188970573426522E-02,  -9.8334899665407760E-01,  -1.7436869005372441E-01,   2.0203431879171436E-03],
            [   2.0997370379502681E-01,   8.0146950485396343E-02,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,   8.0146950485396343E-02,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,  -8.0146950485396343E-02,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,   8.0146950485396343E-02,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,  -8.0146950485396343E-02,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,  -8.0146950485396343E-02,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,   8.0146950485396343E-02,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,  -8.0146950485396343E-02,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,   2.0997370379502681E-01,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,   2.0997370379502681E-01,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,  -2.0997370379502681E-01,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,   2.0997370379502681E-01,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,  -2.0997370379502681E-01,   9.7441649721384016E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,  -2.0997370379502681E-01,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,   2.0997370379502681E-01,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,  -2.0997370379502681E-01,  -9.7441649721384016E-01,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,   2.0997370379502681E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,   2.0997370379502681E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,  -2.0997370379502681E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,   2.0997370379502681E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,  -2.0997370379502681E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,  -2.0997370379502681E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,   2.0997370379502681E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,  -2.0997370379502681E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,   8.0146950485396343E-02,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,   8.0146950485396343E-02,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,  -8.0146950485396343E-02,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,   8.0146950485396343E-02,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,  -8.0146950485396343E-02,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   9.7441649721384016E-01,  -8.0146950485396343E-02,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,   8.0146950485396343E-02,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -9.7441649721384016E-01,  -8.0146950485396343E-02,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,   9.7441649721384016E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,   9.7441649721384016E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,  -9.7441649721384016E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,   9.7441649721384016E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,  -9.7441649721384016E-01,   8.0146950485396343E-02,   2.1884131522359996E-03],
            [   2.0997370379502681E-01,  -9.7441649721384016E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,   9.7441649721384016E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [  -2.0997370379502681E-01,  -9.7441649721384016E-01,  -8.0146950485396343E-02,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,   9.7441649721384016E-01,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,   9.7441649721384016E-01,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,  -9.7441649721384016E-01,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,   9.7441649721384016E-01,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,  -9.7441649721384016E-01,   2.0997370379502681E-01,   2.1884131522359996E-03],
            [   8.0146950485396343E-02,  -9.7441649721384016E-01,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,   9.7441649721384016E-01,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [  -8.0146950485396343E-02,  -9.7441649721384016E-01,  -2.0997370379502681E-01,   2.1884131522359996E-03],
            [   2.4544925909085480E-01,   1.1051178741556990E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,   1.1051178741556990E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,  -1.1051178741556990E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,   1.1051178741556990E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,  -1.1051178741556990E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,  -1.1051178741556990E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,   1.1051178741556990E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,  -1.1051178741556990E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,   2.4544925909085480E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,   2.4544925909085480E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,  -2.4544925909085480E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,   2.4544925909085480E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,  -2.4544925909085480E-01,   9.6308971859010428E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,  -2.4544925909085480E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,   2.4544925909085480E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,  -2.4544925909085480E-01,  -9.6308971859010428E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,   2.4544925909085480E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,   2.4544925909085480E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,  -2.4544925909085480E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,   2.4544925909085480E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,  -2.4544925909085480E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,  -2.4544925909085480E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,   2.4544925909085480E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,  -2.4544925909085480E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,   1.1051178741556990E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,   1.1051178741556990E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,  -1.1051178741556990E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,   1.1051178741556990E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,  -1.1051178741556990E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   9.6308971859010428E-01,  -1.1051178741556990E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,   1.1051178741556990E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -9.6308971859010428E-01,  -1.1051178741556990E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,   9.6308971859010428E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,   9.6308971859010428E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,  -9.6308971859010428E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,   9.6308971859010428E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,  -9.6308971859010428E-01,   1.1051178741556990E-01,   2.3271893810421730E-03],
            [   2.4544925909085480E-01,  -9.6308971859010428E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,   9.6308971859010428E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [  -2.4544925909085480E-01,  -9.6308971859010428E-01,  -1.1051178741556990E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,   9.6308971859010428E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,   9.6308971859010428E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,  -9.6308971859010428E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,   9.6308971859010428E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,  -9.6308971859010428E-01,   2.4544925909085480E-01,   2.3271893810421730E-03],
            [   1.1051178741556990E-01,  -9.6308971859010428E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,   9.6308971859010428E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [  -1.1051178741556990E-01,  -9.6308971859010428E-01,  -2.4544925909085480E-01,   2.3271893810421730E-03],
            [   2.8072192578642780E-01,   1.4179505315709659E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,   1.4179505315709659E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,  -1.4179505315709659E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,   1.4179505315709659E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,  -1.4179505315709659E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,  -1.4179505315709659E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,   1.4179505315709659E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,  -1.4179505315709659E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,   2.8072192578642780E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,   2.8072192578642780E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,  -2.8072192578642780E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,   2.8072192578642780E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,  -2.8072192578642780E-01,   9.4925726928106036E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,  -2.8072192578642780E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,   2.8072192578642780E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,  -2.8072192578642780E-01,  -9.4925726928106036E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,   2.8072192578642780E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,   2.8072192578642780E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,  -2.8072192578642780E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,   2.8072192578642780E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,  -2.8072192578642780E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,  -2.8072192578642780E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,   2.8072192578642780E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,  -2.8072192578642780E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,   1.4179505315709659E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,   1.4179505315709659E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,  -1.4179505315709659E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,   1.4179505315709659E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,  -1.4179505315709659E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   9.4925726928106036E-01,  -1.4179505315709659E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,   1.4179505315709659E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -9.4925726928106036E-01,  -1.4179505315709659E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,   9.4925726928106036E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,   9.4925726928106036E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,  -9.4925726928106036E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,   9.4925726928106036E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,  -9.4925726928106036E-01,   1.4179505315709659E-01,   2.4436924173291850E-03],
            [   2.8072192578642780E-01,  -9.4925726928106036E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,   9.4925726928106036E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [  -2.8072192578642780E-01,  -9.4925726928106036E-01,  -1.4179505315709659E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,   9.4925726928106036E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,   9.4925726928106036E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,  -9.4925726928106036E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,   9.4925726928106036E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,  -9.4925726928106036E-01,   2.8072192578642780E-01,   2.4436924173291850E-03],
            [   1.4179505315709659E-01,  -9.4925726928106036E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,   9.4925726928106036E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [  -1.4179505315709659E-01,  -9.4925726928106036E-01,  -2.8072192578642780E-01,   2.4436924173291850E-03],
            [   3.1568422719758421E-01,   1.7366049457195970E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,   1.7366049457195970E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,  -1.7366049457195970E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,   1.7366049457195970E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,  -1.7366049457195970E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,  -1.7366049457195970E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,   1.7366049457195970E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,  -1.7366049457195970E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,   3.1568422719758421E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,   3.1568422719758421E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,  -3.1568422719758421E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,   3.1568422719758421E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,  -3.1568422719758421E-01,   9.3283733915602152E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,  -3.1568422719758421E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,   3.1568422719758421E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,  -3.1568422719758421E-01,  -9.3283733915602152E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,   3.1568422719758421E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,   3.1568422719758421E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,  -3.1568422719758421E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,   3.1568422719758421E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,  -3.1568422719758421E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,  -3.1568422719758421E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,   3.1568422719758421E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,  -3.1568422719758421E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,   1.7366049457195970E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,   1.7366049457195970E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,  -1.7366049457195970E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,   1.7366049457195970E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,  -1.7366049457195970E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   9.3283733915602152E-01,  -1.7366049457195970E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,   1.7366049457195970E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -9.3283733915602152E-01,  -1.7366049457195970E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,   9.3283733915602152E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,   9.3283733915602152E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,  -9.3283733915602152E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,   9.3283733915602152E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,  -9.3283733915602152E-01,   1.7366049457195970E-01,   2.5415427343747311E-03],
            [   3.1568422719758421E-01,  -9.3283733915602152E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,   9.3283733915602152E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [  -3.1568422719758421E-01,  -9.3283733915602152E-01,  -1.7366049457195970E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,   9.3283733915602152E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,   9.3283733915602152E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,  -9.3283733915602152E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,   9.3283733915602152E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,  -9.3283733915602152E-01,   3.1568422719758421E-01,   2.5415427343747311E-03],
            [   1.7366049457195970E-01,  -9.3283733915602152E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,   9.3283733915602152E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [  -1.7366049457195970E-01,  -9.3283733915602152E-01,  -3.1568422719758421E-01,   2.5415427343747311E-03],
            [   3.5020909451777521E-01,   2.0584663246939811E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,   2.0584663246939811E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,  -2.0584663246939811E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,   2.0584663246939811E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,  -2.0584663246939811E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,  -2.0584663246939811E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,   2.0584663246939811E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,  -2.0584663246939811E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,   3.5020909451777521E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,   3.5020909451777521E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,  -3.5020909451777521E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,   3.5020909451777521E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,  -3.5020909451777521E-01,   9.1377281313138692E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,  -3.5020909451777521E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,   3.5020909451777521E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,  -3.5020909451777521E-01,  -9.1377281313138692E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,   3.5020909451777521E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,   3.5020909451777521E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,  -3.5020909451777521E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,   3.5020909451777521E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,  -3.5020909451777521E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,  -3.5020909451777521E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,   3.5020909451777521E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,  -3.5020909451777521E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,   2.0584663246939811E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,   2.0584663246939811E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,  -2.0584663246939811E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,   2.0584663246939811E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,  -2.0584663246939811E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   9.1377281313138692E-01,  -2.0584663246939811E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,   2.0584663246939811E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -9.1377281313138692E-01,  -2.0584663246939811E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,   9.1377281313138692E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,   9.1377281313138692E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,  -9.1377281313138692E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,   9.1377281313138692E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,  -9.1377281313138692E-01,   2.0584663246939811E-01,   2.6231825941255530E-03],
            [   3.5020909451777521E-01,  -9.1377281313138692E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,   9.1377281313138692E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [  -3.5020909451777521E-01,  -9.1377281313138692E-01,  -2.0584663246939811E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,   9.1377281313138692E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,   9.1377281313138692E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,  -9.1377281313138692E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,   9.1377281313138692E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,  -9.1377281313138692E-01,   3.5020909451777521E-01,   2.6231825941255530E-03],
            [   2.0584663246939811E-01,  -9.1377281313138692E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,   9.1377281313138692E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [  -2.0584663246939811E-01,  -9.1377281313138692E-01,  -3.5020909451777521E-01,   2.6231825941255530E-03],
            [   3.8416848495196859E-01,   2.3812842611959190E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,   2.3812842611959190E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,  -2.3812842611959190E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,   2.3812842611959190E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,  -2.3812842611959190E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,  -2.3812842611959190E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,   2.3812842611959190E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,  -2.3812842611959190E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,   3.8416848495196859E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,   3.8416848495196859E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,  -3.8416848495196859E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,   3.8416848495196859E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,  -3.8416848495196859E-01,   8.9202546367439262E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,  -3.8416848495196859E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,   3.8416848495196859E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,  -3.8416848495196859E-01,  -8.9202546367439262E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,   3.8416848495196859E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,   3.8416848495196859E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,  -3.8416848495196859E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,   3.8416848495196859E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,  -3.8416848495196859E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,  -3.8416848495196859E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,   3.8416848495196859E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,  -3.8416848495196859E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,   2.3812842611959190E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,   2.3812842611959190E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,  -2.3812842611959190E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,   2.3812842611959190E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,  -2.3812842611959190E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   8.9202546367439262E-01,  -2.3812842611959190E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,   2.3812842611959190E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -8.9202546367439262E-01,  -2.3812842611959190E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,   8.9202546367439262E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,   8.9202546367439262E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,  -8.9202546367439262E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,   8.9202546367439262E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,  -8.9202546367439262E-01,   2.3812842611959190E-01,   2.6905538882095056E-03],
            [   3.8416848495196859E-01,  -8.9202546367439262E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,   8.9202546367439262E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [  -3.8416848495196859E-01,  -8.9202546367439262E-01,  -2.3812842611959190E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,   8.9202546367439262E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,   8.9202546367439262E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,  -8.9202546367439262E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,   8.9202546367439262E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,  -8.9202546367439262E-01,   3.8416848495196859E-01,   2.6905538882095056E-03],
            [   2.3812842611959190E-01,  -8.9202546367439262E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,   8.9202546367439262E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [  -2.3812842611959190E-01,  -8.9202546367439262E-01,  -3.8416848495196859E-01,   2.6905538882095056E-03],
            [   4.1743723679060157E-01,   2.7030312704225690E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,   2.7030312704225690E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,  -2.7030312704225690E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,   2.7030312704225690E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,  -2.7030312704225690E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,  -2.7030312704225690E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,   2.7030312704225690E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,  -2.7030312704225690E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,   4.1743723679060157E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,   4.1743723679060157E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,  -4.1743723679060157E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,   4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,  -4.1743723679060157E-01,   8.6757269024088390E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,  -4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,   4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,  -4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,   4.1743723679060157E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,   4.1743723679060157E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,   4.1743723679060157E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,  -4.1743723679060157E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,   4.1743723679060157E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,  -4.1743723679060157E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,   2.7030312704225690E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,   2.7030312704225690E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,  -2.7030312704225690E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,   2.7030312704225690E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,  -2.7030312704225690E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   8.6757269024088390E-01,  -2.7030312704225690E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,   2.7030312704225690E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -8.6757269024088390E-01,  -2.7030312704225690E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,   8.6757269024088390E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,   8.6757269024088390E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,   8.6757269024088390E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,  -8.6757269024088390E-01,   2.7030312704225690E-01,   2.7453007381451674E-03],
            [   4.1743723679060157E-01,  -8.6757269024088390E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,   8.6757269024088390E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [  -4.1743723679060157E-01,  -8.6757269024088390E-01,  -2.7030312704225690E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,   8.6757269024088390E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,   8.6757269024088390E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,  -8.6757269024088390E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,   8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,  -8.6757269024088390E-01,   4.1743723679060157E-01,   2.7453007381451674E-03],
            [   2.7030312704225690E-01,  -8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,   8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [  -2.7030312704225690E-01,  -8.6757269024088390E-01,  -4.1743723679060157E-01,   2.7453007381451674E-03],
            [   4.4989264650118921E-01,   3.0218456830913087E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,   3.0218456830913087E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,  -3.0218456830913087E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,   3.0218456830913087E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,  -3.0218456830913087E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,  -3.0218456830913087E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,   3.0218456830913087E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,  -3.0218456830913087E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,   4.4989264650118921E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,   4.4989264650118921E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,  -4.4989264650118921E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,   4.4989264650118921E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,  -4.4989264650118921E-01,   8.4040531489274883E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,  -4.4989264650118921E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,   4.4989264650118921E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,  -4.4989264650118921E-01,  -8.4040531489274883E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,   4.4989264650118921E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,   4.4989264650118921E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,  -4.4989264650118921E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,   4.4989264650118921E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,  -4.4989264650118921E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,  -4.4989264650118921E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,   4.4989264650118921E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,  -4.4989264650118921E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,   3.0218456830913087E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,   3.0218456830913087E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,  -3.0218456830913087E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,   3.0218456830913087E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,  -3.0218456830913087E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   8.4040531489274883E-01,  -3.0218456830913087E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,   3.0218456830913087E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -8.4040531489274883E-01,  -3.0218456830913087E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,   8.4040531489274883E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,   8.4040531489274883E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,  -8.4040531489274883E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,   8.4040531489274883E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,  -8.4040531489274883E-01,   3.0218456830913087E-01,   2.7888661478002725E-03],
            [   4.4989264650118921E-01,  -8.4040531489274883E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,   8.4040531489274883E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [  -4.4989264650118921E-01,  -8.4040531489274883E-01,  -3.0218456830913087E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,   8.4040531489274883E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,   8.4040531489274883E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,  -8.4040531489274883E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,   8.4040531489274883E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,  -8.4040531489274883E-01,   4.4989264650118921E-01,   2.7888661478002725E-03],
            [   3.0218456830913087E-01,  -8.4040531489274883E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,   8.4040531489274883E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [  -3.0218456830913087E-01,  -8.4040531489274883E-01,  -4.4989264650118921E-01,   2.7888661478002725E-03],
            [   4.8141462298077009E-01,   3.3359933551657200E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,   3.3359933551657200E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,  -3.3359933551657200E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,   3.3359933551657200E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,  -3.3359933551657200E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,  -3.3359933551657200E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,   3.3359933551657200E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,  -3.3359933551657200E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,   4.8141462298077009E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,   4.8141462298077009E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,  -4.8141462298077009E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,   4.8141462298077009E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,  -4.8141462298077009E-01,   8.1052541238580833E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,  -4.8141462298077009E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,   4.8141462298077009E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,  -4.8141462298077009E-01,  -8.1052541238580833E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,   4.8141462298077009E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,   4.8141462298077009E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,  -4.8141462298077009E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,   4.8141462298077009E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,  -4.8141462298077009E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,  -4.8141462298077009E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,   4.8141462298077009E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,  -4.8141462298077009E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,   3.3359933551657200E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,   3.3359933551657200E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,  -3.3359933551657200E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,   3.3359933551657200E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,  -3.3359933551657200E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   8.1052541238580833E-01,  -3.3359933551657200E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,   3.3359933551657200E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -8.1052541238580833E-01,  -3.3359933551657200E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,   8.1052541238580833E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,   8.1052541238580833E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,  -8.1052541238580833E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,   8.1052541238580833E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,  -8.1052541238580833E-01,   3.3359933551657200E-01,   2.8225615550548410E-03],
            [   4.8141462298077009E-01,  -8.1052541238580833E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,   8.1052541238580833E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [  -4.8141462298077009E-01,  -8.1052541238580833E-01,  -3.3359933551657200E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,   8.1052541238580833E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,   8.1052541238580833E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,  -8.1052541238580833E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,   8.1052541238580833E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,  -8.1052541238580833E-01,   4.8141462298077009E-01,   2.8225615550548410E-03],
            [   3.3359933551657200E-01,  -8.1052541238580833E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,   8.1052541238580833E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [  -3.3359933551657200E-01,  -8.1052541238580833E-01,  -4.8141462298077009E-01,   2.8225615550548410E-03],
            [   5.1188636257347009E-01,   3.6438337355182321E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,   3.6438337355182321E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,  -3.6438337355182321E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,   3.6438337355182321E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,  -3.6438337355182321E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,  -3.6438337355182321E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,   3.6438337355182321E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,  -3.6438337355182321E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,   5.1188636257347009E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,   5.1188636257347009E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,  -5.1188636257347009E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,   5.1188636257347009E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,  -5.1188636257347009E-01,   7.7794415538025252E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,  -5.1188636257347009E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,   5.1188636257347009E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,  -5.1188636257347009E-01,  -7.7794415538025252E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,   5.1188636257347009E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,   5.1188636257347009E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,  -5.1188636257347009E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,   5.1188636257347009E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,  -5.1188636257347009E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,  -5.1188636257347009E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,   5.1188636257347009E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,  -5.1188636257347009E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,   3.6438337355182321E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,   3.6438337355182321E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,  -3.6438337355182321E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,   3.6438337355182321E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,  -3.6438337355182321E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   7.7794415538025252E-01,  -3.6438337355182321E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,   3.6438337355182321E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -7.7794415538025252E-01,  -3.6438337355182321E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,   7.7794415538025252E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,   7.7794415538025252E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,  -7.7794415538025252E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,   7.7794415538025252E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,  -7.7794415538025252E-01,   3.6438337355182321E-01,   2.8476184564455664E-03],
            [   5.1188636257347009E-01,  -7.7794415538025252E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,   7.7794415538025252E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [  -5.1188636257347009E-01,  -7.7794415538025252E-01,  -3.6438337355182321E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,   7.7794415538025252E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,   7.7794415538025252E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,  -7.7794415538025252E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,   7.7794415538025252E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,  -7.7794415538025252E-01,   5.1188636257347009E-01,   2.8476184564455664E-03],
            [   3.6438337355182321E-01,  -7.7794415538025252E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,   7.7794415538025252E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [  -3.6438337355182321E-01,  -7.7794415538025252E-01,  -5.1188636257347009E-01,   2.8476184564455664E-03],
            [   5.4119474551191438E-01,   3.9437895419581792E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,   3.9437895419581792E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,  -3.9437895419581792E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,   3.9437895419581792E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,  -3.9437895419581792E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,  -3.9437895419581792E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,   3.9437895419581792E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,  -3.9437895419581792E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,   5.4119474551191438E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,   5.4119474551191438E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,  -5.4119474551191438E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,   5.4119474551191438E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,  -5.4119474551191438E-01,   7.4267993639097807E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,  -5.4119474551191438E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,   5.4119474551191438E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,  -5.4119474551191438E-01,  -7.4267993639097807E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,   5.4119474551191438E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,   5.4119474551191438E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,  -5.4119474551191438E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,   5.4119474551191438E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,  -5.4119474551191438E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,  -5.4119474551191438E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,   5.4119474551191438E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,  -5.4119474551191438E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,   3.9437895419581792E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,   3.9437895419581792E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,  -3.9437895419581792E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,   3.9437895419581792E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,  -3.9437895419581792E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   7.4267993639097807E-01,  -3.9437895419581792E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,   3.9437895419581792E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -7.4267993639097807E-01,  -3.9437895419581792E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,   7.4267993639097807E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,   7.4267993639097807E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,  -7.4267993639097807E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,   7.4267993639097807E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,  -7.4267993639097807E-01,   3.9437895419581792E-01,   2.8652241745508243E-03],
            [   5.4119474551191438E-01,  -7.4267993639097807E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,   7.4267993639097807E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [  -5.4119474551191438E-01,  -7.4267993639097807E-01,  -3.9437895419581792E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,   7.4267993639097807E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,   7.4267993639097807E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,  -7.4267993639097807E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,   7.4267993639097807E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,  -7.4267993639097807E-01,   5.4119474551191438E-01,   2.8652241745508243E-03],
            [   3.9437895419581792E-01,  -7.4267993639097807E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,   7.4267993639097807E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [  -3.9437895419581792E-01,  -7.4267993639097807E-01,  -5.4119474551191438E-01,   2.8652241745508243E-03],
            [   5.6923015003572464E-01,   4.2343201444035422E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,   4.2343201444035422E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,  -4.2343201444035422E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,   4.2343201444035422E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,  -4.2343201444035422E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,  -4.2343201444035422E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,   4.2343201444035422E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,  -4.2343201444035422E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,   5.6923015003572464E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,   5.6923015003572464E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,  -5.6923015003572464E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,   5.6923015003572464E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,  -5.6923015003572464E-01,   7.0475695486975509E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,  -5.6923015003572464E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,   5.6923015003572464E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,  -5.6923015003572464E-01,  -7.0475695486975509E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,   5.6923015003572464E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,   5.6923015003572464E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,  -5.6923015003572464E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,   5.6923015003572464E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,  -5.6923015003572464E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,  -5.6923015003572464E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,   5.6923015003572464E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,  -5.6923015003572464E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,   4.2343201444035422E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,   4.2343201444035422E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,  -4.2343201444035422E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,   4.2343201444035422E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,  -4.2343201444035422E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   7.0475695486975509E-01,  -4.2343201444035422E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,   4.2343201444035422E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -7.0475695486975509E-01,  -4.2343201444035422E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,   7.0475695486975509E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,   7.0475695486975509E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,  -7.0475695486975509E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,   7.0475695486975509E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,  -7.0475695486975509E-01,   4.2343201444035422E-01,   2.8765453095363522E-03],
            [   5.6923015003572464E-01,  -7.0475695486975509E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,   7.0475695486975509E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [  -5.6923015003572464E-01,  -7.0475695486975509E-01,  -4.2343201444035422E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,   7.0475695486975509E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,   7.0475695486975509E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,  -7.0475695486975509E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,   7.0475695486975509E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,  -7.0475695486975509E-01,   5.6923015003572464E-01,   2.8765453095363522E-03],
            [   4.2343201444035422E-01,  -7.0475695486975509E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,   7.0475695486975509E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [  -4.2343201444035422E-01,  -7.0475695486975509E-01,  -5.6923015003572464E-01,   2.8765453095363522E-03],
            [   5.9588572041395760E-01,   4.5138979474192598E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,   4.5138979474192598E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,  -4.5138979474192598E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,   4.5138979474192598E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,  -4.5138979474192598E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,  -4.5138979474192598E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,   4.5138979474192598E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,  -4.5138979474192598E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,   5.9588572041395760E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,   5.9588572041395760E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,  -5.9588572041395760E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,   5.9588572041395760E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,  -5.9588572041395760E-01,   6.6420438225713374E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,  -5.9588572041395760E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,   5.9588572041395760E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,  -5.9588572041395760E-01,  -6.6420438225713374E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,   5.9588572041395760E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,   5.9588572041395760E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,  -5.9588572041395760E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,   5.9588572041395760E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,  -5.9588572041395760E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,  -5.9588572041395760E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,   5.9588572041395760E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,  -5.9588572041395760E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,   4.5138979474192598E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,   4.5138979474192598E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,  -4.5138979474192598E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,   4.5138979474192598E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,  -4.5138979474192598E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   6.6420438225713374E-01,  -4.5138979474192598E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,   4.5138979474192598E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -6.6420438225713374E-01,  -4.5138979474192598E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,   6.6420438225713374E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,   6.6420438225713374E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,  -6.6420438225713374E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,   6.6420438225713374E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,  -6.6420438225713374E-01,   4.5138979474192598E-01,   2.8827413720923173E-03],
            [   5.9588572041395760E-01,  -6.6420438225713374E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,   6.6420438225713374E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [  -5.9588572041395760E-01,  -6.6420438225713374E-01,  -4.5138979474192598E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,   6.6420438225713374E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,   6.6420438225713374E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,  -6.6420438225713374E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,   6.6420438225713374E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,  -6.6420438225713374E-01,   5.9588572041395760E-01,   2.8827413720923173E-03],
            [   4.5138979474192598E-01,  -6.6420438225713374E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,   6.6420438225713374E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [  -4.5138979474192598E-01,  -6.6420438225713374E-01,  -5.9588572041395760E-01,   2.8827413720923173E-03],
            [   2.1562702847857659E-01,   2.6812257554444909E-02,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,   2.6812257554444909E-02,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,  -2.6812257554444909E-02,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,   2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,  -2.6812257554444909E-02,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,  -2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,   2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,  -2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,   2.1562702847857659E-01,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,   2.1562702847857659E-01,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,  -2.1562702847857659E-01,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,   2.1562702847857659E-01,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,  -2.1562702847857659E-01,   9.7610762082586633E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,  -2.1562702847857659E-01,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,   2.1562702847857659E-01,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,  -2.1562702847857659E-01,  -9.7610762082586633E-01,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,   2.1562702847857659E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,   2.1562702847857659E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,  -2.1562702847857659E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,   2.1562702847857659E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,  -2.1562702847857659E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,  -2.1562702847857659E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,   2.1562702847857659E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,  -2.1562702847857659E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,   2.6812257554444909E-02,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,   2.6812257554444909E-02,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,   2.6812257554444909E-02,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   9.7610762082586633E-01,  -2.6812257554444909E-02,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,   2.6812257554444909E-02,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -9.7610762082586633E-01,  -2.6812257554444909E-02,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,   9.7610762082586633E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,   9.7610762082586633E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,  -9.7610762082586633E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,   9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,  -9.7610762082586633E-01,   2.6812257554444909E-02,   2.1644750144422737E-03],
            [   2.1562702847857659E-01,  -9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,   9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [  -2.1562702847857659E-01,  -9.7610762082586633E-01,  -2.6812257554444909E-02,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,   9.7610762082586633E-01,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,   9.7610762082586633E-01,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,   9.7610762082586633E-01,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,  -9.7610762082586633E-01,   2.1562702847857659E-01,   2.1644750144422737E-03],
            [   2.6812257554444909E-02,  -9.7610762082586633E-01,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,   9.7610762082586633E-01,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [  -2.6812257554444909E-02,  -9.7610762082586633E-01,  -2.1562702847857659E-01,   2.1644750144422737E-03],
            [   2.5323850549097099E-01,   5.5574957478056138E-02,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,   5.5574957478056138E-02,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,  -5.5574957478056138E-02,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,   5.5574957478056138E-02,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,  -5.5574957478056138E-02,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,  -5.5574957478056138E-02,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,   5.5574957478056138E-02,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,  -5.5574957478056138E-02,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,   2.5323850549097099E-01,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,   2.5323850549097099E-01,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,  -2.5323850549097099E-01,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,   2.5323850549097099E-01,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,  -2.5323850549097099E-01,   9.6580623493432249E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,  -2.5323850549097099E-01,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,   2.5323850549097099E-01,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,  -2.5323850549097099E-01,  -9.6580623493432249E-01,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,   2.5323850549097099E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,   2.5323850549097099E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,  -2.5323850549097099E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,   2.5323850549097099E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,  -2.5323850549097099E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,  -2.5323850549097099E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,   2.5323850549097099E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,  -2.5323850549097099E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,   5.5574957478056138E-02,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,   5.5574957478056138E-02,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,  -5.5574957478056138E-02,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,   5.5574957478056138E-02,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,  -5.5574957478056138E-02,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   9.6580623493432249E-01,  -5.5574957478056138E-02,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,   5.5574957478056138E-02,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -9.6580623493432249E-01,  -5.5574957478056138E-02,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,   9.6580623493432249E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,   9.6580623493432249E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,  -9.6580623493432249E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,   9.6580623493432249E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,  -9.6580623493432249E-01,   5.5574957478056138E-02,   2.2999441750273758E-03],
            [   2.5323850549097099E-01,  -9.6580623493432249E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,   9.6580623493432249E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [  -2.5323850549097099E-01,  -9.6580623493432249E-01,  -5.5574957478056138E-02,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,   9.6580623493432249E-01,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,   9.6580623493432249E-01,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,  -9.6580623493432249E-01,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,   9.6580623493432249E-01,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,  -9.6580623493432249E-01,   2.5323850549097099E-01,   2.2999441750273758E-03],
            [   5.5574957478056138E-02,  -9.6580623493432249E-01,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,   9.6580623493432249E-01,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [  -5.5574957478056138E-02,  -9.6580623493432249E-01,  -2.5323850549097099E-01,   2.2999441750273758E-03],
            [   2.9025646177715370E-01,   8.5693680629502486E-02,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,   8.5693680629502486E-02,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,  -8.5693680629502486E-02,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,   8.5693680629502486E-02,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,  -8.5693680629502486E-02,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,  -8.5693680629502486E-02,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,   8.5693680629502486E-02,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,  -8.5693680629502486E-02,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,   2.9025646177715370E-01,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,   2.9025646177715370E-01,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,  -2.9025646177715370E-01,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,   2.9025646177715370E-01,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,  -2.9025646177715370E-01,   9.5310428574043071E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,  -2.9025646177715370E-01,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,   2.9025646177715370E-01,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,  -2.9025646177715370E-01,  -9.5310428574043071E-01,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,   2.9025646177715370E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,   2.9025646177715370E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,  -2.9025646177715370E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,   2.9025646177715370E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,  -2.9025646177715370E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,  -2.9025646177715370E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,   2.9025646177715370E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,  -2.9025646177715370E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,   8.5693680629502486E-02,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,   8.5693680629502486E-02,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,  -8.5693680629502486E-02,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,   8.5693680629502486E-02,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,  -8.5693680629502486E-02,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   9.5310428574043071E-01,  -8.5693680629502486E-02,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,   8.5693680629502486E-02,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -9.5310428574043071E-01,  -8.5693680629502486E-02,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,   9.5310428574043071E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,   9.5310428574043071E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,  -9.5310428574043071E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,   9.5310428574043071E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,  -9.5310428574043071E-01,   8.5693680629502486E-02,   2.4175879336487934E-03],
            [   2.9025646177715370E-01,  -9.5310428574043071E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,   9.5310428574043071E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [  -2.9025646177715370E-01,  -9.5310428574043071E-01,  -8.5693680629502486E-02,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,   9.5310428574043071E-01,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,   9.5310428574043071E-01,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,  -9.5310428574043071E-01,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,   9.5310428574043071E-01,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,  -9.5310428574043071E-01,   2.9025646177715370E-01,   2.4175879336487934E-03],
            [   8.5693680629502486E-02,  -9.5310428574043071E-01,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,   9.5310428574043071E-01,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [  -8.5693680629502486E-02,  -9.5310428574043071E-01,  -2.9025646177715370E-01,   2.4175879336487934E-03],
            [   3.2669798231432562E-01,   1.1673674503241351E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,   1.1673674503241351E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,  -1.1673674503241351E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,   1.1673674503241351E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,  -1.1673674503241351E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,  -1.1673674503241351E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,   1.1673674503241351E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,  -1.1673674503241351E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,   3.2669798231432562E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,   3.2669798231432562E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,  -3.2669798231432562E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,   3.2669798231432562E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,  -3.2669798231432562E-01,   9.3789176385710193E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,  -3.2669798231432562E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,   3.2669798231432562E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,  -3.2669798231432562E-01,  -9.3789176385710193E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,   3.2669798231432562E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,   3.2669798231432562E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,  -3.2669798231432562E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,   3.2669798231432562E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,  -3.2669798231432562E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,  -3.2669798231432562E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,   3.2669798231432562E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,  -3.2669798231432562E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,   1.1673674503241351E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,   1.1673674503241351E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,  -1.1673674503241351E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,   1.1673674503241351E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,  -1.1673674503241351E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   9.3789176385710193E-01,  -1.1673674503241351E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,   1.1673674503241351E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -9.3789176385710193E-01,  -1.1673674503241351E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,   9.3789176385710193E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,   9.3789176385710193E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,  -9.3789176385710193E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,   9.3789176385710193E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,  -9.3789176385710193E-01,   1.1673674503241351E-01,   2.5183859489417574E-03],
            [   3.2669798231432562E-01,  -9.3789176385710193E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,   9.3789176385710193E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [  -3.2669798231432562E-01,  -9.3789176385710193E-01,  -1.1673674503241351E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,   9.3789176385710193E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,   9.3789176385710193E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,  -9.3789176385710193E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,   9.3789176385710193E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,  -9.3789176385710193E-01,   3.2669798231432562E-01,   2.5183859489417574E-03],
            [   1.1673674503241351E-01,  -9.3789176385710193E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,   9.3789176385710193E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [  -1.1673674503241351E-01,  -9.3789176385710193E-01,  -3.2669798231432562E-01,   2.5183859489417574E-03],
            [   3.6250396274936142E-01,   1.4838619940033040E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,   1.4838619940033040E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,  -1.4838619940033040E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,   1.4838619940033040E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,  -1.4838619940033040E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,  -1.4838619940033040E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,   1.4838619940033040E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,  -1.4838619940033040E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,   3.6250396274936142E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,   3.6250396274936142E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,  -3.6250396274936142E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,   3.6250396274936142E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,  -3.6250396274936142E-01,   9.2009369784741757E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,  -3.6250396274936142E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,   3.6250396274936142E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,  -3.6250396274936142E-01,  -9.2009369784741757E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,   3.6250396274936142E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,   3.6250396274936142E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,  -3.6250396274936142E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,   3.6250396274936142E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,  -3.6250396274936142E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,  -3.6250396274936142E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,   3.6250396274936142E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,  -3.6250396274936142E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,   1.4838619940033040E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,   1.4838619940033040E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,  -1.4838619940033040E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,   1.4838619940033040E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,  -1.4838619940033040E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   9.2009369784741757E-01,  -1.4838619940033040E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,   1.4838619940033040E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -9.2009369784741757E-01,  -1.4838619940033040E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,   9.2009369784741757E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,   9.2009369784741757E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,  -9.2009369784741757E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,   9.2009369784741757E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,  -9.2009369784741757E-01,   1.4838619940033040E-01,   2.6035224003793651E-03],
            [   3.6250396274936142E-01,  -9.2009369784741757E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,   9.2009369784741757E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [  -3.6250396274936142E-01,  -9.2009369784741757E-01,  -1.4838619940033040E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,   9.2009369784741757E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,   9.2009369784741757E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,  -9.2009369784741757E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,   9.2009369784741757E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,  -9.2009369784741757E-01,   3.6250396274936142E-01,   2.6035224003793651E-03],
            [   1.4838619940033040E-01,  -9.2009369784741757E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,   9.2009369784741757E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [  -1.4838619940033040E-01,  -9.2009369784741757E-01,  -3.6250396274936142E-01,   2.6035224003793651E-03],
            [   3.9758389375486991E-01,   1.8038215030114049E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,   1.8038215030114049E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,  -1.8038215030114049E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,   1.8038215030114049E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,  -1.8038215030114049E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,  -1.8038215030114049E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,   1.8038215030114049E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,  -1.8038215030114049E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,   3.9758389375486991E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,   3.9758389375486991E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,  -3.9758389375486991E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,   3.9758389375486991E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,  -3.9758389375486991E-01,   8.9966067340939893E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,  -3.9758389375486991E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,   3.9758389375486991E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,  -3.9758389375486991E-01,  -8.9966067340939893E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,   3.9758389375486991E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,   3.9758389375486991E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,  -3.9758389375486991E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,   3.9758389375486991E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,  -3.9758389375486991E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,  -3.9758389375486991E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,   3.9758389375486991E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,  -3.9758389375486991E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,   1.8038215030114049E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,   1.8038215030114049E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,  -1.8038215030114049E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,   1.8038215030114049E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,  -1.8038215030114049E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   8.9966067340939893E-01,  -1.8038215030114049E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,   1.8038215030114049E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -8.9966067340939893E-01,  -1.8038215030114049E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,   8.9966067340939893E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,   8.9966067340939893E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,  -8.9966067340939893E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,   8.9966067340939893E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,  -8.9966067340939893E-01,   1.8038215030114049E-01,   2.6744388741646065E-03],
            [   3.9758389375486991E-01,  -8.9966067340939893E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,   8.9966067340939893E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [  -3.9758389375486991E-01,  -8.9966067340939893E-01,  -1.8038215030114049E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,   8.9966067340939893E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,   8.9966067340939893E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,  -8.9966067340939893E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,   8.9966067340939893E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,  -8.9966067340939893E-01,   3.9758389375486991E-01,   2.6744388741646065E-03],
            [   1.8038215030114049E-01,  -8.9966067340939893E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,   8.9966067340939893E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [  -1.8038215030114049E-01,  -8.9966067340939893E-01,  -3.9758389375486991E-01,   2.6744388741646065E-03],
            [   4.3183960990097742E-01,   2.1249629656664240E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,   2.1249629656664240E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,  -2.1249629656664240E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,   2.1249629656664240E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,  -2.1249629656664240E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,  -2.1249629656664240E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,   2.1249629656664240E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,  -2.1249629656664240E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,   4.3183960990097742E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,   4.3183960990097742E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,  -4.3183960990097742E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,   4.3183960990097742E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,  -4.3183960990097742E-01,   8.7656139275354428E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,  -4.3183960990097742E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,   4.3183960990097742E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,  -4.3183960990097742E-01,  -8.7656139275354428E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,   4.3183960990097742E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,   4.3183960990097742E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,  -4.3183960990097742E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,   4.3183960990097742E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,  -4.3183960990097742E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,  -4.3183960990097742E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,   4.3183960990097742E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,  -4.3183960990097742E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,   2.1249629656664240E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,   2.1249629656664240E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,  -2.1249629656664240E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,   2.1249629656664240E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,  -2.1249629656664240E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   8.7656139275354428E-01,  -2.1249629656664240E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,   2.1249629656664240E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -8.7656139275354428E-01,  -2.1249629656664240E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,   8.7656139275354428E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,   8.7656139275354428E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,  -8.7656139275354428E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,   8.7656139275354428E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,  -8.7656139275354428E-01,   2.1249629656664240E-01,   2.7325745304492962E-03],
            [   4.3183960990097742E-01,  -8.7656139275354428E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,   8.7656139275354428E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [  -4.3183960990097742E-01,  -8.7656139275354428E-01,  -2.1249629656664240E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,   8.7656139275354428E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,   8.7656139275354428E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,  -8.7656139275354428E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,   8.7656139275354428E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,  -8.7656139275354428E-01,   4.3183960990097742E-01,   2.7325745304492962E-03],
            [   2.1249629656664240E-01,  -8.7656139275354428E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,   8.7656139275354428E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [  -2.1249629656664240E-01,  -8.7656139275354428E-01,  -4.3183960990097742E-01,   2.7325745304492962E-03],
            [   4.6517065557327419E-01,   2.4452218378059129E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,   2.4452218378059129E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,  -2.4452218378059129E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,   2.4452218378059129E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,  -2.4452218378059129E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,  -2.4452218378059129E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,   2.4452218378059129E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,  -2.4452218378059129E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,   4.6517065557327419E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,   4.6517065557327419E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,  -4.6517065557327419E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,   4.6517065557327419E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,  -4.6517065557327419E-01,   8.5077915044546137E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,  -4.6517065557327419E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,   4.6517065557327419E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,  -4.6517065557327419E-01,  -8.5077915044546137E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,   4.6517065557327419E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,   4.6517065557327419E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,  -4.6517065557327419E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,   4.6517065557327419E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,  -4.6517065557327419E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,  -4.6517065557327419E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,   4.6517065557327419E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,  -4.6517065557327419E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,   2.4452218378059129E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,   2.4452218378059129E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,  -2.4452218378059129E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,   2.4452218378059129E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,  -2.4452218378059129E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   8.5077915044546137E-01,  -2.4452218378059129E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,   2.4452218378059129E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -8.5077915044546137E-01,  -2.4452218378059129E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,   8.5077915044546137E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,   8.5077915044546137E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,  -8.5077915044546137E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,   8.5077915044546137E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,  -8.5077915044546137E-01,   2.4452218378059129E-01,   2.7792562344396816E-03],
            [   4.6517065557327419E-01,  -8.5077915044546137E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,   8.5077915044546137E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [  -4.6517065557327419E-01,  -8.5077915044546137E-01,  -2.4452218378059129E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,   8.5077915044546137E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,   8.5077915044546137E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,  -8.5077915044546137E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,   8.5077915044546137E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,  -8.5077915044546137E-01,   4.6517065557327419E-01,   2.7792562344396816E-03],
            [   2.4452218378059129E-01,  -8.5077915044546137E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,   8.5077915044546137E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [  -2.4452218378059129E-01,  -8.5077915044546137E-01,  -4.6517065557327419E-01,   2.7792562344396816E-03],
            [   4.9747526496209687E-01,   2.7627012243229870E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,   2.7627012243229870E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,  -2.7627012243229870E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,   2.7627012243229870E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,  -2.7627012243229870E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,  -2.7627012243229870E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,   2.7627012243229870E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,  -2.7627012243229870E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,   4.9747526496209687E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,   4.9747526496209687E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,  -4.9747526496209687E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,   4.9747526496209687E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,  -4.9747526496209687E-01,   8.2230966199001587E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,  -4.9747526496209687E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,   4.9747526496209687E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,  -4.9747526496209687E-01,  -8.2230966199001587E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,   4.9747526496209687E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,   4.9747526496209687E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,  -4.9747526496209687E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,   4.9747526496209687E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,  -4.9747526496209687E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,  -4.9747526496209687E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,   4.9747526496209687E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,  -4.9747526496209687E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,   2.7627012243229870E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,   2.7627012243229870E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,  -2.7627012243229870E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,   2.7627012243229870E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,  -2.7627012243229870E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   8.2230966199001587E-01,  -2.7627012243229870E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,   2.7627012243229870E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -8.2230966199001587E-01,  -2.7627012243229870E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,   8.2230966199001587E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,   8.2230966199001587E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,  -8.2230966199001587E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,   8.2230966199001587E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,  -8.2230966199001587E-01,   2.7627012243229870E-01,   2.8157030052398083E-03],
            [   4.9747526496209687E-01,  -8.2230966199001587E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,   8.2230966199001587E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [  -4.9747526496209687E-01,  -8.2230966199001587E-01,  -2.7627012243229870E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,   8.2230966199001587E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,   8.2230966199001587E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,  -8.2230966199001587E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,   8.2230966199001587E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,  -8.2230966199001587E-01,   4.9747526496209687E-01,   2.8157030052398083E-03],
            [   2.7627012243229870E-01,  -8.2230966199001587E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,   8.2230966199001587E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [  -2.7627012243229870E-01,  -8.2230966199001587E-01,  -4.9747526496209687E-01,   2.8157030052398083E-03],
            [   5.2865175796275166E-01,   3.0756277752113281E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,   3.0756277752113281E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,  -3.0756277752113281E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,   3.0756277752113281E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,  -3.0756277752113281E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,  -3.0756277752113281E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,   3.0756277752113281E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,  -3.0756277752113281E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,   5.2865175796275166E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,   5.2865175796275166E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,  -5.2865175796275166E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,   5.2865175796275166E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,  -5.2865175796275166E-01,   7.9115893263387882E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,  -5.2865175796275166E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,   5.2865175796275166E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,  -5.2865175796275166E-01,  -7.9115893263387882E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,   5.2865175796275166E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,   5.2865175796275166E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,  -5.2865175796275166E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,   5.2865175796275166E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,  -5.2865175796275166E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,  -5.2865175796275166E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,   5.2865175796275166E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,  -5.2865175796275166E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,   3.0756277752113281E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,   3.0756277752113281E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,  -3.0756277752113281E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,   3.0756277752113281E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,  -3.0756277752113281E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   7.9115893263387882E-01,  -3.0756277752113281E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,   3.0756277752113281E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -7.9115893263387882E-01,  -3.0756277752113281E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,   7.9115893263387882E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,   7.9115893263387882E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,  -7.9115893263387882E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,   7.9115893263387882E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,  -7.9115893263387882E-01,   3.0756277752113281E-01,   2.8430653458577128E-03],
            [   5.2865175796275166E-01,  -7.9115893263387882E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,   7.9115893263387882E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [  -5.2865175796275166E-01,  -7.9115893263387882E-01,  -3.0756277752113281E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,   7.9115893263387882E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,   7.9115893263387882E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,  -7.9115893263387882E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,   7.9115893263387882E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,  -7.9115893263387882E-01,   5.2865175796275166E-01,   2.8430653458577128E-03],
            [   3.0756277752113281E-01,  -7.9115893263387882E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,   7.9115893263387882E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [  -3.0756277752113281E-01,  -7.9115893263387882E-01,  -5.2865175796275166E-01,   2.8430653458577128E-03],
            [   5.5860011957318945E-01,   3.3823110898268771E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,   3.3823110898268771E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,  -3.3823110898268771E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,   3.3823110898268771E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,  -3.3823110898268771E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,  -3.3823110898268771E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,   3.3823110898268771E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,  -3.3823110898268771E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,   5.5860011957318945E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,   5.5860011957318945E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,  -5.5860011957318945E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,   5.5860011957318945E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,  -5.5860011957318945E-01,   7.5734115385944778E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,  -5.5860011957318945E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,   5.5860011957318945E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,  -5.5860011957318945E-01,  -7.5734115385944778E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,   5.5860011957318945E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,   5.5860011957318945E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,  -5.5860011957318945E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,   5.5860011957318945E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,  -5.5860011957318945E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,  -5.5860011957318945E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,   5.5860011957318945E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,  -5.5860011957318945E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,   3.3823110898268771E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,   3.3823110898268771E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,  -3.3823110898268771E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,   3.3823110898268771E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,  -3.3823110898268771E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   7.5734115385944778E-01,  -3.3823110898268771E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,   3.3823110898268771E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -7.5734115385944778E-01,  -3.3823110898268771E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,   7.5734115385944778E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,   7.5734115385944778E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,  -7.5734115385944778E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,   7.5734115385944778E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,  -7.5734115385944778E-01,   3.3823110898268771E-01,   2.8624615899194971E-03],
            [   5.5860011957318945E-01,  -7.5734115385944778E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,   7.5734115385944778E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [  -5.5860011957318945E-01,  -7.5734115385944778E-01,  -3.3823110898268771E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,   7.5734115385944778E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,   7.5734115385944778E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,  -7.5734115385944778E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,   7.5734115385944778E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,  -7.5734115385944778E-01,   5.5860011957318945E-01,   2.8624615899194971E-03],
            [   3.3823110898268771E-01,  -7.5734115385944778E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,   7.5734115385944778E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [  -3.3823110898268771E-01,  -7.5734115385944778E-01,  -5.5860011957318945E-01,   2.8624615899194971E-03],
            [   5.8722299020213187E-01,   3.6811088347413989E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,   3.6811088347413989E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,  -3.6811088347413989E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,   3.6811088347413989E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,  -3.6811088347413989E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,  -3.6811088347413989E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,   3.6811088347413989E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,  -3.6811088347413989E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,   5.8722299020213187E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,   5.8722299020213187E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,  -5.8722299020213187E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,   5.8722299020213187E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,  -5.8722299020213187E-01,   7.2087692239796042E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,  -5.8722299020213187E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,   5.8722299020213187E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,  -5.8722299020213187E-01,  -7.2087692239796042E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,   5.8722299020213187E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,   5.8722299020213187E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,  -5.8722299020213187E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,   5.8722299020213187E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,  -5.8722299020213187E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,  -5.8722299020213187E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,   5.8722299020213187E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,  -5.8722299020213187E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,   3.6811088347413989E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,   3.6811088347413989E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,  -3.6811088347413989E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,   3.6811088347413989E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,  -3.6811088347413989E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   7.2087692239796042E-01,  -3.6811088347413989E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,   3.6811088347413989E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -7.2087692239796042E-01,  -3.6811088347413989E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,   7.2087692239796042E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,   7.2087692239796042E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,  -7.2087692239796042E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,   7.2087692239796042E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,  -7.2087692239796042E-01,   3.6811088347413989E-01,   2.8750025227102087E-03],
            [   5.8722299020213187E-01,  -7.2087692239796042E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,   7.2087692239796042E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [  -5.8722299020213187E-01,  -7.2087692239796042E-01,  -3.6811088347413989E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,   7.2087692239796042E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,   7.2087692239796042E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,  -7.2087692239796042E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,   7.2087692239796042E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,  -7.2087692239796042E-01,   5.8722299020213187E-01,   2.8750025227102087E-03],
            [   3.6811088347413989E-01,  -7.2087692239796042E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,   7.2087692239796042E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [  -3.6811088347413989E-01,  -7.2087692239796042E-01,  -5.8722299020213187E-01,   2.8750025227102087E-03],
            [   6.1442586162351231E-01,   3.9703974468728392E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,   3.9703974468728392E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,  -3.9703974468728392E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,   3.9703974468728392E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,  -3.9703974468728392E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,  -3.9703974468728392E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,   3.9703974468728392E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,  -3.9703974468728392E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,   6.1442586162351231E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,   6.1442586162351231E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,  -6.1442586162351231E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,   6.1442586162351231E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,  -6.1442586162351231E-01,   6.8179197832393201E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,  -6.1442586162351231E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,   6.1442586162351231E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,  -6.1442586162351231E-01,  -6.8179197832393201E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,   6.1442586162351231E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,   6.1442586162351231E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,  -6.1442586162351231E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,   6.1442586162351231E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,  -6.1442586162351231E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,  -6.1442586162351231E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,   6.1442586162351231E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,  -6.1442586162351231E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,   3.9703974468728392E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,   3.9703974468728392E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,  -3.9703974468728392E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,   3.9703974468728392E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,  -3.9703974468728392E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   6.8179197832393201E-01,  -3.9703974468728392E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,   3.9703974468728392E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -6.8179197832393201E-01,  -3.9703974468728392E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,   6.8179197832393201E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,   6.8179197832393201E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,  -6.8179197832393201E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,   6.8179197832393201E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,  -6.8179197832393201E-01,   3.9703974468728392E-01,   2.8818061884404713E-03],
            [   6.1442586162351231E-01,  -6.8179197832393201E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,   6.8179197832393201E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [  -6.1442586162351231E-01,  -6.8179197832393201E-01,  -3.9703974468728392E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,   6.8179197832393201E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,   6.8179197832393201E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,  -6.8179197832393201E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,   6.8179197832393201E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,  -6.8179197832393201E-01,   6.1442586162351231E-01,   2.8818061884404713E-03],
            [   3.9703974468728392E-01,  -6.8179197832393201E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,   6.8179197832393201E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [  -3.9703974468728392E-01,  -6.8179197832393201E-01,  -6.1442586162351231E-01,   2.8818061884404713E-03],
            [   2.9516765080648610E-01,   2.8674995387504409E-02,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,   2.8674995387504409E-02,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,  -2.8674995387504409E-02,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,   2.8674995387504409E-02,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,  -2.8674995387504409E-02,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,  -2.8674995387504409E-02,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,   2.8674995387504409E-02,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,  -2.8674995387504409E-02,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,   2.9516765080648610E-01,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,   2.9516765080648610E-01,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,  -2.9516765080648610E-01,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,   2.9516765080648610E-01,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,  -2.9516765080648610E-01,   9.5501507975366906E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,  -2.9516765080648610E-01,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,   2.9516765080648610E-01,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,  -2.9516765080648610E-01,  -9.5501507975366906E-01,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,   2.9516765080648610E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,   2.9516765080648610E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,  -2.9516765080648610E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,   2.9516765080648610E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,  -2.9516765080648610E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,  -2.9516765080648610E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,   2.9516765080648610E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,  -2.9516765080648610E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,   2.8674995387504409E-02,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,   2.8674995387504409E-02,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,  -2.8674995387504409E-02,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,   2.8674995387504409E-02,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,  -2.8674995387504409E-02,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   9.5501507975366906E-01,  -2.8674995387504409E-02,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,   2.8674995387504409E-02,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -9.5501507975366906E-01,  -2.8674995387504409E-02,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,   9.5501507975366906E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,   9.5501507975366906E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,  -9.5501507975366906E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,   9.5501507975366906E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,  -9.5501507975366906E-01,   2.8674995387504409E-02,   2.4034794827899066E-03],
            [   2.9516765080648610E-01,  -9.5501507975366906E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,   9.5501507975366906E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [  -2.9516765080648610E-01,  -9.5501507975366906E-01,  -2.8674995387504409E-02,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,   9.5501507975366906E-01,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,   9.5501507975366906E-01,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,  -9.5501507975366906E-01,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,   9.5501507975366906E-01,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,  -9.5501507975366906E-01,   2.9516765080648610E-01,   2.4034794827899066E-03],
            [   2.8674995387504409E-02,  -9.5501507975366906E-01,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,   9.5501507975366906E-01,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [  -2.8674995387504409E-02,  -9.5501507975366906E-01,  -2.9516765080648610E-01,   2.4034794827899066E-03],
            [   3.3350854854727252E-01,   5.8678793419035098E-02,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,   5.8678793419035098E-02,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,  -5.8678793419035098E-02,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,   5.8678793419035098E-02,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,  -5.8678793419035098E-02,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,  -5.8678793419035098E-02,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,   5.8678793419035098E-02,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,  -5.8678793419035098E-02,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,   3.3350854854727252E-01,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,   3.3350854854727252E-01,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,  -3.3350854854727252E-01,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,   3.3350854854727252E-01,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,  -3.3350854854727252E-01,   9.4091915021896422E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,  -3.3350854854727252E-01,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,   3.3350854854727252E-01,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,  -3.3350854854727252E-01,  -9.4091915021896422E-01,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,   3.3350854854727252E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,   3.3350854854727252E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,  -3.3350854854727252E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,   3.3350854854727252E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,  -3.3350854854727252E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,  -3.3350854854727252E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,   3.3350854854727252E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,  -3.3350854854727252E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,   5.8678793419035098E-02,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,   5.8678793419035098E-02,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,  -5.8678793419035098E-02,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,   5.8678793419035098E-02,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,  -5.8678793419035098E-02,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   9.4091915021896422E-01,  -5.8678793419035098E-02,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,   5.8678793419035098E-02,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -9.4091915021896422E-01,  -5.8678793419035098E-02,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,   9.4091915021896422E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,   9.4091915021896422E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,  -9.4091915021896422E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,   9.4091915021896422E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,  -9.4091915021896422E-01,   5.8678793419035098E-02,   2.5038489330340692E-03],
            [   3.3350854854727252E-01,  -9.4091915021896422E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,   9.4091915021896422E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [  -3.3350854854727252E-01,  -9.4091915021896422E-01,  -5.8678793419035098E-02,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,   9.4091915021896422E-01,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,   9.4091915021896422E-01,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,  -9.4091915021896422E-01,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,   9.4091915021896422E-01,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,  -9.4091915021896422E-01,   3.3350854854727252E-01,   2.5038489330340692E-03],
            [   5.8678793419035098E-02,  -9.4091915021896422E-01,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,   9.4091915021896422E-01,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [  -5.8678793419035098E-02,  -9.4091915021896422E-01,  -3.3350854854727252E-01,   2.5038489330340692E-03],
            [   3.7095617606363812E-01,   8.9610992050222840E-02,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,   8.9610992050222840E-02,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,  -8.9610992050222840E-02,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,   8.9610992050222840E-02,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,  -8.9610992050222840E-02,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,  -8.9610992050222840E-02,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,   8.9610992050222840E-02,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,  -8.9610992050222840E-02,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,   3.7095617606363812E-01,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,   3.7095617606363812E-01,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,  -3.7095617606363812E-01,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,   3.7095617606363812E-01,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,  -3.7095617606363812E-01,   9.2431671279059857E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,  -3.7095617606363812E-01,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,   3.7095617606363812E-01,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,  -3.7095617606363812E-01,  -9.2431671279059857E-01,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,   3.7095617606363812E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,   3.7095617606363812E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,  -3.7095617606363812E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,   3.7095617606363812E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,  -3.7095617606363812E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,  -3.7095617606363812E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,   3.7095617606363812E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,  -3.7095617606363812E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,   8.9610992050222840E-02,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,   8.9610992050222840E-02,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,  -8.9610992050222840E-02,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,   8.9610992050222840E-02,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,  -8.9610992050222840E-02,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   9.2431671279059857E-01,  -8.9610992050222840E-02,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,   8.9610992050222840E-02,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -9.2431671279059857E-01,  -8.9610992050222840E-02,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,   9.2431671279059857E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,   9.2431671279059857E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,  -9.2431671279059857E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,   9.2431671279059857E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,  -9.2431671279059857E-01,   8.9610992050222840E-02,   2.5902752291694212E-03],
            [   3.7095617606363812E-01,  -9.2431671279059857E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,   9.2431671279059857E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [  -3.7095617606363812E-01,  -9.2431671279059857E-01,  -8.9610992050222840E-02,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,   9.2431671279059857E-01,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,   9.2431671279059857E-01,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,  -9.2431671279059857E-01,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,   9.2431671279059857E-01,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,  -9.2431671279059857E-01,   3.7095617606363812E-01,   2.5902752291694212E-03],
            [   8.9610992050222840E-02,  -9.2431671279059857E-01,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,   9.2431671279059857E-01,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [  -8.9610992050222840E-02,  -9.2431671279059857E-01,  -3.7095617606363812E-01,   2.5902752291694212E-03],
            [   4.0747228616674980E-01,   1.2116279276262970E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,   1.2116279276262970E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,  -1.2116279276262970E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,   1.2116279276262970E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,  -1.2116279276262970E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,  -1.2116279276262970E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,   1.2116279276262970E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,  -1.2116279276262970E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,   4.0747228616674980E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,   4.0747228616674980E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,  -4.0747228616674980E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,   4.0747228616674980E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,  -4.0747228616674980E-01,   9.0514413971256658E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,  -4.0747228616674980E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,   4.0747228616674980E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,  -4.0747228616674980E-01,  -9.0514413971256658E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,   4.0747228616674980E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,   4.0747228616674980E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,  -4.0747228616674980E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,   4.0747228616674980E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,  -4.0747228616674980E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,  -4.0747228616674980E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,   4.0747228616674980E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,  -4.0747228616674980E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,   1.2116279276262970E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,   1.2116279276262970E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,  -1.2116279276262970E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,   1.2116279276262970E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,  -1.2116279276262970E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   9.0514413971256658E-01,  -1.2116279276262970E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,   1.2116279276262970E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -9.0514413971256658E-01,  -1.2116279276262970E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,   9.0514413971256658E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,   9.0514413971256658E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,  -9.0514413971256658E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,   9.0514413971256658E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,  -9.0514413971256658E-01,   1.2116279276262970E-01,   2.6632138151623571E-03],
            [   4.0747228616674980E-01,  -9.0514413971256658E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,   9.0514413971256658E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [  -4.0747228616674980E-01,  -9.0514413971256658E-01,  -1.2116279276262970E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,   9.0514413971256658E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,   9.0514413971256658E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,  -9.0514413971256658E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,   9.0514413971256658E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,  -9.0514413971256658E-01,   4.0747228616674980E-01,   2.6632138151623571E-03],
            [   1.2116279276262970E-01,  -9.0514413971256658E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,   9.0514413971256658E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [  -1.2116279276262970E-01,  -9.0514413971256658E-01,  -4.0747228616674980E-01,   2.6632138151623571E-03],
            [   4.4299236488391169E-01,   1.5307489035548980E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,   1.5307489035548980E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,  -1.5307489035548980E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,   1.5307489035548980E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,  -1.5307489035548980E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,  -1.5307489035548980E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,   1.5307489035548980E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,  -1.5307489035548980E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,   4.4299236488391169E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,   4.4299236488391169E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,  -4.4299236488391169E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,   4.4299236488391169E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,  -4.4299236488391169E-01,   8.8336053941593640E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,  -4.4299236488391169E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,   4.4299236488391169E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,  -4.4299236488391169E-01,  -8.8336053941593640E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,   4.4299236488391169E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,   4.4299236488391169E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,  -4.4299236488391169E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,   4.4299236488391169E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,  -4.4299236488391169E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,  -4.4299236488391169E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,   4.4299236488391169E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,  -4.4299236488391169E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,   1.5307489035548980E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,   1.5307489035548980E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,  -1.5307489035548980E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,   1.5307489035548980E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,  -1.5307489035548980E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   8.8336053941593640E-01,  -1.5307489035548980E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,   1.5307489035548980E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -8.8336053941593640E-01,  -1.5307489035548980E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,   8.8336053941593640E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,   8.8336053941593640E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,  -8.8336053941593640E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,   8.8336053941593640E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,  -8.8336053941593640E-01,   1.5307489035548980E-01,   2.7236560043644958E-03],
            [   4.4299236488391169E-01,  -8.8336053941593640E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,   8.8336053941593640E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [  -4.4299236488391169E-01,  -8.8336053941593640E-01,  -1.5307489035548980E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,   8.8336053941593640E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,   8.8336053941593640E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,  -8.8336053941593640E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,   8.8336053941593640E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,  -8.8336053941593640E-01,   4.4299236488391169E-01,   2.7236560043644958E-03],
            [   1.5307489035548980E-01,  -8.8336053941593640E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,   8.8336053941593640E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [  -1.5307489035548980E-01,  -8.8336053941593640E-01,  -4.4299236488391169E-01,   2.7236560043644958E-03],
            [   4.7744280527217359E-01,   1.8511764367218769E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,   1.8511764367218769E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,  -1.8511764367218769E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,   1.8511764367218769E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,  -1.8511764367218769E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,  -1.8511764367218769E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,   1.8511764367218769E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,  -1.8511764367218769E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,   4.7744280527217359E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,   4.7744280527217359E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,  -4.7744280527217359E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,   4.7744280527217359E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,  -4.7744280527217359E-01,   8.5894110723325745E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,  -4.7744280527217359E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,   4.7744280527217359E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,  -4.7744280527217359E-01,  -8.5894110723325745E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,   4.7744280527217359E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,   4.7744280527217359E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,  -4.7744280527217359E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,   4.7744280527217359E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,  -4.7744280527217359E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,  -4.7744280527217359E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,   4.7744280527217359E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,  -4.7744280527217359E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,   1.8511764367218769E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,   1.8511764367218769E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,  -1.8511764367218769E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,   1.8511764367218769E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,  -1.8511764367218769E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   8.5894110723325745E-01,  -1.8511764367218769E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,   1.8511764367218769E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -8.5894110723325745E-01,  -1.8511764367218769E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,   8.5894110723325745E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,   8.5894110723325745E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,  -8.5894110723325745E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,   8.5894110723325745E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,  -8.5894110723325745E-01,   1.8511764367218769E-01,   2.7726826294582848E-03],
            [   4.7744280527217359E-01,  -8.5894110723325745E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,   8.5894110723325745E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [  -4.7744280527217359E-01,  -8.5894110723325745E-01,  -1.8511764367218769E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,   8.5894110723325745E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,   8.5894110723325745E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,  -8.5894110723325745E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,   8.5894110723325745E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,  -8.5894110723325745E-01,   4.7744280527217359E-01,   2.7726826294582848E-03],
            [   1.8511764367218769E-01,  -8.5894110723325745E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,   8.5894110723325745E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [  -1.8511764367218769E-01,  -8.5894110723325745E-01,  -4.7744280527217359E-01,   2.7726826294582848E-03],
            [   5.1074465395359037E-01,   2.1708291076581790E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,   2.1708291076581790E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,  -2.1708291076581790E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,   2.1708291076581790E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,  -2.1708291076581790E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,  -2.1708291076581790E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,   2.1708291076581790E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,  -2.1708291076581790E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,   5.1074465395359037E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,   5.1074465395359037E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,  -5.1074465395359037E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,   5.1074465395359037E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,  -5.1074465395359037E-01,   8.3187433444677639E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,  -5.1074465395359037E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,   5.1074465395359037E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,  -5.1074465395359037E-01,  -8.3187433444677639E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,   5.1074465395359037E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,   5.1074465395359037E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,  -5.1074465395359037E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,   5.1074465395359037E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,  -5.1074465395359037E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,  -5.1074465395359037E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,   5.1074465395359037E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,  -5.1074465395359037E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,   2.1708291076581790E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,   2.1708291076581790E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,  -2.1708291076581790E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,   2.1708291076581790E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,  -2.1708291076581790E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   8.3187433444677639E-01,  -2.1708291076581790E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,   2.1708291076581790E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -8.3187433444677639E-01,  -2.1708291076581790E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,   8.3187433444677639E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,   8.3187433444677639E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,  -8.3187433444677639E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,   8.3187433444677639E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,  -8.3187433444677639E-01,   2.1708291076581790E-01,   2.8113320205301840E-03],
            [   5.1074465395359037E-01,  -8.3187433444677639E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,   8.3187433444677639E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [  -5.1074465395359037E-01,  -8.3187433444677639E-01,  -2.1708291076581790E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,   8.3187433444677639E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,   8.3187433444677639E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,  -8.3187433444677639E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,   8.3187433444677639E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,  -8.3187433444677639E-01,   5.1074465395359037E-01,   2.8113320205301840E-03],
            [   2.1708291076581790E-01,  -8.3187433444677639E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,   8.3187433444677639E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [  -2.1708291076581790E-01,  -8.3187433444677639E-01,  -5.1074465395359037E-01,   2.8113320205301840E-03],
            [   5.4281513705429352E-01,   2.4877866890262709E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,   2.4877866890262709E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,  -2.4877866890262709E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,   2.4877866890262709E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,  -2.4877866890262709E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,  -2.4877866890262709E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,   2.4877866890262709E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,  -2.4877866890262709E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,   5.4281513705429352E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,   5.4281513705429352E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,  -5.4281513705429352E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,   5.4281513705429352E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,  -5.4281513705429352E-01,   8.0216014665636781E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,  -5.4281513705429352E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,   5.4281513705429352E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,  -5.4281513705429352E-01,  -8.0216014665636781E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,   5.4281513705429352E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,   5.4281513705429352E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,  -5.4281513705429352E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,   5.4281513705429352E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,  -5.4281513705429352E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,  -5.4281513705429352E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,   5.4281513705429352E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,  -5.4281513705429352E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,   2.4877866890262709E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,   2.4877866890262709E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,  -2.4877866890262709E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,   2.4877866890262709E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,  -2.4877866890262709E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   8.0216014665636781E-01,  -2.4877866890262709E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,   2.4877866890262709E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -8.0216014665636781E-01,  -2.4877866890262709E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,   8.0216014665636781E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,   8.0216014665636781E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,  -8.0216014665636781E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,   8.0216014665636781E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,  -8.0216014665636781E-01,   2.4877866890262709E-01,   2.8406030389237650E-03],
            [   5.4281513705429352E-01,  -8.0216014665636781E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,   8.0216014665636781E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [  -5.4281513705429352E-01,  -8.0216014665636781E-01,  -2.4877866890262709E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,   8.0216014665636781E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,   8.0216014665636781E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,  -8.0216014665636781E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,   8.0216014665636781E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,  -8.0216014665636781E-01,   5.4281513705429352E-01,   2.8406030389237650E-03],
            [   2.4877866890262709E-01,  -8.0216014665636781E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,   8.0216014665636781E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [  -2.4877866890262709E-01,  -8.0216014665636781E-01,  -5.4281513705429352E-01,   2.8406030389237650E-03],
            [   5.7356992925569639E-01,   2.8002399527950161E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,   2.8002399527950161E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,  -2.8002399527950161E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,   2.8002399527950161E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,  -2.8002399527950161E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,  -2.8002399527950161E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,   2.8002399527950161E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,  -2.8002399527950161E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,   5.7356992925569639E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,   5.7356992925569639E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,  -5.7356992925569639E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,   5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,  -5.7356992925569639E-01,   7.6980783207325265E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,  -5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,   5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,  -5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,   5.7356992925569639E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,   5.7356992925569639E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,   5.7356992925569639E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,  -5.7356992925569639E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,   5.7356992925569639E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,  -5.7356992925569639E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,   2.8002399527950161E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,   2.8002399527950161E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,  -2.8002399527950161E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,   2.8002399527950161E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,  -2.8002399527950161E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   7.6980783207325265E-01,  -2.8002399527950161E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,   2.8002399527950161E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -7.6980783207325265E-01,  -2.8002399527950161E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,   7.6980783207325265E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,   7.6980783207325265E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,   7.6980783207325265E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,  -7.6980783207325265E-01,   2.8002399527950161E-01,   2.8614868508906512E-03],
            [   5.7356992925569639E-01,  -7.6980783207325265E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,   7.6980783207325265E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [  -5.7356992925569639E-01,  -7.6980783207325265E-01,  -2.8002399527950161E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,   7.6980783207325265E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,   7.6980783207325265E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,  -7.6980783207325265E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,   7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,  -7.6980783207325265E-01,   5.7356992925569639E-01,   2.8614868508906512E-03],
            [   2.8002399527950161E-01,  -7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,   7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [  -2.8002399527950161E-01,  -7.6980783207325265E-01,  -5.7356992925569639E-01,   2.8614868508906512E-03],
            [   6.0292537945628655E-01,   3.1064457028781189E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,   3.1064457028781189E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,  -3.1064457028781189E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,   3.1064457028781189E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,  -3.1064457028781189E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,  -3.1064457028781189E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,   3.1064457028781189E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,  -3.1064457028781189E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,   6.0292537945628655E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,   6.0292537945628655E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,  -6.0292537945628655E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,   6.0292537945628655E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,  -6.0292537945628655E-01,   7.3483395250777139E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,  -6.0292537945628655E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,   6.0292537945628655E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,  -6.0292537945628655E-01,  -7.3483395250777139E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,   6.0292537945628655E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,   6.0292537945628655E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,  -6.0292537945628655E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,   6.0292537945628655E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,  -6.0292537945628655E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,  -6.0292537945628655E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,   6.0292537945628655E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,  -6.0292537945628655E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,   3.1064457028781189E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,   3.1064457028781189E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,  -3.1064457028781189E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,   3.1064457028781189E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,  -3.1064457028781189E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   7.3483395250777139E-01,  -3.1064457028781189E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,   3.1064457028781189E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -7.3483395250777139E-01,  -3.1064457028781189E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,   7.3483395250777139E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,   7.3483395250777139E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,  -7.3483395250777139E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,   7.3483395250777139E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,  -7.3483395250777139E-01,   3.1064457028781189E-01,   2.8749917164541715E-03],
            [   6.0292537945628655E-01,  -7.3483395250777139E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,   7.3483395250777139E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [  -6.0292537945628655E-01,  -7.3483395250777139E-01,  -3.1064457028781189E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,   7.3483395250777139E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,   7.3483395250777139E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,  -7.3483395250777139E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,   7.3483395250777139E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,  -7.3483395250777139E-01,   6.0292537945628655E-01,   2.8749917164541715E-03],
            [   3.1064457028781189E-01,  -7.3483395250777139E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,   7.3483395250777139E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [  -3.1064457028781189E-01,  -7.3483395250777139E-01,  -6.0292537945628655E-01,   2.8749917164541715E-03],
            [   6.3079989870731445E-01,   3.4046895008411943E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,   3.4046895008411943E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,  -3.4046895008411943E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,   3.4046895008411943E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,  -3.4046895008411943E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,  -3.4046895008411943E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,   3.4046895008411943E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,  -3.4046895008411943E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,   6.3079989870731445E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,   6.3079989870731445E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,  -6.3079989870731445E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,   6.3079989870731445E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,  -6.3079989870731445E-01,   6.9726062689604040E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,  -6.3079989870731445E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,   6.3079989870731445E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,  -6.3079989870731445E-01,  -6.9726062689604040E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,   6.3079989870731445E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,   6.3079989870731445E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,  -6.3079989870731445E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,   6.3079989870731445E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,  -6.3079989870731445E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,  -6.3079989870731445E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,   6.3079989870731445E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,  -6.3079989870731445E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,   3.4046895008411943E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,   3.4046895008411943E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,  -3.4046895008411943E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,   3.4046895008411943E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,  -3.4046895008411943E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   6.9726062689604040E-01,  -3.4046895008411943E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,   3.4046895008411943E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -6.9726062689604040E-01,  -3.4046895008411943E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,   6.9726062689604040E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,   6.9726062689604040E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,  -6.9726062689604040E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,   6.9726062689604040E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,  -6.9726062689604040E-01,   3.4046895008411943E-01,   2.8821564994208322E-03],
            [   6.3079989870731445E-01,  -6.9726062689604040E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,   6.9726062689604040E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [  -6.3079989870731445E-01,  -6.9726062689604040E-01,  -3.4046895008411943E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,   6.9726062689604040E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,   6.9726062689604040E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,  -6.9726062689604040E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,   6.9726062689604040E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,  -6.9726062689604040E-01,   6.3079989870731445E-01,   2.8821564994208322E-03],
            [   3.4046895008411943E-01,  -6.9726062689604040E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,   6.9726062689604040E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [  -3.4046895008411943E-01,  -6.9726062689604040E-01,  -6.3079989870731445E-01,   2.8821564994208322E-03],
            [   3.7526522736927193E-01,   2.9971450981844790E-02,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,   2.9971450981844790E-02,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,  -2.9971450981844790E-02,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,   2.9971450981844790E-02,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,  -2.9971450981844790E-02,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,  -2.9971450981844790E-02,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,   2.9971450981844790E-02,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,  -2.9971450981844790E-02,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,   3.7526522736927193E-01,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,   3.7526522736927193E-01,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,  -3.7526522736927193E-01,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,   3.7526522736927193E-01,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,  -3.7526522736927193E-01,   9.2643279370579901E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,  -3.7526522736927193E-01,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,   3.7526522736927193E-01,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,  -3.7526522736927193E-01,  -9.2643279370579901E-01,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,   3.7526522736927193E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,   3.7526522736927193E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,  -3.7526522736927193E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,   3.7526522736927193E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,  -3.7526522736927193E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,  -3.7526522736927193E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,   3.7526522736927193E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,  -3.7526522736927193E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,   2.9971450981844790E-02,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,   2.9971450981844790E-02,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,  -2.9971450981844790E-02,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,   2.9971450981844790E-02,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,  -2.9971450981844790E-02,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   9.2643279370579901E-01,  -2.9971450981844790E-02,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,   2.9971450981844790E-02,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -9.2643279370579901E-01,  -2.9971450981844790E-02,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,   9.2643279370579901E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,   9.2643279370579901E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,  -9.2643279370579901E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,   9.2643279370579901E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,  -9.2643279370579901E-01,   2.9971450981844790E-02,   2.5837385882075438E-03],
            [   3.7526522736927193E-01,  -9.2643279370579901E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,   9.2643279370579901E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [  -3.7526522736927193E-01,  -9.2643279370579901E-01,  -2.9971450981844790E-02,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,   9.2643279370579901E-01,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,   9.2643279370579901E-01,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,  -9.2643279370579901E-01,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,   9.2643279370579901E-01,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,  -9.2643279370579901E-01,   3.7526522736927193E-01,   2.5837385882075438E-03],
            [   2.9971450981844790E-02,  -9.2643279370579901E-01,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,   9.2643279370579901E-01,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [  -2.9971450981844790E-02,  -9.2643279370579901E-01,  -3.7526522736927193E-01,   2.5837385882075438E-03],
            [   4.1353838793440278E-01,   6.0867258986780109E-02,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,   6.0867258986780109E-02,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,  -6.0867258986780109E-02,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,   6.0867258986780109E-02,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,  -6.0867258986780109E-02,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,  -6.0867258986780109E-02,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,   6.0867258986780109E-02,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,  -6.0867258986780109E-02,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,   4.1353838793440278E-01,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,   4.1353838793440278E-01,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,  -4.1353838793440278E-01,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,   4.1353838793440278E-01,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,  -4.1353838793440278E-01,   9.0844987670649813E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,  -4.1353838793440278E-01,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,   4.1353838793440278E-01,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,  -4.1353838793440278E-01,  -9.0844987670649813E-01,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,   4.1353838793440278E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,   4.1353838793440278E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,  -4.1353838793440278E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,   4.1353838793440278E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,  -4.1353838793440278E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,  -4.1353838793440278E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,   4.1353838793440278E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,  -4.1353838793440278E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,   6.0867258986780109E-02,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,   6.0867258986780109E-02,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,  -6.0867258986780109E-02,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,   6.0867258986780109E-02,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,  -6.0867258986780109E-02,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   9.0844987670649813E-01,  -6.0867258986780109E-02,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,   6.0867258986780109E-02,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -9.0844987670649813E-01,  -6.0867258986780109E-02,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,   9.0844987670649813E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,   9.0844987670649813E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,  -9.0844987670649813E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,   9.0844987670649813E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,  -9.0844987670649813E-01,   6.0867258986780109E-02,   2.6568271456213909E-03],
            [   4.1353838793440278E-01,  -9.0844987670649813E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,   9.0844987670649813E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [  -4.1353838793440278E-01,  -9.0844987670649813E-01,  -6.0867258986780109E-02,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,   9.0844987670649813E-01,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,   9.0844987670649813E-01,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,  -9.0844987670649813E-01,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,   9.0844987670649813E-01,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,  -9.0844987670649813E-01,   4.1353838793440278E-01,   2.6568271456213909E-03],
            [   6.0867258986780109E-02,  -9.0844987670649813E-01,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,   9.0844987670649813E-01,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [  -6.0867258986780109E-02,  -9.0844987670649813E-01,  -4.1353838793440278E-01,   2.6568271456213909E-03],
            [   4.5061138851539068E-01,   9.2388495484356431E-02,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,   9.2388495484356431E-02,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,  -9.2388495484356431E-02,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,   9.2388495484356431E-02,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,  -9.2388495484356431E-02,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,  -9.2388495484356431E-02,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,   9.2388495484356431E-02,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,  -9.2388495484356431E-02,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,   4.5061138851539068E-01,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,   4.5061138851539068E-01,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,  -4.5061138851539068E-01,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,   4.5061138851539068E-01,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,  -4.5061138851539068E-01,   8.8792665375151836E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,  -4.5061138851539068E-01,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,   4.5061138851539068E-01,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,  -4.5061138851539068E-01,  -8.8792665375151836E-01,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,   4.5061138851539068E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,   4.5061138851539068E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,  -4.5061138851539068E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,   4.5061138851539068E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,  -4.5061138851539068E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,  -4.5061138851539068E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,   4.5061138851539068E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,  -4.5061138851539068E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,   9.2388495484356431E-02,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,   9.2388495484356431E-02,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,  -9.2388495484356431E-02,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,   9.2388495484356431E-02,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,  -9.2388495484356431E-02,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   8.8792665375151836E-01,  -9.2388495484356431E-02,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,   9.2388495484356431E-02,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -8.8792665375151836E-01,  -9.2388495484356431E-02,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,   8.8792665375151836E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,   8.8792665375151836E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,  -8.8792665375151836E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,   8.8792665375151836E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,  -8.8792665375151836E-01,   9.2388495484356431E-02,   2.7183266667646548E-03],
            [   4.5061138851539068E-01,  -8.8792665375151836E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,   8.8792665375151836E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [  -4.5061138851539068E-01,  -8.8792665375151836E-01,  -9.2388495484356431E-02,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,   8.8792665375151836E-01,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,   8.8792665375151836E-01,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,  -8.8792665375151836E-01,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,   8.8792665375151836E-01,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,  -8.8792665375151836E-01,   4.5061138851539068E-01,   2.7183266667646548E-03],
            [   9.2388495484356431E-02,  -8.8792665375151836E-01,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,   8.8792665375151836E-01,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [  -9.2388495484356431E-02,  -8.8792665375151836E-01,  -4.5061138851539068E-01,   2.7183266667646548E-03],
            [   4.8644015546060720E-01,   1.2427866038518511E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,   1.2427866038518511E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,  -1.2427866038518511E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,   1.2427866038518511E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,  -1.2427866038518511E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,  -1.2427866038518511E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,   1.2427866038518511E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,  -1.2427866038518511E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,   4.8644015546060720E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,   4.8644015546060720E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,  -4.8644015546060720E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,   4.8644015546060720E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,  -4.8644015546060720E-01,   8.6482991953812749E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,  -4.8644015546060720E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,   4.8644015546060720E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,  -4.8644015546060720E-01,  -8.6482991953812749E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,   4.8644015546060720E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,   4.8644015546060720E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,  -4.8644015546060720E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,   4.8644015546060720E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,  -4.8644015546060720E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,  -4.8644015546060720E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,   4.8644015546060720E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,  -4.8644015546060720E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,   1.2427866038518511E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,   1.2427866038518511E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,  -1.2427866038518511E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,   1.2427866038518511E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,  -1.2427866038518511E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   8.6482991953812749E-01,  -1.2427866038518511E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,   1.2427866038518511E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -8.6482991953812749E-01,  -1.2427866038518511E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,   8.6482991953812749E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,   8.6482991953812749E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,  -8.6482991953812749E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,   8.6482991953812749E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,  -8.6482991953812749E-01,   1.2427866038518511E-01,   2.7688642467603680E-03],
            [   4.8644015546060720E-01,  -8.6482991953812749E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,   8.6482991953812749E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [  -4.8644015546060720E-01,  -8.6482991953812749E-01,  -1.2427866038518511E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,   8.6482991953812749E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,   8.6482991953812749E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,  -8.6482991953812749E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,   8.6482991953812749E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,  -8.6482991953812749E-01,   4.8644015546060720E-01,   2.7688642467603680E-03],
            [   1.2427866038518511E-01,  -8.6482991953812749E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,   8.6482991953812749E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [  -1.2427866038518511E-01,  -8.6482991953812749E-01,  -4.8644015546060720E-01,   2.7688642467603680E-03],
            [   5.2097080766117088E-01,   1.5630867314833860E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,   1.5630867314833860E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,  -1.5630867314833860E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,   1.5630867314833860E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,  -1.5630867314833860E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,  -1.5630867314833860E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,   1.5630867314833860E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,  -1.5630867314833860E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,   5.2097080766117088E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,   5.2097080766117088E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,  -5.2097080766117088E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,   5.2097080766117088E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,  -5.2097080766117088E-01,   8.3914064152767209E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,  -5.2097080766117088E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,   5.2097080766117088E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,  -5.2097080766117088E-01,  -8.3914064152767209E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,   5.2097080766117088E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,   5.2097080766117088E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,  -5.2097080766117088E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,   5.2097080766117088E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,  -5.2097080766117088E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,  -5.2097080766117088E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,   5.2097080766117088E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,  -5.2097080766117088E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,   1.5630867314833860E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,   1.5630867314833860E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,  -1.5630867314833860E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,   1.5630867314833860E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,  -1.5630867314833860E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   8.3914064152767209E-01,  -1.5630867314833860E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,   1.5630867314833860E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -8.3914064152767209E-01,  -1.5630867314833860E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,   8.3914064152767209E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,   8.3914064152767209E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,  -8.3914064152767209E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,   8.3914064152767209E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,  -8.3914064152767209E-01,   1.5630867314833860E-01,   2.8091784438728832E-03],
            [   5.2097080766117088E-01,  -8.3914064152767209E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,   8.3914064152767209E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [  -5.2097080766117088E-01,  -8.3914064152767209E-01,  -1.5630867314833860E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,   8.3914064152767209E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,   8.3914064152767209E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,  -8.3914064152767209E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,   8.3914064152767209E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,  -8.3914064152767209E-01,   5.2097080766117088E-01,   2.8091784438728832E-03],
            [   1.5630867314833860E-01,  -8.3914064152767209E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,   8.3914064152767209E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [  -1.5630867314833860E-01,  -8.3914064152767209E-01,  -5.2097080766117088E-01,   2.8091784438728832E-03],
            [   5.5414221358301219E-01,   1.8826965093885059E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,   1.8826965093885059E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,  -1.8826965093885059E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,   1.8826965093885059E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,  -1.8826965093885059E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,  -1.8826965093885059E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,   1.8826965093885059E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,  -1.8826965093885059E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,   5.5414221358301219E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,   5.5414221358301219E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,  -5.5414221358301219E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,   5.5414221358301219E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,  -5.5414221358301219E-01,   8.1085198751725496E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,  -5.5414221358301219E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,   5.5414221358301219E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,  -5.5414221358301219E-01,  -8.1085198751725496E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,   5.5414221358301219E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,   5.5414221358301219E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,  -5.5414221358301219E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,   5.5414221358301219E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,  -5.5414221358301219E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,  -5.5414221358301219E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,   5.5414221358301219E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,  -5.5414221358301219E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,   1.8826965093885059E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,   1.8826965093885059E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,  -1.8826965093885059E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,   1.8826965093885059E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,  -1.8826965093885059E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   8.1085198751725496E-01,  -1.8826965093885059E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,   1.8826965093885059E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -8.1085198751725496E-01,  -1.8826965093885059E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,   8.1085198751725496E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,   8.1085198751725496E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,  -8.1085198751725496E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,   8.1085198751725496E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,  -8.1085198751725496E-01,   1.8826965093885059E-01,   2.8400300959503435E-03],
            [   5.5414221358301219E-01,  -8.1085198751725496E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,   8.1085198751725496E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [  -5.5414221358301219E-01,  -8.1085198751725496E-01,  -1.8826965093885059E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,   8.1085198751725496E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,   8.1085198751725496E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,  -8.1085198751725496E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,   8.1085198751725496E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,  -8.1085198751725496E-01,   5.5414221358301219E-01,   2.8400300959503435E-03],
            [   1.8826965093885059E-01,  -8.1085198751725496E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,   8.1085198751725496E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [  -1.8826965093885059E-01,  -8.1085198751725496E-01,  -5.5414221358301219E-01,   2.8400300959503435E-03],
            [   5.8588809151138166E-01,   2.1996729791260591E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,   2.1996729791260591E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,  -2.1996729791260591E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,   2.1996729791260591E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,  -2.1996729791260591E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,  -2.1996729791260591E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,   2.1996729791260591E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,  -2.1996729791260591E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,   5.8588809151138166E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,   5.8588809151138166E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,  -5.8588809151138166E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,   5.8588809151138166E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,  -5.8588809151138166E-01,   7.7996764809457175E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,  -5.8588809151138166E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,   5.8588809151138166E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,  -5.8588809151138166E-01,  -7.7996764809457175E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,   5.8588809151138166E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,   5.8588809151138166E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,  -5.8588809151138166E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,   5.8588809151138166E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,  -5.8588809151138166E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,  -5.8588809151138166E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,   5.8588809151138166E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,  -5.8588809151138166E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,   2.1996729791260591E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,   2.1996729791260591E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,  -2.1996729791260591E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,   2.1996729791260591E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,  -2.1996729791260591E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   7.7996764809457175E-01,  -2.1996729791260591E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,   2.1996729791260591E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -7.7996764809457175E-01,  -2.1996729791260591E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,   7.7996764809457175E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,   7.7996764809457175E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,  -7.7996764809457175E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,   7.7996764809457175E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,  -7.7996764809457175E-01,   2.1996729791260591E-01,   2.8622119867355452E-03],
            [   5.8588809151138166E-01,  -7.7996764809457175E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,   7.7996764809457175E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [  -5.8588809151138166E-01,  -7.7996764809457175E-01,  -2.1996729791260591E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,   7.7996764809457175E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,   7.7996764809457175E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,  -7.7996764809457175E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,   7.7996764809457175E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,  -7.7996764809457175E-01,   5.8588809151138166E-01,   2.8622119867355452E-03],
            [   2.1996729791260591E-01,  -7.7996764809457175E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,   7.7996764809457175E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [  -2.1996729791260591E-01,  -7.7996764809457175E-01,  -5.8588809151138166E-01,   2.8622119867355452E-03],
            [   6.1613993906034437E-01,   2.5121654829248669E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,   2.5121654829248669E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,  -2.5121654829248669E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,   2.5121654829248669E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,  -2.5121654829248669E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,  -2.5121654829248669E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,   2.5121654829248669E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,  -2.5121654829248669E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,   6.1613993906034437E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,   6.1613993906034437E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,  -6.1613993906034437E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,   6.1613993906034437E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,  -6.1613993906034437E-01,   7.4649971289929096E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,  -6.1613993906034437E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,   6.1613993906034437E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,  -6.1613993906034437E-01,  -7.4649971289929096E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,   6.1613993906034437E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,   6.1613993906034437E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,  -6.1613993906034437E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,   6.1613993906034437E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,  -6.1613993906034437E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,  -6.1613993906034437E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,   6.1613993906034437E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,  -6.1613993906034437E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,   2.5121654829248669E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,   2.5121654829248669E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,  -2.5121654829248669E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,   2.5121654829248669E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,  -2.5121654829248669E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   7.4649971289929096E-01,  -2.5121654829248669E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,   2.5121654829248669E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -7.4649971289929096E-01,  -2.5121654829248669E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,   7.4649971289929096E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,   7.4649971289929096E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,  -7.4649971289929096E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,   7.4649971289929096E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,  -7.4649971289929096E-01,   2.5121654829248669E-01,   2.8765705517083649E-03],
            [   6.1613993906034437E-01,  -7.4649971289929096E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,   7.4649971289929096E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [  -6.1613993906034437E-01,  -7.4649971289929096E-01,  -2.5121654829248669E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,   7.4649971289929096E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,   7.4649971289929096E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,  -7.4649971289929096E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,   7.4649971289929096E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,  -7.4649971289929096E-01,   6.1613993906034437E-01,   2.8765705517083649E-03],
            [   2.5121654829248669E-01,  -7.4649971289929096E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,   7.4649971289929096E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [  -2.5121654829248669E-01,  -7.4649971289929096E-01,  -6.1613993906034437E-01,   2.8765705517083649E-03],
            [   6.4482964822550903E-01,   2.8183687018718878E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,   2.8183687018718878E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,  -2.8183687018718878E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,   2.8183687018718878E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,  -2.8183687018718878E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,  -2.8183687018718878E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,   2.8183687018718878E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,  -2.8183687018718878E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,   6.4482964822550903E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,   6.4482964822550903E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,  -6.4482964822550903E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,   6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,  -6.4482964822550903E-01,   7.1046653923492831E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,  -6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,   6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,  -6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,   6.4482964822550903E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,   6.4482964822550903E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,   6.4482964822550903E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,  -6.4482964822550903E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,   6.4482964822550903E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,  -6.4482964822550903E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,   2.8183687018718878E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,   2.8183687018718878E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,  -2.8183687018718878E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,   2.8183687018718878E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,  -2.8183687018718878E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   7.1046653923492831E-01,  -2.8183687018718878E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,   2.8183687018718878E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -7.1046653923492831E-01,  -2.8183687018718878E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,   7.1046653923492831E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,   7.1046653923492831E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,   7.1046653923492831E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,  -7.1046653923492831E-01,   2.8183687018718878E-01,   2.8840171848133920E-03],
            [   6.4482964822550903E-01,  -7.1046653923492831E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,   7.1046653923492831E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [  -6.4482964822550903E-01,  -7.1046653923492831E-01,  -2.8183687018718878E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,   7.1046653923492831E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,   7.1046653923492831E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,  -7.1046653923492831E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,   7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,  -7.1046653923492831E-01,   6.4482964822550903E-01,   2.8840171848133920E-03],
            [   2.8183687018718878E-01,  -7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,   7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [  -2.8183687018718878E-01,  -7.1046653923492831E-01,  -6.4482964822550903E-01,   2.8840171848133920E-03],
            [   4.5447962749179482E-01,   3.0889704050603119E-02,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,   3.0889704050603119E-02,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,  -3.0889704050603119E-02,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,   3.0889704050603119E-02,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,  -3.0889704050603119E-02,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,  -3.0889704050603119E-02,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,   3.0889704050603119E-02,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,  -3.0889704050603119E-02,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,   4.5447962749179482E-01,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,   4.5447962749179482E-01,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,  -4.5447962749179482E-01,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,   4.5447962749179482E-01,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,  -4.5447962749179482E-01,   8.9022137380462030E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,  -4.5447962749179482E-01,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,   4.5447962749179482E-01,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,  -4.5447962749179482E-01,  -8.9022137380462030E-01,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,   4.5447962749179482E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,   4.5447962749179482E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,  -4.5447962749179482E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,   4.5447962749179482E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,  -4.5447962749179482E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,  -4.5447962749179482E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,   4.5447962749179482E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,  -4.5447962749179482E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,   3.0889704050603119E-02,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,   3.0889704050603119E-02,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,  -3.0889704050603119E-02,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,   3.0889704050603119E-02,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,  -3.0889704050603119E-02,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   8.9022137380462030E-01,  -3.0889704050603119E-02,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,   3.0889704050603119E-02,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -8.9022137380462030E-01,  -3.0889704050603119E-02,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,   8.9022137380462030E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,   8.9022137380462030E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,  -8.9022137380462030E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,   8.9022137380462030E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,  -8.9022137380462030E-01,   3.0889704050603119E-02,   2.7159465460423406E-03],
            [   4.5447962749179482E-01,  -8.9022137380462030E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,   8.9022137380462030E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [  -4.5447962749179482E-01,  -8.9022137380462030E-01,  -3.0889704050603119E-02,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,   8.9022137380462030E-01,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,   8.9022137380462030E-01,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,  -8.9022137380462030E-01,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,   8.9022137380462030E-01,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,  -8.9022137380462030E-01,   4.5447962749179482E-01,   2.7159465460423406E-03],
            [   3.0889704050603119E-02,  -8.9022137380462030E-01,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,   8.9022137380462030E-01,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [  -3.0889704050603119E-02,  -8.9022137380462030E-01,  -4.5447962749179482E-01,   2.7159465460423406E-03],
            [   4.9193890721466282E-01,   6.2409476776368350E-02,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,   6.2409476776368350E-02,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,  -6.2409476776368350E-02,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,   6.2409476776368350E-02,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,  -6.2409476776368350E-02,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,  -6.2409476776368350E-02,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,   6.2409476776368350E-02,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,  -6.2409476776368350E-02,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,   4.9193890721466282E-01,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,   4.9193890721466282E-01,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,  -4.9193890721466282E-01,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,   4.9193890721466282E-01,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,  -4.9193890721466282E-01,   8.6838998657109312E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,  -4.9193890721466282E-01,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,   4.9193890721466282E-01,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,  -4.9193890721466282E-01,  -8.6838998657109312E-01,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,   4.9193890721466282E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,   4.9193890721466282E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,  -4.9193890721466282E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,   4.9193890721466282E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,  -4.9193890721466282E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,  -4.9193890721466282E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,   4.9193890721466282E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,  -4.9193890721466282E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,   6.2409476776368350E-02,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,   6.2409476776368350E-02,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,  -6.2409476776368350E-02,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,   6.2409476776368350E-02,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,  -6.2409476776368350E-02,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   8.6838998657109312E-01,  -6.2409476776368350E-02,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,   6.2409476776368350E-02,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -8.6838998657109312E-01,  -6.2409476776368350E-02,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,   8.6838998657109312E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,   8.6838998657109312E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,  -8.6838998657109312E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,   8.6838998657109312E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,  -8.6838998657109312E-01,   6.2409476776368350E-02,   2.7670902764530391E-03],
            [   4.9193890721466282E-01,  -8.6838998657109312E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,   8.6838998657109312E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [  -4.9193890721466282E-01,  -8.6838998657109312E-01,  -6.2409476776368350E-02,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,   8.6838998657109312E-01,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,   8.6838998657109312E-01,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,  -8.6838998657109312E-01,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,   8.6838998657109312E-01,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,  -8.6838998657109312E-01,   4.9193890721466282E-01,   2.7670902764530391E-03],
            [   6.2409476776368350E-02,  -8.6838998657109312E-01,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,   8.6838998657109312E-01,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [  -6.2409476776368350E-02,  -8.6838998657109312E-01,  -4.9193890721466282E-01,   2.7670902764530391E-03],
            [   5.2793130269851829E-01,   9.4307061442803125E-02,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,   9.4307061442803125E-02,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,  -9.4307061442803125E-02,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,   9.4307061442803125E-02,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,  -9.4307061442803125E-02,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,  -9.4307061442803125E-02,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,   9.4307061442803125E-02,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,  -9.4307061442803125E-02,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,   5.2793130269851829E-01,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,   5.2793130269851829E-01,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,  -5.2793130269851829E-01,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,   5.2793130269851829E-01,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,  -5.2793130269851829E-01,   8.4403478470562388E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,  -5.2793130269851829E-01,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,   5.2793130269851829E-01,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,  -5.2793130269851829E-01,  -8.4403478470562388E-01,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,   5.2793130269851829E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,   5.2793130269851829E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,  -5.2793130269851829E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,   5.2793130269851829E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,  -5.2793130269851829E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,  -5.2793130269851829E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,   5.2793130269851829E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,  -5.2793130269851829E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,   9.4307061442803125E-02,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,   9.4307061442803125E-02,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,  -9.4307061442803125E-02,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,   9.4307061442803125E-02,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,  -9.4307061442803125E-02,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   8.4403478470562388E-01,  -9.4307061442803125E-02,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,   9.4307061442803125E-02,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -8.4403478470562388E-01,  -9.4307061442803125E-02,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,   8.4403478470562388E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,   8.4403478470562388E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,  -8.4403478470562388E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,   8.4403478470562388E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,  -8.4403478470562388E-01,   9.4307061442803125E-02,   2.8085235974137667E-03],
            [   5.2793130269851829E-01,  -8.4403478470562388E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,   8.4403478470562388E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [  -5.2793130269851829E-01,  -8.4403478470562388E-01,  -9.4307061442803125E-02,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,   8.4403478470562388E-01,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,   8.4403478470562388E-01,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,  -8.4403478470562388E-01,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,   8.4403478470562388E-01,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,  -8.4403478470562388E-01,   5.2793130269851829E-01,   2.8085235974137667E-03],
            [   9.4307061442803125E-02,  -8.4403478470562388E-01,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,   8.4403478470562388E-01,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [  -9.4307061442803125E-02,  -8.4403478470562388E-01,  -5.2793130269851829E-01,   2.8085235974137667E-03],
            [   5.6241699255711353E-01,   1.2635478187703739E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,   1.2635478187703739E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,  -1.2635478187703739E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,   1.2635478187703739E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,  -1.2635478187703739E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,  -1.2635478187703739E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,   1.2635478187703739E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,  -1.2635478187703739E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,   5.6241699255711353E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,   5.6241699255711353E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,  -5.6241699255711353E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,   5.6241699255711353E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,  -5.6241699255711353E-01,   8.1714233495751398E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,  -5.6241699255711353E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,   5.6241699255711353E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,  -5.6241699255711353E-01,  -8.1714233495751398E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,   5.6241699255711353E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,   5.6241699255711353E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,  -5.6241699255711353E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,   5.6241699255711353E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,  -5.6241699255711353E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,  -5.6241699255711353E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,   5.6241699255711353E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,  -5.6241699255711353E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,   1.2635478187703739E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,   1.2635478187703739E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,  -1.2635478187703739E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,   1.2635478187703739E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,  -1.2635478187703739E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   8.1714233495751398E-01,  -1.2635478187703739E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,   1.2635478187703739E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -8.1714233495751398E-01,  -1.2635478187703739E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,   8.1714233495751398E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,   8.1714233495751398E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,  -8.1714233495751398E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,   8.1714233495751398E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,  -8.1714233495751398E-01,   1.2635478187703739E-01,   2.8406784666632850E-03],
            [   5.6241699255711353E-01,  -8.1714233495751398E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,   8.1714233495751398E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [  -5.6241699255711353E-01,  -8.1714233495751398E-01,  -1.2635478187703739E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,   8.1714233495751398E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,   8.1714233495751398E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,  -8.1714233495751398E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,   8.1714233495751398E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,  -8.1714233495751398E-01,   5.6241699255711353E-01,   2.8406784666632850E-03],
            [   1.2635478187703739E-01,  -8.1714233495751398E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,   8.1714233495751398E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [  -1.2635478187703739E-01,  -8.1714233495751398E-01,  -5.6241699255711353E-01,   2.8406784666632850E-03],
            [   5.9534846270932873E-01,   1.5834307888225940E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,   1.5834307888225940E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,  -1.5834307888225940E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,   1.5834307888225940E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,  -1.5834307888225940E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,  -1.5834307888225940E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,   1.5834307888225940E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,  -1.5834307888225940E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,   5.9534846270932873E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,   5.9534846270932873E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,  -5.9534846270932873E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,   5.9534846270932873E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,  -5.9534846270932873E-01,   7.8771040193698438E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,  -5.9534846270932873E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,   5.9534846270932873E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,  -5.9534846270932873E-01,  -7.8771040193698438E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,   5.9534846270932873E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,   5.9534846270932873E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,  -5.9534846270932873E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,   5.9534846270932873E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,  -5.9534846270932873E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,  -5.9534846270932873E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,   5.9534846270932873E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,  -5.9534846270932873E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,   1.5834307888225940E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,   1.5834307888225940E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,  -1.5834307888225940E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,   1.5834307888225940E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,  -1.5834307888225940E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   7.8771040193698438E-01,  -1.5834307888225940E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,   1.5834307888225940E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -7.8771040193698438E-01,  -1.5834307888225940E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,   7.8771040193698438E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,   7.8771040193698438E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,  -7.8771040193698438E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,   7.8771040193698438E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,  -7.8771040193698438E-01,   1.5834307888225940E-01,   2.8640743889230165E-03],
            [   5.9534846270932873E-01,  -7.8771040193698438E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,   7.8771040193698438E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [  -5.9534846270932873E-01,  -7.8771040193698438E-01,  -1.5834307888225940E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,   7.8771040193698438E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,   7.8771040193698438E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,  -7.8771040193698438E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,   7.8771040193698438E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,  -7.8771040193698438E-01,   5.9534846270932873E-01,   2.8640743889230165E-03],
            [   1.5834307888225940E-01,  -7.8771040193698438E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,   7.8771040193698438E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [  -1.5834307888225940E-01,  -7.8771040193698438E-01,  -5.9534846270932873E-01,   2.8640743889230165E-03],
            [   6.2667307153391849E-01,   1.9007484625559881E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,   1.9007484625559881E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,  -1.9007484625559881E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,   1.9007484625559881E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,  -1.9007484625559881E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,  -1.9007484625559881E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,   1.9007484625559881E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,  -1.9007484625559881E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,   6.2667307153391849E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,   6.2667307153391849E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,  -6.2667307153391849E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,   6.2667307153391849E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,  -6.2667307153391849E-01,   7.5574626313012938E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,  -6.2667307153391849E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,   6.2667307153391849E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,  -6.2667307153391849E-01,  -7.5574626313012938E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,   6.2667307153391849E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,   6.2667307153391849E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,  -6.2667307153391849E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,   6.2667307153391849E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,  -6.2667307153391849E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,  -6.2667307153391849E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,   6.2667307153391849E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,  -6.2667307153391849E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,   1.9007484625559881E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,   1.9007484625559881E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,  -1.9007484625559881E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,   1.9007484625559881E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,  -1.9007484625559881E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   7.5574626313012938E-01,  -1.9007484625559881E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,   1.9007484625559881E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -7.5574626313012938E-01,  -1.9007484625559881E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,   7.5574626313012938E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,   7.5574626313012938E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,  -7.5574626313012938E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,   7.5574626313012938E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,  -7.5574626313012938E-01,   1.9007484625559881E-01,   2.8793286266234116E-03],
            [   6.2667307153391849E-01,  -7.5574626313012938E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,   7.5574626313012938E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [  -6.2667307153391849E-01,  -7.5574626313012938E-01,  -1.9007484625559881E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,   7.5574626313012938E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,   7.5574626313012938E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,  -7.5574626313012938E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,   7.5574626313012938E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,  -7.5574626313012938E-01,   6.2667307153391849E-01,   2.8793286266234116E-03],
            [   1.9007484625559881E-01,  -7.5574626313012938E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,   7.5574626313012938E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [  -1.9007484625559881E-01,  -7.5574626313012938E-01,  -6.2667307153391849E-01,   2.8793286266234116E-03],
            [   6.5633632042788714E-01,   2.2135995195925670E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,   2.2135995195925670E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,  -2.2135995195925670E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,   2.2135995195925670E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,  -2.2135995195925670E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,  -2.2135995195925670E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,   2.2135995195925670E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,  -2.2135995195925670E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,   6.5633632042788714E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,   6.5633632042788714E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,  -6.5633632042788714E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,   6.5633632042788714E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,  -6.5633632042788714E-01,   7.2126444952997470E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,  -6.5633632042788714E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,   6.5633632042788714E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,  -6.5633632042788714E-01,  -7.2126444952997470E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,   6.5633632042788714E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,   6.5633632042788714E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,  -6.5633632042788714E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,   6.5633632042788714E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,  -6.5633632042788714E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,  -6.5633632042788714E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,   6.5633632042788714E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,  -6.5633632042788714E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,   2.2135995195925670E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,   2.2135995195925670E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,  -2.2135995195925670E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,   2.2135995195925670E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,  -2.2135995195925670E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   7.2126444952997470E-01,  -2.2135995195925670E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,   2.2135995195925670E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -7.2126444952997470E-01,  -2.2135995195925670E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,   7.2126444952997470E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,   7.2126444952997470E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,  -7.2126444952997470E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,   7.2126444952997470E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,  -7.2126444952997470E-01,   2.2135995195925670E-01,   2.8871660633374902E-03],
            [   6.5633632042788714E-01,  -7.2126444952997470E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,   7.2126444952997470E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [  -6.5633632042788714E-01,  -7.2126444952997470E-01,  -2.2135995195925670E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,   7.2126444952997470E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,   7.2126444952997470E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,  -7.2126444952997470E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,   7.2126444952997470E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,  -7.2126444952997470E-01,   6.5633632042788714E-01,   2.8871660633374902E-03],
            [   2.2135995195925670E-01,  -7.2126444952997470E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,   7.2126444952997470E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [  -2.2135995195925670E-01,  -7.2126444952997470E-01,  -6.5633632042788714E-01,   2.8871660633374902E-03],
            [   5.3145747165856960E-01,   3.1525088115153740E-02,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,   3.1525088115153740E-02,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,  -3.1525088115153740E-02,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,   3.1525088115153740E-02,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,  -3.1525088115153740E-02,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,  -3.1525088115153740E-02,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,   3.1525088115153740E-02,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,  -3.1525088115153740E-02,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,   5.3145747165856960E-01,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,   5.3145747165856960E-01,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,  -5.3145747165856960E-01,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,   5.3145747165856960E-01,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,  -5.3145747165856960E-01,   8.4649815394814210E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,  -5.3145747165856960E-01,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,   5.3145747165856960E-01,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,  -5.3145747165856960E-01,  -8.4649815394814210E-01,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,   5.3145747165856960E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,   5.3145747165856960E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,  -5.3145747165856960E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,   5.3145747165856960E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,  -5.3145747165856960E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,  -5.3145747165856960E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,   5.3145747165856960E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,  -5.3145747165856960E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,   3.1525088115153740E-02,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,   3.1525088115153740E-02,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,  -3.1525088115153740E-02,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,   3.1525088115153740E-02,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,  -3.1525088115153740E-02,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   8.4649815394814210E-01,  -3.1525088115153740E-02,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,   3.1525088115153740E-02,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -8.4649815394814210E-01,  -3.1525088115153740E-02,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,   8.4649815394814210E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,   8.4649815394814210E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,  -8.4649815394814210E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,   8.4649815394814210E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,  -8.4649815394814210E-01,   3.1525088115153740E-02,   2.8084925457521710E-03],
            [   5.3145747165856960E-01,  -8.4649815394814210E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,   8.4649815394814210E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [  -5.3145747165856960E-01,  -8.4649815394814210E-01,  -3.1525088115153740E-02,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,   8.4649815394814210E-01,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,   8.4649815394814210E-01,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,  -8.4649815394814210E-01,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,   8.4649815394814210E-01,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,  -8.4649815394814210E-01,   5.3145747165856960E-01,   2.8084925457521710E-03],
            [   3.1525088115153740E-02,  -8.4649815394814210E-01,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,   8.4649815394814210E-01,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [  -3.1525088115153740E-02,  -8.4649815394814210E-01,  -5.3145747165856960E-01,   2.8084925457521710E-03],
            [   5.6746149322981854E-01,   6.3438652914655613E-02,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,   6.3438652914655613E-02,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,  -6.3438652914655613E-02,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,   6.3438652914655613E-02,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,  -6.3438652914655613E-02,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,  -6.3438652914655613E-02,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,   6.3438652914655613E-02,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,  -6.3438652914655613E-02,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,   5.6746149322981854E-01,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,   5.6746149322981854E-01,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,  -5.6746149322981854E-01,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,   5.6746149322981854E-01,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,  -5.6746149322981854E-01,   8.2095249010996885E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,  -5.6746149322981854E-01,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,   5.6746149322981854E-01,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,  -5.6746149322981854E-01,  -8.2095249010996885E-01,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,   5.6746149322981854E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,   5.6746149322981854E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,  -5.6746149322981854E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,   5.6746149322981854E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,  -5.6746149322981854E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,  -5.6746149322981854E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,   5.6746149322981854E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,  -5.6746149322981854E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,   6.3438652914655613E-02,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,   6.3438652914655613E-02,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,  -6.3438652914655613E-02,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,   6.3438652914655613E-02,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,  -6.3438652914655613E-02,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   8.2095249010996885E-01,  -6.3438652914655613E-02,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,   6.3438652914655613E-02,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -8.2095249010996885E-01,  -6.3438652914655613E-02,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,   8.2095249010996885E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,   8.2095249010996885E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,  -8.2095249010996885E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,   8.2095249010996885E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,  -8.2095249010996885E-01,   6.3438652914655613E-02,   2.8416183236980100E-03],
            [   5.6746149322981854E-01,  -8.2095249010996885E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,   8.2095249010996885E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [  -5.6746149322981854E-01,  -8.2095249010996885E-01,  -6.3438652914655613E-02,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,   8.2095249010996885E-01,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,   8.2095249010996885E-01,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,  -8.2095249010996885E-01,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,   8.2095249010996885E-01,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,  -8.2095249010996885E-01,   5.6746149322981854E-01,   2.8416183236980100E-03],
            [   6.3438652914655613E-02,  -8.2095249010996885E-01,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,   8.2095249010996885E-01,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [  -6.3438652914655613E-02,  -8.2095249010996885E-01,  -5.6746149322981854E-01,   2.8416183236980100E-03],
            [   6.0177060049702635E-01,   9.5515035042239516E-02,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,   9.5515035042239516E-02,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,  -9.5515035042239516E-02,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,   9.5515035042239516E-02,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,  -9.5515035042239516E-02,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,  -9.5515035042239516E-02,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,   9.5515035042239516E-02,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,  -9.5515035042239516E-02,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,   6.0177060049702635E-01,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,   6.0177060049702635E-01,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,  -6.0177060049702635E-01,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,   6.0177060049702635E-01,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,  -6.0177060049702635E-01,   7.9293695995225755E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,  -6.0177060049702635E-01,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,   6.0177060049702635E-01,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,  -6.0177060049702635E-01,  -7.9293695995225755E-01,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,   6.0177060049702635E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,   6.0177060049702635E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,  -6.0177060049702635E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,   6.0177060049702635E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,  -6.0177060049702635E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,  -6.0177060049702635E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,   6.0177060049702635E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,  -6.0177060049702635E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,   9.5515035042239516E-02,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,   9.5515035042239516E-02,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,  -9.5515035042239516E-02,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,   9.5515035042239516E-02,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,  -9.5515035042239516E-02,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   7.9293695995225755E-01,  -9.5515035042239516E-02,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,   9.5515035042239516E-02,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -7.9293695995225755E-01,  -9.5515035042239516E-02,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,   7.9293695995225755E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,   7.9293695995225755E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,  -7.9293695995225755E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,   7.9293695995225755E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,  -7.9293695995225755E-01,   9.5515035042239516E-02,   2.8661606314128161E-03],
            [   6.0177060049702635E-01,  -7.9293695995225755E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,   7.9293695995225755E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [  -6.0177060049702635E-01,  -7.9293695995225755E-01,  -9.5515035042239516E-02,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,   7.9293695995225755E-01,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,   7.9293695995225755E-01,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,  -7.9293695995225755E-01,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,   7.9293695995225755E-01,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,  -7.9293695995225755E-01,   6.0177060049702635E-01,   2.8661606314128161E-03],
            [   9.5515035042239516E-02,  -7.9293695995225755E-01,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,   7.9293695995225755E-01,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [  -9.5515035042239516E-02,  -7.9293695995225755E-01,  -6.0177060049702635E-01,   2.8661606314128161E-03],
            [   6.3434712702641782E-01,   1.2754400998011961E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,   1.2754400998011961E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,  -1.2754400998011961E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,   1.2754400998011961E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,  -1.2754400998011961E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,  -1.2754400998011961E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,   1.2754400998011961E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,  -1.2754400998011961E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,   6.3434712702641782E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,   6.3434712702641782E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,  -6.3434712702641782E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,   6.3434712702641782E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,  -6.3434712702641782E-01,   7.6245409563561317E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,  -6.3434712702641782E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,   6.3434712702641782E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,  -6.3434712702641782E-01,  -7.6245409563561317E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,   6.3434712702641782E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,   6.3434712702641782E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,  -6.3434712702641782E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,   6.3434712702641782E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,  -6.3434712702641782E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,  -6.3434712702641782E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,   6.3434712702641782E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,  -6.3434712702641782E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,   1.2754400998011961E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,   1.2754400998011961E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,  -1.2754400998011961E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,   1.2754400998011961E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,  -1.2754400998011961E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   7.6245409563561317E-01,  -1.2754400998011961E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,   1.2754400998011961E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -7.6245409563561317E-01,  -1.2754400998011961E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,   7.6245409563561317E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,   7.6245409563561317E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,  -7.6245409563561317E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,   7.6245409563561317E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,  -7.6245409563561317E-01,   1.2754400998011961E-01,   2.8824405332553761E-03],
            [   6.3434712702641782E-01,  -7.6245409563561317E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,   7.6245409563561317E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [  -6.3434712702641782E-01,  -7.6245409563561317E-01,  -1.2754400998011961E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,   7.6245409563561317E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,   7.6245409563561317E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,  -7.6245409563561317E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,   7.6245409563561317E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,  -7.6245409563561317E-01,   6.3434712702641782E-01,   2.8824405332553761E-03],
            [   1.2754400998011961E-01,  -7.6245409563561317E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,   7.6245409563561317E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [  -1.2754400998011961E-01,  -7.6245409563561317E-01,  -6.3434712702641782E-01,   2.8824405332553761E-03],
            [   6.6514945991278018E-01,   1.5932520376719600E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,   1.5932520376719600E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,  -1.5932520376719600E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,   1.5932520376719600E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,  -1.5932520376719600E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,  -1.5932520376719600E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,   1.5932520376719600E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,  -1.5932520376719600E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,   6.6514945991278018E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,   6.6514945991278018E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,  -6.6514945991278018E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,   6.6514945991278018E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,  -6.6514945991278018E-01,   7.2951468485718529E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,  -6.6514945991278018E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,   6.6514945991278018E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,  -6.6514945991278018E-01,  -7.2951468485718529E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,   6.6514945991278018E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,   6.6514945991278018E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,  -6.6514945991278018E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,   6.6514945991278018E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,  -6.6514945991278018E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,  -6.6514945991278018E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,   6.6514945991278018E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,  -6.6514945991278018E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,   1.5932520376719600E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,   1.5932520376719600E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,  -1.5932520376719600E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,   1.5932520376719600E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,  -1.5932520376719600E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   7.2951468485718529E-01,  -1.5932520376719600E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,   1.5932520376719600E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -7.2951468485718529E-01,  -1.5932520376719600E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,   7.2951468485718529E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,   7.2951468485718529E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,  -7.2951468485718529E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,   7.2951468485718529E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,  -7.2951468485718529E-01,   1.5932520376719600E-01,   2.8909297099372140E-03],
            [   6.6514945991278018E-01,  -7.2951468485718529E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,   7.2951468485718529E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [  -6.6514945991278018E-01,  -7.2951468485718529E-01,  -1.5932520376719600E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,   7.2951468485718529E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,   7.2951468485718529E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,  -7.2951468485718529E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,   7.2951468485718529E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,  -7.2951468485718529E-01,   6.6514945991278018E-01,   2.8909297099372140E-03],
            [   1.5932520376719600E-01,  -7.2951468485718529E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,   7.2951468485718529E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [  -1.5932520376719600E-01,  -7.2951468485718529E-01,  -6.6514945991278018E-01,   2.8909297099372140E-03],
            [   6.0501849860057044E-01,   3.1925383384961051E-02,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,   3.1925383384961051E-02,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,  -3.1925383384961051E-02,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,   3.1925383384961051E-02,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,  -3.1925383384961051E-02,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,  -3.1925383384961051E-02,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,   3.1925383384961051E-02,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,  -3.1925383384961051E-02,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,   6.0501849860057044E-01,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,   6.0501849860057044E-01,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,  -6.0501849860057044E-01,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,   6.0501849860057044E-01,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,  -6.0501849860057044E-01,   7.9557110697085698E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,  -6.0501849860057044E-01,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,   6.0501849860057044E-01,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,  -6.0501849860057044E-01,  -7.9557110697085698E-01,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,   6.0501849860057044E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,   6.0501849860057044E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,  -6.0501849860057044E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,   6.0501849860057044E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,  -6.0501849860057044E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,  -6.0501849860057044E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,   6.0501849860057044E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,  -6.0501849860057044E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,   3.1925383384961051E-02,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,   3.1925383384961051E-02,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,  -3.1925383384961051E-02,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,   3.1925383384961051E-02,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,  -3.1925383384961051E-02,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   7.9557110697085698E-01,  -3.1925383384961051E-02,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,   3.1925383384961051E-02,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -7.9557110697085698E-01,  -3.1925383384961051E-02,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,   7.9557110697085698E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,   7.9557110697085698E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,  -7.9557110697085698E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,   7.9557110697085698E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,  -7.9557110697085698E-01,   3.1925383384961051E-02,   2.8675123885383950E-03],
            [   6.0501849860057044E-01,  -7.9557110697085698E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,   7.9557110697085698E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [  -6.0501849860057044E-01,  -7.9557110697085698E-01,  -3.1925383384961051E-02,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,   7.9557110697085698E-01,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,   7.9557110697085698E-01,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,  -7.9557110697085698E-01,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,   7.9557110697085698E-01,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,  -7.9557110697085698E-01,   6.0501849860057044E-01,   2.8675123885383950E-03],
            [   3.1925383384961051E-02,  -7.9557110697085698E-01,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,   7.9557110697085698E-01,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [  -3.1925383384961051E-02,  -7.9557110697085698E-01,  -6.0501849860057044E-01,   2.8675123885383950E-03],
            [   6.3901635508804000E-01,   6.4028243539623053E-02,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,   6.4028243539623053E-02,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,  -6.4028243539623053E-02,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,   6.4028243539623053E-02,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,  -6.4028243539623053E-02,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,  -6.4028243539623053E-02,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,   6.4028243539623053E-02,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,  -6.4028243539623053E-02,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,   6.3901635508804000E-01,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,   6.3901635508804000E-01,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,  -6.3901635508804000E-01,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,   6.3901635508804000E-01,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,  -6.3901635508804000E-01,   7.6652363431222825E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,  -6.3901635508804000E-01,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,   6.3901635508804000E-01,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,  -6.3901635508804000E-01,  -7.6652363431222825E-01,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,   6.3901635508804000E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,   6.3901635508804000E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,  -6.3901635508804000E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,   6.3901635508804000E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,  -6.3901635508804000E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,  -6.3901635508804000E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,   6.3901635508804000E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,  -6.3901635508804000E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,   6.4028243539623053E-02,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,   6.4028243539623053E-02,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,  -6.4028243539623053E-02,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,   6.4028243539623053E-02,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,  -6.4028243539623053E-02,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   7.6652363431222825E-01,  -6.4028243539623053E-02,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,   6.4028243539623053E-02,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -7.6652363431222825E-01,  -6.4028243539623053E-02,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,   7.6652363431222825E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,   7.6652363431222825E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,  -7.6652363431222825E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,   7.6652363431222825E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,  -7.6652363431222825E-01,   6.4028243539623053E-02,   2.8848873936830077E-03],
            [   6.3901635508804000E-01,  -7.6652363431222825E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,   7.6652363431222825E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [  -6.3901635508804000E-01,  -7.6652363431222825E-01,  -6.4028243539623053E-02,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,   7.6652363431222825E-01,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,   7.6652363431222825E-01,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,  -7.6652363431222825E-01,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,   7.6652363431222825E-01,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,  -7.6652363431222825E-01,   6.3901635508804000E-01,   2.8848873936830077E-03],
            [   6.4028243539623053E-02,  -7.6652363431222825E-01,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,   7.6652363431222825E-01,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [  -6.4028243539623053E-02,  -7.6652363431222825E-01,  -6.3901635508804000E-01,   2.8848873936830077E-03],
            [   6.7111991070884480E-01,   9.6098050770029086E-02,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,   9.6098050770029086E-02,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,  -9.6098050770029086E-02,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,   9.6098050770029086E-02,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,  -9.6098050770029086E-02,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,  -9.6098050770029086E-02,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,   9.6098050770029086E-02,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,  -9.6098050770029086E-02,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,   6.7111991070884480E-01,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,   6.7111991070884480E-01,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,  -6.7111991070884480E-01,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,   6.7111991070884480E-01,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,  -6.7111991070884480E-01,   7.3509402805923618E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,  -6.7111991070884480E-01,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,   6.7111991070884480E-01,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,  -6.7111991070884480E-01,  -7.3509402805923618E-01,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,   6.7111991070884480E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,   6.7111991070884480E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,  -6.7111991070884480E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,   6.7111991070884480E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,  -6.7111991070884480E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,  -6.7111991070884480E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,   6.7111991070884480E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,  -6.7111991070884480E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,   9.6098050770029086E-02,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,   9.6098050770029086E-02,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,  -9.6098050770029086E-02,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,   9.6098050770029086E-02,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,  -9.6098050770029086E-02,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   7.3509402805923618E-01,  -9.6098050770029086E-02,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,   9.6098050770029086E-02,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -7.3509402805923618E-01,  -9.6098050770029086E-02,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,   7.3509402805923618E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,   7.3509402805923618E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,  -7.3509402805923618E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,   7.3509402805923618E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,  -7.3509402805923618E-01,   9.6098050770029086E-02,   2.8943212246909352E-03],
            [   6.7111991070884480E-01,  -7.3509402805923618E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,   7.3509402805923618E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [  -6.7111991070884480E-01,  -7.3509402805923618E-01,  -9.6098050770029086E-02,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,   7.3509402805923618E-01,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,   7.3509402805923618E-01,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,  -7.3509402805923618E-01,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,   7.3509402805923618E-01,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,  -7.3509402805923618E-01,   6.7111991070884480E-01,   2.8943212246909352E-03],
            [   9.6098050770029086E-02,  -7.3509402805923618E-01,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,   7.3509402805923618E-01,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [  -9.6098050770029086E-02,  -7.3509402805923618E-01,  -6.7111991070884480E-01,   2.8943212246909352E-03],
            [   6.7413544295722749E-01,   3.2118531962732330E-02,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,   3.2118531962732330E-02,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,  -3.2118531962732330E-02,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,   3.2118531962732330E-02,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,  -3.2118531962732330E-02,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,  -3.2118531962732330E-02,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,   3.2118531962732330E-02,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,  -3.2118531962732330E-02,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,   6.7413544295722749E-01,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,   6.7413544295722749E-01,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,  -6.7413544295722749E-01,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,   6.7413544295722749E-01,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,  -6.7413544295722749E-01,   7.3790907600694389E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,  -6.7413544295722749E-01,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,   6.7413544295722749E-01,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,  -6.7413544295722749E-01,  -7.3790907600694389E-01,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,   6.7413544295722749E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,   6.7413544295722749E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,  -6.7413544295722749E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,   6.7413544295722749E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,  -6.7413544295722749E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,  -6.7413544295722749E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,   6.7413544295722749E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,  -6.7413544295722749E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,   3.2118531962732330E-02,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,   3.2118531962732330E-02,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,  -3.2118531962732330E-02,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,   3.2118531962732330E-02,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,  -3.2118531962732330E-02,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   7.3790907600694389E-01,  -3.2118531962732330E-02,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,   3.2118531962732330E-02,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -7.3790907600694389E-01,  -3.2118531962732330E-02,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,   7.3790907600694389E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,   7.3790907600694389E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,  -7.3790907600694389E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,   7.3790907600694389E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,  -7.3790907600694389E-01,   3.2118531962732330E-02,   2.8963372025414438E-03],
            [   6.7413544295722749E-01,  -7.3790907600694389E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,   7.3790907600694389E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [  -6.7413544295722749E-01,  -7.3790907600694389E-01,  -3.2118531962732330E-02,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,   7.3790907600694389E-01,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,   7.3790907600694389E-01,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,  -7.3790907600694389E-01,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,   7.3790907600694389E-01,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,  -7.3790907600694389E-01,   6.7413544295722749E-01,   2.8963372025414438E-03],
            [   3.2118531962732330E-02,  -7.3790907600694389E-01,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,   7.3790907600694389E-01,  -6.7413544295722749E-01,   2.8963372025414438E-03],
            [  -3.2118531962732330E-02,  -7.3790907600694389E-01,  -6.7413544295722749E-01,   2.8963372025414438E-03],
        ])
  
        order = 119
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build5294():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.1410906363197425E-03],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.1410906363197425E-03],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.1410906363197425E-03],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.1410906363197425E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.1410906363197425E-03],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.1410906363197425E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.6198675598583512E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.6198675598583512E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.6198675598583512E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6198675598583512E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.6198675598583512E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6198675598583512E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6198675598583512E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.6198675598583512E-03],
            [   2.3032616862614499E-02,   2.3032616862614499E-02,   9.9946935776987178E-01,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,   2.3032616862614499E-02,   9.9946935776987178E-01,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,  -2.3032616862614499E-02,   9.9946935776987178E-01,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,   2.3032616862614499E-02,  -9.9946935776987178E-01,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,  -2.3032616862614499E-02,   9.9946935776987178E-01,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,   2.3032616862614499E-02,  -9.9946935776987178E-01,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,  -2.3032616862614499E-02,  -9.9946935776987178E-01,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,  -2.3032616862614499E-02,  -9.9946935776987178E-01,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,   9.9946935776987178E-01,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,  -9.9946935776987178E-01,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,   9.9946935776987178E-01,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,  -9.9946935776987178E-01,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,   9.9946935776987178E-01,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,  -9.9946935776987178E-01,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -2.3032616862614499E-02,  -9.9946935776987178E-01,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [   2.3032616862614499E-02,   9.9946935776987178E-01,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [   9.9946935776987178E-01,   2.3032616862614499E-02,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -9.9946935776987178E-01,   2.3032616862614499E-02,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [   9.9946935776987178E-01,  -2.3032616862614499E-02,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [   9.9946935776987178E-01,   2.3032616862614499E-02,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -9.9946935776987178E-01,  -2.3032616862614499E-02,   2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -9.9946935776987178E-01,   2.3032616862614499E-02,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [   9.9946935776987178E-01,  -2.3032616862614499E-02,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [  -9.9946935776987178E-01,  -2.3032616862614499E-02,  -2.3032616862614499E-02,   6.2971410876584927E-04],
            [   3.7572086201623937E-02,   3.7572086201623937E-02,   9.9858734053507581E-01,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,   3.7572086201623937E-02,   9.9858734053507581E-01,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,  -3.7572086201623937E-02,   9.9858734053507581E-01,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,   3.7572086201623937E-02,  -9.9858734053507581E-01,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,  -3.7572086201623937E-02,   9.9858734053507581E-01,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,   3.7572086201623937E-02,  -9.9858734053507581E-01,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,  -3.7572086201623937E-02,  -9.9858734053507581E-01,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,  -3.7572086201623937E-02,  -9.9858734053507581E-01,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,   9.9858734053507581E-01,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,  -9.9858734053507581E-01,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,   9.9858734053507581E-01,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,  -9.9858734053507581E-01,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,   9.9858734053507581E-01,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,  -9.9858734053507581E-01,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -3.7572086201623937E-02,  -9.9858734053507581E-01,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [   3.7572086201623937E-02,   9.9858734053507581E-01,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [   9.9858734053507581E-01,   3.7572086201623937E-02,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -9.9858734053507581E-01,   3.7572086201623937E-02,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [   9.9858734053507581E-01,  -3.7572086201623937E-02,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [   9.9858734053507581E-01,   3.7572086201623937E-02,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -9.9858734053507581E-01,  -3.7572086201623937E-02,   3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -9.9858734053507581E-01,   3.7572086201623937E-02,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [   9.9858734053507581E-01,  -3.7572086201623937E-02,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [  -9.9858734053507581E-01,  -3.7572086201623937E-02,  -3.7572086201623937E-02,   7.4675913851480807E-04],
            [   5.8219120338218522E-02,   5.8219120338218522E-02,   9.9660477023446359E-01,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,   5.8219120338218522E-02,   9.9660477023446359E-01,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,  -5.8219120338218522E-02,   9.9660477023446359E-01,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,   5.8219120338218522E-02,  -9.9660477023446359E-01,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,  -5.8219120338218522E-02,   9.9660477023446359E-01,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,   5.8219120338218522E-02,  -9.9660477023446359E-01,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,  -5.8219120338218522E-02,  -9.9660477023446359E-01,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,  -5.8219120338218522E-02,  -9.9660477023446359E-01,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,   9.9660477023446359E-01,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,  -9.9660477023446359E-01,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,   9.9660477023446359E-01,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,  -9.9660477023446359E-01,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,   9.9660477023446359E-01,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,  -9.9660477023446359E-01,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -5.8219120338218522E-02,  -9.9660477023446359E-01,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [   5.8219120338218522E-02,   9.9660477023446359E-01,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [   9.9660477023446359E-01,   5.8219120338218522E-02,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -9.9660477023446359E-01,   5.8219120338218522E-02,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [   9.9660477023446359E-01,  -5.8219120338218522E-02,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [   9.9660477023446359E-01,   5.8219120338218522E-02,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -9.9660477023446359E-01,  -5.8219120338218522E-02,   5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -9.9660477023446359E-01,   5.8219120338218522E-02,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [   9.9660477023446359E-01,  -5.8219120338218522E-02,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [  -9.9660477023446359E-01,  -5.8219120338218522E-02,  -5.8219120338218522E-02,   1.2018973008695410E-03],
            [   8.4031275291948718E-02,   8.4031275291948718E-02,   9.9291363649897446E-01,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,   8.4031275291948718E-02,   9.9291363649897446E-01,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,  -8.4031275291948718E-02,   9.9291363649897446E-01,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,   8.4031275291948718E-02,  -9.9291363649897446E-01,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,  -8.4031275291948718E-02,   9.9291363649897446E-01,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,   8.4031275291948718E-02,  -9.9291363649897446E-01,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,  -8.4031275291948718E-02,  -9.9291363649897446E-01,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,  -8.4031275291948718E-02,  -9.9291363649897446E-01,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,   9.9291363649897446E-01,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,  -9.9291363649897446E-01,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,   9.9291363649897446E-01,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,  -9.9291363649897446E-01,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,   9.9291363649897446E-01,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,  -9.9291363649897446E-01,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -8.4031275291948718E-02,  -9.9291363649897446E-01,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [   8.4031275291948718E-02,   9.9291363649897446E-01,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [   9.9291363649897446E-01,   8.4031275291948718E-02,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -9.9291363649897446E-01,   8.4031275291948718E-02,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [   9.9291363649897446E-01,  -8.4031275291948718E-02,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [   9.9291363649897446E-01,   8.4031275291948718E-02,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -9.9291363649897446E-01,  -8.4031275291948718E-02,   8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -9.9291363649897446E-01,   8.4031275291948718E-02,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [   9.9291363649897446E-01,  -8.4031275291948718E-02,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [  -9.9291363649897446E-01,  -8.4031275291948718E-02,  -8.4031275291948718E-02,   1.4897817612134334E-03],
            [   1.1229277980605780E-01,   1.1229277980605780E-01,   9.8730981115699257E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,   1.1229277980605780E-01,   9.8730981115699257E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,  -1.1229277980605780E-01,   9.8730981115699257E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,   1.1229277980605780E-01,  -9.8730981115699257E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,  -1.1229277980605780E-01,   9.8730981115699257E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,   1.1229277980605780E-01,  -9.8730981115699257E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,  -1.1229277980605780E-01,  -9.8730981115699257E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,  -1.1229277980605780E-01,  -9.8730981115699257E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,   9.8730981115699257E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,  -9.8730981115699257E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,   9.8730981115699257E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,  -9.8730981115699257E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,   9.8730981115699257E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,  -9.8730981115699257E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -1.1229277980605780E-01,  -9.8730981115699257E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [   1.1229277980605780E-01,   9.8730981115699257E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [   9.8730981115699257E-01,   1.1229277980605780E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -9.8730981115699257E-01,   1.1229277980605780E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [   9.8730981115699257E-01,  -1.1229277980605780E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [   9.8730981115699257E-01,   1.1229277980605780E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -9.8730981115699257E-01,  -1.1229277980605780E-01,   1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -9.8730981115699257E-01,   1.1229277980605780E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [   9.8730981115699257E-01,  -1.1229277980605780E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [  -9.8730981115699257E-01,  -1.1229277980605780E-01,  -1.1229277980605780E-01,   1.7146939802459907E-03],
            [   1.4201253191929869E-01,   1.4201253191929869E-01,   9.7962486777119961E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,   1.4201253191929869E-01,   9.7962486777119961E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,  -1.4201253191929869E-01,   9.7962486777119961E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,   1.4201253191929869E-01,  -9.7962486777119961E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,  -1.4201253191929869E-01,   9.7962486777119961E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,   1.4201253191929869E-01,  -9.7962486777119961E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,  -1.4201253191929869E-01,  -9.7962486777119961E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,  -1.4201253191929869E-01,  -9.7962486777119961E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,   9.7962486777119961E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,  -9.7962486777119961E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,   9.7962486777119961E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,  -9.7962486777119961E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,   9.7962486777119961E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,  -9.7962486777119961E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -1.4201253191929869E-01,  -9.7962486777119961E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [   1.4201253191929869E-01,   9.7962486777119961E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [   9.7962486777119961E-01,   1.4201253191929869E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -9.7962486777119961E-01,   1.4201253191929869E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [   9.7962486777119961E-01,  -1.4201253191929869E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [   9.7962486777119961E-01,   1.4201253191929869E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -9.7962486777119961E-01,  -1.4201253191929869E-01,   1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -9.7962486777119961E-01,   1.4201253191929869E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [   9.7962486777119961E-01,  -1.4201253191929869E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [  -9.7962486777119961E-01,  -1.4201253191929869E-01,  -1.4201253191929869E-01,   1.8922803104342871E-03],
            [   1.7263964373419780E-01,   1.7263964373419780E-01,   9.6973764845068200E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,   1.7263964373419780E-01,   9.6973764845068200E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,  -1.7263964373419780E-01,   9.6973764845068200E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,   1.7263964373419780E-01,  -9.6973764845068200E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,  -1.7263964373419780E-01,   9.6973764845068200E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,   1.7263964373419780E-01,  -9.6973764845068200E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,  -1.7263964373419780E-01,  -9.6973764845068200E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,  -1.7263964373419780E-01,  -9.6973764845068200E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,   9.6973764845068200E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,  -9.6973764845068200E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,   9.6973764845068200E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,  -9.6973764845068200E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,   9.6973764845068200E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,  -9.6973764845068200E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -1.7263964373419780E-01,  -9.6973764845068200E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [   1.7263964373419780E-01,   9.6973764845068200E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [   9.6973764845068200E-01,   1.7263964373419780E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -9.6973764845068200E-01,   1.7263964373419780E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [   9.6973764845068200E-01,  -1.7263964373419780E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [   9.6973764845068200E-01,   1.7263964373419780E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -9.6973764845068200E-01,  -1.7263964373419780E-01,   1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -9.6973764845068200E-01,   1.7263964373419780E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [   9.6973764845068200E-01,  -1.7263964373419780E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [  -9.6973764845068200E-01,  -1.7263964373419780E-01,  -1.7263964373419780E-01,   2.0348708226197499E-03],
            [   2.0381700581156961E-01,   2.0381700581156961E-01,   9.5755796497340739E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,   2.0381700581156961E-01,   9.5755796497340739E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,  -2.0381700581156961E-01,   9.5755796497340739E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,   2.0381700581156961E-01,  -9.5755796497340739E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,  -2.0381700581156961E-01,   9.5755796497340739E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,   2.0381700581156961E-01,  -9.5755796497340739E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,  -2.0381700581156961E-01,  -9.5755796497340739E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,  -2.0381700581156961E-01,  -9.5755796497340739E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,   9.5755796497340739E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,  -9.5755796497340739E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,   9.5755796497340739E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,  -9.5755796497340739E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,   9.5755796497340739E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,  -9.5755796497340739E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -2.0381700581156961E-01,  -9.5755796497340739E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [   2.0381700581156961E-01,   9.5755796497340739E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [   9.5755796497340739E-01,   2.0381700581156961E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -9.5755796497340739E-01,   2.0381700581156961E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [   9.5755796497340739E-01,  -2.0381700581156961E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [   9.5755796497340739E-01,   2.0381700581156961E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -9.5755796497340739E-01,  -2.0381700581156961E-01,   2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -9.5755796497340739E-01,   2.0381700581156961E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [   9.5755796497340739E-01,  -2.0381700581156961E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [  -9.5755796497340739E-01,  -2.0381700581156961E-01,  -2.0381700581156961E-01,   2.1519287695375292E-03],
            [   2.3528498928765079E-01,   2.3528498928765079E-01,   9.4301746942027542E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,   2.3528498928765079E-01,   9.4301746942027542E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,  -2.3528498928765079E-01,   9.4301746942027542E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,   2.3528498928765079E-01,  -9.4301746942027542E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,  -2.3528498928765079E-01,   9.4301746942027542E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,   2.3528498928765079E-01,  -9.4301746942027542E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,  -2.3528498928765079E-01,  -9.4301746942027542E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,  -2.3528498928765079E-01,  -9.4301746942027542E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,   9.4301746942027542E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,  -9.4301746942027542E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,   9.4301746942027542E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,  -9.4301746942027542E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,   9.4301746942027542E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,  -9.4301746942027542E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -2.3528498928765079E-01,  -9.4301746942027542E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [   2.3528498928765079E-01,   9.4301746942027542E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [   9.4301746942027542E-01,   2.3528498928765079E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -9.4301746942027542E-01,   2.3528498928765079E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [   9.4301746942027542E-01,  -2.3528498928765079E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [   9.4301746942027542E-01,   2.3528498928765079E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -9.4301746942027542E-01,  -2.3528498928765079E-01,   2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -9.4301746942027542E-01,   2.3528498928765079E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [   9.4301746942027542E-01,  -2.3528498928765079E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [  -9.4301746942027542E-01,  -2.3528498928765079E-01,  -2.3528498928765079E-01,   2.2492434898883709E-03],
            [   2.6683633543124607E-01,   2.6683633543124607E-01,   9.2606519219072647E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,   2.6683633543124607E-01,   9.2606519219072647E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,  -2.6683633543124607E-01,   9.2606519219072647E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,   2.6683633543124607E-01,  -9.2606519219072647E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,  -2.6683633543124607E-01,   9.2606519219072647E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,   2.6683633543124607E-01,  -9.2606519219072647E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,  -2.6683633543124607E-01,  -9.2606519219072647E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,  -2.6683633543124607E-01,  -9.2606519219072647E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,   9.2606519219072647E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,  -9.2606519219072647E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,   9.2606519219072647E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,  -9.2606519219072647E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,   9.2606519219072647E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,  -9.2606519219072647E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -2.6683633543124607E-01,  -9.2606519219072647E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [   2.6683633543124607E-01,   9.2606519219072647E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [   9.2606519219072647E-01,   2.6683633543124607E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -9.2606519219072647E-01,   2.6683633543124607E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [   9.2606519219072647E-01,  -2.6683633543124607E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [   9.2606519219072647E-01,   2.6683633543124607E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -9.2606519219072647E-01,  -2.6683633543124607E-01,   2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -9.2606519219072647E-01,   2.6683633543124607E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [   9.2606519219072647E-01,  -2.6683633543124607E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [  -9.2606519219072647E-01,  -2.6683633543124607E-01,  -2.6683633543124607E-01,   2.3304019587491284E-03],
            [   2.9829412799004518E-01,   2.9829412799004518E-01,   9.0666489201541112E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,   2.9829412799004518E-01,   9.0666489201541112E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,  -2.9829412799004518E-01,   9.0666489201541112E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,   2.9829412799004518E-01,  -9.0666489201541112E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,  -2.9829412799004518E-01,   9.0666489201541112E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,   2.9829412799004518E-01,  -9.0666489201541112E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,  -2.9829412799004518E-01,  -9.0666489201541112E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,  -2.9829412799004518E-01,  -9.0666489201541112E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,   9.0666489201541112E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,  -9.0666489201541112E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,   9.0666489201541112E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,  -9.0666489201541112E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,   9.0666489201541112E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,  -9.0666489201541112E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -2.9829412799004518E-01,  -9.0666489201541112E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [   2.9829412799004518E-01,   9.0666489201541112E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [   9.0666489201541112E-01,   2.9829412799004518E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -9.0666489201541112E-01,   2.9829412799004518E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [   9.0666489201541112E-01,  -2.9829412799004518E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [   9.0666489201541112E-01,   2.9829412799004518E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -9.0666489201541112E-01,  -2.9829412799004518E-01,   2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -9.0666489201541112E-01,   2.9829412799004518E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [   9.0666489201541112E-01,  -2.9829412799004518E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [  -9.0666489201541112E-01,  -2.9829412799004518E-01,  -2.9829412799004518E-01,   2.3978502955725408E-03],
            [   3.2950029220870758E-01,   3.2950029220870758E-01,   8.8479326108913869E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,   3.2950029220870758E-01,   8.8479326108913869E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,  -3.2950029220870758E-01,   8.8479326108913869E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,   3.2950029220870758E-01,  -8.8479326108913869E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,  -3.2950029220870758E-01,   8.8479326108913869E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,   3.2950029220870758E-01,  -8.8479326108913869E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,  -3.2950029220870758E-01,  -8.8479326108913869E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,  -3.2950029220870758E-01,  -8.8479326108913869E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,   8.8479326108913869E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,  -8.8479326108913869E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,   8.8479326108913869E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,  -8.8479326108913869E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,   8.8479326108913869E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,  -8.8479326108913869E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -3.2950029220870758E-01,  -8.8479326108913869E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [   3.2950029220870758E-01,   8.8479326108913869E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [   8.8479326108913869E-01,   3.2950029220870758E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -8.8479326108913869E-01,   3.2950029220870758E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [   8.8479326108913869E-01,  -3.2950029220870758E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [   8.8479326108913869E-01,   3.2950029220870758E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -8.8479326108913869E-01,  -3.2950029220870758E-01,   3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -8.8479326108913869E-01,   3.2950029220870758E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [   8.8479326108913869E-01,  -3.2950029220870758E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [  -8.8479326108913869E-01,  -3.2950029220870758E-01,  -3.2950029220870758E-01,   2.4534298053872435E-03],
            [   3.6030949183635930E-01,   3.6030949183635930E-01,   8.6043834188467516E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,   3.6030949183635930E-01,   8.6043834188467516E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,  -3.6030949183635930E-01,   8.6043834188467516E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,   3.6030949183635930E-01,  -8.6043834188467516E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,  -3.6030949183635930E-01,   8.6043834188467516E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,   3.6030949183635930E-01,  -8.6043834188467516E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,  -3.6030949183635930E-01,  -8.6043834188467516E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,  -3.6030949183635930E-01,  -8.6043834188467516E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,   8.6043834188467516E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,  -8.6043834188467516E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,   8.6043834188467516E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,  -8.6043834188467516E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,   8.6043834188467516E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,  -8.6043834188467516E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -3.6030949183635930E-01,  -8.6043834188467516E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [   3.6030949183635930E-01,   8.6043834188467516E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [   8.6043834188467516E-01,   3.6030949183635930E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -8.6043834188467516E-01,   3.6030949183635930E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [   8.6043834188467516E-01,  -3.6030949183635930E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [   8.6043834188467516E-01,   3.6030949183635930E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -8.6043834188467516E-01,  -3.6030949183635930E-01,   3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -8.6043834188467516E-01,   3.6030949183635930E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [   8.6043834188467516E-01,  -3.6030949183635930E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [  -8.6043834188467516E-01,  -3.6030949183635930E-01,  -3.6030949183635930E-01,   2.4986333640095214E-03],
            [   3.9058578951739198E-01,   3.9058578951739198E-01,   8.3359791389743243E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,   3.9058578951739198E-01,   8.3359791389743243E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,  -3.9058578951739198E-01,   8.3359791389743243E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,   3.9058578951739198E-01,  -8.3359791389743243E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,  -3.9058578951739198E-01,   8.3359791389743243E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,   3.9058578951739198E-01,  -8.3359791389743243E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,  -3.9058578951739198E-01,  -8.3359791389743243E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,  -3.9058578951739198E-01,  -8.3359791389743243E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,   8.3359791389743243E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,  -8.3359791389743243E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,   8.3359791389743243E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,  -8.3359791389743243E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,   8.3359791389743243E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,  -8.3359791389743243E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -3.9058578951739198E-01,  -8.3359791389743243E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [   3.9058578951739198E-01,   8.3359791389743243E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [   8.3359791389743243E-01,   3.9058578951739198E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -8.3359791389743243E-01,   3.9058578951739198E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [   8.3359791389743243E-01,  -3.9058578951739198E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [   8.3359791389743243E-01,   3.9058578951739198E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -8.3359791389743243E-01,  -3.9058578951739198E-01,   3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -8.3359791389743243E-01,   3.9058578951739198E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [   8.3359791389743243E-01,  -3.9058578951739198E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [  -8.3359791389743243E-01,  -3.9058578951739198E-01,  -3.9058578951739198E-01,   2.5347372415513319E-03],
            [   4.2020057581608372E-01,   4.2020057581608372E-01,   8.0427790729800819E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,   4.2020057581608372E-01,   8.0427790729800819E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,  -4.2020057581608372E-01,   8.0427790729800819E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,   4.2020057581608372E-01,  -8.0427790729800819E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,  -4.2020057581608372E-01,   8.0427790729800819E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,   4.2020057581608372E-01,  -8.0427790729800819E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,  -4.2020057581608372E-01,  -8.0427790729800819E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,  -4.2020057581608372E-01,  -8.0427790729800819E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,   8.0427790729800819E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,  -8.0427790729800819E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,   8.0427790729800819E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,  -8.0427790729800819E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,   8.0427790729800819E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,  -8.0427790729800819E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -4.2020057581608372E-01,  -8.0427790729800819E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [   4.2020057581608372E-01,   8.0427790729800819E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [   8.0427790729800819E-01,   4.2020057581608372E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -8.0427790729800819E-01,   4.2020057581608372E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [   8.0427790729800819E-01,  -4.2020057581608372E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [   8.0427790729800819E-01,   4.2020057581608372E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -8.0427790729800819E-01,  -4.2020057581608372E-01,   4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -8.0427790729800819E-01,   4.2020057581608372E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [   8.0427790729800819E-01,  -4.2020057581608372E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [  -8.0427790729800819E-01,  -4.2020057581608372E-01,  -4.2020057581608372E-01,   2.5628774615332073E-03],
            [   4.4903100615972269E-01,   4.4903100615972269E-01,   7.7249097795014676E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,   4.4903100615972269E-01,   7.7249097795014676E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,  -4.4903100615972269E-01,   7.7249097795014676E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,   4.4903100615972269E-01,  -7.7249097795014676E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,  -4.4903100615972269E-01,   7.7249097795014676E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,   4.4903100615972269E-01,  -7.7249097795014676E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,  -4.4903100615972269E-01,  -7.7249097795014676E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,  -4.4903100615972269E-01,  -7.7249097795014676E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,   7.7249097795014676E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,  -7.7249097795014676E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,   7.7249097795014676E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,  -7.7249097795014676E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,   7.7249097795014676E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,  -7.7249097795014676E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -4.4903100615972269E-01,  -7.7249097795014676E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [   4.4903100615972269E-01,   7.7249097795014676E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [   7.7249097795014676E-01,   4.4903100615972269E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -7.7249097795014676E-01,   4.4903100615972269E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [   7.7249097795014676E-01,  -4.4903100615972269E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [   7.7249097795014676E-01,   4.4903100615972269E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -7.7249097795014676E-01,  -4.4903100615972269E-01,   4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -7.7249097795014676E-01,   4.4903100615972269E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [   7.7249097795014676E-01,  -4.4903100615972269E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [  -7.7249097795014676E-01,  -4.4903100615972269E-01,  -4.4903100615972269E-01,   2.5840985386192117E-03],
            [   4.7695861603114909E-01,   4.7695861603114909E-01,   7.3825534687349326E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,   4.7695861603114909E-01,   7.3825534687349326E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,  -4.7695861603114909E-01,   7.3825534687349326E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,   4.7695861603114909E-01,  -7.3825534687349326E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,  -4.7695861603114909E-01,   7.3825534687349326E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,   4.7695861603114909E-01,  -7.3825534687349326E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,  -4.7695861603114909E-01,  -7.3825534687349326E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,  -4.7695861603114909E-01,  -7.3825534687349326E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,   7.3825534687349326E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,  -7.3825534687349326E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,   7.3825534687349326E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,  -7.3825534687349326E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,   7.3825534687349326E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,  -7.3825534687349326E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -4.7695861603114909E-01,  -7.3825534687349326E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [   4.7695861603114909E-01,   7.3825534687349326E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [   7.3825534687349326E-01,   4.7695861603114909E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -7.3825534687349326E-01,   4.7695861603114909E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [   7.3825534687349326E-01,  -4.7695861603114909E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [   7.3825534687349326E-01,   4.7695861603114909E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -7.3825534687349326E-01,  -4.7695861603114909E-01,   4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -7.3825534687349326E-01,   4.7695861603114909E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [   7.3825534687349326E-01,  -4.7695861603114909E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [  -7.3825534687349326E-01,  -4.7695861603114909E-01,  -4.7695861603114909E-01,   2.5993862118030573E-03],
            [   5.0386798870497496E-01,   5.0386798870497496E-01,   7.0159397083840913E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,   5.0386798870497496E-01,   7.0159397083840913E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,  -5.0386798870497496E-01,   7.0159397083840913E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,   5.0386798870497496E-01,  -7.0159397083840913E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,  -5.0386798870497496E-01,   7.0159397083840913E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,   5.0386798870497496E-01,  -7.0159397083840913E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,  -5.0386798870497496E-01,  -7.0159397083840913E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,  -5.0386798870497496E-01,  -7.0159397083840913E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,   7.0159397083840913E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,  -7.0159397083840913E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,   7.0159397083840913E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,  -7.0159397083840913E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,   7.0159397083840913E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,  -7.0159397083840913E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -5.0386798870497496E-01,  -7.0159397083840913E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [   5.0386798870497496E-01,   7.0159397083840913E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [   7.0159397083840913E-01,   5.0386798870497496E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -7.0159397083840913E-01,   5.0386798870497496E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [   7.0159397083840913E-01,  -5.0386798870497496E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [   7.0159397083840913E-01,   5.0386798870497496E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -7.0159397083840913E-01,  -5.0386798870497496E-01,   5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -7.0159397083840913E-01,   5.0386798870497496E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [   7.0159397083840913E-01,  -5.0386798870497496E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [  -7.0159397083840913E-01,  -5.0386798870497496E-01,  -5.0386798870497496E-01,   2.6096894475158040E-03],
            [   5.2964542865199615E-01,   5.2964542865199615E-01,   6.6253410464374329E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,   5.2964542865199615E-01,   6.6253410464374329E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,  -5.2964542865199615E-01,   6.6253410464374329E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,   5.2964542865199615E-01,  -6.6253410464374329E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,  -5.2964542865199615E-01,   6.6253410464374329E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,   5.2964542865199615E-01,  -6.6253410464374329E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,  -5.2964542865199615E-01,  -6.6253410464374329E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,  -5.2964542865199615E-01,  -6.6253410464374329E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,   6.6253410464374329E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,  -6.6253410464374329E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,   6.6253410464374329E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,  -6.6253410464374329E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,   6.6253410464374329E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,  -6.6253410464374329E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -5.2964542865199615E-01,  -6.6253410464374329E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [   5.2964542865199615E-01,   6.6253410464374329E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [   6.6253410464374329E-01,   5.2964542865199615E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -6.6253410464374329E-01,   5.2964542865199615E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [   6.6253410464374329E-01,  -5.2964542865199615E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [   6.6253410464374329E-01,   5.2964542865199615E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -6.6253410464374329E-01,  -5.2964542865199615E-01,   5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -6.6253410464374329E-01,   5.2964542865199615E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [   6.6253410464374329E-01,  -5.2964542865199615E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [  -6.6253410464374329E-01,  -5.2964542865199615E-01,  -5.2964542865199615E-01,   2.6159341806128189E-03],
            [   5.5417762071648502E-01,   5.5417762071648502E-01,   6.2110734128170741E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,   5.5417762071648502E-01,   6.2110734128170741E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,  -5.5417762071648502E-01,   6.2110734128170741E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,   5.5417762071648502E-01,  -6.2110734128170741E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,  -5.5417762071648502E-01,   6.2110734128170741E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,   5.5417762071648502E-01,  -6.2110734128170741E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,  -5.5417762071648502E-01,  -6.2110734128170741E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,  -5.5417762071648502E-01,  -6.2110734128170741E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,   6.2110734128170741E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,  -6.2110734128170741E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,   6.2110734128170741E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,  -6.2110734128170741E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,   6.2110734128170741E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,  -6.2110734128170741E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -5.5417762071648502E-01,  -6.2110734128170741E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [   5.5417762071648502E-01,   6.2110734128170741E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [   6.2110734128170741E-01,   5.5417762071648502E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -6.2110734128170741E-01,   5.5417762071648502E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [   6.2110734128170741E-01,  -5.5417762071648502E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [   6.2110734128170741E-01,   5.5417762071648502E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -6.2110734128170741E-01,  -5.5417762071648502E-01,   5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -6.2110734128170741E-01,   5.5417762071648502E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [   6.2110734128170741E-01,  -5.5417762071648502E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [  -6.2110734128170741E-01,  -5.5417762071648502E-01,  -5.5417762071648502E-01,   2.6190297212646961E-03],
            [   5.9904673219212135E-01,   5.9904673219212135E-01,   5.3130596204059455E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,   5.9904673219212135E-01,   5.3130596204059455E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,  -5.9904673219212135E-01,   5.3130596204059455E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,   5.9904673219212135E-01,  -5.3130596204059455E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,  -5.9904673219212135E-01,   5.3130596204059455E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,   5.9904673219212135E-01,  -5.3130596204059455E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,  -5.9904673219212135E-01,  -5.3130596204059455E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,  -5.9904673219212135E-01,  -5.3130596204059455E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,   5.3130596204059455E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,  -5.3130596204059455E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,   5.3130596204059455E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,  -5.3130596204059455E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,   5.3130596204059455E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,  -5.3130596204059455E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.9904673219212135E-01,  -5.3130596204059455E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.9904673219212135E-01,   5.3130596204059455E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.3130596204059455E-01,   5.9904673219212135E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.3130596204059455E-01,   5.9904673219212135E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.3130596204059455E-01,  -5.9904673219212135E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.3130596204059455E-01,   5.9904673219212135E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.3130596204059455E-01,  -5.9904673219212135E-01,   5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.3130596204059455E-01,   5.9904673219212135E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [   5.3130596204059455E-01,  -5.9904673219212135E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [  -5.3130596204059455E-01,  -5.9904673219212135E-01,  -5.9904673219212135E-01,   2.6193110821887329E-03],
            [   6.1914670962945872E-01,   6.1914670962945872E-01,   4.8302660786961765E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,   6.1914670962945872E-01,   4.8302660786961765E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,  -6.1914670962945872E-01,   4.8302660786961765E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,   6.1914670962945872E-01,  -4.8302660786961765E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,  -6.1914670962945872E-01,   4.8302660786961765E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,   6.1914670962945872E-01,  -4.8302660786961765E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,  -6.1914670962945872E-01,  -4.8302660786961765E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,  -6.1914670962945872E-01,  -4.8302660786961765E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,   4.8302660786961765E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,  -4.8302660786961765E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,   4.8302660786961765E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,  -4.8302660786961765E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,   4.8302660786961765E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,  -4.8302660786961765E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -6.1914670962945872E-01,  -4.8302660786961765E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [   6.1914670962945872E-01,   4.8302660786961765E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [   4.8302660786961765E-01,   6.1914670962945872E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -4.8302660786961765E-01,   6.1914670962945872E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [   4.8302660786961765E-01,  -6.1914670962945872E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [   4.8302660786961765E-01,   6.1914670962945872E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -4.8302660786961765E-01,  -6.1914670962945872E-01,   6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -4.8302660786961765E-01,   6.1914670962945872E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [   4.8302660786961765E-01,  -6.1914670962945872E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [  -4.8302660786961765E-01,  -6.1914670962945872E-01,  -6.1914670962945872E-01,   2.6181735064632174E-03],
            [   6.3752512129018490E-01,   6.3752512129018490E-01,   4.3257766868837555E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,   6.3752512129018490E-01,   4.3257766868837555E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,  -6.3752512129018490E-01,   4.3257766868837555E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,   6.3752512129018490E-01,  -4.3257766868837555E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,  -6.3752512129018490E-01,   4.3257766868837555E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,   6.3752512129018490E-01,  -4.3257766868837555E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,  -6.3752512129018490E-01,  -4.3257766868837555E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,  -6.3752512129018490E-01,  -4.3257766868837555E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,   4.3257766868837555E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,  -4.3257766868837555E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,   4.3257766868837555E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,  -4.3257766868837555E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,   4.3257766868837555E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,  -4.3257766868837555E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -6.3752512129018490E-01,  -4.3257766868837555E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [   6.3752512129018490E-01,   4.3257766868837555E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [   4.3257766868837555E-01,   6.3752512129018490E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -4.3257766868837555E-01,   6.3752512129018490E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [   4.3257766868837555E-01,  -6.3752512129018490E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [   4.3257766868837555E-01,   6.3752512129018490E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -4.3257766868837555E-01,  -6.3752512129018490E-01,   6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -4.3257766868837555E-01,   6.3752512129018490E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [   4.3257766868837555E-01,  -6.3752512129018490E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [  -4.3257766868837555E-01,  -6.3752512129018490E-01,  -6.3752512129018490E-01,   2.6171806592990309E-03],
            [   6.5405143811311683E-01,   6.5405143811311683E-01,   3.8004398772290476E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,   6.5405143811311683E-01,   3.8004398772290476E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,  -6.5405143811311683E-01,   3.8004398772290476E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,   6.5405143811311683E-01,  -3.8004398772290476E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,  -6.5405143811311683E-01,   3.8004398772290476E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,   6.5405143811311683E-01,  -3.8004398772290476E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,  -6.5405143811311683E-01,  -3.8004398772290476E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,  -6.5405143811311683E-01,  -3.8004398772290476E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,   3.8004398772290476E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,  -3.8004398772290476E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,   3.8004398772290476E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,  -3.8004398772290476E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,   3.8004398772290476E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,  -3.8004398772290476E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -6.5405143811311683E-01,  -3.8004398772290476E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [   6.5405143811311683E-01,   3.8004398772290476E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [   3.8004398772290476E-01,   6.5405143811311683E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -3.8004398772290476E-01,   6.5405143811311683E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [   3.8004398772290476E-01,  -6.5405143811311683E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [   3.8004398772290476E-01,   6.5405143811311683E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -3.8004398772290476E-01,  -6.5405143811311683E-01,   6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -3.8004398772290476E-01,   6.5405143811311683E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [   3.8004398772290476E-01,  -6.5405143811311683E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [  -3.8004398772290476E-01,  -6.5405143811311683E-01,  -6.5405143811311683E-01,   2.6169161267080507E-03],
            [   6.6858990643915095E-01,   6.6858990643915095E-01,   3.2553812989475556E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,   6.6858990643915095E-01,   3.2553812989475556E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,  -6.6858990643915095E-01,   3.2553812989475556E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,   6.6858990643915095E-01,  -3.2553812989475556E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,  -6.6858990643915095E-01,   3.2553812989475556E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,   6.6858990643915095E-01,  -3.2553812989475556E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,  -6.6858990643915095E-01,  -3.2553812989475556E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,  -6.6858990643915095E-01,  -3.2553812989475556E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,   3.2553812989475556E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,  -3.2553812989475556E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,   3.2553812989475556E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,  -3.2553812989475556E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,   3.2553812989475556E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,  -3.2553812989475556E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -6.6858990643915095E-01,  -3.2553812989475556E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [   6.6858990643915095E-01,   3.2553812989475556E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [   3.2553812989475556E-01,   6.6858990643915095E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -3.2553812989475556E-01,   6.6858990643915095E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [   3.2553812989475556E-01,  -6.6858990643915095E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [   3.2553812989475556E-01,   6.6858990643915095E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -3.2553812989475556E-01,  -6.6858990643915095E-01,   6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -3.2553812989475556E-01,   6.6858990643915095E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [   3.2553812989475556E-01,  -6.6858990643915095E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [  -3.2553812989475556E-01,  -6.6858990643915095E-01,  -6.6858990643915095E-01,   2.6177507525947459E-03],
            [   6.8100130096816480E-01,   6.8100130096816480E-01,   2.6921080245661394E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,   6.8100130096816480E-01,   2.6921080245661394E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6921080245661394E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,   6.8100130096816480E-01,  -2.6921080245661394E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6921080245661394E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,   6.8100130096816480E-01,  -2.6921080245661394E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,  -6.8100130096816480E-01,  -2.6921080245661394E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,  -6.8100130096816480E-01,  -2.6921080245661394E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,   2.6921080245661394E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,  -2.6921080245661394E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,   2.6921080245661394E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,  -2.6921080245661394E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,   2.6921080245661394E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,  -2.6921080245661394E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -6.8100130096816480E-01,  -2.6921080245661394E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [   6.8100130096816480E-01,   2.6921080245661394E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [   2.6921080245661394E-01,   6.8100130096816480E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -2.6921080245661394E-01,   6.8100130096816480E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [   2.6921080245661394E-01,  -6.8100130096816480E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [   2.6921080245661394E-01,   6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -2.6921080245661394E-01,  -6.8100130096816480E-01,   6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -2.6921080245661394E-01,   6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [   2.6921080245661394E-01,  -6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [  -2.6921080245661394E-01,  -6.8100130096816480E-01,  -6.8100130096816480E-01,   2.6197685366611758E-03],
            [   6.9114695787303404E-01,   6.9114695787303404E-01,   2.1126231383211963E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,   6.9114695787303404E-01,   2.1126231383211963E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,  -6.9114695787303404E-01,   2.1126231383211963E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,   6.9114695787303404E-01,  -2.1126231383211963E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,  -6.9114695787303404E-01,   2.1126231383211963E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,   6.9114695787303404E-01,  -2.1126231383211963E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,  -6.9114695787303404E-01,  -2.1126231383211963E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,  -6.9114695787303404E-01,  -2.1126231383211963E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,   2.1126231383211963E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,  -2.1126231383211963E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,   2.1126231383211963E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,  -2.1126231383211963E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,   2.1126231383211963E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,  -2.1126231383211963E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -6.9114695787303404E-01,  -2.1126231383211963E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [   6.9114695787303404E-01,   2.1126231383211963E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [   2.1126231383211963E-01,   6.9114695787303404E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -2.1126231383211963E-01,   6.9114695787303404E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [   2.1126231383211963E-01,  -6.9114695787303404E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [   2.1126231383211963E-01,   6.9114695787303404E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -2.1126231383211963E-01,  -6.9114695787303404E-01,   6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -2.1126231383211963E-01,   6.9114695787303404E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [   2.1126231383211963E-01,  -6.9114695787303404E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [  -2.1126231383211963E-01,  -6.9114695787303404E-01,  -6.9114695787303404E-01,   2.6227162949891076E-03],
            [   6.9889569151417363E-01,   6.9889569151417363E-01,   1.5195270568782276E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,   6.9889569151417363E-01,   1.5195270568782276E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,  -6.9889569151417363E-01,   1.5195270568782276E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,   6.9889569151417363E-01,  -1.5195270568782276E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,  -6.9889569151417363E-01,   1.5195270568782276E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,   6.9889569151417363E-01,  -1.5195270568782276E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,  -6.9889569151417363E-01,  -1.5195270568782276E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,  -6.9889569151417363E-01,  -1.5195270568782276E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,   1.5195270568782276E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,  -1.5195270568782276E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,   1.5195270568782276E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,  -1.5195270568782276E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,   1.5195270568782276E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,  -1.5195270568782276E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -6.9889569151417363E-01,  -1.5195270568782276E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [   6.9889569151417363E-01,   1.5195270568782276E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [   1.5195270568782276E-01,   6.9889569151417363E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -1.5195270568782276E-01,   6.9889569151417363E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [   1.5195270568782276E-01,  -6.9889569151417363E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [   1.5195270568782276E-01,   6.9889569151417363E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -1.5195270568782276E-01,  -6.9889569151417363E-01,   6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -1.5195270568782276E-01,   6.9889569151417363E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [   1.5195270568782276E-01,  -6.9889569151417363E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [  -1.5195270568782276E-01,  -6.9889569151417363E-01,  -6.9889569151417363E-01,   2.6260176061149456E-03],
            [   7.0413357948687205E-01,   7.0413357948687205E-01,   9.1606792750372451E-02,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,   7.0413357948687205E-01,   9.1606792750372451E-02,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,  -7.0413357948687205E-01,   9.1606792750372451E-02,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,   7.0413357948687205E-01,  -9.1606792750372451E-02,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,  -7.0413357948687205E-01,   9.1606792750372451E-02,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,   7.0413357948687205E-01,  -9.1606792750372451E-02,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,  -7.0413357948687205E-01,  -9.1606792750372451E-02,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,  -7.0413357948687205E-01,  -9.1606792750372451E-02,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,   9.1606792750372451E-02,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,  -9.1606792750372451E-02,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,   9.1606792750372451E-02,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,  -9.1606792750372451E-02,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,   9.1606792750372451E-02,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,  -9.1606792750372451E-02,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -7.0413357948687205E-01,  -9.1606792750372451E-02,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [   7.0413357948687205E-01,   9.1606792750372451E-02,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [   9.1606792750372451E-02,   7.0413357948687205E-01,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -9.1606792750372451E-02,   7.0413357948687205E-01,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [   9.1606792750372451E-02,  -7.0413357948687205E-01,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [   9.1606792750372451E-02,   7.0413357948687205E-01,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -9.1606792750372451E-02,  -7.0413357948687205E-01,   7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -9.1606792750372451E-02,   7.0413357948687205E-01,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [   9.1606792750372451E-02,  -7.0413357948687205E-01,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [  -9.1606792750372451E-02,  -7.0413357948687205E-01,  -7.0413357948687205E-01,   2.6288888837990784E-03],
            [   7.0677543980185675E-01,   7.0677543980185675E-01,   3.0609726979899339E-02,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,   7.0677543980185675E-01,   3.0609726979899339E-02,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,  -7.0677543980185675E-01,   3.0609726979899339E-02,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,   7.0677543980185675E-01,  -3.0609726979899339E-02,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,  -7.0677543980185675E-01,   3.0609726979899339E-02,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,   7.0677543980185675E-01,  -3.0609726979899339E-02,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,  -7.0677543980185675E-01,  -3.0609726979899339E-02,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,  -7.0677543980185675E-01,  -3.0609726979899339E-02,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,   3.0609726979899339E-02,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,  -3.0609726979899339E-02,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,   3.0609726979899339E-02,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,  -3.0609726979899339E-02,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,   3.0609726979899339E-02,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,  -3.0609726979899339E-02,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -7.0677543980185675E-01,  -3.0609726979899339E-02,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [   7.0677543980185675E-01,   3.0609726979899339E-02,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [   3.0609726979899339E-02,   7.0677543980185675E-01,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -3.0609726979899339E-02,   7.0677543980185675E-01,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [   3.0609726979899339E-02,  -7.0677543980185675E-01,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [   3.0609726979899339E-02,   7.0677543980185675E-01,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -3.0609726979899339E-02,  -7.0677543980185675E-01,   7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -3.0609726979899339E-02,   7.0677543980185675E-01,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [   3.0609726979899339E-02,  -7.0677543980185675E-01,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [  -3.0609726979899339E-02,  -7.0677543980185675E-01,  -7.0677543980185675E-01,   2.6305637859511009E-03],
            [   3.8403687078536232E-02,   9.9926230631339930E-01,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [  -3.8403687078536232E-02,   9.9926230631339930E-01,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [   3.8403687078536232E-02,  -9.9926230631339930E-01,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [  -3.8403687078536232E-02,  -9.9926230631339930E-01,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [   9.9926230631339930E-01,   3.8403687078536232E-02,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [  -9.9926230631339930E-01,   3.8403687078536232E-02,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [   9.9926230631339930E-01,  -3.8403687078536232E-02,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [  -9.9926230631339930E-01,  -3.8403687078536232E-02,   0.0000000000000000E+00,   9.5400217798850882E-04],
            [   3.8403687078536232E-02,   0.0000000000000000E+00,   9.9926230631339930E-01,   9.5400217798850882E-04],
            [  -3.8403687078536232E-02,   0.0000000000000000E+00,   9.9926230631339930E-01,   9.5400217798850882E-04],
            [   3.8403687078536232E-02,   0.0000000000000000E+00,  -9.9926230631339930E-01,   9.5400217798850882E-04],
            [  -3.8403687078536232E-02,   0.0000000000000000E+00,  -9.9926230631339930E-01,   9.5400217798850882E-04],
            [   9.9926230631339930E-01,   0.0000000000000000E+00,   3.8403687078536232E-02,   9.5400217798850882E-04],
            [  -9.9926230631339930E-01,   0.0000000000000000E+00,   3.8403687078536232E-02,   9.5400217798850882E-04],
            [   9.9926230631339930E-01,   0.0000000000000000E+00,  -3.8403687078536232E-02,   9.5400217798850882E-04],
            [  -9.9926230631339930E-01,   0.0000000000000000E+00,  -3.8403687078536232E-02,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,   3.8403687078536232E-02,   9.9926230631339930E-01,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,  -3.8403687078536232E-02,   9.9926230631339930E-01,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,   3.8403687078536232E-02,  -9.9926230631339930E-01,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,  -3.8403687078536232E-02,  -9.9926230631339930E-01,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,   9.9926230631339930E-01,   3.8403687078536232E-02,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,  -9.9926230631339930E-01,   3.8403687078536232E-02,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,   9.9926230631339930E-01,  -3.8403687078536232E-02,   9.5400217798850882E-04],
            [   0.0000000000000000E+00,  -9.9926230631339930E-01,  -3.8403687078536232E-02,   9.5400217798850882E-04],
            [   9.8354859541173983E-02,   9.9515140637223443E-01,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [  -9.8354859541173983E-02,   9.9515140637223443E-01,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [   9.8354859541173983E-02,  -9.9515140637223443E-01,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [  -9.8354859541173983E-02,  -9.9515140637223443E-01,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [   9.9515140637223443E-01,   9.8354859541173983E-02,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [  -9.9515140637223443E-01,   9.8354859541173983E-02,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [   9.9515140637223443E-01,  -9.8354859541173983E-02,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [  -9.9515140637223443E-01,  -9.8354859541173983E-02,   0.0000000000000000E+00,   1.3614204461669093E-03],
            [   9.8354859541173983E-02,   0.0000000000000000E+00,   9.9515140637223443E-01,   1.3614204461669093E-03],
            [  -9.8354859541173983E-02,   0.0000000000000000E+00,   9.9515140637223443E-01,   1.3614204461669093E-03],
            [   9.8354859541173983E-02,   0.0000000000000000E+00,  -9.9515140637223443E-01,   1.3614204461669093E-03],
            [  -9.8354859541173983E-02,   0.0000000000000000E+00,  -9.9515140637223443E-01,   1.3614204461669093E-03],
            [   9.9515140637223443E-01,   0.0000000000000000E+00,   9.8354859541173983E-02,   1.3614204461669093E-03],
            [  -9.9515140637223443E-01,   0.0000000000000000E+00,   9.8354859541173983E-02,   1.3614204461669093E-03],
            [   9.9515140637223443E-01,   0.0000000000000000E+00,  -9.8354859541173983E-02,   1.3614204461669093E-03],
            [  -9.9515140637223443E-01,   0.0000000000000000E+00,  -9.8354859541173983E-02,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,   9.8354859541173983E-02,   9.9515140637223443E-01,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,  -9.8354859541173983E-02,   9.9515140637223443E-01,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,   9.8354859541173983E-02,  -9.9515140637223443E-01,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,  -9.8354859541173983E-02,  -9.9515140637223443E-01,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,   9.9515140637223443E-01,   9.8354859541173983E-02,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,  -9.9515140637223443E-01,   9.8354859541173983E-02,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,   9.9515140637223443E-01,  -9.8354859541173983E-02,   1.3614204461669093E-03],
            [   0.0000000000000000E+00,  -9.9515140637223443E-01,  -9.8354859541173983E-02,   1.3614204461669093E-03],
            [   1.6657749476129979E-01,   9.8602836583895959E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [  -1.6657749476129979E-01,   9.8602836583895959E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [   1.6657749476129979E-01,  -9.8602836583895959E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [  -1.6657749476129979E-01,  -9.8602836583895959E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [   9.8602836583895959E-01,   1.6657749476129979E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [  -9.8602836583895959E-01,   1.6657749476129979E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [   9.8602836583895959E-01,  -1.6657749476129979E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [  -9.8602836583895959E-01,  -1.6657749476129979E-01,   0.0000000000000000E+00,   1.7630861700379775E-03],
            [   1.6657749476129979E-01,   0.0000000000000000E+00,   9.8602836583895959E-01,   1.7630861700379775E-03],
            [  -1.6657749476129979E-01,   0.0000000000000000E+00,   9.8602836583895959E-01,   1.7630861700379775E-03],
            [   1.6657749476129979E-01,   0.0000000000000000E+00,  -9.8602836583895959E-01,   1.7630861700379775E-03],
            [  -1.6657749476129979E-01,   0.0000000000000000E+00,  -9.8602836583895959E-01,   1.7630861700379775E-03],
            [   9.8602836583895959E-01,   0.0000000000000000E+00,   1.6657749476129979E-01,   1.7630861700379775E-03],
            [  -9.8602836583895959E-01,   0.0000000000000000E+00,   1.6657749476129979E-01,   1.7630861700379775E-03],
            [   9.8602836583895959E-01,   0.0000000000000000E+00,  -1.6657749476129979E-01,   1.7630861700379775E-03],
            [  -9.8602836583895959E-01,   0.0000000000000000E+00,  -1.6657749476129979E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,   1.6657749476129979E-01,   9.8602836583895959E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,  -1.6657749476129979E-01,   9.8602836583895959E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,   1.6657749476129979E-01,  -9.8602836583895959E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,  -1.6657749476129979E-01,  -9.8602836583895959E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,   9.8602836583895959E-01,   1.6657749476129979E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,  -9.8602836583895959E-01,   1.6657749476129979E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,   9.8602836583895959E-01,  -1.6657749476129979E-01,   1.7630861700379775E-03],
            [   0.0000000000000000E+00,  -9.8602836583895959E-01,  -1.6657749476129979E-01,   1.7630861700379775E-03],
            [   2.4057023353629101E-01,   9.7063173383951051E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [  -2.4057023353629101E-01,   9.7063173383951051E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [   2.4057023353629101E-01,  -9.7063173383951051E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [  -2.4057023353629101E-01,  -9.7063173383951051E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [   9.7063173383951051E-01,   2.4057023353629101E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [  -9.7063173383951051E-01,   2.4057023353629101E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [   9.7063173383951051E-01,  -2.4057023353629101E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [  -9.7063173383951051E-01,  -2.4057023353629101E-01,   0.0000000000000000E+00,   2.0306880174665791E-03],
            [   2.4057023353629101E-01,   0.0000000000000000E+00,   9.7063173383951051E-01,   2.0306880174665791E-03],
            [  -2.4057023353629101E-01,   0.0000000000000000E+00,   9.7063173383951051E-01,   2.0306880174665791E-03],
            [   2.4057023353629101E-01,   0.0000000000000000E+00,  -9.7063173383951051E-01,   2.0306880174665791E-03],
            [  -2.4057023353629101E-01,   0.0000000000000000E+00,  -9.7063173383951051E-01,   2.0306880174665791E-03],
            [   9.7063173383951051E-01,   0.0000000000000000E+00,   2.4057023353629101E-01,   2.0306880174665791E-03],
            [  -9.7063173383951051E-01,   0.0000000000000000E+00,   2.4057023353629101E-01,   2.0306880174665791E-03],
            [   9.7063173383951051E-01,   0.0000000000000000E+00,  -2.4057023353629101E-01,   2.0306880174665791E-03],
            [  -9.7063173383951051E-01,   0.0000000000000000E+00,  -2.4057023353629101E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,   2.4057023353629101E-01,   9.7063173383951051E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,  -2.4057023353629101E-01,   9.7063173383951051E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,   2.4057023353629101E-01,  -9.7063173383951051E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,  -2.4057023353629101E-01,  -9.7063173383951051E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,   9.7063173383951051E-01,   2.4057023353629101E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,  -9.7063173383951051E-01,   2.4057023353629101E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,   9.7063173383951051E-01,  -2.4057023353629101E-01,   2.0306880174665791E-03],
            [   0.0000000000000000E+00,  -9.7063173383951051E-01,  -2.4057023353629101E-01,   2.0306880174665791E-03],
            [   3.1652707701890459E-01,   9.4858347524815578E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [  -3.1652707701890459E-01,   9.4858347524815578E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [   3.1652707701890459E-01,  -9.4858347524815578E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [  -3.1652707701890459E-01,  -9.4858347524815578E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [   9.4858347524815578E-01,   3.1652707701890459E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [  -9.4858347524815578E-01,   3.1652707701890459E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [   9.4858347524815578E-01,  -3.1652707701890459E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [  -9.4858347524815578E-01,  -3.1652707701890459E-01,   0.0000000000000000E+00,   2.2256854271654764E-03],
            [   3.1652707701890459E-01,   0.0000000000000000E+00,   9.4858347524815578E-01,   2.2256854271654764E-03],
            [  -3.1652707701890459E-01,   0.0000000000000000E+00,   9.4858347524815578E-01,   2.2256854271654764E-03],
            [   3.1652707701890459E-01,   0.0000000000000000E+00,  -9.4858347524815578E-01,   2.2256854271654764E-03],
            [  -3.1652707701890459E-01,   0.0000000000000000E+00,  -9.4858347524815578E-01,   2.2256854271654764E-03],
            [   9.4858347524815578E-01,   0.0000000000000000E+00,   3.1652707701890459E-01,   2.2256854271654764E-03],
            [  -9.4858347524815578E-01,   0.0000000000000000E+00,   3.1652707701890459E-01,   2.2256854271654764E-03],
            [   9.4858347524815578E-01,   0.0000000000000000E+00,  -3.1652707701890459E-01,   2.2256854271654764E-03],
            [  -9.4858347524815578E-01,   0.0000000000000000E+00,  -3.1652707701890459E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,   3.1652707701890459E-01,   9.4858347524815578E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,  -3.1652707701890459E-01,   9.4858347524815578E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,   3.1652707701890459E-01,  -9.4858347524815578E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,  -3.1652707701890459E-01,  -9.4858347524815578E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,   9.4858347524815578E-01,   3.1652707701890459E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,  -9.4858347524815578E-01,   3.1652707701890459E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,   9.4858347524815578E-01,  -3.1652707701890459E-01,   2.2256854271654764E-03],
            [   0.0000000000000000E+00,  -9.4858347524815578E-01,  -3.1652707701890459E-01,   2.2256854271654764E-03],
            [   3.9273861456454429E-01,   9.1965014034138126E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [  -3.9273861456454429E-01,   9.1965014034138126E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [   3.9273861456454429E-01,  -9.1965014034138126E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [  -3.9273861456454429E-01,  -9.1965014034138126E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [   9.1965014034138126E-01,   3.9273861456454429E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [  -9.1965014034138126E-01,   3.9273861456454429E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [   9.1965014034138126E-01,  -3.9273861456454429E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [  -9.1965014034138126E-01,  -3.9273861456454429E-01,   0.0000000000000000E+00,   2.3722292079840510E-03],
            [   3.9273861456454429E-01,   0.0000000000000000E+00,   9.1965014034138126E-01,   2.3722292079840510E-03],
            [  -3.9273861456454429E-01,   0.0000000000000000E+00,   9.1965014034138126E-01,   2.3722292079840510E-03],
            [   3.9273861456454429E-01,   0.0000000000000000E+00,  -9.1965014034138126E-01,   2.3722292079840510E-03],
            [  -3.9273861456454429E-01,   0.0000000000000000E+00,  -9.1965014034138126E-01,   2.3722292079840510E-03],
            [   9.1965014034138126E-01,   0.0000000000000000E+00,   3.9273861456454429E-01,   2.3722292079840510E-03],
            [  -9.1965014034138126E-01,   0.0000000000000000E+00,   3.9273861456454429E-01,   2.3722292079840510E-03],
            [   9.1965014034138126E-01,   0.0000000000000000E+00,  -3.9273861456454429E-01,   2.3722292079840510E-03],
            [  -9.1965014034138126E-01,   0.0000000000000000E+00,  -3.9273861456454429E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,   3.9273861456454429E-01,   9.1965014034138126E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,  -3.9273861456454429E-01,   9.1965014034138126E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,   3.9273861456454429E-01,  -9.1965014034138126E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,  -3.9273861456454429E-01,  -9.1965014034138126E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,   9.1965014034138126E-01,   3.9273861456454429E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,  -9.1965014034138126E-01,   3.9273861456454429E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,   9.1965014034138126E-01,  -3.9273861456454429E-01,   2.3722292079840510E-03],
            [   0.0000000000000000E+00,  -9.1965014034138126E-01,  -3.9273861456454429E-01,   2.3722292079840510E-03],
            [   4.6788259183746561E-01,   8.8379063145942860E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [  -4.6788259183746561E-01,   8.8379063145942860E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [   4.6788259183746561E-01,  -8.8379063145942860E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [  -4.6788259183746561E-01,  -8.8379063145942860E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [   8.8379063145942860E-01,   4.6788259183746561E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [  -8.8379063145942860E-01,   4.6788259183746561E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [   8.8379063145942860E-01,  -4.6788259183746561E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [  -8.8379063145942860E-01,  -4.6788259183746561E-01,   0.0000000000000000E+00,   2.4799414110923826E-03],
            [   4.6788259183746561E-01,   0.0000000000000000E+00,   8.8379063145942860E-01,   2.4799414110923826E-03],
            [  -4.6788259183746561E-01,   0.0000000000000000E+00,   8.8379063145942860E-01,   2.4799414110923826E-03],
            [   4.6788259183746561E-01,   0.0000000000000000E+00,  -8.8379063145942860E-01,   2.4799414110923826E-03],
            [  -4.6788259183746561E-01,   0.0000000000000000E+00,  -8.8379063145942860E-01,   2.4799414110923826E-03],
            [   8.8379063145942860E-01,   0.0000000000000000E+00,   4.6788259183746561E-01,   2.4799414110923826E-03],
            [  -8.8379063145942860E-01,   0.0000000000000000E+00,   4.6788259183746561E-01,   2.4799414110923826E-03],
            [   8.8379063145942860E-01,   0.0000000000000000E+00,  -4.6788259183746561E-01,   2.4799414110923826E-03],
            [  -8.8379063145942860E-01,   0.0000000000000000E+00,  -4.6788259183746561E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,   4.6788259183746561E-01,   8.8379063145942860E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,  -4.6788259183746561E-01,   8.8379063145942860E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,   4.6788259183746561E-01,  -8.8379063145942860E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,  -4.6788259183746561E-01,  -8.8379063145942860E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,   8.8379063145942860E-01,   4.6788259183746561E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,  -8.8379063145942860E-01,   4.6788259183746561E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,   8.8379063145942860E-01,  -4.6788259183746561E-01,   2.4799414110923826E-03],
            [   0.0000000000000000E+00,  -8.8379063145942860E-01,  -4.6788259183746561E-01,   2.4799414110923826E-03],
            [   5.4080220242669352E-01,   8.4114979513190014E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [  -5.4080220242669352E-01,   8.4114979513190014E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [   5.4080220242669352E-01,  -8.4114979513190014E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [  -5.4080220242669352E-01,  -8.4114979513190014E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [   8.4114979513190014E-01,   5.4080220242669352E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [  -8.4114979513190014E-01,   5.4080220242669352E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [   8.4114979513190014E-01,  -5.4080220242669352E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [  -8.4114979513190014E-01,  -5.4080220242669352E-01,   0.0000000000000000E+00,   2.5557329501985485E-03],
            [   5.4080220242669352E-01,   0.0000000000000000E+00,   8.4114979513190014E-01,   2.5557329501985485E-03],
            [  -5.4080220242669352E-01,   0.0000000000000000E+00,   8.4114979513190014E-01,   2.5557329501985485E-03],
            [   5.4080220242669352E-01,   0.0000000000000000E+00,  -8.4114979513190014E-01,   2.5557329501985485E-03],
            [  -5.4080220242669352E-01,   0.0000000000000000E+00,  -8.4114979513190014E-01,   2.5557329501985485E-03],
            [   8.4114979513190014E-01,   0.0000000000000000E+00,   5.4080220242669352E-01,   2.5557329501985485E-03],
            [  -8.4114979513190014E-01,   0.0000000000000000E+00,   5.4080220242669352E-01,   2.5557329501985485E-03],
            [   8.4114979513190014E-01,   0.0000000000000000E+00,  -5.4080220242669352E-01,   2.5557329501985485E-03],
            [  -8.4114979513190014E-01,   0.0000000000000000E+00,  -5.4080220242669352E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,   5.4080220242669352E-01,   8.4114979513190014E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,  -5.4080220242669352E-01,   8.4114979513190014E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,   5.4080220242669352E-01,  -8.4114979513190014E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,  -5.4080220242669352E-01,  -8.4114979513190014E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,   8.4114979513190014E-01,   5.4080220242669352E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,  -8.4114979513190014E-01,   5.4080220242669352E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,   8.4114979513190014E-01,  -5.4080220242669352E-01,   2.5557329501985485E-03],
            [   0.0000000000000000E+00,  -8.4114979513190014E-01,  -5.4080220242669352E-01,   2.5557329501985485E-03],
            [   6.1049674457524383E-01,   7.9201876547404448E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [  -6.1049674457524383E-01,   7.9201876547404448E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [   6.1049674457524383E-01,  -7.9201876547404448E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [  -6.1049674457524383E-01,  -7.9201876547404448E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [   7.9201876547404448E-01,   6.1049674457524383E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [  -7.9201876547404448E-01,   6.1049674457524383E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [   7.9201876547404448E-01,  -6.1049674457524383E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [  -7.9201876547404448E-01,  -6.1049674457524383E-01,   0.0000000000000000E+00,   2.6041838051121908E-03],
            [   6.1049674457524383E-01,   0.0000000000000000E+00,   7.9201876547404448E-01,   2.6041838051121908E-03],
            [  -6.1049674457524383E-01,   0.0000000000000000E+00,   7.9201876547404448E-01,   2.6041838051121908E-03],
            [   6.1049674457524383E-01,   0.0000000000000000E+00,  -7.9201876547404448E-01,   2.6041838051121908E-03],
            [  -6.1049674457524383E-01,   0.0000000000000000E+00,  -7.9201876547404448E-01,   2.6041838051121908E-03],
            [   7.9201876547404448E-01,   0.0000000000000000E+00,   6.1049674457524383E-01,   2.6041838051121908E-03],
            [  -7.9201876547404448E-01,   0.0000000000000000E+00,   6.1049674457524383E-01,   2.6041838051121908E-03],
            [   7.9201876547404448E-01,   0.0000000000000000E+00,  -6.1049674457524383E-01,   2.6041838051121908E-03],
            [  -7.9201876547404448E-01,   0.0000000000000000E+00,  -6.1049674457524383E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,   6.1049674457524383E-01,   7.9201876547404448E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,  -6.1049674457524383E-01,   7.9201876547404448E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,   6.1049674457524383E-01,  -7.9201876547404448E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,  -6.1049674457524383E-01,  -7.9201876547404448E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,   7.9201876547404448E-01,   6.1049674457524383E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,  -7.9201876547404448E-01,   6.1049674457524383E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,   7.9201876547404448E-01,  -6.1049674457524383E-01,   2.6041838051121908E-03],
            [   0.0000000000000000E+00,  -7.9201876547404448E-01,  -6.1049674457524383E-01,   2.6041838051121908E-03],
            [   6.7609107026857385E-01,   7.3681806757373591E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [  -6.7609107026857385E-01,   7.3681806757373591E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [   6.7609107026857385E-01,  -7.3681806757373591E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [  -6.7609107026857385E-01,  -7.3681806757373591E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [   7.3681806757373591E-01,   6.7609107026857385E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [  -7.3681806757373591E-01,   6.7609107026857385E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [   7.3681806757373591E-01,  -6.7609107026857385E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [  -7.3681806757373591E-01,  -6.7609107026857385E-01,   0.0000000000000000E+00,   2.6278515685428400E-03],
            [   6.7609107026857385E-01,   0.0000000000000000E+00,   7.3681806757373591E-01,   2.6278515685428400E-03],
            [  -6.7609107026857385E-01,   0.0000000000000000E+00,   7.3681806757373591E-01,   2.6278515685428400E-03],
            [   6.7609107026857385E-01,   0.0000000000000000E+00,  -7.3681806757373591E-01,   2.6278515685428400E-03],
            [  -6.7609107026857385E-01,   0.0000000000000000E+00,  -7.3681806757373591E-01,   2.6278515685428400E-03],
            [   7.3681806757373591E-01,   0.0000000000000000E+00,   6.7609107026857385E-01,   2.6278515685428400E-03],
            [  -7.3681806757373591E-01,   0.0000000000000000E+00,   6.7609107026857385E-01,   2.6278515685428400E-03],
            [   7.3681806757373591E-01,   0.0000000000000000E+00,  -6.7609107026857385E-01,   2.6278515685428400E-03],
            [  -7.3681806757373591E-01,   0.0000000000000000E+00,  -6.7609107026857385E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,   6.7609107026857385E-01,   7.3681806757373591E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,  -6.7609107026857385E-01,   7.3681806757373591E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,   6.7609107026857385E-01,  -7.3681806757373591E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,  -6.7609107026857385E-01,  -7.3681806757373591E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,   7.3681806757373591E-01,   6.7609107026857385E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,  -7.3681806757373591E-01,   6.7609107026857385E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,   7.3681806757373591E-01,  -6.7609107026857385E-01,   2.6278515685428400E-03],
            [   0.0000000000000000E+00,  -7.3681806757373591E-01,  -6.7609107026857385E-01,   2.6278515685428400E-03],
            [   6.6556441202173924E-02,   1.9365088745884239E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,   1.9365088745884239E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,  -1.9365088745884239E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,   1.9365088745884239E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,  -1.9365088745884239E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,  -1.9365088745884239E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,   1.9365088745884239E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,  -1.9365088745884239E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,   6.6556441202173924E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,   6.6556441202173924E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,  -6.6556441202173924E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,   6.6556441202173924E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,  -6.6556441202173924E-02,   9.9759472406000904E-01,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,  -6.6556441202173924E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,   6.6556441202173924E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,  -6.6556441202173924E-02,  -9.9759472406000904E-01,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,   6.6556441202173924E-02,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,   6.6556441202173924E-02,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,  -6.6556441202173924E-02,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,   6.6556441202173924E-02,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,  -6.6556441202173924E-02,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,  -6.6556441202173924E-02,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,   6.6556441202173924E-02,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,  -6.6556441202173924E-02,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,   1.9365088745884239E-02,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,   1.9365088745884239E-02,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,  -1.9365088745884239E-02,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,   1.9365088745884239E-02,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,  -1.9365088745884239E-02,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   9.9759472406000904E-01,  -1.9365088745884239E-02,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,   1.9365088745884239E-02,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -9.9759472406000904E-01,  -1.9365088745884239E-02,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,   9.9759472406000904E-01,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,   9.9759472406000904E-01,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,  -9.9759472406000904E-01,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,   9.9759472406000904E-01,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,  -9.9759472406000904E-01,   1.9365088745884239E-02,   1.1707691013148305E-03],
            [   6.6556441202173924E-02,  -9.9759472406000904E-01,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,   9.9759472406000904E-01,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [  -6.6556441202173924E-02,  -9.9759472406000904E-01,  -1.9365088745884239E-02,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,   9.9759472406000904E-01,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,   9.9759472406000904E-01,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,  -9.9759472406000904E-01,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,   9.9759472406000904E-01,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,  -9.9759472406000904E-01,   6.6556441202173924E-02,   1.1707691013148305E-03],
            [   1.9365088745884239E-02,  -9.9759472406000904E-01,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,   9.9759472406000904E-01,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [  -1.9365088745884239E-02,  -9.9759472406000904E-01,  -6.6556441202173924E-02,   1.1707691013148305E-03],
            [   9.4462461612701817E-02,   4.2524420021158693E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,   4.2524420021158693E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,  -4.2524420021158693E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,   4.2524420021158693E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,  -4.2524420021158693E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,  -4.2524420021158693E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,   4.2524420021158693E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,  -4.2524420021158693E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,   9.4462461612701817E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,   9.4462461612701817E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,  -9.4462461612701817E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,   9.4462461612701817E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,  -9.4462461612701817E-02,   9.9461978516814809E-01,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,  -9.4462461612701817E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,   9.4462461612701817E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,  -9.4462461612701817E-02,  -9.9461978516814809E-01,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,   9.4462461612701817E-02,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,   9.4462461612701817E-02,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,  -9.4462461612701817E-02,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,   9.4462461612701817E-02,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,  -9.4462461612701817E-02,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,  -9.4462461612701817E-02,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,   9.4462461612701817E-02,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,  -9.4462461612701817E-02,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,   4.2524420021158693E-02,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,   4.2524420021158693E-02,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,  -4.2524420021158693E-02,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,   4.2524420021158693E-02,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,  -4.2524420021158693E-02,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   9.9461978516814809E-01,  -4.2524420021158693E-02,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,   4.2524420021158693E-02,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -9.9461978516814809E-01,  -4.2524420021158693E-02,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,   9.9461978516814809E-01,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,   9.9461978516814809E-01,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,  -9.9461978516814809E-01,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,   9.9461978516814809E-01,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,  -9.9461978516814809E-01,   4.2524420021158693E-02,   1.4026503569398920E-03],
            [   9.4462461612701817E-02,  -9.9461978516814809E-01,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,   9.9461978516814809E-01,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [  -9.4462461612701817E-02,  -9.9461978516814809E-01,  -4.2524420021158693E-02,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,   9.9461978516814809E-01,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,   9.9461978516814809E-01,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,  -9.9461978516814809E-01,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,   9.9461978516814809E-01,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,  -9.9461978516814809E-01,   9.4462461612701817E-02,   1.4026503569398920E-03],
            [   4.2524420021158693E-02,  -9.9461978516814809E-01,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,   9.9461978516814809E-01,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [  -4.2524420021158693E-02,  -9.9461978516814809E-01,  -9.4462461612701817E-02,   1.4026503569398920E-03],
            [   1.2426519254525090E-01,   6.8065293153543746E-02,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,   6.8065293153543746E-02,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,  -6.8065293153543746E-02,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,   6.8065293153543746E-02,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,  -6.8065293153543746E-02,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,  -6.8065293153543746E-02,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,   6.8065293153543746E-02,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,  -6.8065293153543746E-02,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,   1.2426519254525090E-01,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,   1.2426519254525090E-01,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,  -1.2426519254525090E-01,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,   1.2426519254525090E-01,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,  -1.2426519254525090E-01,   9.8991175252626129E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,  -1.2426519254525090E-01,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,   1.2426519254525090E-01,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,  -1.2426519254525090E-01,  -9.8991175252626129E-01,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,   1.2426519254525090E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,   1.2426519254525090E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,  -1.2426519254525090E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,   1.2426519254525090E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,  -1.2426519254525090E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,  -1.2426519254525090E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,   1.2426519254525090E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,  -1.2426519254525090E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,   6.8065293153543746E-02,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,   6.8065293153543746E-02,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,  -6.8065293153543746E-02,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,   6.8065293153543746E-02,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,  -6.8065293153543746E-02,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   9.8991175252626129E-01,  -6.8065293153543746E-02,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,   6.8065293153543746E-02,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -9.8991175252626129E-01,  -6.8065293153543746E-02,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,   9.8991175252626129E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,   9.8991175252626129E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,  -9.8991175252626129E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,   9.8991175252626129E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,  -9.8991175252626129E-01,   6.8065293153543746E-02,   1.6318984837430963E-03],
            [   1.2426519254525090E-01,  -9.8991175252626129E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,   9.8991175252626129E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [  -1.2426519254525090E-01,  -9.8991175252626129E-01,  -6.8065293153543746E-02,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,   9.8991175252626129E-01,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,   9.8991175252626129E-01,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,  -9.8991175252626129E-01,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,   9.8991175252626129E-01,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,  -9.8991175252626129E-01,   1.2426519254525090E-01,   1.6318984837430963E-03],
            [   6.8065293153543746E-02,  -9.8991175252626129E-01,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,   9.8991175252626129E-01,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [  -6.8065293153543746E-02,  -9.8991175252626129E-01,  -1.2426519254525090E-01,   1.6318984837430963E-03],
            [   1.5534380648467511E-01,   9.5609574912053685E-02,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,   9.5609574912053685E-02,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,  -9.5609574912053685E-02,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,   9.5609574912053685E-02,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,  -9.5609574912053685E-02,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,  -9.5609574912053685E-02,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,   9.5609574912053685E-02,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,  -9.5609574912053685E-02,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,   1.5534380648467511E-01,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,   1.5534380648467511E-01,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,  -1.5534380648467511E-01,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,   1.5534380648467511E-01,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,  -1.5534380648467511E-01,   9.8322281857775662E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,  -1.5534380648467511E-01,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,   1.5534380648467511E-01,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,  -1.5534380648467511E-01,  -9.8322281857775662E-01,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,   1.5534380648467511E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,   1.5534380648467511E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,  -1.5534380648467511E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,   1.5534380648467511E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,  -1.5534380648467511E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,  -1.5534380648467511E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,   1.5534380648467511E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,  -1.5534380648467511E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,   9.5609574912053685E-02,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,   9.5609574912053685E-02,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,  -9.5609574912053685E-02,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,   9.5609574912053685E-02,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,  -9.5609574912053685E-02,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.8322281857775662E-01,  -9.5609574912053685E-02,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,   9.5609574912053685E-02,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.8322281857775662E-01,  -9.5609574912053685E-02,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,   9.8322281857775662E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,   9.8322281857775662E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,  -9.8322281857775662E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,   9.8322281857775662E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,  -9.8322281857775662E-01,   9.5609574912053685E-02,   1.8224213515241759E-03],
            [   1.5534380648467511E-01,  -9.8322281857775662E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,   9.8322281857775662E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [  -1.5534380648467511E-01,  -9.8322281857775662E-01,  -9.5609574912053685E-02,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,   9.8322281857775662E-01,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,   9.8322281857775662E-01,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,  -9.8322281857775662E-01,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,   9.8322281857775662E-01,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,  -9.8322281857775662E-01,   1.5534380648467511E-01,   1.8224213515241759E-03],
            [   9.5609574912053685E-02,  -9.8322281857775662E-01,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,   9.8322281857775662E-01,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [  -9.5609574912053685E-02,  -9.8322281857775662E-01,  -1.5534380648467511E-01,   1.8224213515241759E-03],
            [   1.8711371105426700E-01,   1.2459316574528879E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,   1.2459316574528879E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,  -1.2459316574528879E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,   1.2459316574528879E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,  -1.2459316574528879E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,  -1.2459316574528879E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,   1.2459316574528879E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,  -1.2459316574528879E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,   1.8711371105426700E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,   1.8711371105426700E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,  -1.8711371105426700E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,   1.8711371105426700E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,  -1.8711371105426700E-01,   9.7440494774250164E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,  -1.8711371105426700E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,   1.8711371105426700E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,  -1.8711371105426700E-01,  -9.7440494774250164E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,   1.8711371105426700E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,   1.8711371105426700E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,  -1.8711371105426700E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,   1.8711371105426700E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,  -1.8711371105426700E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,  -1.8711371105426700E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,   1.8711371105426700E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,  -1.8711371105426700E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,   1.2459316574528879E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,   1.2459316574528879E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,  -1.2459316574528879E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,   1.2459316574528879E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,  -1.2459316574528879E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   9.7440494774250164E-01,  -1.2459316574528879E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,   1.2459316574528879E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -9.7440494774250164E-01,  -1.2459316574528879E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,   9.7440494774250164E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,   9.7440494774250164E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,  -9.7440494774250164E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,   9.7440494774250164E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,  -9.7440494774250164E-01,   1.2459316574528879E-01,   1.9763381866711267E-03],
            [   1.8711371105426700E-01,  -9.7440494774250164E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,   9.7440494774250164E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [  -1.8711371105426700E-01,  -9.7440494774250164E-01,  -1.2459316574528879E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,   9.7440494774250164E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,   9.7440494774250164E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,  -9.7440494774250164E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,   9.7440494774250164E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,  -9.7440494774250164E-01,   1.8711371105426700E-01,   1.9763381866711267E-03],
            [   1.2459316574528879E-01,  -9.7440494774250164E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,   9.7440494774250164E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [  -1.2459316574528879E-01,  -9.7440494774250164E-01,  -1.8711371105426700E-01,   1.9763381866711267E-03],
            [   2.1926126288362571E-01,   1.5453858287789779E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,   1.5453858287789779E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,  -1.5453858287789779E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,   1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,  -1.5453858287789779E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,  -1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,   1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,  -1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,   2.1926126288362571E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,   2.1926126288362571E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,  -2.1926126288362571E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,   2.1926126288362571E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,  -2.1926126288362571E-01,   9.6334953417789571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,  -2.1926126288362571E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,   2.1926126288362571E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,  -2.1926126288362571E-01,  -9.6334953417789571E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,   2.1926126288362571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,   2.1926126288362571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,  -2.1926126288362571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,   2.1926126288362571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,  -2.1926126288362571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,  -2.1926126288362571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,   2.1926126288362571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,  -2.1926126288362571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,   1.5453858287789779E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,   1.5453858287789779E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,   1.5453858287789779E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   9.6334953417789571E-01,  -1.5453858287789779E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,   1.5453858287789779E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -9.6334953417789571E-01,  -1.5453858287789779E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,   9.6334953417789571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,   9.6334953417789571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,  -9.6334953417789571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,   9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,  -9.6334953417789571E-01,   1.5453858287789779E-01,   2.1026488444045081E-03],
            [   2.1926126288362571E-01,  -9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,   9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [  -2.1926126288362571E-01,  -9.6334953417789571E-01,  -1.5453858287789779E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,   9.6334953417789571E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,   9.6334953417789571E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,   9.6334953417789571E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,  -9.6334953417789571E-01,   2.1926126288362571E-01,   2.1026488444045081E-03],
            [   1.5453858287789779E-01,  -9.6334953417789571E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,   9.6334953417789571E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [  -1.5453858287789779E-01,  -9.6334953417789571E-01,  -2.1926126288362571E-01,   2.1026488444045081E-03],
            [   2.5156828072069548E-01,   1.8510042497233681E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,   1.8510042497233681E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,  -1.8510042497233681E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,   1.8510042497233681E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,  -1.8510042497233681E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,  -1.8510042497233681E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,   1.8510042497233681E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,  -1.8510042497233681E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,   2.5156828072069548E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,   2.5156828072069548E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,  -2.5156828072069548E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,   2.5156828072069548E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,  -2.5156828072069548E-01,   9.4997433271130727E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,  -2.5156828072069548E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,   2.5156828072069548E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,  -2.5156828072069548E-01,  -9.4997433271130727E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,   2.5156828072069548E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,   2.5156828072069548E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,  -2.5156828072069548E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,   2.5156828072069548E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,  -2.5156828072069548E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,  -2.5156828072069548E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,   2.5156828072069548E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,  -2.5156828072069548E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,   1.8510042497233681E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,   1.8510042497233681E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,  -1.8510042497233681E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,   1.8510042497233681E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,  -1.8510042497233681E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   9.4997433271130727E-01,  -1.8510042497233681E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,   1.8510042497233681E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -9.4997433271130727E-01,  -1.8510042497233681E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,   9.4997433271130727E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,   9.4997433271130727E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,  -9.4997433271130727E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,   9.4997433271130727E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,  -9.4997433271130727E-01,   1.8510042497233681E-01,   2.2077355369487768E-03],
            [   2.5156828072069548E-01,  -9.4997433271130727E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,   9.4997433271130727E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [  -2.5156828072069548E-01,  -9.4997433271130727E-01,  -1.8510042497233681E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,   9.4997433271130727E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,   9.4997433271130727E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,  -9.4997433271130727E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,   9.4997433271130727E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,  -9.4997433271130727E-01,   2.5156828072069548E-01,   2.2077355369487768E-03],
            [   1.8510042497233681E-01,  -9.4997433271130727E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,   9.4997433271130727E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [  -1.8510042497233681E-01,  -9.4997433271130727E-01,  -2.5156828072069548E-01,   2.2077355369487768E-03],
            [   2.8385358662872900E-01,   2.1601826082723841E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,   2.1601826082723841E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,  -2.1601826082723841E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,   2.1601826082723841E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,  -2.1601826082723841E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,  -2.1601826082723841E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,   2.1601826082723841E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,  -2.1601826082723841E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,   2.8385358662872900E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,   2.8385358662872900E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,  -2.8385358662872900E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,   2.8385358662872900E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,  -2.8385358662872900E-01,   9.3421798973643289E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,  -2.8385358662872900E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,   2.8385358662872900E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,  -2.8385358662872900E-01,  -9.3421798973643289E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,   2.8385358662872900E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,   2.8385358662872900E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,  -2.8385358662872900E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,   2.8385358662872900E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,  -2.8385358662872900E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,  -2.8385358662872900E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,   2.8385358662872900E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,  -2.8385358662872900E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,   2.1601826082723841E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,   2.1601826082723841E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,  -2.1601826082723841E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,   2.1601826082723841E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,  -2.1601826082723841E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   9.3421798973643289E-01,  -2.1601826082723841E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,   2.1601826082723841E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -9.3421798973643289E-01,  -2.1601826082723841E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,   9.3421798973643289E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,   9.3421798973643289E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,  -9.3421798973643289E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,   9.3421798973643289E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,  -9.3421798973643289E-01,   2.1601826082723841E-01,   2.2955947895185319E-03],
            [   2.8385358662872900E-01,  -9.3421798973643289E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,   9.3421798973643289E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [  -2.8385358662872900E-01,  -9.3421798973643289E-01,  -2.1601826082723841E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,   9.3421798973643289E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,   9.3421798973643289E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,  -9.3421798973643289E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,   9.3421798973643289E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,  -9.3421798973643289E-01,   2.8385358662872900E-01,   2.2955947895185319E-03],
            [   2.1601826082723841E-01,  -9.3421798973643289E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,   9.3421798973643289E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [  -2.1601826082723841E-01,  -9.3421798973643289E-01,  -2.8385358662872900E-01,   2.2955947895185319E-03],
            [   3.1595788175285211E-01,   2.4707990122771109E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,   2.4707990122771109E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,  -2.4707990122771109E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,   2.4707990122771109E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,  -2.4707990122771109E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,  -2.4707990122771109E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,   2.4707990122771109E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,  -2.4707990122771109E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,   3.1595788175285211E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,   3.1595788175285211E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,  -3.1595788175285211E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,   3.1595788175285211E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,  -3.1595788175285211E-01,   9.1603610156344561E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,  -3.1595788175285211E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,   3.1595788175285211E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,  -3.1595788175285211E-01,  -9.1603610156344561E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,   3.1595788175285211E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,   3.1595788175285211E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,  -3.1595788175285211E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,   3.1595788175285211E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,  -3.1595788175285211E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,  -3.1595788175285211E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,   3.1595788175285211E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,  -3.1595788175285211E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,   2.4707990122771109E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,   2.4707990122771109E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,  -2.4707990122771109E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,   2.4707990122771109E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,  -2.4707990122771109E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   9.1603610156344561E-01,  -2.4707990122771109E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,   2.4707990122771109E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -9.1603610156344561E-01,  -2.4707990122771109E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,   9.1603610156344561E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,   9.1603610156344561E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,  -9.1603610156344561E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,   9.1603610156344561E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,  -9.1603610156344561E-01,   2.4707990122771109E-01,   2.3689070680065617E-03],
            [   3.1595788175285211E-01,  -9.1603610156344561E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,   9.1603610156344561E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [  -3.1595788175285211E-01,  -9.1603610156344561E-01,  -2.4707990122771109E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,   9.1603610156344561E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,   9.1603610156344561E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,  -9.1603610156344561E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,   9.1603610156344561E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,  -9.1603610156344561E-01,   3.1595788175285211E-01,   2.3689070680065617E-03],
            [   2.4707990122771109E-01,  -9.1603610156344561E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,   9.1603610156344561E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [  -2.4707990122771109E-01,  -9.1603610156344561E-01,  -3.1595788175285211E-01,   2.3689070680065617E-03],
            [   3.4773708827913918E-01,   2.7810142089864021E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,   2.7810142089864021E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,  -2.7810142089864021E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,   2.7810142089864021E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,  -2.7810142089864021E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,  -2.7810142089864021E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,   2.7810142089864021E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,  -2.7810142089864021E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,   3.4773708827913918E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,   3.4773708827913918E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,  -3.4773708827913918E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,   3.4773708827913918E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,  -3.4773708827913918E-01,   8.9539852419428489E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,  -3.4773708827913918E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,   3.4773708827913918E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,  -3.4773708827913918E-01,  -8.9539852419428489E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,   3.4773708827913918E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,   3.4773708827913918E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,  -3.4773708827913918E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,   3.4773708827913918E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,  -3.4773708827913918E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,  -3.4773708827913918E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,   3.4773708827913918E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,  -3.4773708827913918E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,   2.7810142089864021E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,   2.7810142089864021E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,  -2.7810142089864021E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,   2.7810142089864021E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,  -2.7810142089864021E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   8.9539852419428489E-01,  -2.7810142089864021E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,   2.7810142089864021E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -8.9539852419428489E-01,  -2.7810142089864021E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,   8.9539852419428489E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,   8.9539852419428489E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,  -8.9539852419428489E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,   8.9539852419428489E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,  -8.9539852419428489E-01,   2.7810142089864021E-01,   2.4296548038149264E-03],
            [   3.4773708827913918E-01,  -8.9539852419428489E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,   8.9539852419428489E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [  -3.4773708827913918E-01,  -8.9539852419428489E-01,  -2.7810142089864021E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,   8.9539852419428489E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,   8.9539852419428489E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,  -8.9539852419428489E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,   8.9539852419428489E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,  -8.9539852419428489E-01,   3.4773708827913918E-01,   2.4296548038149264E-03],
            [   2.7810142089864021E-01,  -8.9539852419428489E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,   8.9539852419428489E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [  -2.7810142089864021E-01,  -8.9539852419428489E-01,  -3.4773708827913918E-01,   2.4296548038149264E-03],
            [   3.7905769608905399E-01,   3.0891725235157308E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,   3.0891725235157308E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,  -3.0891725235157308E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,   3.0891725235157308E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,  -3.0891725235157308E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,  -3.0891725235157308E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,   3.0891725235157308E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,  -3.0891725235157308E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,   3.7905769608905399E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,   3.7905769608905399E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,  -3.7905769608905399E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,   3.7905769608905399E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,  -3.7905769608905399E-01,   8.7228744931657298E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,  -3.7905769608905399E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,   3.7905769608905399E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,  -3.7905769608905399E-01,  -8.7228744931657298E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,   3.7905769608905399E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,   3.7905769608905399E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,  -3.7905769608905399E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,   3.7905769608905399E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,  -3.7905769608905399E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,  -3.7905769608905399E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,   3.7905769608905399E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,  -3.7905769608905399E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,   3.0891725235157308E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,   3.0891725235157308E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,  -3.0891725235157308E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,   3.0891725235157308E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,  -3.0891725235157308E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   8.7228744931657298E-01,  -3.0891725235157308E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,   3.0891725235157308E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -8.7228744931657298E-01,  -3.0891725235157308E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,   8.7228744931657298E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,   8.7228744931657298E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,  -8.7228744931657298E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,   8.7228744931657298E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,  -8.7228744931657298E-01,   3.0891725235157308E-01,   2.4794211647737861E-03],
            [   3.7905769608905399E-01,  -8.7228744931657298E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,   8.7228744931657298E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [  -3.7905769608905399E-01,  -8.7228744931657298E-01,  -3.0891725235157308E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,   8.7228744931657298E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,   8.7228744931657298E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,  -8.7228744931657298E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,   8.7228744931657298E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,  -8.7228744931657298E-01,   3.7905769608905399E-01,   2.4794211647737861E-03],
            [   3.0891725235157308E-01,  -8.7228744931657298E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,   8.7228744931657298E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [  -3.0891725235157308E-01,  -8.7228744931657298E-01,  -3.7905769608905399E-01,   2.4794211647737861E-03],
            [   4.0979383178102002E-01,   3.3937500554722438E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,   3.3937500554722438E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,  -3.3937500554722438E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,   3.3937500554722438E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,  -3.3937500554722438E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,  -3.3937500554722438E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,   3.3937500554722438E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,  -3.3937500554722438E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,   4.0979383178102002E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,   4.0979383178102002E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,  -4.0979383178102002E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,   4.0979383178102002E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,  -4.0979383178102002E-01,   8.4669570746759459E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,  -4.0979383178102002E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,   4.0979383178102002E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,  -4.0979383178102002E-01,  -8.4669570746759459E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,   4.0979383178102002E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,   4.0979383178102002E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,  -4.0979383178102002E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,   4.0979383178102002E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,  -4.0979383178102002E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,  -4.0979383178102002E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,   4.0979383178102002E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,  -4.0979383178102002E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,   3.3937500554722438E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,   3.3937500554722438E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,  -3.3937500554722438E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,   3.3937500554722438E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,  -3.3937500554722438E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   8.4669570746759459E-01,  -3.3937500554722438E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,   3.3937500554722438E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -8.4669570746759459E-01,  -3.3937500554722438E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,   8.4669570746759459E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,   8.4669570746759459E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,  -8.4669570746759459E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,   8.4669570746759459E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,  -8.4669570746759459E-01,   3.3937500554722438E-01,   2.5195410970787636E-03],
            [   4.0979383178102002E-01,  -8.4669570746759459E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,   8.4669570746759459E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [  -4.0979383178102002E-01,  -8.4669570746759459E-01,  -3.3937500554722438E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,   8.4669570746759459E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,   8.4669570746759459E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,  -8.4669570746759459E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,   8.4669570746759459E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,  -8.4669570746759459E-01,   4.0979383178102002E-01,   2.5195410970787636E-03],
            [   3.3937500554722438E-01,  -8.4669570746759459E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,   8.4669570746759459E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [  -3.3937500554722438E-01,  -8.4669570746759459E-01,  -4.0979383178102002E-01,   2.5195410970787636E-03],
            [   4.3982565728596368E-01,   3.6933224709877299E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,   3.6933224709877299E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,  -3.6933224709877299E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,   3.6933224709877299E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,  -3.6933224709877299E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,  -3.6933224709877299E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,   3.6933224709877299E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,  -3.6933224709877299E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,   4.3982565728596368E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,   4.3982565728596368E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,  -4.3982565728596368E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,   4.3982565728596368E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,  -4.3982565728596368E-01,   8.1862511716043806E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,  -4.3982565728596368E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,   4.3982565728596368E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,  -4.3982565728596368E-01,  -8.1862511716043806E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,   4.3982565728596368E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,   4.3982565728596368E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,  -4.3982565728596368E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,   4.3982565728596368E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,  -4.3982565728596368E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,  -4.3982565728596368E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,   4.3982565728596368E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,  -4.3982565728596368E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,   3.6933224709877299E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,   3.6933224709877299E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,  -3.6933224709877299E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,   3.6933224709877299E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,  -3.6933224709877299E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   8.1862511716043806E-01,  -3.6933224709877299E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,   3.6933224709877299E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -8.1862511716043806E-01,  -3.6933224709877299E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,   8.1862511716043806E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,   8.1862511716043806E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,  -8.1862511716043806E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,   8.1862511716043806E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,  -8.1862511716043806E-01,   3.6933224709877299E-01,   2.5511880056521873E-03],
            [   4.3982565728596368E-01,  -8.1862511716043806E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,   8.1862511716043806E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [  -4.3982565728596368E-01,  -8.1862511716043806E-01,  -3.6933224709877299E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,   8.1862511716043806E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,   8.1862511716043806E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,  -8.1862511716043806E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,   8.1862511716043806E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,  -8.1862511716043806E-01,   4.3982565728596368E-01,   2.5511880056521873E-03],
            [   3.6933224709877299E-01,  -8.1862511716043806E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,   8.1862511716043806E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [  -3.6933224709877299E-01,  -8.1862511716043806E-01,  -4.3982565728596368E-01,   2.5511880056521873E-03],
            [   4.6903841147184799E-01,   3.9865410056098771E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,   3.9865410056098771E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,  -3.9865410056098771E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,   3.9865410056098771E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,  -3.9865410056098771E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,  -3.9865410056098771E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,   3.9865410056098771E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,  -3.9865410056098771E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,   4.6903841147184799E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,   4.6903841147184799E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,  -4.6903841147184799E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,   4.6903841147184799E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,  -4.6903841147184799E-01,   7.8808494254735972E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,  -4.6903841147184799E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,   4.6903841147184799E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,  -4.6903841147184799E-01,  -7.8808494254735972E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,   4.6903841147184799E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,   4.6903841147184799E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,  -4.6903841147184799E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,   4.6903841147184799E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,  -4.6903841147184799E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,  -4.6903841147184799E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,   4.6903841147184799E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,  -4.6903841147184799E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,   3.9865410056098771E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,   3.9865410056098771E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,  -3.9865410056098771E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,   3.9865410056098771E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,  -3.9865410056098771E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   7.8808494254735972E-01,  -3.9865410056098771E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,   3.9865410056098771E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -7.8808494254735972E-01,  -3.9865410056098771E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,   7.8808494254735972E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,   7.8808494254735972E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,  -7.8808494254735972E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,   7.8808494254735972E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,  -7.8808494254735972E-01,   3.9865410056098771E-01,   2.5754292267702052E-03],
            [   4.6903841147184799E-01,  -7.8808494254735972E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,   7.8808494254735972E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [  -4.6903841147184799E-01,  -7.8808494254735972E-01,  -3.9865410056098771E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,   7.8808494254735972E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,   7.8808494254735972E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,  -7.8808494254735972E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,   7.8808494254735972E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,  -7.8808494254735972E-01,   4.6903841147184799E-01,   2.5754292267702052E-03],
            [   3.9865410056098771E-01,  -7.8808494254735972E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,   7.8808494254735972E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [  -3.9865410056098771E-01,  -7.8808494254735972E-01,  -4.6903841147184799E-01,   2.5754292267702052E-03],
            [   4.9732160483010529E-01,   4.2721124914085618E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,   4.2721124914085618E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,  -4.2721124914085618E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,   4.2721124914085618E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,  -4.2721124914085618E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,  -4.2721124914085618E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,   4.2721124914085618E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,  -4.2721124914085618E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,   4.9732160483010529E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,   4.9732160483010529E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,  -4.9732160483010529E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,   4.9732160483010529E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,  -4.9732160483010529E-01,   7.5509057071103591E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,  -4.9732160483010529E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,   4.9732160483010529E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,  -4.9732160483010529E-01,  -7.5509057071103591E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,   4.9732160483010529E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,   4.9732160483010529E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,  -4.9732160483010529E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,   4.9732160483010529E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,  -4.9732160483010529E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,  -4.9732160483010529E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,   4.9732160483010529E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,  -4.9732160483010529E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,   4.2721124914085618E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,   4.2721124914085618E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,  -4.2721124914085618E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,   4.2721124914085618E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,  -4.2721124914085618E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   7.5509057071103591E-01,  -4.2721124914085618E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,   4.2721124914085618E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -7.5509057071103591E-01,  -4.2721124914085618E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,   7.5509057071103591E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,   7.5509057071103591E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,  -7.5509057071103591E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,   7.5509057071103591E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,  -7.5509057071103591E-01,   4.2721124914085618E-01,   2.5932635519949157E-03],
            [   4.9732160483010529E-01,  -7.5509057071103591E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,   7.5509057071103591E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [  -4.9732160483010529E-01,  -7.5509057071103591E-01,  -4.2721124914085618E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,   7.5509057071103591E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,   7.5509057071103591E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,  -7.5509057071103591E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,   7.5509057071103591E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,  -7.5509057071103591E-01,   4.9732160483010529E-01,   2.5932635519949157E-03],
            [   4.2721124914085618E-01,  -7.5509057071103591E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,   7.5509057071103591E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [  -4.2721124914085618E-01,  -7.5509057071103591E-01,  -4.9732160483010529E-01,   2.5932635519949157E-03],
            [   5.2456815261324463E-01,   4.5487817353099358E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,   4.5487817353099358E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,  -4.5487817353099358E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,   4.5487817353099358E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,  -4.5487817353099358E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,  -4.5487817353099358E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,   4.5487817353099358E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,  -4.5487817353099358E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,   5.2456815261324463E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,   5.2456815261324463E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,  -5.2456815261324463E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,   5.2456815261324463E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,  -5.2456815261324463E-01,   7.1966249069201527E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,  -5.2456815261324463E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,   5.2456815261324463E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,  -5.2456815261324463E-01,  -7.1966249069201527E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,   5.2456815261324463E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,   5.2456815261324463E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,  -5.2456815261324463E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,   5.2456815261324463E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,  -5.2456815261324463E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,  -5.2456815261324463E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,   5.2456815261324463E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,  -5.2456815261324463E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,   4.5487817353099358E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,   4.5487817353099358E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,  -4.5487817353099358E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,   4.5487817353099358E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,  -4.5487817353099358E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   7.1966249069201527E-01,  -4.5487817353099358E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,   4.5487817353099358E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -7.1966249069201527E-01,  -4.5487817353099358E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,   7.1966249069201527E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,   7.1966249069201527E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,  -7.1966249069201527E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,   7.1966249069201527E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,  -7.1966249069201527E-01,   4.5487817353099358E-01,   2.6056469087281731E-03],
            [   5.2456815261324463E-01,  -7.1966249069201527E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,   7.1966249069201527E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [  -5.2456815261324463E-01,  -7.1966249069201527E-01,  -4.5487817353099358E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,   7.1966249069201527E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,   7.1966249069201527E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,  -7.1966249069201527E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,   7.1966249069201527E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,  -7.1966249069201527E-01,   5.2456815261324463E-01,   2.6056469087281731E-03],
            [   4.5487817353099358E-01,  -7.1966249069201527E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,   7.1966249069201527E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [  -4.5487817353099358E-01,  -7.1966249069201527E-01,  -5.2456815261324463E-01,   2.6056469087281731E-03],
            [   5.5067339118038883E-01,   4.8153153550232508E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,   4.8153153550232508E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,  -4.8153153550232508E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,   4.8153153550232508E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,  -4.8153153550232508E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,  -4.8153153550232508E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,   4.8153153550232508E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,  -4.8153153550232508E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,   5.5067339118038883E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,   5.5067339118038883E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,  -5.5067339118038883E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,   5.5067339118038883E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,  -5.5067339118038883E-01,   6.8182563501430737E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,  -5.5067339118038883E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,   5.5067339118038883E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,  -5.5067339118038883E-01,  -6.8182563501430737E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,   5.5067339118038883E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,   5.5067339118038883E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,  -5.5067339118038883E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,   5.5067339118038883E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,  -5.5067339118038883E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,  -5.5067339118038883E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,   5.5067339118038883E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,  -5.5067339118038883E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,   4.8153153550232508E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,   4.8153153550232508E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,  -4.8153153550232508E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,   4.8153153550232508E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,  -4.8153153550232508E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   6.8182563501430737E-01,  -4.8153153550232508E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,   4.8153153550232508E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -6.8182563501430737E-01,  -4.8153153550232508E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,   6.8182563501430737E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,   6.8182563501430737E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,  -6.8182563501430737E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,   6.8182563501430737E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,  -6.8182563501430737E-01,   4.8153153550232508E-01,   2.6135092669478388E-03],
            [   5.5067339118038883E-01,  -6.8182563501430737E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,   6.8182563501430737E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [  -5.5067339118038883E-01,  -6.8182563501430737E-01,  -4.8153153550232508E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,   6.8182563501430737E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,   6.8182563501430737E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,  -6.8182563501430737E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,   6.8182563501430737E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,  -6.8182563501430737E-01,   5.5067339118038883E-01,   2.6135092669478388E-03],
            [   4.8153153550232508E-01,  -6.8182563501430737E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,   6.8182563501430737E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [  -4.8153153550232508E-01,  -6.8182563501430737E-01,  -5.5067339118038883E-01,   2.6135092669478388E-03],
            [   5.7553398295224745E-01,   5.0704864458018550E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,   5.0704864458018550E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,  -5.0704864458018550E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,   5.0704864458018550E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,  -5.0704864458018550E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,  -5.0704864458018550E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,   5.0704864458018550E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,  -5.0704864458018550E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,   5.7553398295224745E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,   5.7553398295224745E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,  -5.7553398295224745E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,   5.7553398295224745E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,  -5.7553398295224745E-01,   6.4160915399994012E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,  -5.7553398295224745E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,   5.7553398295224745E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,  -5.7553398295224745E-01,  -6.4160915399994012E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,   5.7553398295224745E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,   5.7553398295224745E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,  -5.7553398295224745E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,   5.7553398295224745E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,  -5.7553398295224745E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,  -5.7553398295224745E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,   5.7553398295224745E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,  -5.7553398295224745E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,   5.0704864458018550E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,   5.0704864458018550E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,  -5.0704864458018550E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,   5.0704864458018550E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,  -5.0704864458018550E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   6.4160915399994012E-01,  -5.0704864458018550E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,   5.0704864458018550E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -6.4160915399994012E-01,  -5.0704864458018550E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,   6.4160915399994012E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,   6.4160915399994012E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,  -6.4160915399994012E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,   6.4160915399994012E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,  -6.4160915399994012E-01,   5.0704864458018550E-01,   2.6177641667918241E-03],
            [   5.7553398295224745E-01,  -6.4160915399994012E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,   6.4160915399994012E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [  -5.7553398295224745E-01,  -6.4160915399994012E-01,  -5.0704864458018550E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,   6.4160915399994012E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,   6.4160915399994012E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,  -6.4160915399994012E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,   6.4160915399994012E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,  -6.4160915399994012E-01,   5.7553398295224745E-01,   2.6177641667918241E-03],
            [   5.0704864458018550E-01,  -6.4160915399994012E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,   6.4160915399994012E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [  -5.0704864458018550E-01,  -6.4160915399994012E-01,  -5.7553398295224745E-01,   2.6177641667918241E-03],
            [   1.3054723860563619E-01,   2.2849703757223661E-02,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,   2.2849703757223661E-02,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,  -2.2849703757223661E-02,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,   2.2849703757223661E-02,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,  -2.2849703757223661E-02,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,  -2.2849703757223661E-02,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,   2.2849703757223661E-02,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,  -2.2849703757223661E-02,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,   1.3054723860563619E-01,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,   1.3054723860563619E-01,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,  -1.3054723860563619E-01,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,   1.3054723860563619E-01,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,  -1.3054723860563619E-01,   9.9117874751764645E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,  -1.3054723860563619E-01,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,   1.3054723860563619E-01,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,  -1.3054723860563619E-01,  -9.9117874751764645E-01,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,   1.3054723860563619E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,   1.3054723860563619E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,  -1.3054723860563619E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,   1.3054723860563619E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,  -1.3054723860563619E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,  -1.3054723860563619E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,   1.3054723860563619E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,  -1.3054723860563619E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,   2.2849703757223661E-02,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,   2.2849703757223661E-02,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,  -2.2849703757223661E-02,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,   2.2849703757223661E-02,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,  -2.2849703757223661E-02,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   9.9117874751764645E-01,  -2.2849703757223661E-02,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,   2.2849703757223661E-02,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -9.9117874751764645E-01,  -2.2849703757223661E-02,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,   9.9117874751764645E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,   9.9117874751764645E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,  -9.9117874751764645E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,   9.9117874751764645E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,  -9.9117874751764645E-01,   2.2849703757223661E-02,   1.5867746198263888E-03],
            [   1.3054723860563619E-01,  -9.9117874751764645E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,   9.9117874751764645E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [  -1.3054723860563619E-01,  -9.9117874751764645E-01,  -2.2849703757223661E-02,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,   9.9117874751764645E-01,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,   9.9117874751764645E-01,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,  -9.9117874751764645E-01,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,   9.9117874751764645E-01,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,  -9.9117874751764645E-01,   1.3054723860563619E-01,   1.5867746198263888E-03],
            [   2.2849703757223661E-02,  -9.9117874751764645E-01,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,   9.9117874751764645E-01,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [  -2.2849703757223661E-02,  -9.9117874751764645E-01,  -1.3054723860563619E-01,   1.5867746198263888E-03],
            [   1.6373279082164771E-01,   4.8122543382883839E-02,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,   4.8122543382883839E-02,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,  -4.8122543382883839E-02,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,   4.8122543382883839E-02,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,  -4.8122543382883839E-02,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,  -4.8122543382883839E-02,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,   4.8122543382883839E-02,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,  -4.8122543382883839E-02,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,   1.6373279082164771E-01,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,   1.6373279082164771E-01,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,  -1.6373279082164771E-01,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,   1.6373279082164771E-01,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,  -1.6373279082164771E-01,   9.8533029691982832E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,  -1.6373279082164771E-01,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,   1.6373279082164771E-01,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,  -1.6373279082164771E-01,  -9.8533029691982832E-01,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,   1.6373279082164771E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,   1.6373279082164771E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,  -1.6373279082164771E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,   1.6373279082164771E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,  -1.6373279082164771E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,  -1.6373279082164771E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,   1.6373279082164771E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,  -1.6373279082164771E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,   4.8122543382883839E-02,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,   4.8122543382883839E-02,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,  -4.8122543382883839E-02,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,   4.8122543382883839E-02,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,  -4.8122543382883839E-02,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   9.8533029691982832E-01,  -4.8122543382883839E-02,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,   4.8122543382883839E-02,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -9.8533029691982832E-01,  -4.8122543382883839E-02,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,   9.8533029691982832E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,   9.8533029691982832E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,  -9.8533029691982832E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,   9.8533029691982832E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,  -9.8533029691982832E-01,   4.8122543382883839E-02,   1.7773700283117337E-03],
            [   1.6373279082164771E-01,  -9.8533029691982832E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,   9.8533029691982832E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [  -1.6373279082164771E-01,  -9.8533029691982832E-01,  -4.8122543382883839E-02,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,   9.8533029691982832E-01,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,   9.8533029691982832E-01,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,  -9.8533029691982832E-01,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,   9.8533029691982832E-01,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,  -9.8533029691982832E-01,   1.6373279082164771E-01,   1.7773700283117337E-03],
            [   4.8122543382883839E-02,  -9.8533029691982832E-01,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,   9.8533029691982832E-01,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [  -4.8122543382883839E-02,  -9.8533029691982832E-01,  -1.6373279082164771E-01,   1.7773700283117337E-03],
            [   1.9727346341496371E-01,   7.5317344575119349E-02,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,   7.5317344575119349E-02,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,  -7.5317344575119349E-02,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,   7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,  -7.5317344575119349E-02,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,  -7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,   7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,  -7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,   1.9727346341496371E-01,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,   1.9727346341496371E-01,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,  -1.9727346341496371E-01,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,   1.9727346341496371E-01,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,  -1.9727346341496371E-01,   9.7745101065905993E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,  -1.9727346341496371E-01,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,   1.9727346341496371E-01,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,  -1.9727346341496371E-01,  -9.7745101065905993E-01,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,   1.9727346341496371E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,   1.9727346341496371E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,  -1.9727346341496371E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,   1.9727346341496371E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,  -1.9727346341496371E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,  -1.9727346341496371E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,   1.9727346341496371E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,  -1.9727346341496371E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,   7.5317344575119349E-02,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,   7.5317344575119349E-02,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,   7.5317344575119349E-02,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   9.7745101065905993E-01,  -7.5317344575119349E-02,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,   7.5317344575119349E-02,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -9.7745101065905993E-01,  -7.5317344575119349E-02,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,   9.7745101065905993E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,   9.7745101065905993E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,  -9.7745101065905993E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,   9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,  -9.7745101065905993E-01,   7.5317344575119349E-02,   1.9336382162198208E-03],
            [   1.9727346341496371E-01,  -9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,   9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [  -1.9727346341496371E-01,  -9.7745101065905993E-01,  -7.5317344575119349E-02,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,   9.7745101065905993E-01,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,   9.7745101065905993E-01,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,   9.7745101065905993E-01,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,  -9.7745101065905993E-01,   1.9727346341496371E-01,   1.9336382162198208E-03],
            [   7.5317344575119349E-02,  -9.7745101065905993E-01,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,   9.7745101065905993E-01,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [  -7.5317344575119349E-02,  -9.7745101065905993E-01,  -1.9727346341496371E-01,   1.9336382162198208E-03],
            [   2.3086946531101299E-01,   1.0390436398820170E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,   1.0390436398820170E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,  -1.0390436398820170E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,   1.0390436398820170E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,  -1.0390436398820170E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,  -1.0390436398820170E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,   1.0390436398820170E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,  -1.0390436398820170E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,   2.3086946531101299E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,   2.3086946531101299E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,  -2.3086946531101299E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,   2.3086946531101299E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,  -2.3086946531101299E-01,   9.6742088727255326E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,  -2.3086946531101299E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,   2.3086946531101299E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,  -2.3086946531101299E-01,  -9.6742088727255326E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,   2.3086946531101299E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,   2.3086946531101299E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,  -2.3086946531101299E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,   2.3086946531101299E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,  -2.3086946531101299E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,  -2.3086946531101299E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,   2.3086946531101299E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,  -2.3086946531101299E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,   1.0390436398820170E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,   1.0390436398820170E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,  -1.0390436398820170E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,   1.0390436398820170E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,  -1.0390436398820170E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   9.6742088727255326E-01,  -1.0390436398820170E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,   1.0390436398820170E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -9.6742088727255326E-01,  -1.0390436398820170E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,   9.6742088727255326E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,   9.6742088727255326E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,  -9.6742088727255326E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,   9.6742088727255326E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,  -9.6742088727255326E-01,   1.0390436398820170E-01,   2.0639446195310409E-03],
            [   2.3086946531101299E-01,  -9.6742088727255326E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,   9.6742088727255326E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [  -2.3086946531101299E-01,  -9.6742088727255326E-01,  -1.0390436398820170E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,   9.6742088727255326E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,   9.6742088727255326E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,  -9.6742088727255326E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,   9.6742088727255326E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,  -9.6742088727255326E-01,   2.3086946531101299E-01,   2.0639446195310409E-03],
            [   1.0390436398820170E-01,  -9.6742088727255326E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,   9.6742088727255326E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [  -1.0390436398820170E-01,  -9.6742088727255326E-01,  -2.3086946531101299E-01,   2.0639446195310409E-03],
            [   2.6438992183381599E-01,   1.3345265871176260E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,   1.3345265871176260E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,  -1.3345265871176260E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,   1.3345265871176260E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,  -1.3345265871176260E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,  -1.3345265871176260E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,   1.3345265871176260E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,  -1.3345265871176260E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,   2.6438992183381599E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,   2.6438992183381599E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,  -2.6438992183381599E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,   2.6438992183381599E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,  -2.6438992183381599E-01,   9.5513787335414069E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,  -2.6438992183381599E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,   2.6438992183381599E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,  -2.6438992183381599E-01,  -9.5513787335414069E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,   2.6438992183381599E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,   2.6438992183381599E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,  -2.6438992183381599E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,   2.6438992183381599E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,  -2.6438992183381599E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,  -2.6438992183381599E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,   2.6438992183381599E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,  -2.6438992183381599E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,   1.3345265871176260E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,   1.3345265871176260E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,  -1.3345265871176260E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,   1.3345265871176260E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,  -1.3345265871176260E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   9.5513787335414069E-01,  -1.3345265871176260E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,   1.3345265871176260E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -9.5513787335414069E-01,  -1.3345265871176260E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,   9.5513787335414069E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,   9.5513787335414069E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,  -9.5513787335414069E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,   9.5513787335414069E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,  -9.5513787335414069E-01,   1.3345265871176260E-01,   2.1737189880916522E-03],
            [   2.6438992183381599E-01,  -9.5513787335414069E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,   9.5513787335414069E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [  -2.6438992183381599E-01,  -9.5513787335414069E-01,  -1.3345265871176260E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,   9.5513787335414069E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,   9.5513787335414069E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,  -9.5513787335414069E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,   9.5513787335414069E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,  -9.5513787335414069E-01,   2.6438992183381599E-01,   2.1737189880916522E-03],
            [   1.3345265871176260E-01,  -9.5513787335414069E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,   9.5513787335414069E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [  -1.3345265871176260E-01,  -9.5513787335414069E-01,  -2.6438992183381599E-01,   2.1737189880916522E-03],
            [   2.9771715996221709E-01,   1.6364148689363819E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,   1.6364148689363819E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,  -1.6364148689363819E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,   1.6364148689363819E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,  -1.6364148689363819E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,  -1.6364148689363819E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,   1.6364148689363819E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,  -1.6364148689363819E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,   2.9771715996221709E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,   2.9771715996221709E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,  -2.9771715996221709E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,   2.9771715996221709E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,  -2.9771715996221709E-01,   9.4052429869263399E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,  -2.9771715996221709E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,   2.9771715996221709E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,  -2.9771715996221709E-01,  -9.4052429869263399E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,   2.9771715996221709E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,   2.9771715996221709E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,  -2.9771715996221709E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,   2.9771715996221709E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,  -2.9771715996221709E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,  -2.9771715996221709E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,   2.9771715996221709E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,  -2.9771715996221709E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,   1.6364148689363819E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,   1.6364148689363819E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,  -1.6364148689363819E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,   1.6364148689363819E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,  -1.6364148689363819E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   9.4052429869263399E-01,  -1.6364148689363819E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,   1.6364148689363819E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -9.4052429869263399E-01,  -1.6364148689363819E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,   9.4052429869263399E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,   9.4052429869263399E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,  -9.4052429869263399E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,   9.4052429869263399E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,  -9.4052429869263399E-01,   1.6364148689363819E-01,   2.2663514625737916E-03],
            [   2.9771715996221709E-01,  -9.4052429869263399E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,   9.4052429869263399E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [  -2.9771715996221709E-01,  -9.4052429869263399E-01,  -1.6364148689363819E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,   9.4052429869263399E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,   9.4052429869263399E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,  -9.4052429869263399E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,   9.4052429869263399E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,  -9.4052429869263399E-01,   2.9771715996221709E-01,   2.2663514625737916E-03],
            [   1.6364148689363819E-01,  -9.4052429869263399E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,   9.4052429869263399E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [  -1.6364148689363819E-01,  -9.4052429869263399E-01,  -2.9771715996221709E-01,   2.2663514625737916E-03],
            [   3.3072939030323101E-01,   1.9421954061665681E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,   1.9421954061665681E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,  -1.9421954061665681E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,   1.9421954061665681E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,  -1.9421954061665681E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,  -1.9421954061665681E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,   1.9421954061665681E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,  -1.9421954061665681E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,   3.3072939030323101E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,   3.3072939030323101E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,  -3.3072939030323101E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,   3.3072939030323101E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,  -3.3072939030323101E-01,   9.2352414177015862E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,  -3.3072939030323101E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,   3.3072939030323101E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,  -3.3072939030323101E-01,  -9.2352414177015862E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,   3.3072939030323101E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,   3.3072939030323101E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,  -3.3072939030323101E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,   3.3072939030323101E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,  -3.3072939030323101E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,  -3.3072939030323101E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,   3.3072939030323101E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,  -3.3072939030323101E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,   1.9421954061665681E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,   1.9421954061665681E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,  -1.9421954061665681E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,   1.9421954061665681E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,  -1.9421954061665681E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   9.2352414177015862E-01,  -1.9421954061665681E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,   1.9421954061665681E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -9.2352414177015862E-01,  -1.9421954061665681E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,   9.2352414177015862E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,   9.2352414177015862E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,  -9.2352414177015862E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,   9.2352414177015862E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,  -9.2352414177015862E-01,   1.9421954061665681E-01,   2.3442254621052392E-03],
            [   3.3072939030323101E-01,  -9.2352414177015862E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,   9.2352414177015862E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [  -3.3072939030323101E-01,  -9.2352414177015862E-01,  -1.9421954061665681E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,   9.2352414177015862E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,   9.2352414177015862E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,  -9.2352414177015862E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,   9.2352414177015862E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,  -9.2352414177015862E-01,   3.3072939030323101E-01,   2.3442254621052392E-03],
            [   1.9421954061665681E-01,  -9.2352414177015862E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,   9.2352414177015862E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [  -1.9421954061665681E-01,  -9.2352414177015862E-01,  -3.3072939030323101E-01,   2.3442254621052392E-03],
            [   3.6330691982190733E-01,   2.2497528799437530E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,   2.2497528799437530E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,  -2.2497528799437530E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,   2.2497528799437530E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,  -2.2497528799437530E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,  -2.2497528799437530E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,   2.2497528799437530E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,  -2.2497528799437530E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,   3.6330691982190733E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,   3.6330691982190733E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,  -3.6330691982190733E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,   3.6330691982190733E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,  -3.6330691982190733E-01,   9.0409855757066993E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,  -3.6330691982190733E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,   3.6330691982190733E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,  -3.6330691982190733E-01,  -9.0409855757066993E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,   3.6330691982190733E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,   3.6330691982190733E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,  -3.6330691982190733E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,   3.6330691982190733E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,  -3.6330691982190733E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,  -3.6330691982190733E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,   3.6330691982190733E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,  -3.6330691982190733E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,   2.2497528799437530E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,   2.2497528799437530E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,  -2.2497528799437530E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,   2.2497528799437530E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,  -2.2497528799437530E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   9.0409855757066993E-01,  -2.2497528799437530E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,   2.2497528799437530E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -9.0409855757066993E-01,  -2.2497528799437530E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,   9.0409855757066993E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,   9.0409855757066993E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,  -9.0409855757066993E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,   9.0409855757066993E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,  -9.0409855757066993E-01,   2.2497528799437530E-01,   2.4092027962613724E-03],
            [   3.6330691982190733E-01,  -9.0409855757066993E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,   9.0409855757066993E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [  -3.6330691982190733E-01,  -9.0409855757066993E-01,  -2.2497528799437530E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,   9.0409855757066993E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,   9.0409855757066993E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,  -9.0409855757066993E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,   9.0409855757066993E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,  -9.0409855757066993E-01,   3.6330691982190733E-01,   2.4092027962613724E-03],
            [   2.2497528799437530E-01,  -9.0409855757066993E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,   9.0409855757066993E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [  -2.2497528799437530E-01,  -9.0409855757066993E-01,  -3.6330691982190733E-01,   2.4092027962613724E-03],
            [   3.9533469559227269E-01,   2.5572188218200320E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,   2.5572188218200320E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,  -2.5572188218200320E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,   2.5572188218200320E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,  -2.5572188218200320E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,  -2.5572188218200320E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,   2.5572188218200320E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,  -2.5572188218200320E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,   3.9533469559227269E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,   3.9533469559227269E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,  -3.9533469559227269E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,   3.9533469559227269E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,  -3.9533469559227269E-01,   8.8222264618080326E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,  -3.9533469559227269E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,   3.9533469559227269E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,  -3.9533469559227269E-01,  -8.8222264618080326E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,   3.9533469559227269E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,   3.9533469559227269E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,  -3.9533469559227269E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,   3.9533469559227269E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,  -3.9533469559227269E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,  -3.9533469559227269E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,   3.9533469559227269E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,  -3.9533469559227269E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,   2.5572188218200320E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,   2.5572188218200320E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,  -2.5572188218200320E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,   2.5572188218200320E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,  -2.5572188218200320E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   8.8222264618080326E-01,  -2.5572188218200320E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,   2.5572188218200320E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -8.8222264618080326E-01,  -2.5572188218200320E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,   8.8222264618080326E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,   8.8222264618080326E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,  -8.8222264618080326E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,   8.8222264618080326E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,  -8.8222264618080326E-01,   2.5572188218200320E-01,   2.4628222924911263E-03],
            [   3.9533469559227269E-01,  -8.8222264618080326E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,   8.8222264618080326E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [  -3.9533469559227269E-01,  -8.8222264618080326E-01,  -2.5572188218200320E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,   8.8222264618080326E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,   8.8222264618080326E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,  -8.8222264618080326E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,   8.8222264618080326E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,  -8.8222264618080326E-01,   3.9533469559227269E-01,   2.4628222924911263E-03],
            [   2.5572188218200320E-01,  -8.8222264618080326E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,   8.8222264618080326E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [  -2.5572188218200320E-01,  -8.8222264618080326E-01,  -3.9533469559227269E-01,   2.4628222924911263E-03],
            [   4.2670183941849138E-01,   2.8628979252131931E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,   2.8628979252131931E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,  -2.8628979252131931E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,   2.8628979252131931E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,  -2.8628979252131931E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,  -2.8628979252131931E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,   2.8628979252131931E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,  -2.8628979252131931E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,   4.2670183941849138E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,   4.2670183941849138E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,  -4.2670183941849138E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,   4.2670183941849138E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,  -4.2670183941849138E-01,   8.5788326416533844E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,  -4.2670183941849138E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,   4.2670183941849138E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,  -4.2670183941849138E-01,  -8.5788326416533844E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,   4.2670183941849138E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,   4.2670183941849138E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,  -4.2670183941849138E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,   4.2670183941849138E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,  -4.2670183941849138E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,  -4.2670183941849138E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,   4.2670183941849138E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,  -4.2670183941849138E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,   2.8628979252131931E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,   2.8628979252131931E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,  -2.8628979252131931E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,   2.8628979252131931E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,  -2.8628979252131931E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   8.5788326416533844E-01,  -2.8628979252131931E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,   2.8628979252131931E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -8.5788326416533844E-01,  -2.8628979252131931E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,   8.5788326416533844E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,   8.5788326416533844E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,  -8.5788326416533844E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,   8.5788326416533844E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,  -8.5788326416533844E-01,   2.8628979252131931E-01,   2.5063997502939631E-03],
            [   4.2670183941849138E-01,  -8.5788326416533844E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,   8.5788326416533844E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [  -4.2670183941849138E-01,  -8.5788326416533844E-01,  -2.8628979252131931E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,   8.5788326416533844E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,   8.5788326416533844E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,  -8.5788326416533844E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,   8.5788326416533844E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,  -8.5788326416533844E-01,   4.2670183941849138E-01,   2.5063997502939631E-03],
            [   2.8628979252131931E-01,  -8.5788326416533844E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,   8.5788326416533844E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [  -2.8628979252131931E-01,  -8.5788326416533844E-01,  -4.2670183941849138E-01,   2.5063997502939631E-03],
            [   4.5730096225717037E-01,   3.1652245366365178E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,   3.1652245366365178E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,  -3.1652245366365178E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,   3.1652245366365178E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,  -3.1652245366365178E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,  -3.1652245366365178E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,   3.1652245366365178E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,  -3.1652245366365178E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,   4.5730096225717037E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,   4.5730096225717037E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,  -4.5730096225717037E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,   4.5730096225717037E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,  -4.5730096225717037E-01,   8.3107723241911002E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,  -4.5730096225717037E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,   4.5730096225717037E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,  -4.5730096225717037E-01,  -8.3107723241911002E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,   4.5730096225717037E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,   4.5730096225717037E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,  -4.5730096225717037E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,   4.5730096225717037E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,  -4.5730096225717037E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,  -4.5730096225717037E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,   4.5730096225717037E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,  -4.5730096225717037E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,   3.1652245366365178E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,   3.1652245366365178E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,  -3.1652245366365178E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,   3.1652245366365178E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,  -3.1652245366365178E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   8.3107723241911002E-01,  -3.1652245366365178E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,   3.1652245366365178E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -8.3107723241911002E-01,  -3.1652245366365178E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,   8.3107723241911002E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,   8.3107723241911002E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,  -8.3107723241911002E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,   8.3107723241911002E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,  -8.3107723241911002E-01,   3.1652245366365178E-01,   2.5410946991184236E-03],
            [   4.5730096225717037E-01,  -8.3107723241911002E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,   8.3107723241911002E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [  -4.5730096225717037E-01,  -8.3107723241911002E-01,  -3.1652245366365178E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,   8.3107723241911002E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,   8.3107723241911002E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,  -8.3107723241911002E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,   8.3107723241911002E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,  -8.3107723241911002E-01,   4.5730096225717037E-01,   2.5410946991184236E-03],
            [   3.1652245366365178E-01,  -8.3107723241911002E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,   8.3107723241911002E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [  -3.1652245366365178E-01,  -8.3107723241911002E-01,  -4.5730096225717037E-01,   2.5410946991184236E-03],
            [   4.8702795598561088E-01,   3.4627302216364958E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,   3.4627302216364958E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,  -3.4627302216364958E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,   3.4627302216364958E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,  -3.4627302216364958E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,  -3.4627302216364958E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,   3.4627302216364958E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,  -3.4627302216364958E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,   4.8702795598561088E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,   4.8702795598561088E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,  -4.8702795598561088E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,   4.8702795598561088E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,  -4.8702795598561088E-01,   8.0180968079097825E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,  -4.8702795598561088E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,   4.8702795598561088E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,  -4.8702795598561088E-01,  -8.0180968079097825E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,   4.8702795598561088E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,   4.8702795598561088E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,  -4.8702795598561088E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,   4.8702795598561088E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,  -4.8702795598561088E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,  -4.8702795598561088E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,   4.8702795598561088E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,  -4.8702795598561088E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,   3.4627302216364958E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,   3.4627302216364958E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,  -3.4627302216364958E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,   3.4627302216364958E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,  -3.4627302216364958E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   8.0180968079097825E-01,  -3.4627302216364958E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,   3.4627302216364958E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -8.0180968079097825E-01,  -3.4627302216364958E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,   8.0180968079097825E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,   8.0180968079097825E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,  -8.0180968079097825E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,   8.0180968079097825E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,  -8.0180968079097825E-01,   3.4627302216364958E-01,   2.5679604849328163E-03],
            [   4.8702795598561088E-01,  -8.0180968079097825E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,   8.0180968079097825E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [  -4.8702795598561088E-01,  -8.0180968079097825E-01,  -3.4627302216364958E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,   8.0180968079097825E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,   8.0180968079097825E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,  -8.0180968079097825E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,   8.0180968079097825E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,  -8.0180968079097825E-01,   4.8702795598561088E-01,   2.5679604849328163E-03],
            [   3.4627302216364958E-01,  -8.0180968079097825E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,   8.0180968079097825E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [  -3.4627302216364958E-01,  -8.0180968079097825E-01,  -4.8702795598561088E-01,   2.5679604849328163E-03],
            [   5.1578195814503225E-01,   3.7540168702828353E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,   3.7540168702828353E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,  -3.7540168702828353E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,   3.7540168702828353E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,  -3.7540168702828353E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,  -3.7540168702828353E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,   3.7540168702828353E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,  -3.7540168702828353E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,   5.1578195814503225E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,   5.1578195814503225E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,  -5.1578195814503225E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,   5.1578195814503225E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,  -5.1578195814503225E-01,   7.7009255614399685E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,  -5.1578195814503225E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,   5.1578195814503225E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,  -5.1578195814503225E-01,  -7.7009255614399685E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,   5.1578195814503225E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,   5.1578195814503225E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,  -5.1578195814503225E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,   5.1578195814503225E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,  -5.1578195814503225E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,  -5.1578195814503225E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,   5.1578195814503225E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,  -5.1578195814503225E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,   3.7540168702828353E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,   3.7540168702828353E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,  -3.7540168702828353E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,   3.7540168702828353E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,  -3.7540168702828353E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   7.7009255614399685E-01,  -3.7540168702828353E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,   3.7540168702828353E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -7.7009255614399685E-01,  -3.7540168702828353E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,   7.7009255614399685E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,   7.7009255614399685E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,  -7.7009255614399685E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,   7.7009255614399685E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,  -7.7009255614399685E-01,   3.7540168702828353E-01,   2.5879815895243578E-03],
            [   5.1578195814503225E-01,  -7.7009255614399685E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,   7.7009255614399685E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [  -5.1578195814503225E-01,  -7.7009255614399685E-01,  -3.7540168702828353E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,   7.7009255614399685E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,   7.7009255614399685E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,  -7.7009255614399685E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,   7.7009255614399685E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,  -7.7009255614399685E-01,   5.1578195814503225E-01,   2.5879815895243578E-03],
            [   3.7540168702828353E-01,  -7.7009255614399685E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,   7.7009255614399685E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [  -3.7540168702828353E-01,  -7.7009255614399685E-01,  -5.1578195814503225E-01,   2.5879815895243578E-03],
            [   5.4346516664653932E-01,   4.0377337849936129E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,   4.0377337849936129E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,  -4.0377337849936129E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,   4.0377337849936129E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,  -4.0377337849936129E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,  -4.0377337849936129E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,   4.0377337849936129E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,  -4.0377337849936129E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,   5.4346516664653932E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,   5.4346516664653932E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,  -5.4346516664653932E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,   5.4346516664653932E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,  -5.4346516664653932E-01,   7.3594338875830712E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,  -5.4346516664653932E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,   5.4346516664653932E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,  -5.4346516664653932E-01,  -7.3594338875830712E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,   5.4346516664653932E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,   5.4346516664653932E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,  -5.4346516664653932E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,   5.4346516664653932E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,  -5.4346516664653932E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,  -5.4346516664653932E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,   5.4346516664653932E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,  -5.4346516664653932E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,   4.0377337849936129E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,   4.0377337849936129E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,  -4.0377337849936129E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,   4.0377337849936129E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,  -4.0377337849936129E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   7.3594338875830712E-01,  -4.0377337849936129E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,   4.0377337849936129E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -7.3594338875830712E-01,  -4.0377337849936129E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,   7.3594338875830712E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,   7.3594338875830712E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,  -7.3594338875830712E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,   7.3594338875830712E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,  -7.3594338875830712E-01,   4.0377337849936129E-01,   2.6021004124551347E-03],
            [   5.4346516664653932E-01,  -7.3594338875830712E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,   7.3594338875830712E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [  -5.4346516664653932E-01,  -7.3594338875830712E-01,  -4.0377337849936129E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,   7.3594338875830712E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,   7.3594338875830712E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,  -7.3594338875830712E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,   7.3594338875830712E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,  -7.3594338875830712E-01,   5.4346516664653932E-01,   2.6021004124551347E-03],
            [   4.0377337849936129E-01,  -7.3594338875830712E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,   7.3594338875830712E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [  -4.0377337849936129E-01,  -7.3594338875830712E-01,  -5.4346516664653932E-01,   2.6021004124551347E-03],
            [   5.6998238877646268E-01,   4.3125577841391233E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,   4.3125577841391233E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,  -4.3125577841391233E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,   4.3125577841391233E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,  -4.3125577841391233E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,  -4.3125577841391233E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,   4.3125577841391233E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,  -4.3125577841391233E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,   5.6998238877646268E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,   5.6998238877646268E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,  -5.6998238877646268E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,   5.6998238877646268E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,  -5.6998238877646268E-01,   6.9938439364149951E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,  -5.6998238877646268E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,   5.6998238877646268E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,  -5.6998238877646268E-01,  -6.9938439364149951E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,   5.6998238877646268E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,   5.6998238877646268E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,  -5.6998238877646268E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,   5.6998238877646268E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,  -5.6998238877646268E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,  -5.6998238877646268E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,   5.6998238877646268E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,  -5.6998238877646268E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,   4.3125577841391233E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,   4.3125577841391233E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,  -4.3125577841391233E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,   4.3125577841391233E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,  -4.3125577841391233E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   6.9938439364149951E-01,  -4.3125577841391233E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,   4.3125577841391233E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -6.9938439364149951E-01,  -4.3125577841391233E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,   6.9938439364149951E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,   6.9938439364149951E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,  -6.9938439364149951E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,   6.9938439364149951E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,  -6.9938439364149951E-01,   4.3125577841391233E-01,   2.6112356554261352E-03],
            [   5.6998238877646268E-01,  -6.9938439364149951E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,   6.9938439364149951E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [  -5.6998238877646268E-01,  -6.9938439364149951E-01,  -4.3125577841391233E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,   6.9938439364149951E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,   6.9938439364149951E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,  -6.9938439364149951E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,   6.9938439364149951E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,  -6.9938439364149951E-01,   5.6998238877646268E-01,   2.6112356554261352E-03],
            [   4.3125577841391233E-01,  -6.9938439364149951E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,   6.9938439364149951E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [  -4.3125577841391233E-01,  -6.9938439364149951E-01,  -5.6998238877646268E-01,   2.6112356554261352E-03],
            [   5.9524033509477414E-01,   4.5771753671221099E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,   4.5771753671221099E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,  -4.5771753671221099E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,   4.5771753671221099E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,  -4.5771753671221099E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,  -4.5771753671221099E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,   4.5771753671221099E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,  -4.5771753671221099E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,   5.9524033509477414E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,   5.9524033509477414E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,  -5.9524033509477414E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,   5.9524033509477414E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,  -5.9524033509477414E-01,   6.6044197327423604E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,  -5.9524033509477414E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,   5.9524033509477414E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,  -5.9524033509477414E-01,  -6.6044197327423604E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,   5.9524033509477414E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,   5.9524033509477414E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,  -5.9524033509477414E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,   5.9524033509477414E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,  -5.9524033509477414E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,  -5.9524033509477414E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,   5.9524033509477414E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,  -5.9524033509477414E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,   4.5771753671221099E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,   4.5771753671221099E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,  -4.5771753671221099E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,   4.5771753671221099E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,  -4.5771753671221099E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   6.6044197327423604E-01,  -4.5771753671221099E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,   4.5771753671221099E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -6.6044197327423604E-01,  -4.5771753671221099E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,   6.6044197327423604E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,   6.6044197327423604E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,  -6.6044197327423604E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,   6.6044197327423604E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,  -6.6044197327423604E-01,   4.5771753671221099E-01,   2.6162937165232574E-03],
            [   5.9524033509477414E-01,  -6.6044197327423604E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,   6.6044197327423604E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [  -5.9524033509477414E-01,  -6.6044197327423604E-01,  -4.5771753671221099E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,   6.6044197327423604E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,   6.6044197327423604E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,  -6.6044197327423604E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,   6.6044197327423604E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,  -6.6044197327423604E-01,   5.9524033509477414E-01,   2.6162937165232574E-03],
            [   4.5771753671221099E-01,  -6.6044197327423604E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,   6.6044197327423604E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [  -4.5771753671221099E-01,  -6.6044197327423604E-01,  -5.9524033509477414E-01,   2.6162937165232574E-03],
            [   2.0251525992103689E-01,   2.5202536177195568E-02,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,   2.5202536177195568E-02,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,  -2.5202536177195568E-02,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,   2.5202536177195568E-02,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,  -2.5202536177195568E-02,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,  -2.5202536177195568E-02,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,   2.5202536177195568E-02,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,  -2.5202536177195568E-02,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,   2.0251525992103689E-01,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,   2.0251525992103689E-01,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,  -2.0251525992103689E-01,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,   2.0251525992103689E-01,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,  -2.0251525992103689E-01,   9.7895474955145501E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,  -2.0251525992103689E-01,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,   2.0251525992103689E-01,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,  -2.0251525992103689E-01,  -9.7895474955145501E-01,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,   2.0251525992103689E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,   2.0251525992103689E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,  -2.0251525992103689E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,   2.0251525992103689E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,  -2.0251525992103689E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,  -2.0251525992103689E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,   2.0251525992103689E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,  -2.0251525992103689E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,   2.5202536177195568E-02,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,   2.5202536177195568E-02,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,  -2.5202536177195568E-02,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,   2.5202536177195568E-02,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,  -2.5202536177195568E-02,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   9.7895474955145501E-01,  -2.5202536177195568E-02,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,   2.5202536177195568E-02,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -9.7895474955145501E-01,  -2.5202536177195568E-02,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,   9.7895474955145501E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,   9.7895474955145501E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,  -9.7895474955145501E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,   9.7895474955145501E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,  -9.7895474955145501E-01,   2.5202536177195568E-02,   1.9117453480531278E-03],
            [   2.0251525992103689E-01,  -9.7895474955145501E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,   9.7895474955145501E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [  -2.0251525992103689E-01,  -9.7895474955145501E-01,  -2.5202536177195568E-02,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,   9.7895474955145501E-01,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,   9.7895474955145501E-01,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,  -9.7895474955145501E-01,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,   9.7895474955145501E-01,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,  -9.7895474955145501E-01,   2.0251525992103689E-01,   1.9117453480531278E-03],
            [   2.5202536177195568E-02,  -9.7895474955145501E-01,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,   9.7895474955145501E-01,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [  -2.5202536177195568E-02,  -9.7895474955145501E-01,  -2.0251525992103689E-01,   1.9117453480531278E-03],
            [   2.3810666532744251E-01,   5.2232545061190003E-02,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,   5.2232545061190003E-02,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,  -5.2232545061190003E-02,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,   5.2232545061190003E-02,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,  -5.2232545061190003E-02,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,  -5.2232545061190003E-02,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,   5.2232545061190003E-02,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,  -5.2232545061190003E-02,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,   2.3810666532744251E-01,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,   2.3810666532744251E-01,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,  -2.3810666532744251E-01,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,   2.3810666532744251E-01,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,  -2.3810666532744251E-01,   9.6983347908961981E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,  -2.3810666532744251E-01,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,   2.3810666532744251E-01,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,  -2.3810666532744251E-01,  -9.6983347908961981E-01,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,   2.3810666532744251E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,   2.3810666532744251E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,  -2.3810666532744251E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,   2.3810666532744251E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,  -2.3810666532744251E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,  -2.3810666532744251E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,   2.3810666532744251E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,  -2.3810666532744251E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,   5.2232545061190003E-02,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,   5.2232545061190003E-02,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,  -5.2232545061190003E-02,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,   5.2232545061190003E-02,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,  -5.2232545061190003E-02,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   9.6983347908961981E-01,  -5.2232545061190003E-02,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,   5.2232545061190003E-02,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -9.6983347908961981E-01,  -5.2232545061190003E-02,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,   9.6983347908961981E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,   9.6983347908961981E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,  -9.6983347908961981E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,   9.6983347908961981E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,  -9.6983347908961981E-01,   5.2232545061190003E-02,   2.0392363424725970E-03],
            [   2.3810666532744251E-01,  -9.6983347908961981E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,   9.6983347908961981E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [  -2.3810666532744251E-01,  -9.6983347908961981E-01,  -5.2232545061190003E-02,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,   9.6983347908961981E-01,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,   9.6983347908961981E-01,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,  -9.6983347908961981E-01,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,   9.6983347908961981E-01,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,  -9.6983347908961981E-01,   2.3810666532744251E-01,   2.0392363424725970E-03],
            [   5.2232545061190003E-02,  -9.6983347908961981E-01,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,   9.6983347908961981E-01,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [  -5.2232545061190003E-02,  -9.6983347908961981E-01,  -2.3810666532744251E-01,   2.0392363424725970E-03],
            [   2.7328233836516119E-01,   8.0606696885886203E-02,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,   8.0606696885886203E-02,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,  -8.0606696885886203E-02,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,   8.0606696885886203E-02,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,  -8.0606696885886203E-02,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,  -8.0606696885886203E-02,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,   8.0606696885886203E-02,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,  -8.0606696885886203E-02,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,   2.7328233836516119E-01,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,   2.7328233836516119E-01,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,  -2.7328233836516119E-01,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,   2.7328233836516119E-01,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,  -2.7328233836516119E-01,   9.5855063713651378E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,  -2.7328233836516119E-01,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,   2.7328233836516119E-01,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,  -2.7328233836516119E-01,  -9.5855063713651378E-01,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,   2.7328233836516119E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,   2.7328233836516119E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,  -2.7328233836516119E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,   2.7328233836516119E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,  -2.7328233836516119E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,  -2.7328233836516119E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,   2.7328233836516119E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,  -2.7328233836516119E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,   8.0606696885886203E-02,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,   8.0606696885886203E-02,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,  -8.0606696885886203E-02,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,   8.0606696885886203E-02,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,  -8.0606696885886203E-02,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   9.5855063713651378E-01,  -8.0606696885886203E-02,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,   8.0606696885886203E-02,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -9.5855063713651378E-01,  -8.0606696885886203E-02,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,   9.5855063713651378E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,   9.5855063713651378E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,  -9.5855063713651378E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,   9.5855063713651378E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,  -9.5855063713651378E-01,   8.0606696885886203E-02,   2.1494753555132439E-03],
            [   2.7328233836516119E-01,  -9.5855063713651378E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,   9.5855063713651378E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [  -2.7328233836516119E-01,  -9.5855063713651378E-01,  -8.0606696885886203E-02,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,   9.5855063713651378E-01,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,   9.5855063713651378E-01,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,  -9.5855063713651378E-01,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,   9.5855063713651378E-01,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,  -9.5855063713651378E-01,   2.7328233836516119E-01,   2.1494753555132439E-03],
            [   8.0606696885886203E-02,  -9.5855063713651378E-01,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,   9.5855063713651378E-01,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [  -8.0606696885886203E-02,  -9.5855063713651378E-01,  -2.7328233836516119E-01,   2.1494753555132439E-03],
            [   3.0801376926111179E-01,   1.0993357540812550E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,   1.0993357540812550E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,  -1.0993357540812550E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,   1.0993357540812550E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,  -1.0993357540812550E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,  -1.0993357540812550E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,   1.0993357540812550E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,  -1.0993357540812550E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,   3.0801376926111179E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,   3.0801376926111179E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,  -3.0801376926111179E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,   3.0801376926111179E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,  -3.0801376926111179E-01,   9.4500906183144540E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,  -3.0801376926111179E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,   3.0801376926111179E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,  -3.0801376926111179E-01,  -9.4500906183144540E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,   3.0801376926111179E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,   3.0801376926111179E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,  -3.0801376926111179E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,   3.0801376926111179E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,  -3.0801376926111179E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,  -3.0801376926111179E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,   3.0801376926111179E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,  -3.0801376926111179E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,   1.0993357540812550E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,   1.0993357540812550E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,  -1.0993357540812550E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,   1.0993357540812550E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,  -1.0993357540812550E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   9.4500906183144540E-01,  -1.0993357540812550E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,   1.0993357540812550E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -9.4500906183144540E-01,  -1.0993357540812550E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,   9.4500906183144540E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,   9.4500906183144540E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,  -9.4500906183144540E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,   9.4500906183144540E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,  -9.4500906183144540E-01,   1.0993357540812550E-01,   2.2442421388289011E-03],
            [   3.0801376926111179E-01,  -9.4500906183144540E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,   9.4500906183144540E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [  -3.0801376926111179E-01,  -9.4500906183144540E-01,  -1.0993357540812550E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,   9.4500906183144540E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,   9.4500906183144540E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,  -9.4500906183144540E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,   9.4500906183144540E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,  -9.4500906183144540E-01,   3.0801376926111179E-01,   2.2442421388289011E-03],
            [   1.0993357540812550E-01,  -9.4500906183144540E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,   9.4500906183144540E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [  -1.0993357540812550E-01,  -9.4500906183144540E-01,  -3.0801376926111179E-01,   2.2442421388289011E-03],
            [   3.4224056145876008E-01,   1.3991209559598569E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,   1.3991209559598569E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,  -1.3991209559598569E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,   1.3991209559598569E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,  -1.3991209559598569E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,  -1.3991209559598569E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,   1.3991209559598569E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,  -1.3991209559598569E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,   3.4224056145876008E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,   3.4224056145876008E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,  -3.4224056145876008E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,   3.4224056145876008E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,  -3.4224056145876008E-01,   9.2913723614885468E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,  -3.4224056145876008E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,   3.4224056145876008E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,  -3.4224056145876008E-01,  -9.2913723614885468E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,   3.4224056145876008E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,   3.4224056145876008E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,  -3.4224056145876008E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,   3.4224056145876008E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,  -3.4224056145876008E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,  -3.4224056145876008E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,   3.4224056145876008E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,  -3.4224056145876008E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,   1.3991209559598569E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,   1.3991209559598569E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,  -1.3991209559598569E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,   1.3991209559598569E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,  -1.3991209559598569E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   9.2913723614885468E-01,  -1.3991209559598569E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,   1.3991209559598569E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -9.2913723614885468E-01,  -1.3991209559598569E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,   9.2913723614885468E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,   9.2913723614885468E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,  -9.2913723614885468E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,   9.2913723614885468E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,  -9.2913723614885468E-01,   1.3991209559598569E-01,   2.3249360374807612E-03],
            [   3.4224056145876008E-01,  -9.2913723614885468E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,   9.2913723614885468E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [  -3.4224056145876008E-01,  -9.2913723614885468E-01,  -1.3991209559598569E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,   9.2913723614885468E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,   9.2913723614885468E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,  -9.2913723614885468E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,   9.2913723614885468E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,  -9.2913723614885468E-01,   3.4224056145876008E-01,   2.3249360374807612E-03],
            [   1.3991209559598569E-01,  -9.2913723614885468E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,   9.2913723614885468E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [  -1.3991209559598569E-01,  -9.2913723614885468E-01,  -3.4224056145876008E-01,   2.3249360374807612E-03],
            [   3.7588087738904202E-01,   1.7029778016517050E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,   1.7029778016517050E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,  -1.7029778016517050E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,   1.7029778016517050E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,  -1.7029778016517050E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,  -1.7029778016517050E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,   1.7029778016517050E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,  -1.7029778016517050E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,   3.7588087738904202E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,   3.7588087738904202E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,  -3.7588087738904202E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,   3.7588087738904202E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,  -3.7588087738904202E-01,   9.1088541106116039E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,  -3.7588087738904202E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,   3.7588087738904202E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,  -3.7588087738904202E-01,  -9.1088541106116039E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,   3.7588087738904202E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,   3.7588087738904202E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,  -3.7588087738904202E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,   3.7588087738904202E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,  -3.7588087738904202E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,  -3.7588087738904202E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,   3.7588087738904202E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,  -3.7588087738904202E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,   1.7029778016517050E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,   1.7029778016517050E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,  -1.7029778016517050E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,   1.7029778016517050E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,  -1.7029778016517050E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   9.1088541106116039E-01,  -1.7029778016517050E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,   1.7029778016517050E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -9.1088541106116039E-01,  -1.7029778016517050E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,   9.1088541106116039E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,   9.1088541106116039E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,  -9.1088541106116039E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,   9.1088541106116039E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,  -9.1088541106116039E-01,   1.7029778016517050E-01,   2.3929256194497265E-03],
            [   3.7588087738904202E-01,  -9.1088541106116039E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,   9.1088541106116039E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [  -3.7588087738904202E-01,  -9.1088541106116039E-01,  -1.7029778016517050E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,   9.1088541106116039E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,   9.1088541106116039E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,  -9.1088541106116039E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,   9.1088541106116039E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,  -9.1088541106116039E-01,   3.7588087738904202E-01,   2.3929256194497265E-03],
            [   1.7029778016517050E-01,  -9.1088541106116039E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,   9.1088541106116039E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [  -1.7029778016517050E-01,  -9.1088541106116039E-01,  -3.7588087738904202E-01,   2.3929256194497265E-03],
            [   4.0884583834389321E-01,   2.0087992566016799E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,   2.0087992566016799E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,  -2.0087992566016799E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,   2.0087992566016799E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,  -2.0087992566016799E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,  -2.0087992566016799E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,   2.0087992566016799E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,  -2.0087992566016799E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,   4.0884583834389321E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,   4.0884583834389321E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,  -4.0884583834389321E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,   4.0884583834389321E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,  -4.0884583834389321E-01,   8.9022038616044097E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,  -4.0884583834389321E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,   4.0884583834389321E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,  -4.0884583834389321E-01,  -8.9022038616044097E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,   4.0884583834389321E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,   4.0884583834389321E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,  -4.0884583834389321E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,   4.0884583834389321E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,  -4.0884583834389321E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,  -4.0884583834389321E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,   4.0884583834389321E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,  -4.0884583834389321E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,   2.0087992566016799E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,   2.0087992566016799E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,  -2.0087992566016799E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,   2.0087992566016799E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,  -2.0087992566016799E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   8.9022038616044097E-01,  -2.0087992566016799E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,   2.0087992566016799E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -8.9022038616044097E-01,  -2.0087992566016799E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,   8.9022038616044097E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,   8.9022038616044097E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,  -8.9022038616044097E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,   8.9022038616044097E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,  -8.9022038616044097E-01,   2.0087992566016799E-01,   2.4495123032358388E-03],
            [   4.0884583834389321E-01,  -8.9022038616044097E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,   8.9022038616044097E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [  -4.0884583834389321E-01,  -8.9022038616044097E-01,  -2.0087992566016799E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,   8.9022038616044097E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,   8.9022038616044097E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,  -8.9022038616044097E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,   8.9022038616044097E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,  -8.9022038616044097E-01,   4.0884583834389321E-01,   2.4495123032358388E-03],
            [   2.0087992566016799E-01,  -8.9022038616044097E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,   8.9022038616044097E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [  -2.0087992566016799E-01,  -8.9022038616044097E-01,  -4.0884583834389321E-01,   2.4495123032358388E-03],
            [   4.4104505508411518E-01,   2.3147030521808359E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,   2.3147030521808359E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,  -2.3147030521808359E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,   2.3147030521808359E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,  -2.3147030521808359E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,  -2.3147030521808359E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,   2.3147030521808359E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,  -2.3147030521808359E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,   4.4104505508411518E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,   4.4104505508411518E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,  -4.4104505508411518E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,   4.4104505508411518E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,  -4.4104505508411518E-01,   8.6712211203964640E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,  -4.4104505508411518E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,   4.4104505508411518E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,  -4.4104505508411518E-01,  -8.6712211203964640E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,   4.4104505508411518E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,   4.4104505508411518E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,  -4.4104505508411518E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,   4.4104505508411518E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,  -4.4104505508411518E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,  -4.4104505508411518E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,   4.4104505508411518E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,  -4.4104505508411518E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,   2.3147030521808359E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,   2.3147030521808359E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,  -2.3147030521808359E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,   2.3147030521808359E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,  -2.3147030521808359E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   8.6712211203964640E-01,  -2.3147030521808359E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,   2.3147030521808359E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -8.6712211203964640E-01,  -2.3147030521808359E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,   8.6712211203964640E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,   8.6712211203964640E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,  -8.6712211203964640E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,   8.6712211203964640E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,  -8.6712211203964640E-01,   2.3147030521808359E-01,   2.4958842079031872E-03],
            [   4.4104505508411518E-01,  -8.6712211203964640E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,   8.6712211203964640E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [  -4.4104505508411518E-01,  -8.6712211203964640E-01,  -2.3147030521808359E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,   8.6712211203964640E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,   8.6712211203964640E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,  -8.6712211203964640E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,   8.6712211203964640E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,  -8.6712211203964640E-01,   4.4104505508411518E-01,   2.4958842079031872E-03],
            [   2.3147030521808359E-01,  -8.6712211203964640E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,   8.6712211203964640E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [  -2.3147030521808359E-01,  -8.6712211203964640E-01,  -4.4104505508411518E-01,   2.4958842079031872E-03],
            [   4.7238794205613122E-01,   2.6189721113758918E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,   2.6189721113758918E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,  -2.6189721113758918E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,   2.6189721113758918E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,  -2.6189721113758918E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,  -2.6189721113758918E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,   2.6189721113758918E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,  -2.6189721113758918E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,   4.7238794205613122E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,   4.7238794205613122E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,  -4.7238794205613122E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,   4.7238794205613122E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,  -4.7238794205613122E-01,   8.4158153674990177E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,  -4.7238794205613122E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,   4.7238794205613122E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,  -4.7238794205613122E-01,  -8.4158153674990177E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,   4.7238794205613122E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,   4.7238794205613122E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,  -4.7238794205613122E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,   4.7238794205613122E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,  -4.7238794205613122E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,  -4.7238794205613122E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,   4.7238794205613122E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,  -4.7238794205613122E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,   2.6189721113758918E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,   2.6189721113758918E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,  -2.6189721113758918E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,   2.6189721113758918E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,  -2.6189721113758918E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   8.4158153674990177E-01,  -2.6189721113758918E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,   2.6189721113758918E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -8.4158153674990177E-01,  -2.6189721113758918E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,   8.4158153674990177E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,   8.4158153674990177E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,  -8.4158153674990177E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,   8.4158153674990177E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,  -8.4158153674990177E-01,   2.6189721113758918E-01,   2.5331171580105579E-03],
            [   4.7238794205613122E-01,  -8.4158153674990177E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,   8.4158153674990177E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [  -4.7238794205613122E-01,  -8.4158153674990177E-01,  -2.6189721113758918E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,   8.4158153674990177E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,   8.4158153674990177E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,  -8.4158153674990177E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,   8.4158153674990177E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,  -8.4158153674990177E-01,   4.7238794205613122E-01,   2.5331171580105579E-03],
            [   2.6189721113758918E-01,  -8.4158153674990177E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,   8.4158153674990177E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [  -2.6189721113758918E-01,  -8.4158153674990177E-01,  -4.7238794205613122E-01,   2.5331171580105579E-03],
            [   5.0278435618743433E-01,   2.9200131956002701E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,   2.9200131956002701E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,  -2.9200131956002701E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,   2.9200131956002701E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,  -2.9200131956002701E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,  -2.9200131956002701E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,   2.9200131956002701E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,  -2.9200131956002701E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,   5.0278435618743433E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,   5.0278435618743433E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,  -5.0278435618743433E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,   5.0278435618743433E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,  -5.0278435618743433E-01,   8.1359886955943483E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,  -5.0278435618743433E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,   5.0278435618743433E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,  -5.0278435618743433E-01,  -8.1359886955943483E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,   5.0278435618743433E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,   5.0278435618743433E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,  -5.0278435618743433E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,   5.0278435618743433E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,  -5.0278435618743433E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,  -5.0278435618743433E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,   5.0278435618743433E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,  -5.0278435618743433E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,   2.9200131956002701E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,   2.9200131956002701E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,  -2.9200131956002701E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,   2.9200131956002701E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,  -2.9200131956002701E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   8.1359886955943483E-01,  -2.9200131956002701E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,   2.9200131956002701E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -8.1359886955943483E-01,  -2.9200131956002701E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,   8.1359886955943483E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,   8.1359886955943483E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,  -8.1359886955943483E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,   8.1359886955943483E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,  -8.1359886955943483E-01,   2.9200131956002701E-01,   2.5622002799248864E-03],
            [   5.0278435618743433E-01,  -8.1359886955943483E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,   8.1359886955943483E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [  -5.0278435618743433E-01,  -8.1359886955943483E-01,  -2.9200131956002701E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,   8.1359886955943483E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,   8.1359886955943483E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,  -8.1359886955943483E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,   8.1359886955943483E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,  -8.1359886955943483E-01,   5.0278435618743433E-01,   2.5622002799248864E-03],
            [   2.9200131956002701E-01,  -8.1359886955943483E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,   8.1359886955943483E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [  -2.9200131956002701E-01,  -8.1359886955943483E-01,  -5.0278435618743433E-01,   2.5622002799248864E-03],
            [   5.3214536744524576E-01,   3.2163225551905511E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,   3.2163225551905511E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,  -3.2163225551905511E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,   3.2163225551905511E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,  -3.2163225551905511E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,  -3.2163225551905511E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,   3.2163225551905511E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,  -3.2163225551905511E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,   5.3214536744524576E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,   5.3214536744524576E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,  -5.3214536744524576E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,   5.3214536744524576E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,  -5.3214536744524576E-01,   7.8318197126612255E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,  -5.3214536744524576E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,   5.3214536744524576E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,  -5.3214536744524576E-01,  -7.8318197126612255E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,   5.3214536744524576E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,   5.3214536744524576E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,  -5.3214536744524576E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,   5.3214536744524576E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,  -5.3214536744524576E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,  -5.3214536744524576E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,   5.3214536744524576E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,  -5.3214536744524576E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,   3.2163225551905511E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,   3.2163225551905511E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,  -3.2163225551905511E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,   3.2163225551905511E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,  -3.2163225551905511E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   7.8318197126612255E-01,  -3.2163225551905511E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,   3.2163225551905511E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -7.8318197126612255E-01,  -3.2163225551905511E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,   7.8318197126612255E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,   7.8318197126612255E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,  -7.8318197126612255E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,   7.8318197126612255E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,  -7.8318197126612255E-01,   3.2163225551905511E-01,   2.5840655911653753E-03],
            [   5.3214536744524576E-01,  -7.8318197126612255E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,   7.8318197126612255E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [  -5.3214536744524576E-01,  -7.8318197126612255E-01,  -3.2163225551905511E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,   7.8318197126612255E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,   7.8318197126612255E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,  -7.8318197126612255E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,   7.8318197126612255E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,  -7.8318197126612255E-01,   5.3214536744524576E-01,   2.5840655911653753E-03],
            [   3.2163225551905511E-01,  -7.8318197126612255E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,   7.8318197126612255E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [  -3.2163225551905511E-01,  -7.8318197126612255E-01,  -5.3214536744524576E-01,   2.5840655911653753E-03],
            [   5.6038391138340304E-01,   3.5064566159341981E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,   3.5064566159341981E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,  -3.5064566159341981E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,   3.5064566159341981E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,  -3.5064566159341981E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,  -3.5064566159341981E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,   3.5064566159341981E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,  -3.5064566159341981E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,   5.6038391138340304E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,   5.6038391138340304E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,  -5.6038391138340304E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,   5.6038391138340304E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,  -5.6038391138340304E-01,   7.5034491526787284E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,  -5.6038391138340304E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,   5.6038391138340304E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,  -5.6038391138340304E-01,  -7.5034491526787284E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,   5.6038391138340304E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,   5.6038391138340304E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,  -5.6038391138340304E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,   5.6038391138340304E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,  -5.6038391138340304E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,  -5.6038391138340304E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,   5.6038391138340304E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,  -5.6038391138340304E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,   3.5064566159341981E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,   3.5064566159341981E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,  -3.5064566159341981E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,   3.5064566159341981E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,  -3.5064566159341981E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   7.5034491526787284E-01,  -3.5064566159341981E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,   3.5064566159341981E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -7.5034491526787284E-01,  -3.5064566159341981E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,   7.5034491526787284E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,   7.5034491526787284E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,  -7.5034491526787284E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,   7.5034491526787284E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,  -7.5034491526787284E-01,   3.5064566159341981E-01,   2.5996125778736607E-03],
            [   5.6038391138340304E-01,  -7.5034491526787284E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,   7.5034491526787284E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [  -5.6038391138340304E-01,  -7.5034491526787284E-01,  -3.5064566159341981E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,   7.5034491526787284E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,   7.5034491526787284E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,  -7.5034491526787284E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,   7.5034491526787284E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,  -7.5034491526787284E-01,   5.6038391138340304E-01,   2.5996125778736607E-03],
            [   3.5064566159341981E-01,  -7.5034491526787284E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,   7.5034491526787284E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [  -3.5064566159341981E-01,  -7.5034491526787284E-01,  -5.6038391138340304E-01,   2.5996125778736607E-03],
            [   5.8741507068751464E-01,   3.7890071813062670E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,   3.7890071813062670E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,  -3.7890071813062670E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,   3.7890071813062670E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,  -3.7890071813062670E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,  -3.7890071813062670E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,   3.7890071813062670E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,  -3.7890071813062670E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,   5.8741507068751464E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,   5.8741507068751464E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,  -5.8741507068751464E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,   5.8741507068751464E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,  -5.8741507068751464E-01,   7.1510683154985832E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,  -5.8741507068751464E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,   5.8741507068751464E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,  -5.8741507068751464E-01,  -7.1510683154985832E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,   5.8741507068751464E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,   5.8741507068751464E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,  -5.8741507068751464E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,   5.8741507068751464E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,  -5.8741507068751464E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,  -5.8741507068751464E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,   5.8741507068751464E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,  -5.8741507068751464E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,   3.7890071813062670E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,   3.7890071813062670E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,  -3.7890071813062670E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,   3.7890071813062670E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,  -3.7890071813062670E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   7.1510683154985832E-01,  -3.7890071813062670E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,   3.7890071813062670E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -7.1510683154985832E-01,  -3.7890071813062670E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,   7.1510683154985832E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,   7.1510683154985832E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,  -7.1510683154985832E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,   7.1510683154985832E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,  -7.1510683154985832E-01,   3.7890071813062670E-01,   2.6097259258946091E-03],
            [   5.8741507068751464E-01,  -7.1510683154985832E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,   7.1510683154985832E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [  -5.8741507068751464E-01,  -7.1510683154985832E-01,  -3.7890071813062670E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,   7.1510683154985832E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,   7.1510683154985832E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,  -7.1510683154985832E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,   7.1510683154985832E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,  -7.1510683154985832E-01,   5.8741507068751464E-01,   2.6097259258946091E-03],
            [   3.7890071813062670E-01,  -7.1510683154985832E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,   7.1510683154985832E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [  -3.7890071813062670E-01,  -7.1510683154985832E-01,  -5.8741507068751464E-01,   2.6097259258946091E-03],
            [   6.1315593816600378E-01,   4.0625801705727821E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,   4.0625801705727821E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,  -4.0625801705727821E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,   4.0625801705727821E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,  -4.0625801705727821E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,  -4.0625801705727821E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,   4.0625801705727821E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,  -4.0625801705727821E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,   6.1315593816600378E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,   6.1315593816600378E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,  -6.1315593816600378E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,   6.1315593816600378E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,  -6.1315593816600378E-01,   6.7749112102554976E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,  -6.1315593816600378E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,   6.1315593816600378E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,  -6.1315593816600378E-01,  -6.7749112102554976E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,   6.1315593816600378E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,   6.1315593816600378E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,  -6.1315593816600378E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,   6.1315593816600378E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,  -6.1315593816600378E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,  -6.1315593816600378E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,   6.1315593816600378E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,  -6.1315593816600378E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,   4.0625801705727821E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,   4.0625801705727821E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,  -4.0625801705727821E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,   4.0625801705727821E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,  -4.0625801705727821E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   6.7749112102554976E-01,  -4.0625801705727821E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,   4.0625801705727821E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -6.7749112102554976E-01,  -4.0625801705727821E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,   6.7749112102554976E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,   6.7749112102554976E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,  -6.7749112102554976E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,   6.7749112102554976E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,  -6.7749112102554976E-01,   4.0625801705727821E-01,   2.6152871551506124E-03],
            [   6.1315593816600378E-01,  -6.7749112102554976E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,   6.7749112102554976E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [  -6.1315593816600378E-01,  -6.7749112102554976E-01,  -4.0625801705727821E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,   6.7749112102554976E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,   6.7749112102554976E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,  -6.7749112102554976E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,   6.7749112102554976E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,  -6.7749112102554976E-01,   6.1315593816600378E-01,   2.6152871551506124E-03],
            [   4.0625801705727821E-01,  -6.7749112102554976E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,   6.7749112102554976E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [  -4.0625801705727821E-01,  -6.7749112102554976E-01,  -6.1315593816600378E-01,   2.6152871551506124E-03],
            [   2.7784970163945061E-01,   2.6962712768762259E-02,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,   2.6962712768762259E-02,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,  -2.6962712768762259E-02,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,   2.6962712768762259E-02,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,  -2.6962712768762259E-02,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,  -2.6962712768762259E-02,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,   2.6962712768762259E-02,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,  -2.6962712768762259E-02,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,   2.7784970163945061E-01,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,   2.7784970163945061E-01,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,  -2.7784970163945061E-01,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,   2.7784970163945061E-01,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,  -2.7784970163945061E-01,   9.6024609107198011E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,  -2.7784970163945061E-01,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,   2.7784970163945061E-01,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,  -2.7784970163945061E-01,  -9.6024609107198011E-01,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,   2.7784970163945061E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,   2.7784970163945061E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,  -2.7784970163945061E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,   2.7784970163945061E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,  -2.7784970163945061E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,  -2.7784970163945061E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,   2.7784970163945061E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,  -2.7784970163945061E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,   2.6962712768762259E-02,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,   2.6962712768762259E-02,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,  -2.6962712768762259E-02,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,   2.6962712768762259E-02,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,  -2.6962712768762259E-02,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   9.6024609107198011E-01,  -2.6962712768762259E-02,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,   2.6962712768762259E-02,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -9.6024609107198011E-01,  -2.6962712768762259E-02,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,   9.6024609107198011E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,   9.6024609107198011E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,  -9.6024609107198011E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,   9.6024609107198011E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,  -9.6024609107198011E-01,   2.6962712768762259E-02,   2.1367168159485582E-03],
            [   2.7784970163945061E-01,  -9.6024609107198011E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,   9.6024609107198011E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [  -2.7784970163945061E-01,  -9.6024609107198011E-01,  -2.6962712768762259E-02,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,   9.6024609107198011E-01,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,   9.6024609107198011E-01,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,  -9.6024609107198011E-01,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,   9.6024609107198011E-01,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,  -9.6024609107198011E-01,   2.7784970163945061E-01,   2.1367168159485582E-03],
            [   2.6962712768762259E-02,  -9.6024609107198011E-01,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,   9.6024609107198011E-01,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [  -2.6962712768762259E-02,  -9.6024609107198011E-01,  -2.7784970163945061E-01,   2.1367168159485582E-03],
            [   3.1437335622619123E-01,   5.5234693169604651E-02,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,   5.5234693169604651E-02,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,  -5.5234693169604651E-02,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,   5.5234693169604651E-02,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,  -5.5234693169604651E-02,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,  -5.5234693169604651E-02,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,   5.5234693169604651E-02,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,  -5.5234693169604651E-02,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,   3.1437335622619123E-01,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,   3.1437335622619123E-01,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,  -3.1437335622619123E-01,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,   3.1437335622619123E-01,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,  -3.1437335622619123E-01,   9.4769115304804863E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,  -3.1437335622619123E-01,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,   3.1437335622619123E-01,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,  -3.1437335622619123E-01,  -9.4769115304804863E-01,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,   3.1437335622619123E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,   3.1437335622619123E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,  -3.1437335622619123E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,   3.1437335622619123E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,  -3.1437335622619123E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,  -3.1437335622619123E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,   3.1437335622619123E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,  -3.1437335622619123E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,   5.5234693169604651E-02,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,   5.5234693169604651E-02,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,  -5.5234693169604651E-02,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,   5.5234693169604651E-02,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,  -5.5234693169604651E-02,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   9.4769115304804863E-01,  -5.5234693169604651E-02,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,   5.5234693169604651E-02,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -9.4769115304804863E-01,  -5.5234693169604651E-02,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,   9.4769115304804863E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,   9.4769115304804863E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,  -9.4769115304804863E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,   9.4769115304804863E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,  -9.4769115304804863E-01,   5.5234693169604651E-02,   2.2304136403298348E-03],
            [   3.1437335622619123E-01,  -9.4769115304804863E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,   9.4769115304804863E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [  -3.1437335622619123E-01,  -9.4769115304804863E-01,  -5.5234693169604651E-02,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,   9.4769115304804863E-01,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,   9.4769115304804863E-01,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,  -9.4769115304804863E-01,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,   9.4769115304804863E-01,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,  -9.4769115304804863E-01,   3.1437335622619123E-01,   2.2304136403298348E-03],
            [   5.5234693169604651E-02,  -9.4769115304804863E-01,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,   9.4769115304804863E-01,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [  -5.5234693169604651E-02,  -9.4769115304804863E-01,  -3.1437335622619123E-01,   2.2304136403298348E-03],
            [   3.5014858102618268E-01,   8.4451932016264636E-02,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,   8.4451932016264636E-02,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,  -8.4451932016264636E-02,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,   8.4451932016264636E-02,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,  -8.4451932016264636E-02,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,  -8.4451932016264636E-02,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,   8.4451932016264636E-02,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,  -8.4451932016264636E-02,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,   3.5014858102618268E-01,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,   3.5014858102618268E-01,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,  -3.5014858102618268E-01,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,   3.5014858102618268E-01,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,  -3.5014858102618268E-01,   9.3287932895100156E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,  -3.5014858102618268E-01,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,   3.5014858102618268E-01,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,  -3.5014858102618268E-01,  -9.3287932895100156E-01,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,   3.5014858102618268E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,   3.5014858102618268E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,  -3.5014858102618268E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,   3.5014858102618268E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,  -3.5014858102618268E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,  -3.5014858102618268E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,   3.5014858102618268E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,  -3.5014858102618268E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,   8.4451932016264636E-02,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,   8.4451932016264636E-02,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,  -8.4451932016264636E-02,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,   8.4451932016264636E-02,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,  -8.4451932016264636E-02,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   9.3287932895100156E-01,  -8.4451932016264636E-02,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,   8.4451932016264636E-02,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -9.3287932895100156E-01,  -8.4451932016264636E-02,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,   9.3287932895100156E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,   9.3287932895100156E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,  -9.3287932895100156E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,   9.3287932895100156E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,  -9.3287932895100156E-01,   8.4451932016264636E-02,   2.3117841535596302E-03],
            [   3.5014858102618268E-01,  -9.3287932895100156E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,   9.3287932895100156E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [  -3.5014858102618268E-01,  -9.3287932895100156E-01,  -8.4451932016264636E-02,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,   9.3287932895100156E-01,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,   9.3287932895100156E-01,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,  -9.3287932895100156E-01,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,   9.3287932895100156E-01,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,  -9.3287932895100156E-01,   3.5014858102618268E-01,   2.3117841535596302E-03],
            [   8.4451932016264636E-02,  -9.3287932895100156E-01,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,   9.3287932895100156E-01,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [  -8.4451932016264636E-02,  -9.3287932895100156E-01,  -3.5014858102618268E-01,   2.3117841535596302E-03],
            [   3.8514303223036528E-01,   1.1432631193360830E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,   1.1432631193360830E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,  -1.1432631193360830E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,   1.1432631193360830E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,  -1.1432631193360830E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,  -1.1432631193360830E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,   1.1432631193360830E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,  -1.1432631193360830E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,   3.8514303223036528E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,   3.8514303223036528E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,  -3.8514303223036528E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,   3.8514303223036528E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,  -3.8514303223036528E-01,   9.1574796703244676E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,  -3.8514303223036528E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,   3.8514303223036528E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,  -3.8514303223036528E-01,  -9.1574796703244676E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,   3.8514303223036528E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,   3.8514303223036528E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,  -3.8514303223036528E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,   3.8514303223036528E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,  -3.8514303223036528E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,  -3.8514303223036528E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,   3.8514303223036528E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,  -3.8514303223036528E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,   1.1432631193360830E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,   1.1432631193360830E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,  -1.1432631193360830E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,   1.1432631193360830E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,  -1.1432631193360830E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   9.1574796703244676E-01,  -1.1432631193360830E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,   1.1432631193360830E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -9.1574796703244676E-01,  -1.1432631193360830E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,   9.1574796703244676E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,   9.1574796703244676E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,  -9.1574796703244676E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,   9.1574796703244676E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,  -9.1574796703244676E-01,   1.1432631193360830E-01,   2.3813114769310204E-03],
            [   3.8514303223036528E-01,  -9.1574796703244676E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,   9.1574796703244676E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [  -3.8514303223036528E-01,  -9.1574796703244676E-01,  -1.1432631193360830E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,   9.1574796703244676E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,   9.1574796703244676E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,  -9.1574796703244676E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,   9.1574796703244676E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,  -9.1574796703244676E-01,   3.8514303223036528E-01,   2.3813114769310204E-03],
            [   1.1432631193360830E-01,  -9.1574796703244676E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,   9.1574796703244676E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [  -1.1432631193360830E-01,  -9.1574796703244676E-01,  -3.8514303223036528E-01,   2.3813114769310204E-03],
            [   4.1930139794704152E-01,   1.4461778983444751E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,   1.4461778983444751E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,  -1.4461778983444751E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,   1.4461778983444751E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,  -1.4461778983444751E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,  -1.4461778983444751E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,   1.4461778983444751E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,  -1.4461778983444751E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,   4.1930139794704152E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,   4.1930139794704152E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,  -4.1930139794704152E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,   4.1930139794704152E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,  -4.1930139794704152E-01,   8.9625444631703577E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,  -4.1930139794704152E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,   4.1930139794704152E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,  -4.1930139794704152E-01,  -8.9625444631703577E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,   4.1930139794704152E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,   4.1930139794704152E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,  -4.1930139794704152E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,   4.1930139794704152E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,  -4.1930139794704152E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,  -4.1930139794704152E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,   4.1930139794704152E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,  -4.1930139794704152E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,   1.4461778983444751E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,   1.4461778983444751E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,  -1.4461778983444751E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,   1.4461778983444751E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,  -1.4461778983444751E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   8.9625444631703577E-01,  -1.4461778983444751E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,   1.4461778983444751E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -8.9625444631703577E-01,  -1.4461778983444751E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,   8.9625444631703577E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,   8.9625444631703577E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,  -8.9625444631703577E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,   8.9625444631703577E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,  -8.9625444631703577E-01,   1.4461778983444751E-01,   2.4398221905449127E-03],
            [   4.1930139794704152E-01,  -8.9625444631703577E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,   8.9625444631703577E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [  -4.1930139794704152E-01,  -8.9625444631703577E-01,  -1.4461778983444751E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,   8.9625444631703577E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,   8.9625444631703577E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,  -8.9625444631703577E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,   8.9625444631703577E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,  -8.9625444631703577E-01,   4.1930139794704152E-01,   2.4398221905449127E-03],
            [   1.4461778983444751E-01,  -8.9625444631703577E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,   8.9625444631703577E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [  -1.4461778983444751E-01,  -8.9625444631703577E-01,  -4.1930139794704152E-01,   2.4398221905449127E-03],
            [   4.5255859604585669E-01,   1.7511654384380909E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,   1.7511654384380909E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,  -1.7511654384380909E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,   1.7511654384380909E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,  -1.7511654384380909E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,  -1.7511654384380909E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,   1.7511654384380909E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,  -1.7511654384380909E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,   4.5255859604585669E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,   4.5255859604585669E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,  -4.5255859604585669E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,   4.5255859604585669E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,  -4.5255859604585669E-01,   8.7437115301066648E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,  -4.5255859604585669E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,   4.5255859604585669E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,  -4.5255859604585669E-01,  -8.7437115301066648E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,   4.5255859604585669E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,   4.5255859604585669E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,  -4.5255859604585669E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,   4.5255859604585669E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,  -4.5255859604585669E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,  -4.5255859604585669E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,   4.5255859604585669E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,  -4.5255859604585669E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,   1.7511654384380909E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,   1.7511654384380909E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,  -1.7511654384380909E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,   1.7511654384380909E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,  -1.7511654384380909E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   8.7437115301066648E-01,  -1.7511654384380909E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,   1.7511654384380909E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -8.7437115301066648E-01,  -1.7511654384380909E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,   8.7437115301066648E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,   8.7437115301066648E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,  -8.7437115301066648E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,   8.7437115301066648E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,  -8.7437115301066648E-01,   1.7511654384380909E-01,   2.4882399362350887E-03],
            [   4.5255859604585669E-01,  -8.7437115301066648E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,   8.7437115301066648E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [  -4.5255859604585669E-01,  -8.7437115301066648E-01,  -1.7511654384380909E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,   8.7437115301066648E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,   8.7437115301066648E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,  -8.7437115301066648E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,   8.7437115301066648E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,  -8.7437115301066648E-01,   4.5255859604585669E-01,   2.4882399362350887E-03],
            [   1.7511654384380909E-01,  -8.7437115301066648E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,   8.7437115301066648E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [  -1.7511654384380909E-01,  -8.7437115301066648E-01,  -4.5255859604585669E-01,   2.4882399362350887E-03],
            [   4.8484477796229469E-01,   2.0563383067456600E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,   2.0563383067456600E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,  -2.0563383067456600E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,   2.0563383067456600E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,  -2.0563383067456600E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,  -2.0563383067456600E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,   2.0563383067456600E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,  -2.0563383067456600E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,   4.8484477796229469E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,   4.8484477796229469E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,  -4.8484477796229469E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,   4.8484477796229469E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,  -4.8484477796229469E-01,   8.5008250715139233E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,  -4.8484477796229469E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,   4.8484477796229469E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,  -4.8484477796229469E-01,  -8.5008250715139233E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,   4.8484477796229469E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,   4.8484477796229469E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,  -4.8484477796229469E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,   4.8484477796229469E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,  -4.8484477796229469E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,  -4.8484477796229469E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,   4.8484477796229469E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,  -4.8484477796229469E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,   2.0563383067456600E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,   2.0563383067456600E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,  -2.0563383067456600E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,   2.0563383067456600E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,  -2.0563383067456600E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   8.5008250715139233E-01,  -2.0563383067456600E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,   2.0563383067456600E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -8.5008250715139233E-01,  -2.0563383067456600E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,   8.5008250715139233E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,   8.5008250715139233E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,  -8.5008250715139233E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,   8.5008250715139233E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,  -8.5008250715139233E-01,   2.0563383067456600E-01,   2.5274694529382915E-03],
            [   4.8484477796229469E-01,  -8.5008250715139233E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,   8.5008250715139233E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [  -4.8484477796229469E-01,  -8.5008250715139233E-01,  -2.0563383067456600E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,   8.5008250715139233E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,   8.5008250715139233E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,  -8.5008250715139233E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,   8.5008250715139233E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,  -8.5008250715139233E-01,   4.8484477796229469E-01,   2.5274694529382915E-03],
            [   2.0563383067456600E-01,  -8.5008250715139233E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,   8.5008250715139233E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [  -2.0563383067456600E-01,  -8.5008250715139233E-01,  -4.8484477796229469E-01,   2.5274694529382915E-03],
            [   5.1608712082768937E-01,   2.3599654872292261E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,   2.3599654872292261E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,  -2.3599654872292261E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,   2.3599654872292261E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,  -2.3599654872292261E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,  -2.3599654872292261E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,   2.3599654872292261E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,  -2.3599654872292261E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,   5.1608712082768937E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,   5.1608712082768937E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,  -5.1608712082768937E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,   5.1608712082768937E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,  -5.1608712082768937E-01,   8.2338308988383724E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,  -5.1608712082768937E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,   5.1608712082768937E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,  -5.1608712082768937E-01,  -8.2338308988383724E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,   5.1608712082768937E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,   5.1608712082768937E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,  -5.1608712082768937E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,   5.1608712082768937E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,  -5.1608712082768937E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,  -5.1608712082768937E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,   5.1608712082768937E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,  -5.1608712082768937E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,   2.3599654872292261E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,   2.3599654872292261E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,  -2.3599654872292261E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,   2.3599654872292261E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,  -2.3599654872292261E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   8.2338308988383724E-01,  -2.3599654872292261E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,   2.3599654872292261E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -8.2338308988383724E-01,  -2.3599654872292261E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,   8.2338308988383724E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,   8.2338308988383724E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,  -8.2338308988383724E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,   8.2338308988383724E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,  -8.2338308988383724E-01,   2.3599654872292261E-01,   2.5583728879740334E-03],
            [   5.1608712082768937E-01,  -8.2338308988383724E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,   8.2338308988383724E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [  -5.1608712082768937E-01,  -8.2338308988383724E-01,  -2.3599654872292261E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,   8.2338308988383724E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,   8.2338308988383724E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,  -8.2338308988383724E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,   8.2338308988383724E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,  -8.2338308988383724E-01,   5.1608712082768937E-01,   2.5583728879740334E-03],
            [   2.3599654872292261E-01,  -8.2338308988383724E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,   8.2338308988383724E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [  -2.3599654872292261E-01,  -8.2338308988383724E-01,  -5.1608712082768937E-01,   2.5583728879740334E-03],
            [   5.4621121856969257E-01,   2.6604302231391458E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,   2.6604302231391458E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,  -2.6604302231391458E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,   2.6604302231391458E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,  -2.6604302231391458E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,  -2.6604302231391458E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,   2.6604302231391458E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,  -2.6604302231391458E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,   5.4621121856969257E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,   5.4621121856969257E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,  -5.4621121856969257E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,   5.4621121856969257E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,  -5.4621121856969257E-01,   7.9427603198553687E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,  -5.4621121856969257E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,   5.4621121856969257E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,  -5.4621121856969257E-01,  -7.9427603198553687E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,   5.4621121856969257E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,   5.4621121856969257E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,  -5.4621121856969257E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,   5.4621121856969257E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,  -5.4621121856969257E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,  -5.4621121856969257E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,   5.4621121856969257E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,  -5.4621121856969257E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,   2.6604302231391458E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,   2.6604302231391458E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,  -2.6604302231391458E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,   2.6604302231391458E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,  -2.6604302231391458E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   7.9427603198553687E-01,  -2.6604302231391458E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,   2.6604302231391458E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -7.9427603198553687E-01,  -2.6604302231391458E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,   7.9427603198553687E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,   7.9427603198553687E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,  -7.9427603198553687E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,   7.9427603198553687E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,  -7.9427603198553687E-01,   2.6604302231391458E-01,   2.5817813577626346E-03],
            [   5.4621121856969257E-01,  -7.9427603198553687E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,   7.9427603198553687E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [  -5.4621121856969257E-01,  -7.9427603198553687E-01,  -2.6604302231391458E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,   7.9427603198553687E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,   7.9427603198553687E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,  -7.9427603198553687E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,   7.9427603198553687E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,  -7.9427603198553687E-01,   5.4621121856969257E-01,   2.5817813577626346E-03],
            [   2.6604302231391458E-01,  -7.9427603198553687E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,   7.9427603198553687E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [  -2.6604302231391458E-01,  -7.9427603198553687E-01,  -5.4621121856969257E-01,   2.5817813577626346E-03],
            [   5.7514250681017565E-01,   2.9561936644980319E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,   2.9561936644980319E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,  -2.9561936644980319E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,   2.9561936644980319E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,  -2.9561936644980319E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,  -2.9561936644980319E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,   2.9561936644980319E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,  -2.9561936644980319E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,   5.7514250681017565E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,   5.7514250681017565E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,  -5.7514250681017565E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,   5.7514250681017565E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,  -5.7514250681017565E-01,   7.6277145137971969E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,  -5.7514250681017565E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,   5.7514250681017565E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,  -5.7514250681017565E-01,  -7.6277145137971969E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,   5.7514250681017565E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,   5.7514250681017565E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,  -5.7514250681017565E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,   5.7514250681017565E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,  -5.7514250681017565E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,  -5.7514250681017565E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,   5.7514250681017565E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,  -5.7514250681017565E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,   2.9561936644980319E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,   2.9561936644980319E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,  -2.9561936644980319E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,   2.9561936644980319E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,  -2.9561936644980319E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   7.6277145137971969E-01,  -2.9561936644980319E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,   2.9561936644980319E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -7.6277145137971969E-01,  -2.9561936644980319E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,   7.6277145137971969E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,   7.6277145137971969E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,  -7.6277145137971969E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,   7.6277145137971969E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,  -7.6277145137971969E-01,   2.9561936644980319E-01,   2.5985131129715260E-03],
            [   5.7514250681017565E-01,  -7.6277145137971969E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,   7.6277145137971969E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [  -5.7514250681017565E-01,  -7.6277145137971969E-01,  -2.9561936644980319E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,   7.6277145137971969E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,   7.6277145137971969E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,  -7.6277145137971969E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,   7.6277145137971969E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,  -7.6277145137971969E-01,   5.7514250681017565E-01,   2.5985131129715260E-03],
            [   2.9561936644980319E-01,  -7.6277145137971969E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,   7.6277145137971969E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [  -2.9561936644980319E-01,  -7.6277145137971969E-01,  -5.7514250681017565E-01,   2.5985131129715260E-03],
            [   6.0280738728535965E-01,   3.2457639053127790E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,   3.2457639053127790E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,  -3.2457639053127790E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,   3.2457639053127790E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,  -3.2457639053127790E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,  -3.2457639053127790E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,   3.2457639053127790E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,  -3.2457639053127790E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,   6.0280738728535965E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,   6.0280738728535965E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,  -6.0280738728535965E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,   6.0280738728535965E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,  -6.0280738728535965E-01,   7.2888505303915085E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,  -6.0280738728535965E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,   6.0280738728535965E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,  -6.0280738728535965E-01,  -7.2888505303915085E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,   6.0280738728535965E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,   6.0280738728535965E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,  -6.0280738728535965E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,   6.0280738728535965E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,  -6.0280738728535965E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,  -6.0280738728535965E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,   6.0280738728535965E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,  -6.0280738728535965E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,   3.2457639053127790E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,   3.2457639053127790E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,  -3.2457639053127790E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,   3.2457639053127790E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,  -3.2457639053127790E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   7.2888505303915085E-01,  -3.2457639053127790E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,   3.2457639053127790E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -7.2888505303915085E-01,  -3.2457639053127790E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,   7.2888505303915085E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,   7.2888505303915085E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,  -7.2888505303915085E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,   7.2888505303915085E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,  -7.2888505303915085E-01,   3.2457639053127790E-01,   2.6093884109976060E-03],
            [   6.0280738728535965E-01,  -7.2888505303915085E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,   7.2888505303915085E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [  -6.0280738728535965E-01,  -7.2888505303915085E-01,  -3.2457639053127790E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,   7.2888505303915085E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,   7.2888505303915085E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,  -7.2888505303915085E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,   7.2888505303915085E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,  -7.2888505303915085E-01,   6.0280738728535965E-01,   2.6093884109976060E-03],
            [   3.2457639053127790E-01,  -7.2888505303915085E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,   7.2888505303915085E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [  -3.2457639053127790E-01,  -7.2888505303915085E-01,  -6.0280738728535965E-01,   2.6093884109976060E-03],
            [   6.2913382752784086E-01,   3.5276700262069721E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,   3.5276700262069721E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,  -3.5276700262069721E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,   3.5276700262069721E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,  -3.5276700262069721E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,  -3.5276700262069721E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,   3.5276700262069721E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,  -3.5276700262069721E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,   6.2913382752784086E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,   6.2913382752784086E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,  -6.2913382752784086E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,   6.2913382752784086E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,  -6.2913382752784086E-01,   6.9263703981391145E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,  -6.2913382752784086E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,   6.2913382752784086E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,  -6.2913382752784086E-01,  -6.9263703981391145E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,   6.2913382752784086E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,   6.2913382752784086E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,  -6.2913382752784086E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,   6.2913382752784086E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,  -6.2913382752784086E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,  -6.2913382752784086E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,   6.2913382752784086E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,  -6.2913382752784086E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,   3.5276700262069721E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,   3.5276700262069721E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,  -3.5276700262069721E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,   3.5276700262069721E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,  -3.5276700262069721E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   6.9263703981391145E-01,  -3.5276700262069721E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,   3.5276700262069721E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -6.9263703981391145E-01,  -3.5276700262069721E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,   6.9263703981391145E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,   6.9263703981391145E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,  -6.9263703981391145E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,   6.9263703981391145E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,  -6.9263703981391145E-01,   3.5276700262069721E-01,   2.6152394629975315E-03],
            [   6.2913382752784086E-01,  -6.9263703981391145E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,   6.9263703981391145E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [  -6.2913382752784086E-01,  -6.9263703981391145E-01,  -3.5276700262069721E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,   6.9263703981391145E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,   6.9263703981391145E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,  -6.9263703981391145E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,   6.9263703981391145E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,  -6.9263703981391145E-01,   6.2913382752784086E-01,   2.6152394629975315E-03],
            [   3.5276700262069721E-01,  -6.9263703981391145E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,   6.9263703981391145E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [  -3.5276700262069721E-01,  -6.9263703981391145E-01,  -6.2913382752784086E-01,   2.6152394629975315E-03],
            [   3.5417975284393910E-01,   2.8238534794355501E-02,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,   2.8238534794355501E-02,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,  -2.8238534794355501E-02,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,   2.8238534794355501E-02,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,  -2.8238534794355501E-02,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,  -2.8238534794355501E-02,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,   2.8238534794355501E-02,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,  -2.8238534794355501E-02,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,   3.5417975284393910E-01,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,   3.5417975284393910E-01,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,  -3.5417975284393910E-01,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,   3.5417975284393910E-01,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,  -3.5417975284393910E-01,   9.3475092288163819E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,  -3.5417975284393910E-01,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,   3.5417975284393910E-01,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,  -3.5417975284393910E-01,  -9.3475092288163819E-01,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,   3.5417975284393910E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,   3.5417975284393910E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,  -3.5417975284393910E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,   3.5417975284393910E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,  -3.5417975284393910E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,  -3.5417975284393910E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,   3.5417975284393910E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,  -3.5417975284393910E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,   2.8238534794355501E-02,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,   2.8238534794355501E-02,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,  -2.8238534794355501E-02,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,   2.8238534794355501E-02,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,  -2.8238534794355501E-02,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   9.3475092288163819E-01,  -2.8238534794355501E-02,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,   2.8238534794355501E-02,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -9.3475092288163819E-01,  -2.8238534794355501E-02,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,   9.3475092288163819E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,   9.3475092288163819E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,  -9.3475092288163819E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,   9.3475092288163819E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,  -9.3475092288163819E-01,   2.8238534794355501E-02,   2.3051536821072000E-03],
            [   3.5417975284393910E-01,  -9.3475092288163819E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,   9.3475092288163819E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [  -3.5417975284393910E-01,  -9.3475092288163819E-01,  -2.8238534794355501E-02,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,   9.3475092288163819E-01,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,   9.3475092288163819E-01,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,  -9.3475092288163819E-01,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,   9.3475092288163819E-01,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,  -9.3475092288163819E-01,   3.5417975284393910E-01,   2.3051536821072000E-03],
            [   2.8238534794355501E-02,  -9.3475092288163819E-01,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,   9.3475092288163819E-01,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [  -2.8238534794355501E-02,  -9.3475092288163819E-01,  -3.5417975284393910E-01,   2.3051536821072000E-03],
            [   3.9082349720746568E-01,   5.7412963747131063E-02,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,   5.7412963747131063E-02,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,  -5.7412963747131063E-02,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,   5.7412963747131063E-02,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,  -5.7412963747131063E-02,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,  -5.7412963747131063E-02,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,   5.7412963747131063E-02,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,  -5.7412963747131063E-02,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,   3.9082349720746568E-01,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,   3.9082349720746568E-01,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,  -3.9082349720746568E-01,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,   3.9082349720746568E-01,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,  -3.9082349720746568E-01,   9.1867336176918546E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,  -3.9082349720746568E-01,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,   3.9082349720746568E-01,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,  -3.9082349720746568E-01,  -9.1867336176918546E-01,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,   3.9082349720746568E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,   3.9082349720746568E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,  -3.9082349720746568E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,   3.9082349720746568E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,  -3.9082349720746568E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,  -3.9082349720746568E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,   3.9082349720746568E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,  -3.9082349720746568E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,   5.7412963747131063E-02,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,   5.7412963747131063E-02,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,  -5.7412963747131063E-02,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,   5.7412963747131063E-02,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,  -5.7412963747131063E-02,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   9.1867336176918546E-01,  -5.7412963747131063E-02,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,   5.7412963747131063E-02,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -9.1867336176918546E-01,  -5.7412963747131063E-02,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,   9.1867336176918546E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,   9.1867336176918546E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,  -9.1867336176918546E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,   9.1867336176918546E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,  -9.1867336176918546E-01,   5.7412963747131063E-02,   2.3744667367153840E-03],
            [   3.9082349720746568E-01,  -9.1867336176918546E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,   9.1867336176918546E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [  -3.9082349720746568E-01,  -9.1867336176918546E-01,  -5.7412963747131063E-02,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,   9.1867336176918546E-01,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,   9.1867336176918546E-01,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,  -9.1867336176918546E-01,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,   9.1867336176918546E-01,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,  -9.1867336176918546E-01,   3.9082349720746568E-01,   2.3744667367153840E-03],
            [   5.7412963747131063E-02,  -9.1867336176918546E-01,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,   9.1867336176918546E-01,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [  -5.7412963747131063E-02,  -9.1867336176918546E-01,  -3.9082349720746568E-01,   2.3744667367153840E-03],
            [   4.2644084501075902E-01,   8.7246466336501988E-02,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,   8.7246466336501988E-02,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,  -8.7246466336501988E-02,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,   8.7246466336501988E-02,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,  -8.7246466336501988E-02,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,  -8.7246466336501988E-02,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,   8.7246466336501988E-02,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,  -8.7246466336501988E-02,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,   4.2644084501075902E-01,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,   4.2644084501075902E-01,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,  -4.2644084501075902E-01,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,   4.2644084501075902E-01,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,  -4.2644084501075902E-01,   9.0029787282782325E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,  -4.2644084501075902E-01,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,   4.2644084501075902E-01,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,  -4.2644084501075902E-01,  -9.0029787282782325E-01,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,   4.2644084501075902E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,   4.2644084501075902E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,  -4.2644084501075902E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,   4.2644084501075902E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,  -4.2644084501075902E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,  -4.2644084501075902E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,   4.2644084501075902E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,  -4.2644084501075902E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,   8.7246466336501988E-02,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,   8.7246466336501988E-02,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,  -8.7246466336501988E-02,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,   8.7246466336501988E-02,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,  -8.7246466336501988E-02,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   9.0029787282782325E-01,  -8.7246466336501988E-02,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,   8.7246466336501988E-02,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -9.0029787282782325E-01,  -8.7246466336501988E-02,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,   9.0029787282782325E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,   9.0029787282782325E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,  -9.0029787282782325E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,   9.0029787282782325E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,  -9.0029787282782325E-01,   8.7246466336501988E-02,   2.4337001238838637E-03],
            [   4.2644084501075902E-01,  -9.0029787282782325E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,   9.0029787282782325E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [  -4.2644084501075902E-01,  -9.0029787282782325E-01,  -8.7246466336501988E-02,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,   9.0029787282782325E-01,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,   9.0029787282782325E-01,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,  -9.0029787282782325E-01,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,   9.0029787282782325E-01,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,  -9.0029787282782325E-01,   4.2644084501075902E-01,   2.4337001238838637E-03],
            [   8.7246466336501988E-02,  -9.0029787282782325E-01,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,   9.0029787282782325E-01,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [  -8.7246466336501988E-02,  -9.0029787282782325E-01,  -4.2644084501075902E-01,   2.4337001238838637E-03],
            [   4.6099496665532858E-01,   1.1750344229156159E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,   1.1750344229156159E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,  -1.1750344229156159E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,   1.1750344229156159E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,  -1.1750344229156159E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,  -1.1750344229156159E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,   1.1750344229156159E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,  -1.1750344229156159E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,   4.6099496665532858E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,   4.6099496665532858E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,  -4.6099496665532858E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,   4.6099496665532858E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,  -4.6099496665532858E-01,   8.7958887087552784E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,  -4.6099496665532858E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,   4.6099496665532858E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,  -4.6099496665532858E-01,  -8.7958887087552784E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,   4.6099496665532858E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,   4.6099496665532858E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,  -4.6099496665532858E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,   4.6099496665532858E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,  -4.6099496665532858E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,  -4.6099496665532858E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,   4.6099496665532858E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,  -4.6099496665532858E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,   1.1750344229156159E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,   1.1750344229156159E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,  -1.1750344229156159E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,   1.1750344229156159E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,  -1.1750344229156159E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   8.7958887087552784E-01,  -1.1750344229156159E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,   1.1750344229156159E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -8.7958887087552784E-01,  -1.1750344229156159E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,   8.7958887087552784E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,   8.7958887087552784E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,  -8.7958887087552784E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,   8.7958887087552784E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,  -8.7958887087552784E-01,   1.1750344229156159E-01,   2.4833366236391018E-03],
            [   4.6099496665532858E-01,  -8.7958887087552784E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,   8.7958887087552784E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [  -4.6099496665532858E-01,  -8.7958887087552784E-01,  -1.1750344229156159E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,   8.7958887087552784E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,   8.7958887087552784E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,  -8.7958887087552784E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,   8.7958887087552784E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,  -8.7958887087552784E-01,   4.6099496665532858E-01,   2.4833366236391018E-03],
            [   1.1750344229156159E-01,  -8.7958887087552784E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,   8.7958887087552784E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [  -1.1750344229156159E-01,  -8.7958887087552784E-01,  -4.6099496665532858E-01,   2.4833366236391018E-03],
            [   4.9443894965360058E-01,   1.4797556526284281E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,   1.4797556526284281E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,  -1.4797556526284281E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,   1.4797556526284281E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,  -1.4797556526284281E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,  -1.4797556526284281E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,   1.4797556526284281E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,  -1.4797556526284281E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,   4.9443894965360058E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,   4.9443894965360058E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,  -4.9443894965360058E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,   4.9443894965360058E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,  -4.9443894965360058E-01,   8.5652399683288871E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,  -4.9443894965360058E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,   4.9443894965360058E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,  -4.9443894965360058E-01,  -8.5652399683288871E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,   4.9443894965360058E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,   4.9443894965360058E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,  -4.9443894965360058E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,   4.9443894965360058E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,  -4.9443894965360058E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,  -4.9443894965360058E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,   4.9443894965360058E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,  -4.9443894965360058E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,   1.4797556526284281E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,   1.4797556526284281E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,  -1.4797556526284281E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,   1.4797556526284281E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,  -1.4797556526284281E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   8.5652399683288871E-01,  -1.4797556526284281E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,   1.4797556526284281E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -8.5652399683288871E-01,  -1.4797556526284281E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,   8.5652399683288871E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,   8.5652399683288871E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,  -8.5652399683288871E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,   8.5652399683288871E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,  -8.5652399683288871E-01,   1.4797556526284281E-01,   2.5240007825597520E-03],
            [   4.9443894965360058E-01,  -8.5652399683288871E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,   8.5652399683288871E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [  -4.9443894965360058E-01,  -8.5652399683288871E-01,  -1.4797556526284281E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,   8.5652399683288871E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,   8.5652399683288871E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,  -8.5652399683288871E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,   8.5652399683288871E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,  -8.5652399683288871E-01,   4.9443894965360058E-01,   2.5240007825597520E-03],
            [   1.4797556526284281E-01,  -8.5652399683288871E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,   8.5652399683288871E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [  -1.4797556526284281E-01,  -8.5652399683288871E-01,  -4.9443894965360058E-01,   2.5240007825597520E-03],
            [   5.2671948843460858E-01,   1.7847406594843521E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,   1.7847406594843521E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,  -1.7847406594843521E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,   1.7847406594843521E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,  -1.7847406594843521E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,  -1.7847406594843521E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,   1.7847406594843521E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,  -1.7847406594843521E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,   5.2671948843460858E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,   5.2671948843460858E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,  -5.2671948843460858E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,   5.2671948843460858E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,  -5.2671948843460858E-01,   8.3109180496923307E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,  -5.2671948843460858E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,   5.2671948843460858E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,  -5.2671948843460858E-01,  -8.3109180496923307E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,   5.2671948843460858E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,   5.2671948843460858E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,  -5.2671948843460858E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,   5.2671948843460858E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,  -5.2671948843460858E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,  -5.2671948843460858E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,   5.2671948843460858E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,  -5.2671948843460858E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,   1.7847406594843521E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,   1.7847406594843521E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,  -1.7847406594843521E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,   1.7847406594843521E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,  -1.7847406594843521E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   8.3109180496923307E-01,  -1.7847406594843521E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,   1.7847406594843521E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -8.3109180496923307E-01,  -1.7847406594843521E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,   8.3109180496923307E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,   8.3109180496923307E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,  -8.3109180496923307E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,   8.3109180496923307E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,  -8.3109180496923307E-01,   1.7847406594843521E-01,   2.5563520833125574E-03],
            [   5.2671948843460858E-01,  -8.3109180496923307E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,   8.3109180496923307E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [  -5.2671948843460858E-01,  -8.3109180496923307E-01,  -1.7847406594843521E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,   8.3109180496923307E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,   8.3109180496923307E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,  -8.3109180496923307E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,   8.3109180496923307E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,  -8.3109180496923307E-01,   5.2671948843460858E-01,   2.5563520833125574E-03],
            [   1.7847406594843521E-01,  -8.3109180496923307E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,   8.3109180496923307E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [  -1.7847406594843521E-01,  -8.3109180496923307E-01,  -5.2671948843460858E-01,   2.5563520833125574E-03],
            [   5.5777878102209899E-01,   2.0882457004312441E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,   2.0882457004312441E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,  -2.0882457004312441E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,   2.0882457004312441E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,  -2.0882457004312441E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,  -2.0882457004312441E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,   2.0882457004312441E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,  -2.0882457004312441E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,   5.5777878102209899E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,   5.5777878102209899E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,  -5.5777878102209899E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,   5.5777878102209899E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,  -5.5777878102209899E-01,   8.0329019064582485E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,  -5.5777878102209899E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,   5.5777878102209899E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,  -5.5777878102209899E-01,  -8.0329019064582485E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,   5.5777878102209899E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,   5.5777878102209899E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,  -5.5777878102209899E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,   5.5777878102209899E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,  -5.5777878102209899E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,  -5.5777878102209899E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,   5.5777878102209899E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,  -5.5777878102209899E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,   2.0882457004312441E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,   2.0882457004312441E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,  -2.0882457004312441E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,   2.0882457004312441E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,  -2.0882457004312441E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   8.0329019064582485E-01,  -2.0882457004312441E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,   2.0882457004312441E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -8.0329019064582485E-01,  -2.0882457004312441E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,   8.0329019064582485E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,   8.0329019064582485E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,  -8.0329019064582485E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,   8.0329019064582485E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,  -8.0329019064582485E-01,   2.0882457004312441E-01,   2.5810627381416861E-03],
            [   5.5777878102209899E-01,  -8.0329019064582485E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,   8.0329019064582485E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [  -5.5777878102209899E-01,  -8.0329019064582485E-01,  -2.0882457004312441E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,   8.0329019064582485E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,   8.0329019064582485E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,  -8.0329019064582485E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,   8.0329019064582485E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,  -8.0329019064582485E-01,   5.5777878102209899E-01,   2.5810627381416861E-03],
            [   2.0882457004312441E-01,  -8.0329019064582485E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,   8.0329019064582485E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [  -2.0882457004312441E-01,  -8.0329019064582485E-01,  -5.5777878102209899E-01,   2.5810627381416861E-03],
            [   5.8755637635366698E-01,   2.3886281365707629E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,   2.3886281365707629E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,  -2.3886281365707629E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,   2.3886281365707629E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,  -2.3886281365707629E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,  -2.3886281365707629E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,   2.3886281365707629E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,  -2.3886281365707629E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,   5.8755637635366698E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,   5.8755637635366698E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,  -5.8755637635366698E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,   5.8755637635366698E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,  -5.8755637635366698E-01,   7.7312486757183851E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,  -5.8755637635366698E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,   5.8755637635366698E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,  -5.8755637635366698E-01,  -7.7312486757183851E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,   5.8755637635366698E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,   5.8755637635366698E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,  -5.8755637635366698E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,   5.8755637635366698E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,  -5.8755637635366698E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,  -5.8755637635366698E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,   5.8755637635366698E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,  -5.8755637635366698E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,   2.3886281365707629E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,   2.3886281365707629E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,  -2.3886281365707629E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,   2.3886281365707629E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,  -2.3886281365707629E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   7.7312486757183851E-01,  -2.3886281365707629E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,   2.3886281365707629E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -7.7312486757183851E-01,  -2.3886281365707629E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,   7.7312486757183851E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,   7.7312486757183851E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,  -7.7312486757183851E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,   7.7312486757183851E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,  -7.7312486757183851E-01,   2.3886281365707629E-01,   2.5988230119730073E-03],
            [   5.8755637635366698E-01,  -7.7312486757183851E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,   7.7312486757183851E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [  -5.8755637635366698E-01,  -7.7312486757183851E-01,  -2.3886281365707629E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,   7.7312486757183851E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,   7.7312486757183851E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,  -7.7312486757183851E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,   7.7312486757183851E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,  -7.7312486757183851E-01,   5.8755637635366698E-01,   2.5988230119730073E-03],
            [   2.3886281365707629E-01,  -7.7312486757183851E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,   7.7312486757183851E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [  -2.3886281365707629E-01,  -7.7312486757183851E-01,  -5.8755637635366698E-01,   2.5988230119730073E-03],
            [   6.1599100163912690E-01,   2.6843089287691851E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,   2.6843089287691851E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,  -2.6843089287691851E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,   2.6843089287691851E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,  -2.6843089287691851E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,  -2.6843089287691851E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,   2.6843089287691851E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,  -2.6843089287691851E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,   6.1599100163912690E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,   6.1599100163912690E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,  -6.1599100163912690E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,   6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,  -6.1599100163912690E-01,   7.4060781905737771E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,  -6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,   6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,  -6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,   6.1599100163912690E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,   6.1599100163912690E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,   6.1599100163912690E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,  -6.1599100163912690E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,   6.1599100163912690E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,  -6.1599100163912690E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,   2.6843089287691851E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,   2.6843089287691851E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,  -2.6843089287691851E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,   2.6843089287691851E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,  -2.6843089287691851E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   7.4060781905737771E-01,  -2.6843089287691851E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,   2.6843089287691851E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -7.4060781905737771E-01,  -2.6843089287691851E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,   7.4060781905737771E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,   7.4060781905737771E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,   7.4060781905737771E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,  -7.4060781905737771E-01,   2.6843089287691851E-01,   2.6103505292477203E-03],
            [   6.1599100163912690E-01,  -7.4060781905737771E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,   7.4060781905737771E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [  -6.1599100163912690E-01,  -7.4060781905737771E-01,  -2.6843089287691851E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,   7.4060781905737771E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,   7.4060781905737771E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,  -7.4060781905737771E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,   7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,  -7.4060781905737771E-01,   6.1599100163912690E-01,   2.6103505292477203E-03],
            [   2.6843089287691851E-01,  -7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,   7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [  -2.6843089287691851E-01,  -7.4060781905737771E-01,  -6.1599100163912690E-01,   2.6103505292477203E-03],
            [   6.4302196029562675E-01,   2.9737407619602518E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,   2.9737407619602518E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,  -2.9737407619602518E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,   2.9737407619602518E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,  -2.9737407619602518E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,  -2.9737407619602518E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,   2.9737407619602518E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,  -2.9737407619602518E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,   6.4302196029562675E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,   6.4302196029562675E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,  -6.4302196029562675E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,   6.4302196029562675E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,  -6.4302196029562675E-01,   7.0575591912794466E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,  -6.4302196029562675E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,   6.4302196029562675E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,  -6.4302196029562675E-01,  -7.0575591912794466E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,   6.4302196029562675E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,   6.4302196029562675E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,  -6.4302196029562675E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,   6.4302196029562675E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,  -6.4302196029562675E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,  -6.4302196029562675E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,   6.4302196029562675E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,  -6.4302196029562675E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,   2.9737407619602518E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,   2.9737407619602518E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,  -2.9737407619602518E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,   2.9737407619602518E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,  -2.9737407619602518E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   7.0575591912794466E-01,  -2.9737407619602518E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,   2.9737407619602518E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -7.0575591912794466E-01,  -2.9737407619602518E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,   7.0575591912794466E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,   7.0575591912794466E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,  -7.0575591912794466E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,   7.0575591912794466E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,  -7.0575591912794466E-01,   2.9737407619602518E-01,   2.6163968272140269E-03],
            [   6.4302196029562675E-01,  -7.0575591912794466E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,   7.0575591912794466E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [  -6.4302196029562675E-01,  -7.0575591912794466E-01,  -2.9737407619602518E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,   7.0575591912794466E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,   7.0575591912794466E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,  -7.0575591912794466E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,   7.0575591912794466E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,  -7.0575591912794466E-01,   6.4302196029562675E-01,   2.6163968272140269E-03],
            [   2.9737407619602518E-01,  -7.0575591912794466E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,   7.0575591912794466E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [  -2.9737407619602518E-01,  -7.0575591912794466E-01,  -6.4302196029562675E-01,   2.6163968272140269E-03],
            [   4.3006470362136462E-01,   2.9163999204939769E-02,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,   2.9163999204939769E-02,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,  -2.9163999204939769E-02,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,   2.9163999204939769E-02,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,  -2.9163999204939769E-02,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,  -2.9163999204939769E-02,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,   2.9163999204939769E-02,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,  -2.9163999204939769E-02,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,   4.3006470362136462E-01,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,   4.3006470362136462E-01,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,  -4.3006470362136462E-01,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,   4.3006470362136462E-01,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,  -4.3006470362136462E-01,   9.0232688746897161E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,  -4.3006470362136462E-01,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,   4.3006470362136462E-01,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,  -4.3006470362136462E-01,  -9.0232688746897161E-01,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,   4.3006470362136462E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,   4.3006470362136462E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,  -4.3006470362136462E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,   4.3006470362136462E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,  -4.3006470362136462E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,  -4.3006470362136462E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,   4.3006470362136462E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,  -4.3006470362136462E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,   2.9163999204939769E-02,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,   2.9163999204939769E-02,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,  -2.9163999204939769E-02,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,   2.9163999204939769E-02,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,  -2.9163999204939769E-02,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   9.0232688746897161E-01,  -2.9163999204939769E-02,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,   2.9163999204939769E-02,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -9.0232688746897161E-01,  -2.9163999204939769E-02,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,   9.0232688746897161E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,   9.0232688746897161E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,  -9.0232688746897161E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,   9.0232688746897161E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,  -9.0232688746897161E-01,   2.9163999204939769E-02,   2.4308066704905634E-03],
            [   4.3006470362136462E-01,  -9.0232688746897161E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,   9.0232688746897161E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [  -4.3006470362136462E-01,  -9.0232688746897161E-01,  -2.9163999204939769E-02,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,   9.0232688746897161E-01,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,   9.0232688746897161E-01,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,  -9.0232688746897161E-01,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,   9.0232688746897161E-01,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,  -9.0232688746897161E-01,   4.3006470362136462E-01,   2.4308066704905634E-03],
            [   2.9163999204939769E-02,  -9.0232688746897161E-01,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,   9.0232688746897161E-01,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [  -2.9163999204939769E-02,  -9.0232688746897161E-01,  -4.3006470362136462E-01,   2.4308066704905634E-03],
            [   4.6614863089355307E-01,   5.8988030247556590E-02,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,   5.8988030247556590E-02,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,  -5.8988030247556590E-02,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,   5.8988030247556590E-02,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,  -5.8988030247556590E-02,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,  -5.8988030247556590E-02,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,   5.8988030247556590E-02,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,  -5.8988030247556590E-02,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,   4.6614863089355307E-01,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,   4.6614863089355307E-01,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,  -4.6614863089355307E-01,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,   4.6614863089355307E-01,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,  -4.6614863089355307E-01,   8.8273771087655439E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,  -4.6614863089355307E-01,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,   4.6614863089355307E-01,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,  -4.6614863089355307E-01,  -8.8273771087655439E-01,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,   4.6614863089355307E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,   4.6614863089355307E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,  -4.6614863089355307E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,   4.6614863089355307E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,  -4.6614863089355307E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,  -4.6614863089355307E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,   4.6614863089355307E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,  -4.6614863089355307E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,   5.8988030247556590E-02,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,   5.8988030247556590E-02,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,  -5.8988030247556590E-02,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,   5.8988030247556590E-02,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,  -5.8988030247556590E-02,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   8.8273771087655439E-01,  -5.8988030247556590E-02,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,   5.8988030247556590E-02,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -8.8273771087655439E-01,  -5.8988030247556590E-02,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,   8.8273771087655439E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,   8.8273771087655439E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,  -8.8273771087655439E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,   8.8273771087655439E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,  -8.8273771087655439E-01,   5.8988030247556590E-02,   2.4807360326150342E-03],
            [   4.6614863089355307E-01,  -8.8273771087655439E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,   8.8273771087655439E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [  -4.6614863089355307E-01,  -8.8273771087655439E-01,  -5.8988030247556590E-02,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,   8.8273771087655439E-01,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,   8.8273771087655439E-01,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,  -8.8273771087655439E-01,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,   8.8273771087655439E-01,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,  -8.8273771087655439E-01,   4.6614863089355307E-01,   2.4807360326150342E-03],
            [   5.8988030247556590E-02,  -8.8273771087655439E-01,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,   8.8273771087655439E-01,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [  -5.8988030247556590E-02,  -8.8273771087655439E-01,  -4.6614863089355307E-01,   2.4807360326150342E-03],
            [   5.0096585552872608E-01,   8.9241626985254091E-02,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,   8.9241626985254091E-02,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,  -8.9241626985254091E-02,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,   8.9241626985254091E-02,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,  -8.9241626985254091E-02,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,  -8.9241626985254091E-02,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,   8.9241626985254091E-02,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,  -8.9241626985254091E-02,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,   5.0096585552872608E-01,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,   5.0096585552872608E-01,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,  -5.0096585552872608E-01,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,   5.0096585552872608E-01,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,  -5.0096585552872608E-01,   8.6085372950774641E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,  -5.0096585552872608E-01,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,   5.0096585552872608E-01,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,  -5.0096585552872608E-01,  -8.6085372950774641E-01,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,   5.0096585552872608E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,   5.0096585552872608E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,  -5.0096585552872608E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,   5.0096585552872608E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,  -5.0096585552872608E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,  -5.0096585552872608E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,   5.0096585552872608E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,  -5.0096585552872608E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,   8.9241626985254091E-02,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,   8.9241626985254091E-02,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,  -8.9241626985254091E-02,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,   8.9241626985254091E-02,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,  -8.9241626985254091E-02,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.6085372950774641E-01,  -8.9241626985254091E-02,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,   8.9241626985254091E-02,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.6085372950774641E-01,  -8.9241626985254091E-02,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,   8.6085372950774641E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,   8.6085372950774641E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,  -8.6085372950774641E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,   8.6085372950774641E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,  -8.6085372950774641E-01,   8.9241626985254091E-02,   2.5222330533959609E-03],
            [   5.0096585552872608E-01,  -8.6085372950774641E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,   8.6085372950774641E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [  -5.0096585552872608E-01,  -8.6085372950774641E-01,  -8.9241626985254091E-02,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,   8.6085372950774641E-01,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,   8.6085372950774641E-01,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,  -8.6085372950774641E-01,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,   8.6085372950774641E-01,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,  -8.6085372950774641E-01,   5.0096585552872608E-01,   2.5222330533959609E-03],
            [   8.9241626985254091E-02,  -8.6085372950774641E-01,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,   8.6085372950774641E-01,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [  -8.9241626985254091E-02,  -8.6085372950774641E-01,  -5.0096585552872608E-01,   2.5222330533959609E-03],
            [   5.3448242704477045E-01,   1.1971851996373210E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,   1.1971851996373210E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,  -1.1971851996373210E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,   1.1971851996373210E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,  -1.1971851996373210E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,  -1.1971851996373210E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,   1.1971851996373210E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,  -1.1971851996373210E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,   5.3448242704477045E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,   5.3448242704477045E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,  -5.3448242704477045E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,   5.3448242704477045E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,  -5.3448242704477045E-01,   8.3665764274165633E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,  -5.3448242704477045E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,   5.3448242704477045E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,  -5.3448242704477045E-01,  -8.3665764274165633E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,   5.3448242704477045E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,   5.3448242704477045E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,  -5.3448242704477045E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,   5.3448242704477045E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,  -5.3448242704477045E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,  -5.3448242704477045E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,   5.3448242704477045E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,  -5.3448242704477045E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,   1.1971851996373210E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,   1.1971851996373210E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,  -1.1971851996373210E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,   1.1971851996373210E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,  -1.1971851996373210E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   8.3665764274165633E-01,  -1.1971851996373210E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,   1.1971851996373210E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -8.3665764274165633E-01,  -1.1971851996373210E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,   8.3665764274165633E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,   8.3665764274165633E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,  -8.3665764274165633E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,   8.3665764274165633E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,  -8.3665764274165633E-01,   1.1971851996373210E-01,   2.5556692214039780E-03],
            [   5.3448242704477045E-01,  -8.3665764274165633E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,   8.3665764274165633E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [  -5.3448242704477045E-01,  -8.3665764274165633E-01,  -1.1971851996373210E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,   8.3665764274165633E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,   8.3665764274165633E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,  -8.3665764274165633E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,   8.3665764274165633E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,  -8.3665764274165633E-01,   5.3448242704477045E-01,   2.5556692214039780E-03],
            [   1.1971851996373210E-01,  -8.3665764274165633E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,   8.3665764274165633E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [  -1.1971851996373210E-01,  -8.3665764274165633E-01,  -5.3448242704477045E-01,   2.5556692214039780E-03],
            [   5.6665759974163710E-01,   1.5023007561613819E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,   1.5023007561613819E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,  -1.5023007561613819E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,   1.5023007561613819E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,  -1.5023007561613819E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,  -1.5023007561613819E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,   1.5023007561613819E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,  -1.5023007561613819E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,   5.6665759974163710E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,   5.6665759974163710E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,  -5.6665759974163710E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,   5.6665759974163710E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,  -5.6665759974163710E-01,   8.1014201781873774E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,  -5.6665759974163710E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,   5.6665759974163710E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,  -5.6665759974163710E-01,  -8.1014201781873774E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,   5.6665759974163710E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,   5.6665759974163710E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,  -5.6665759974163710E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,   5.6665759974163710E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,  -5.6665759974163710E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,  -5.6665759974163710E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,   5.6665759974163710E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,  -5.6665759974163710E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,   1.5023007561613819E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,   1.5023007561613819E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,  -1.5023007561613819E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,   1.5023007561613819E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,  -1.5023007561613819E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   8.1014201781873774E-01,  -1.5023007561613819E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,   1.5023007561613819E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -8.1014201781873774E-01,  -1.5023007561613819E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,   8.1014201781873774E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,   8.1014201781873774E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,  -8.1014201781873774E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,   8.1014201781873774E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,  -8.1014201781873774E-01,   1.5023007561613819E-01,   2.5814933372397451E-03],
            [   5.6665759974163710E-01,  -8.1014201781873774E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,   8.1014201781873774E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [  -5.6665759974163710E-01,  -8.1014201781873774E-01,  -1.5023007561613819E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,   8.1014201781873774E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,   8.1014201781873774E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,  -8.1014201781873774E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,   8.1014201781873774E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,  -8.1014201781873774E-01,   5.6665759974163710E-01,   2.5814933372397451E-03],
            [   1.5023007561613819E-01,  -8.1014201781873774E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,   8.1014201781873774E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [  -1.5023007561613819E-01,  -8.1014201781873774E-01,  -5.6665759974163710E-01,   2.5814933372397451E-03],
            [   5.9744574714047516E-01,   1.8060041919135639E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,   1.8060041919135639E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,  -1.8060041919135639E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,   1.8060041919135639E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,  -1.8060041919135639E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,  -1.8060041919135639E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,   1.8060041919135639E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,  -1.8060041919135639E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,   5.9744574714047516E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,   5.9744574714047516E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,  -5.9744574714047516E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,   5.9744574714047516E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,  -5.9744574714047516E-01,   7.8130792125234838E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,  -5.9744574714047516E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,   5.9744574714047516E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,  -5.9744574714047516E-01,  -7.8130792125234838E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,   5.9744574714047516E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,   5.9744574714047516E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,  -5.9744574714047516E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,   5.9744574714047516E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,  -5.9744574714047516E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,  -5.9744574714047516E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,   5.9744574714047516E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,  -5.9744574714047516E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,   1.8060041919135639E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,   1.8060041919135639E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,  -1.8060041919135639E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,   1.8060041919135639E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,  -1.8060041919135639E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   7.8130792125234838E-01,  -1.8060041919135639E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,   1.8060041919135639E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -7.8130792125234838E-01,  -1.8060041919135639E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,   7.8130792125234838E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,   7.8130792125234838E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,  -7.8130792125234838E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,   7.8130792125234838E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,  -7.8130792125234838E-01,   1.8060041919135639E-01,   2.6002144785715591E-03],
            [   5.9744574714047516E-01,  -7.8130792125234838E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,   7.8130792125234838E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [  -5.9744574714047516E-01,  -7.8130792125234838E-01,  -1.8060041919135639E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,   7.8130792125234838E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,   7.8130792125234838E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,  -7.8130792125234838E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,   7.8130792125234838E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,  -7.8130792125234838E-01,   5.9744574714047516E-01,   2.6002144785715591E-03],
            [   1.8060041919135639E-01,  -7.8130792125234838E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,   7.8130792125234838E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [  -1.8060041919135639E-01,  -7.8130792125234838E-01,  -5.9744574714047516E-01,   2.6002144785715591E-03],
            [   6.2679844441168864E-01,   2.1066217647862520E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,   2.1066217647862520E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,  -2.1066217647862520E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,   2.1066217647862520E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,  -2.1066217647862520E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,  -2.1066217647862520E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,   2.1066217647862520E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,  -2.1066217647862520E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,   6.2679844441168864E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,   6.2679844441168864E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,  -6.2679844441168864E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,   6.2679844441168864E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,  -6.2679844441168864E-01,   7.5016342051873997E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,  -6.2679844441168864E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,   6.2679844441168864E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,  -6.2679844441168864E-01,  -7.5016342051873997E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,   6.2679844441168864E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,   6.2679844441168864E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,  -6.2679844441168864E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,   6.2679844441168864E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,  -6.2679844441168864E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,  -6.2679844441168864E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,   6.2679844441168864E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,  -6.2679844441168864E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,   2.1066217647862520E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,   2.1066217647862520E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,  -2.1066217647862520E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,   2.1066217647862520E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,  -2.1066217647862520E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   7.5016342051873997E-01,  -2.1066217647862520E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,   2.1066217647862520E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -7.5016342051873997E-01,  -2.1066217647862520E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,   7.5016342051873997E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,   7.5016342051873997E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,  -7.5016342051873997E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,   7.5016342051873997E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,  -7.5016342051873997E-01,   2.1066217647862520E-01,   2.6124022910283648E-03],
            [   6.2679844441168864E-01,  -7.5016342051873997E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,   7.5016342051873997E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [  -6.2679844441168864E-01,  -7.5016342051873997E-01,  -2.1066217647862520E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,   7.5016342051873997E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,   7.5016342051873997E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,  -7.5016342051873997E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,   7.5016342051873997E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,  -7.5016342051873997E-01,   6.2679844441168864E-01,   2.6124022910283648E-03],
            [   2.1066217647862520E-01,  -7.5016342051873997E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,   7.5016342051873997E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [  -2.1066217647862520E-01,  -7.5016342051873997E-01,  -6.2679844441168864E-01,   2.6124022910283648E-03],
            [   6.5466647135754175E-01,   2.4025269326719140E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,   2.4025269326719140E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,  -2.4025269326719140E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,   2.4025269326719140E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,  -2.4025269326719140E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,  -2.4025269326719140E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,   2.4025269326719140E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,  -2.4025269326719140E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,   6.5466647135754175E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,   6.5466647135754175E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,  -6.5466647135754175E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,   6.5466647135754175E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,  -6.5466647135754175E-01,   7.1672202049199363E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,  -6.5466647135754175E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,   6.5466647135754175E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,  -6.5466647135754175E-01,  -7.1672202049199363E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,   6.5466647135754175E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,   6.5466647135754175E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,  -6.5466647135754175E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,   6.5466647135754175E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,  -6.5466647135754175E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,  -6.5466647135754175E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,   6.5466647135754175E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,  -6.5466647135754175E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,   2.4025269326719140E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,   2.4025269326719140E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,  -2.4025269326719140E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,   2.4025269326719140E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,  -2.4025269326719140E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   7.1672202049199363E-01,  -2.4025269326719140E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,   2.4025269326719140E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -7.1672202049199363E-01,  -2.4025269326719140E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,   7.1672202049199363E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,   7.1672202049199363E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,  -7.1672202049199363E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,   7.1672202049199363E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,  -7.1672202049199363E-01,   2.4025269326719140E-01,   2.6186888394828336E-03],
            [   6.5466647135754175E-01,  -7.1672202049199363E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,   7.1672202049199363E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [  -6.5466647135754175E-01,  -7.1672202049199363E-01,  -2.4025269326719140E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,   7.1672202049199363E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,   7.1672202049199363E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,  -7.1672202049199363E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,   7.1672202049199363E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,  -7.1672202049199363E-01,   6.5466647135754175E-01,   2.6186888394828336E-03],
            [   2.4025269326719140E-01,  -7.1672202049199363E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,   7.1672202049199363E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [  -2.4025269326719140E-01,  -7.1672202049199363E-01,  -6.5466647135754175E-01,   2.6186888394828336E-03],
            [   5.0427110044372525E-01,   2.9825292036076569E-02,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,   2.9825292036076569E-02,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,  -2.9825292036076569E-02,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,   2.9825292036076569E-02,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,  -2.9825292036076569E-02,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,  -2.9825292036076569E-02,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,   2.9825292036076569E-02,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,  -2.9825292036076569E-02,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,   5.0427110044372525E-01,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,   5.0427110044372525E-01,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,  -5.0427110044372525E-01,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,   5.0427110044372525E-01,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,  -5.0427110044372525E-01,   8.6303019020903149E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,  -5.0427110044372525E-01,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,   5.0427110044372525E-01,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,  -5.0427110044372525E-01,  -8.6303019020903149E-01,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,   5.0427110044372525E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,   5.0427110044372525E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,  -5.0427110044372525E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,   5.0427110044372525E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,  -5.0427110044372525E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,  -5.0427110044372525E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,   5.0427110044372525E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,  -5.0427110044372525E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,   2.9825292036076569E-02,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,   2.9825292036076569E-02,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,  -2.9825292036076569E-02,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,   2.9825292036076569E-02,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,  -2.9825292036076569E-02,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   8.6303019020903149E-01,  -2.9825292036076569E-02,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,   2.9825292036076569E-02,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -8.6303019020903149E-01,  -2.9825292036076569E-02,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,   8.6303019020903149E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,   8.6303019020903149E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,  -8.6303019020903149E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,   8.6303019020903149E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,  -8.6303019020903149E-01,   2.9825292036076569E-02,   2.5215594771847193E-03],
            [   5.0427110044372525E-01,  -8.6303019020903149E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,   8.6303019020903149E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [  -5.0427110044372525E-01,  -8.6303019020903149E-01,  -2.9825292036076569E-02,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,   8.6303019020903149E-01,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,   8.6303019020903149E-01,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,  -8.6303019020903149E-01,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,   8.6303019020903149E-01,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,  -8.6303019020903149E-01,   5.0427110044372525E-01,   2.5215594771847193E-03],
            [   2.9825292036076569E-02,  -8.6303019020903149E-01,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,   8.6303019020903149E-01,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [  -2.9825292036076569E-02,  -8.6303019020903149E-01,  -5.0427110044372525E-01,   2.5215594771847193E-03],
            [   5.3921274567743804E-01,   6.0087280623399221E-02,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,   6.0087280623399221E-02,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,  -6.0087280623399221E-02,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,   6.0087280623399221E-02,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,  -6.0087280623399221E-02,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,  -6.0087280623399221E-02,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,   6.0087280623399221E-02,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,  -6.0087280623399221E-02,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,   5.3921274567743804E-01,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,   5.3921274567743804E-01,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,  -5.3921274567743804E-01,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,   5.3921274567743804E-01,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,  -5.3921274567743804E-01,   8.4002329349029570E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,  -5.3921274567743804E-01,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,   5.3921274567743804E-01,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,  -5.3921274567743804E-01,  -8.4002329349029570E-01,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,   5.3921274567743804E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,   5.3921274567743804E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,  -5.3921274567743804E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,   5.3921274567743804E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,  -5.3921274567743804E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,  -5.3921274567743804E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,   5.3921274567743804E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,  -5.3921274567743804E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,   6.0087280623399221E-02,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,   6.0087280623399221E-02,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,  -6.0087280623399221E-02,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,   6.0087280623399221E-02,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,  -6.0087280623399221E-02,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   8.4002329349029570E-01,  -6.0087280623399221E-02,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,   6.0087280623399221E-02,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -8.4002329349029570E-01,  -6.0087280623399221E-02,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,   8.4002329349029570E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,   8.4002329349029570E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,  -8.4002329349029570E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,   8.4002329349029570E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,  -8.4002329349029570E-01,   6.0087280623399221E-02,   2.5556585131774781E-03],
            [   5.3921274567743804E-01,  -8.4002329349029570E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,   8.4002329349029570E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [  -5.3921274567743804E-01,  -8.4002329349029570E-01,  -6.0087280623399221E-02,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,   8.4002329349029570E-01,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,   8.4002329349029570E-01,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,  -8.4002329349029570E-01,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,   8.4002329349029570E-01,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,  -8.4002329349029570E-01,   5.3921274567743804E-01,   2.5556585131774781E-03],
            [   6.0087280623399221E-02,  -8.4002329349029570E-01,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,   8.4002329349029570E-01,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [  -6.0087280623399221E-02,  -8.4002329349029570E-01,  -5.3921274567743804E-01,   2.5556585131774781E-03],
            [   5.7268194376686177E-01,   9.0582276745713980E-02,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,   9.0582276745713980E-02,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,  -9.0582276745713980E-02,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,   9.0582276745713980E-02,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,  -9.0582276745713980E-02,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,  -9.0582276745713980E-02,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,   9.0582276745713980E-02,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,  -9.0582276745713980E-02,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,   5.7268194376686177E-01,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,   5.7268194376686177E-01,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,  -5.7268194376686177E-01,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,   5.7268194376686177E-01,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,  -5.7268194376686177E-01,   8.1475778144364586E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,  -5.7268194376686177E-01,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,   5.7268194376686177E-01,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,  -5.7268194376686177E-01,  -8.1475778144364586E-01,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,   5.7268194376686177E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,   5.7268194376686177E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,  -5.7268194376686177E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,   5.7268194376686177E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,  -5.7268194376686177E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,  -5.7268194376686177E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,   5.7268194376686177E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,  -5.7268194376686177E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,   9.0582276745713980E-02,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,   9.0582276745713980E-02,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,  -9.0582276745713980E-02,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,   9.0582276745713980E-02,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,  -9.0582276745713980E-02,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   8.1475778144364586E-01,  -9.0582276745713980E-02,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,   9.0582276745713980E-02,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -8.1475778144364586E-01,  -9.0582276745713980E-02,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,   8.1475778144364586E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,   8.1475778144364586E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,  -8.1475778144364586E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,   8.1475778144364586E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,  -8.1475778144364586E-01,   9.0582276745713980E-02,   2.5824001962553625E-03],
            [   5.7268194376686177E-01,  -8.1475778144364586E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,   8.1475778144364586E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [  -5.7268194376686177E-01,  -8.1475778144364586E-01,  -9.0582276745713980E-02,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,   8.1475778144364586E-01,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,   8.1475778144364586E-01,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,  -8.1475778144364586E-01,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,   8.1475778144364586E-01,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,  -8.1475778144364586E-01,   5.7268194376686177E-01,   2.5824001962553625E-03],
            [   9.0582276745713980E-02,  -8.1475778144364586E-01,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,   8.1475778144364586E-01,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [  -9.0582276745713980E-02,  -8.1475778144364586E-01,  -5.7268194376686177E-01,   2.5824001962553625E-03],
            [   6.0464692542072784E-01,   1.2112192358034000E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,   1.2112192358034000E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,  -1.2112192358034000E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,   1.2112192358034000E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,  -1.2112192358034000E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,  -1.2112192358034000E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,   1.2112192358034000E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,  -1.2112192358034000E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,   6.0464692542072784E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,   6.0464692542072784E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,  -6.0464692542072784E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,   6.0464692542072784E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,  -6.0464692542072784E-01,   7.8723031903468954E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,  -6.0464692542072784E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,   6.0464692542072784E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,  -6.0464692542072784E-01,  -7.8723031903468954E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,   6.0464692542072784E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,   6.0464692542072784E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,  -6.0464692542072784E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,   6.0464692542072784E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,  -6.0464692542072784E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,  -6.0464692542072784E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,   6.0464692542072784E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,  -6.0464692542072784E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,   1.2112192358034000E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,   1.2112192358034000E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,  -1.2112192358034000E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,   1.2112192358034000E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,  -1.2112192358034000E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   7.8723031903468954E-01,  -1.2112192358034000E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,   1.2112192358034000E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -7.8723031903468954E-01,  -1.2112192358034000E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,   7.8723031903468954E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,   7.8723031903468954E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,  -7.8723031903468954E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,   7.8723031903468954E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,  -7.8723031903468954E-01,   1.2112192358034000E-01,   2.6020577724977312E-03],
            [   6.0464692542072784E-01,  -7.8723031903468954E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,   7.8723031903468954E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [  -6.0464692542072784E-01,  -7.8723031903468954E-01,  -1.2112192358034000E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,   7.8723031903468954E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,   7.8723031903468954E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,  -7.8723031903468954E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,   7.8723031903468954E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,  -7.8723031903468954E-01,   6.0464692542072784E-01,   2.6020577724977312E-03],
            [   1.2112192358034000E-01,  -7.8723031903468954E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,   7.8723031903468954E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [  -1.2112192358034000E-01,  -7.8723031903468954E-01,  -6.0464692542072784E-01,   2.6020577724977312E-03],
            [   6.3507161574349524E-01,   1.5152864047915801E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,   1.5152864047915801E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,  -1.5152864047915801E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,   1.5152864047915801E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,  -1.5152864047915801E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,  -1.5152864047915801E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,   1.5152864047915801E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,  -1.5152864047915801E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,   6.3507161574349524E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,   6.3507161574349524E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,  -6.3507161574349524E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,   6.3507161574349524E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,  -6.3507161574349524E-01,   7.5744512275905795E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,  -6.3507161574349524E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,   6.3507161574349524E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,  -6.3507161574349524E-01,  -7.5744512275905795E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,   6.3507161574349524E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,   6.3507161574349524E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,  -6.3507161574349524E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,   6.3507161574349524E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,  -6.3507161574349524E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,  -6.3507161574349524E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,   6.3507161574349524E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,  -6.3507161574349524E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,   1.5152864047915801E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,   1.5152864047915801E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,  -1.5152864047915801E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,   1.5152864047915801E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,  -1.5152864047915801E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   7.5744512275905795E-01,  -1.5152864047915801E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,   1.5152864047915801E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -7.5744512275905795E-01,  -1.5152864047915801E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,   7.5744512275905795E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,   7.5744512275905795E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,  -7.5744512275905795E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,   7.5744512275905795E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,  -7.5744512275905795E-01,   1.5152864047915801E-01,   2.6150030839981980E-03],
            [   6.3507161574349524E-01,  -7.5744512275905795E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,   7.5744512275905795E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [  -6.3507161574349524E-01,  -7.5744512275905795E-01,  -1.5152864047915801E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,   7.5744512275905795E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,   7.5744512275905795E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,  -7.5744512275905795E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,   7.5744512275905795E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,  -7.5744512275905795E-01,   6.3507161574349524E-01,   2.6150030839981980E-03],
            [   1.5152864047915801E-01,  -7.5744512275905795E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,   7.5744512275905795E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [  -1.5152864047915801E-01,  -7.5744512275905795E-01,  -6.3507161574349524E-01,   2.6150030839981980E-03],
            [   6.6391776791854540E-01,   1.8163146812555520E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,   1.8163146812555520E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,  -1.8163146812555520E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,   1.8163146812555520E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,  -1.8163146812555520E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,  -1.8163146812555520E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,   1.8163146812555520E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,  -1.8163146812555520E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,   6.6391776791854540E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,   6.6391776791854540E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,  -6.6391776791854540E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,   6.6391776791854540E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,  -6.6391776791854540E-01,   7.2541243939472932E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,  -6.6391776791854540E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,   6.6391776791854540E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,  -6.6391776791854540E-01,  -7.2541243939472932E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,   6.6391776791854540E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,   6.6391776791854540E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,  -6.6391776791854540E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,   6.6391776791854540E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,  -6.6391776791854540E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,  -6.6391776791854540E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,   6.6391776791854540E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,  -6.6391776791854540E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,   1.8163146812555520E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,   1.8163146812555520E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,  -1.8163146812555520E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,   1.8163146812555520E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,  -1.8163146812555520E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   7.2541243939472932E-01,  -1.8163146812555520E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,   1.8163146812555520E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -7.2541243939472932E-01,  -1.8163146812555520E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,   7.2541243939472932E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,   7.2541243939472932E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,  -7.2541243939472932E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,   7.2541243939472932E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,  -7.2541243939472932E-01,   1.8163146812555520E-01,   2.6217030504467709E-03],
            [   6.6391776791854540E-01,  -7.2541243939472932E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,   7.2541243939472932E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [  -6.6391776791854540E-01,  -7.2541243939472932E-01,  -1.8163146812555520E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,   7.2541243939472932E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,   7.2541243939472932E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,  -7.2541243939472932E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,   7.2541243939472932E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,  -7.2541243939472932E-01,   6.6391776791854540E-01,   2.6217030504467709E-03],
            [   1.8163146812555520E-01,  -7.2541243939472932E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,   7.2541243939472932E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [  -1.8163146812555520E-01,  -7.2541243939472932E-01,  -6.6391776791854540E-01,   2.6217030504467709E-03],
            [   5.7572760409722534E-01,   3.0269917525754399E-02,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,   3.0269917525754399E-02,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,  -3.0269917525754399E-02,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,   3.0269917525754399E-02,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,  -3.0269917525754399E-02,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,  -3.0269917525754399E-02,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,   3.0269917525754399E-02,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,  -3.0269917525754399E-02,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,   5.7572760409722534E-01,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,   5.7572760409722534E-01,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,  -5.7572760409722534E-01,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,   5.7572760409722534E-01,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,  -5.7572760409722534E-01,   8.1708105961003197E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,  -5.7572760409722534E-01,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,   5.7572760409722534E-01,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,  -5.7572760409722534E-01,  -8.1708105961003197E-01,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,   5.7572760409722534E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,   5.7572760409722534E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,  -5.7572760409722534E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,   5.7572760409722534E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,  -5.7572760409722534E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,  -5.7572760409722534E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,   5.7572760409722534E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,  -5.7572760409722534E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,   3.0269917525754399E-02,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,   3.0269917525754399E-02,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,  -3.0269917525754399E-02,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,   3.0269917525754399E-02,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,  -3.0269917525754399E-02,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   8.1708105961003197E-01,  -3.0269917525754399E-02,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,   3.0269917525754399E-02,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -8.1708105961003197E-01,  -3.0269917525754399E-02,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,   8.1708105961003197E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,   8.1708105961003197E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,  -8.1708105961003197E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,   8.1708105961003197E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,  -8.1708105961003197E-01,   3.0269917525754399E-02,   2.5830795421261945E-03],
            [   5.7572760409722534E-01,  -8.1708105961003197E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,   8.1708105961003197E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [  -5.7572760409722534E-01,  -8.1708105961003197E-01,  -3.0269917525754399E-02,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,   8.1708105961003197E-01,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,   8.1708105961003197E-01,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,  -8.1708105961003197E-01,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,   8.1708105961003197E-01,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,  -8.1708105961003197E-01,   5.7572760409722534E-01,   2.5830795421261945E-03],
            [   3.0269917525754399E-02,  -8.1708105961003197E-01,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,   8.1708105961003197E-01,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [  -3.0269917525754399E-02,  -8.1708105961003197E-01,  -5.7572760409722534E-01,   2.5830795421261945E-03],
            [   6.0902658231397555E-01,   6.0784022978707698E-02,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,   6.0784022978707698E-02,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,  -6.0784022978707698E-02,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,   6.0784022978707698E-02,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,  -6.0784022978707698E-02,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,  -6.0784022978707698E-02,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,   6.0784022978707698E-02,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,  -6.0784022978707698E-02,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,   6.0902658231397555E-01,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,   6.0902658231397555E-01,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,  -6.0902658231397555E-01,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,   6.0902658231397555E-01,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,  -6.0902658231397555E-01,   7.9081725106719969E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,  -6.0902658231397555E-01,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,   6.0902658231397555E-01,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,  -6.0902658231397555E-01,  -7.9081725106719969E-01,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,   6.0902658231397555E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,   6.0902658231397555E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,  -6.0902658231397555E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,   6.0902658231397555E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,  -6.0902658231397555E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,  -6.0902658231397555E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,   6.0902658231397555E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,  -6.0902658231397555E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,   6.0784022978707698E-02,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,   6.0784022978707698E-02,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,  -6.0784022978707698E-02,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,   6.0784022978707698E-02,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,  -6.0784022978707698E-02,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   7.9081725106719969E-01,  -6.0784022978707698E-02,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,   6.0784022978707698E-02,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -7.9081725106719969E-01,  -6.0784022978707698E-02,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,   7.9081725106719969E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,   7.9081725106719969E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,  -7.9081725106719969E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,   7.9081725106719969E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,  -7.9081725106719969E-01,   6.0784022978707698E-02,   2.6035909535921413E-03],
            [   6.0902658231397555E-01,  -7.9081725106719969E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,   7.9081725106719969E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [  -6.0902658231397555E-01,  -7.9081725106719969E-01,  -6.0784022978707698E-02,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,   7.9081725106719969E-01,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,   7.9081725106719969E-01,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,  -7.9081725106719969E-01,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,   7.9081725106719969E-01,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,  -7.9081725106719969E-01,   6.0902658231397555E-01,   2.6035909535921413E-03],
            [   6.0784022978707698E-02,  -7.9081725106719969E-01,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,   7.9081725106719969E-01,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [  -6.0784022978707698E-02,  -7.9081725106719969E-01,  -6.0902658231397555E-01,   2.6035909535921413E-03],
            [   6.4067353443876607E-01,   9.1354599841766360E-02,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,   9.1354599841766360E-02,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,  -9.1354599841766360E-02,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,   9.1354599841766360E-02,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,  -9.1354599841766360E-02,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,  -9.1354599841766360E-02,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,   9.1354599841766360E-02,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,  -9.1354599841766360E-02,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,   6.4067353443876607E-01,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,   6.4067353443876607E-01,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,  -6.4067353443876607E-01,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,   6.4067353443876607E-01,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,  -6.4067353443876607E-01,   7.6235933742395379E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,  -6.4067353443876607E-01,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,   6.4067353443876607E-01,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,  -6.4067353443876607E-01,  -7.6235933742395379E-01,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,   6.4067353443876607E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,   6.4067353443876607E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,  -6.4067353443876607E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,   6.4067353443876607E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,  -6.4067353443876607E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,  -6.4067353443876607E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,   6.4067353443876607E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,  -6.4067353443876607E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,   9.1354599841766360E-02,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,   9.1354599841766360E-02,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,  -9.1354599841766360E-02,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,   9.1354599841766360E-02,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,  -9.1354599841766360E-02,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   7.6235933742395379E-01,  -9.1354599841766360E-02,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,   9.1354599841766360E-02,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -7.6235933742395379E-01,  -9.1354599841766360E-02,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,   7.6235933742395379E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,   7.6235933742395379E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,  -7.6235933742395379E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,   7.6235933742395379E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,  -7.6235933742395379E-01,   9.1354599841766360E-02,   2.6173947977592292E-03],
            [   6.4067353443876607E-01,  -7.6235933742395379E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,   7.6235933742395379E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [  -6.4067353443876607E-01,  -7.6235933742395379E-01,  -9.1354599841766360E-02,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,   7.6235933742395379E-01,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,   7.6235933742395379E-01,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,  -7.6235933742395379E-01,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,   7.6235933742395379E-01,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,  -7.6235933742395379E-01,   6.4067353443876607E-01,   2.6173947977592292E-03],
            [   9.1354599841766360E-02,  -7.6235933742395379E-01,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,   7.6235933742395379E-01,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [  -9.1354599841766360E-02,  -7.6235933742395379E-01,  -6.4067353443876607E-01,   2.6173947977592292E-03],
            [   6.7063979277937091E-01,   1.2180241559665900E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,   1.2180241559665900E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,  -1.2180241559665900E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,   1.2180241559665900E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,  -1.2180241559665900E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,  -1.2180241559665900E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,   1.2180241559665900E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,  -1.2180241559665900E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,   6.7063979277937091E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,   6.7063979277937091E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,  -6.7063979277937091E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,   6.7063979277937091E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,  -6.7063979277937091E-01,   7.3171472576111329E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,  -6.7063979277937091E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,   6.7063979277937091E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,  -6.7063979277937091E-01,  -7.3171472576111329E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,   6.7063979277937091E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,   6.7063979277937091E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,  -6.7063979277937091E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,   6.7063979277937091E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,  -6.7063979277937091E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,  -6.7063979277937091E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,   6.7063979277937091E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,  -6.7063979277937091E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,   1.2180241559665900E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,   1.2180241559665900E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,  -1.2180241559665900E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,   1.2180241559665900E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,  -1.2180241559665900E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   7.3171472576111329E-01,  -1.2180241559665900E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,   1.2180241559665900E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -7.3171472576111329E-01,  -1.2180241559665900E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,   7.3171472576111329E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,   7.3171472576111329E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,  -7.3171472576111329E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,   7.3171472576111329E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,  -7.3171472576111329E-01,   1.2180241559665900E-01,   2.6247451926307416E-03],
            [   6.7063979277937091E-01,  -7.3171472576111329E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,   7.3171472576111329E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [  -6.7063979277937091E-01,  -7.3171472576111329E-01,  -1.2180241559665900E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,   7.3171472576111329E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,   7.3171472576111329E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,  -7.3171472576111329E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,   7.3171472576111329E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,  -7.3171472576111329E-01,   6.7063979277937091E-01,   2.6247451926307416E-03],
            [   1.2180241559665900E-01,  -7.3171472576111329E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,   7.3171472576111329E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [  -1.2180241559665900E-01,  -7.3171472576111329E-01,  -6.7063979277937091E-01,   2.6247451926307416E-03],
            [   6.4350196744266652E-01,   3.0526083576606390E-02,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,   3.0526083576606390E-02,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,  -3.0526083576606390E-02,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,   3.0526083576606390E-02,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,  -3.0526083576606390E-02,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,  -3.0526083576606390E-02,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,   3.0526083576606390E-02,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,  -3.0526083576606390E-02,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,   6.4350196744266652E-01,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,   6.4350196744266652E-01,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,  -6.4350196744266652E-01,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,   6.4350196744266652E-01,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,  -6.4350196744266652E-01,   7.6483552226533735E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,  -6.4350196744266652E-01,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,   6.4350196744266652E-01,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,  -6.4350196744266652E-01,  -7.6483552226533735E-01,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,   6.4350196744266652E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,   6.4350196744266652E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,  -6.4350196744266652E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,   6.4350196744266652E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,  -6.4350196744266652E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,  -6.4350196744266652E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,   6.4350196744266652E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,  -6.4350196744266652E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,   3.0526083576606390E-02,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,   3.0526083576606390E-02,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,  -3.0526083576606390E-02,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,   3.0526083576606390E-02,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,  -3.0526083576606390E-02,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   7.6483552226533735E-01,  -3.0526083576606390E-02,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,   3.0526083576606390E-02,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -7.6483552226533735E-01,  -3.0526083576606390E-02,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,   7.6483552226533735E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,   7.6483552226533735E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,  -7.6483552226533735E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,   7.6483552226533735E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,  -7.6483552226533735E-01,   3.0526083576606390E-02,   2.6188264430254387E-03],
            [   6.4350196744266652E-01,  -7.6483552226533735E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,   7.6483552226533735E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [  -6.4350196744266652E-01,  -7.6483552226533735E-01,  -3.0526083576606390E-02,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,   7.6483552226533735E-01,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,   7.6483552226533735E-01,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,  -7.6483552226533735E-01,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,   7.6483552226533735E-01,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,  -7.6483552226533735E-01,   6.4350196744266652E-01,   2.6188264430254387E-03],
            [   3.0526083576606390E-02,  -7.6483552226533735E-01,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,   7.6483552226533735E-01,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [  -3.0526083576606390E-02,  -7.6483552226533735E-01,  -6.4350196744266652E-01,   2.6188264430254387E-03],
            [   6.7472186763756814E-01,   6.1121857739830893E-02,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,   6.1121857739830893E-02,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,  -6.1121857739830893E-02,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,   6.1121857739830893E-02,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,  -6.1121857739830893E-02,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,  -6.1121857739830893E-02,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,   6.1121857739830893E-02,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,  -6.1121857739830893E-02,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,   6.7472186763756814E-01,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,   6.7472186763756814E-01,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,  -6.7472186763756814E-01,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,   6.7472186763756814E-01,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,  -6.7472186763756814E-01,   7.3553689223457985E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,  -6.7472186763756814E-01,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,   6.7472186763756814E-01,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,  -6.7472186763756814E-01,  -7.3553689223457985E-01,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,   6.7472186763756814E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,   6.7472186763756814E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,  -6.7472186763756814E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,   6.7472186763756814E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,  -6.7472186763756814E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,  -6.7472186763756814E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,   6.7472186763756814E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,  -6.7472186763756814E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,   6.1121857739830893E-02,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,   6.1121857739830893E-02,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,  -6.1121857739830893E-02,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,   6.1121857739830893E-02,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,  -6.1121857739830893E-02,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   7.3553689223457985E-01,  -6.1121857739830893E-02,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,   6.1121857739830893E-02,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -7.3553689223457985E-01,  -6.1121857739830893E-02,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,   7.3553689223457985E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,   7.3553689223457985E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,  -7.3553689223457985E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,   7.3553689223457985E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,  -7.3553689223457985E-01,   6.1121857739830893E-02,   2.6270119825088766E-03],
            [   6.7472186763756814E-01,  -7.3553689223457985E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,   7.3553689223457985E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [  -6.7472186763756814E-01,  -7.3553689223457985E-01,  -6.1121857739830893E-02,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,   7.3553689223457985E-01,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,   7.3553689223457985E-01,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,  -7.3553689223457985E-01,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,   7.3553689223457985E-01,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,  -7.3553689223457985E-01,   6.7472186763756814E-01,   2.6270119825088766E-03],
            [   6.1121857739830893E-02,  -7.3553689223457985E-01,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,   7.3553689223457985E-01,  -6.7472186763756814E-01,   2.6270119825088766E-03],
            [  -6.1121857739830893E-02,  -7.3553689223457985E-01,  -6.7472186763756814E-01,   2.6270119825088766E-03],
        ])
  
        order = 125
  
        return Lebedev(order,xyzw)
  
    @staticmethod
    def build5810():
  
        xyzw = np.array([
            [   1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.2233799035138155E-04],
            [  -1.0000000000000000E+00,   0.0000000000000000E+00,   0.0000000000000000E+00,   1.2233799035138155E-04],
            [   0.0000000000000000E+00,   1.0000000000000000E+00,   0.0000000000000000E+00,   1.2233799035138155E-04],
            [   0.0000000000000000E+00,  -1.0000000000000000E+00,   0.0000000000000000E+00,   1.2233799035138155E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,   1.0000000000000000E+00,   1.2233799035138155E-04],
            [   0.0000000000000000E+00,   0.0000000000000000E+00,  -1.0000000000000000E+00,   1.2233799035138155E-04],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,   7.0710678118654757E-01,   2.3971372861498097E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,   7.0710678118654757E-01,   2.3971372861498097E-03],
            [   0.0000000000000000E+00,   7.0710678118654757E-01,  -7.0710678118654757E-01,   2.3971372861498097E-03],
            [   0.0000000000000000E+00,  -7.0710678118654757E-01,  -7.0710678118654757E-01,   2.3971372861498097E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.3971372861498097E-03],
            [   7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.3971372861498097E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,   7.0710678118654757E-01,   2.3971372861498097E-03],
            [  -7.0710678118654757E-01,   0.0000000000000000E+00,  -7.0710678118654757E-01,   2.3971372861498097E-03],
            [   7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.3971372861498097E-03],
            [  -7.0710678118654757E-01,   7.0710678118654757E-01,   0.0000000000000000E+00,   2.3971372861498097E-03],
            [   7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.3971372861498097E-03],
            [  -7.0710678118654757E-01,  -7.0710678118654757E-01,   0.0000000000000000E+00,   2.3971372861498097E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.3889418824270068E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,   5.7735026918962573E-01,   2.3889418824270068E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.3889418824270068E-03],
            [   5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3889418824270068E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,   5.7735026918962573E-01,   2.3889418824270068E-03],
            [   5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3889418824270068E-03],
            [  -5.7735026918962573E-01,   5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3889418824270068E-03],
            [  -5.7735026918962573E-01,  -5.7735026918962573E-01,  -5.7735026918962573E-01,   2.3889418824270068E-03],
            [   1.1823616624002770E-02,   1.1823616624002770E-02,   9.9986019231683443E-01,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,   1.1823616624002770E-02,   9.9986019231683443E-01,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,  -1.1823616624002770E-02,   9.9986019231683443E-01,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,   1.1823616624002770E-02,  -9.9986019231683443E-01,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,  -1.1823616624002770E-02,   9.9986019231683443E-01,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,   1.1823616624002770E-02,  -9.9986019231683443E-01,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,  -1.1823616624002770E-02,  -9.9986019231683443E-01,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,  -1.1823616624002770E-02,  -9.9986019231683443E-01,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,   9.9986019231683443E-01,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,  -9.9986019231683443E-01,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,   9.9986019231683443E-01,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,  -9.9986019231683443E-01,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,   9.9986019231683443E-01,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,  -9.9986019231683443E-01,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -1.1823616624002770E-02,  -9.9986019231683443E-01,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [   1.1823616624002770E-02,   9.9986019231683443E-01,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [   9.9986019231683443E-01,   1.1823616624002770E-02,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -9.9986019231683443E-01,   1.1823616624002770E-02,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [   9.9986019231683443E-01,  -1.1823616624002770E-02,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [   9.9986019231683443E-01,   1.1823616624002770E-02,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -9.9986019231683443E-01,  -1.1823616624002770E-02,   1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -9.9986019231683443E-01,   1.1823616624002770E-02,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [   9.9986019231683443E-01,  -1.1823616624002770E-02,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [  -9.9986019231683443E-01,  -1.1823616624002770E-02,  -1.1823616624002770E-02,   4.9340905945373153E-04],
            [   3.0621450091389581E-02,   3.0621450091389581E-02,   9.9906188676608065E-01,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,   3.0621450091389581E-02,   9.9906188676608065E-01,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,  -3.0621450091389581E-02,   9.9906188676608065E-01,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,   3.0621450091389581E-02,  -9.9906188676608065E-01,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,  -3.0621450091389581E-02,   9.9906188676608065E-01,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,   3.0621450091389581E-02,  -9.9906188676608065E-01,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,  -3.0621450091389581E-02,  -9.9906188676608065E-01,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,  -3.0621450091389581E-02,  -9.9906188676608065E-01,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,   9.9906188676608065E-01,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,  -9.9906188676608065E-01,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,   9.9906188676608065E-01,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,  -9.9906188676608065E-01,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,   9.9906188676608065E-01,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,  -9.9906188676608065E-01,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -3.0621450091389581E-02,  -9.9906188676608065E-01,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [   3.0621450091389581E-02,   9.9906188676608065E-01,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [   9.9906188676608065E-01,   3.0621450091389581E-02,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -9.9906188676608065E-01,   3.0621450091389581E-02,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [   9.9906188676608065E-01,  -3.0621450091389581E-02,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [   9.9906188676608065E-01,   3.0621450091389581E-02,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -9.9906188676608065E-01,  -3.0621450091389581E-02,   3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -9.9906188676608065E-01,   3.0621450091389581E-02,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [   9.9906188676608065E-01,  -3.0621450091389581E-02,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [  -9.9906188676608065E-01,  -3.0621450091389581E-02,  -3.0621450091389581E-02,   8.3791371323532976E-04],
            [   5.3297940368342428E-02,   5.3297940368342428E-02,   9.9715528334607206E-01,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,   5.3297940368342428E-02,   9.9715528334607206E-01,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,  -5.3297940368342428E-02,   9.9715528334607206E-01,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,   5.3297940368342428E-02,  -9.9715528334607206E-01,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,  -5.3297940368342428E-02,   9.9715528334607206E-01,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,   5.3297940368342428E-02,  -9.9715528334607206E-01,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,  -5.3297940368342428E-02,  -9.9715528334607206E-01,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,  -5.3297940368342428E-02,  -9.9715528334607206E-01,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,   9.9715528334607206E-01,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,  -9.9715528334607206E-01,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,   9.9715528334607206E-01,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,  -9.9715528334607206E-01,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,   9.9715528334607206E-01,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,  -9.9715528334607206E-01,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -5.3297940368342428E-02,  -9.9715528334607206E-01,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [   5.3297940368342428E-02,   9.9715528334607206E-01,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [   9.9715528334607206E-01,   5.3297940368342428E-02,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -9.9715528334607206E-01,   5.3297940368342428E-02,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [   9.9715528334607206E-01,  -5.3297940368342428E-02,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [   9.9715528334607206E-01,   5.3297940368342428E-02,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -9.9715528334607206E-01,  -5.3297940368342428E-02,   5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -9.9715528334607206E-01,   5.3297940368342428E-02,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [   9.9715528334607206E-01,  -5.3297940368342428E-02,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [  -9.9715528334607206E-01,  -5.3297940368342428E-02,  -5.3297940368342428E-02,   1.1144977520300174E-03],
            [   7.8481655328622196E-02,   7.8481655328622196E-02,   9.9382154311212167E-01,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,   7.8481655328622196E-02,   9.9382154311212167E-01,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,  -7.8481655328622196E-02,   9.9382154311212167E-01,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,   7.8481655328622196E-02,  -9.9382154311212167E-01,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,  -7.8481655328622196E-02,   9.9382154311212167E-01,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,   7.8481655328622196E-02,  -9.9382154311212167E-01,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,  -7.8481655328622196E-02,  -9.9382154311212167E-01,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,  -7.8481655328622196E-02,  -9.9382154311212167E-01,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,   9.9382154311212167E-01,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,  -9.9382154311212167E-01,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,   9.9382154311212167E-01,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,  -9.9382154311212167E-01,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,   9.9382154311212167E-01,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,  -9.9382154311212167E-01,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -7.8481655328622196E-02,  -9.9382154311212167E-01,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [   7.8481655328622196E-02,   9.9382154311212167E-01,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [   9.9382154311212167E-01,   7.8481655328622196E-02,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -9.9382154311212167E-01,   7.8481655328622196E-02,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [   9.9382154311212167E-01,  -7.8481655328622196E-02,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [   9.9382154311212167E-01,   7.8481655328622196E-02,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -9.9382154311212167E-01,  -7.8481655328622196E-02,   7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -9.9382154311212167E-01,   7.8481655328622196E-02,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [   9.9382154311212167E-01,  -7.8481655328622196E-02,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [  -9.9382154311212167E-01,  -7.8481655328622196E-02,  -7.8481655328622196E-02,   1.3399596396364412E-03],
            [   1.0540381576362010E-01,   1.0540381576362010E-01,   9.8882762463684115E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,   1.0540381576362010E-01,   9.8882762463684115E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,  -1.0540381576362010E-01,   9.8882762463684115E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,   1.0540381576362010E-01,  -9.8882762463684115E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,  -1.0540381576362010E-01,   9.8882762463684115E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,   1.0540381576362010E-01,  -9.8882762463684115E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,  -1.0540381576362010E-01,  -9.8882762463684115E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,  -1.0540381576362010E-01,  -9.8882762463684115E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,   9.8882762463684115E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,  -9.8882762463684115E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,   9.8882762463684115E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,  -9.8882762463684115E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,   9.8882762463684115E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,  -9.8882762463684115E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -1.0540381576362010E-01,  -9.8882762463684115E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [   1.0540381576362010E-01,   9.8882762463684115E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [   9.8882762463684115E-01,   1.0540381576362010E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -9.8882762463684115E-01,   1.0540381576362010E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [   9.8882762463684115E-01,  -1.0540381576362010E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [   9.8882762463684115E-01,   1.0540381576362010E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -9.8882762463684115E-01,  -1.0540381576362010E-01,   1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -9.8882762463684115E-01,   1.0540381576362010E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [   9.8882762463684115E-01,  -1.0540381576362010E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [  -9.8882762463684115E-01,  -1.0540381576362010E-01,  -1.0540381576362010E-01,   1.5261941850400176E-03],
            [   1.3355777977662109E-01,   1.3355777977662109E-01,   9.8200032531678882E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,   1.3355777977662109E-01,   9.8200032531678882E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,  -1.3355777977662109E-01,   9.8200032531678882E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,   1.3355777977662109E-01,  -9.8200032531678882E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,  -1.3355777977662109E-01,   9.8200032531678882E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,   1.3355777977662109E-01,  -9.8200032531678882E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,  -1.3355777977662109E-01,  -9.8200032531678882E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,  -1.3355777977662109E-01,  -9.8200032531678882E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,   9.8200032531678882E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,  -9.8200032531678882E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,   9.8200032531678882E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,  -9.8200032531678882E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,   9.8200032531678882E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,  -9.8200032531678882E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -1.3355777977662109E-01,  -9.8200032531678882E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [   1.3355777977662109E-01,   9.8200032531678882E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [   9.8200032531678882E-01,   1.3355777977662109E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -9.8200032531678882E-01,   1.3355777977662109E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [   9.8200032531678882E-01,  -1.3355777977662109E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [   9.8200032531678882E-01,   1.3355777977662109E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -9.8200032531678882E-01,  -1.3355777977662109E-01,   1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -9.8200032531678882E-01,   1.3355777977662109E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [   9.8200032531678882E-01,  -1.3355777977662109E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [  -9.8200032531678882E-01,  -1.3355777977662109E-01,  -1.3355777977662109E-01,   1.6814491031777561E-03],
            [   1.6257699555022520E-01,   1.6257699555022520E-01,   9.7320986484710692E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,   1.6257699555022520E-01,   9.7320986484710692E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,  -1.6257699555022520E-01,   9.7320986484710692E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,   1.6257699555022520E-01,  -9.7320986484710692E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,  -1.6257699555022520E-01,   9.7320986484710692E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,   1.6257699555022520E-01,  -9.7320986484710692E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,  -1.6257699555022520E-01,  -9.7320986484710692E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,  -1.6257699555022520E-01,  -9.7320986484710692E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,   9.7320986484710692E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,  -9.7320986484710692E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,   9.7320986484710692E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,  -9.7320986484710692E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,   9.7320986484710692E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,  -9.7320986484710692E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -1.6257699555022520E-01,  -9.7320986484710692E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [   1.6257699555022520E-01,   9.7320986484710692E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [   9.7320986484710692E-01,   1.6257699555022520E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -9.7320986484710692E-01,   1.6257699555022520E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [   9.7320986484710692E-01,  -1.6257699555022520E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [   9.7320986484710692E-01,   1.6257699555022520E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -9.7320986484710692E-01,  -1.6257699555022520E-01,   1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -9.7320986484710692E-01,   1.6257699555022520E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [   9.7320986484710692E-01,  -1.6257699555022520E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [  -9.7320986484710692E-01,  -1.6257699555022520E-01,  -1.6257699555022520E-01,   1.8116647785122026E-03],
            [   1.9217871934127920E-01,   1.9217871934127920E-01,   9.6235891416076758E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,   1.9217871934127920E-01,   9.6235891416076758E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,  -1.9217871934127920E-01,   9.6235891416076758E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,   1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,  -1.9217871934127920E-01,   9.6235891416076758E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,   1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,  -1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,  -1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,   9.6235891416076758E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,   9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,  -9.6235891416076758E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,   9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,  -9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -1.9217871934127920E-01,  -9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [   1.9217871934127920E-01,   9.6235891416076758E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [   9.6235891416076758E-01,   1.9217871934127920E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -9.6235891416076758E-01,   1.9217871934127920E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [   9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [   9.6235891416076758E-01,   1.9217871934127920E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -9.6235891416076758E-01,  -1.9217871934127920E-01,   1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -9.6235891416076758E-01,   1.9217871934127920E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [   9.6235891416076758E-01,  -1.9217871934127920E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [  -9.6235891416076758E-01,  -1.9217871934127920E-01,  -1.9217871934127920E-01,   1.9212475228542396E-03],
            [   2.2213405346905479E-01,   2.2213405346905479E-01,   9.4937501788219292E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,   2.2213405346905479E-01,   9.4937501788219292E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,  -2.2213405346905479E-01,   9.4937501788219292E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,   2.2213405346905479E-01,  -9.4937501788219292E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,  -2.2213405346905479E-01,   9.4937501788219292E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,   2.2213405346905479E-01,  -9.4937501788219292E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,  -2.2213405346905479E-01,  -9.4937501788219292E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,  -2.2213405346905479E-01,  -9.4937501788219292E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,   9.4937501788219292E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,  -9.4937501788219292E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,   9.4937501788219292E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,  -9.4937501788219292E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,   9.4937501788219292E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,  -9.4937501788219292E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -2.2213405346905479E-01,  -9.4937501788219292E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [   2.2213405346905479E-01,   9.4937501788219292E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [   9.4937501788219292E-01,   2.2213405346905479E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -9.4937501788219292E-01,   2.2213405346905479E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [   9.4937501788219292E-01,  -2.2213405346905479E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [   9.4937501788219292E-01,   2.2213405346905479E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -9.4937501788219292E-01,  -2.2213405346905479E-01,   2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -9.4937501788219292E-01,   2.2213405346905479E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [   9.4937501788219292E-01,  -2.2213405346905479E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [  -9.4937501788219292E-01,  -2.2213405346905479E-01,  -2.2213405346905479E-01,   2.0135480465076484E-03],
            [   2.5225049127911320E-01,   2.5225049127911320E-01,   9.3420521262669687E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,   2.5225049127911320E-01,   9.3420521262669687E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,  -2.5225049127911320E-01,   9.3420521262669687E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,   2.5225049127911320E-01,  -9.3420521262669687E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,  -2.5225049127911320E-01,   9.3420521262669687E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,   2.5225049127911320E-01,  -9.3420521262669687E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,  -2.5225049127911320E-01,  -9.3420521262669687E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,  -2.5225049127911320E-01,  -9.3420521262669687E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,   9.3420521262669687E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,  -9.3420521262669687E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,   9.3420521262669687E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,  -9.3420521262669687E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,   9.3420521262669687E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,  -9.3420521262669687E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -2.5225049127911320E-01,  -9.3420521262669687E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [   2.5225049127911320E-01,   9.3420521262669687E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [   9.3420521262669687E-01,   2.5225049127911320E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -9.3420521262669687E-01,   2.5225049127911320E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [   9.3420521262669687E-01,  -2.5225049127911320E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [   9.3420521262669687E-01,   2.5225049127911320E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -9.3420521262669687E-01,  -2.5225049127911320E-01,   2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -9.3420521262669687E-01,   2.5225049127911320E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [   9.3420521262669687E-01,  -2.5225049127911320E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [  -9.3420521262669687E-01,  -2.5225049127911320E-01,  -2.5225049127911320E-01,   2.0911730683531439E-03],
            [   2.8236108606796972E-01,   2.8236108606796972E-01,   9.1681210405896862E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,   2.8236108606796972E-01,   9.1681210405896862E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,  -2.8236108606796972E-01,   9.1681210405896862E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,   2.8236108606796972E-01,  -9.1681210405896862E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,  -2.8236108606796972E-01,   9.1681210405896862E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,   2.8236108606796972E-01,  -9.1681210405896862E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,  -2.8236108606796972E-01,  -9.1681210405896862E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,  -2.8236108606796972E-01,  -9.1681210405896862E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,   9.1681210405896862E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,  -9.1681210405896862E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,   9.1681210405896862E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,  -9.1681210405896862E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,   9.1681210405896862E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,  -9.1681210405896862E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -2.8236108606796972E-01,  -9.1681210405896862E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [   2.8236108606796972E-01,   9.1681210405896862E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [   9.1681210405896862E-01,   2.8236108606796972E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -9.1681210405896862E-01,   2.8236108606796972E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [   9.1681210405896862E-01,  -2.8236108606796972E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [   9.1681210405896862E-01,   2.8236108606796972E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -9.1681210405896862E-01,  -2.8236108606796972E-01,   2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -9.1681210405896862E-01,   2.8236108606796972E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [   9.1681210405896862E-01,  -2.8236108606796972E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [  -9.1681210405896862E-01,  -2.8236108606796972E-01,  -2.8236108606796972E-01,   2.1561954918617905E-03],
            [   3.1231739662675601E-01,   3.1231739662675601E-01,   8.9717093551260962E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,   3.1231739662675601E-01,   8.9717093551260962E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,  -3.1231739662675601E-01,   8.9717093551260962E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,   3.1231739662675601E-01,  -8.9717093551260962E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,  -3.1231739662675601E-01,   8.9717093551260962E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,   3.1231739662675601E-01,  -8.9717093551260962E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,  -3.1231739662675601E-01,  -8.9717093551260962E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,  -3.1231739662675601E-01,  -8.9717093551260962E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,   8.9717093551260962E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,  -8.9717093551260962E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,   8.9717093551260962E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,  -8.9717093551260962E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,   8.9717093551260962E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,  -8.9717093551260962E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -3.1231739662675601E-01,  -8.9717093551260962E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [   3.1231739662675601E-01,   8.9717093551260962E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [   8.9717093551260962E-01,   3.1231739662675601E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -8.9717093551260962E-01,   3.1231739662675601E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [   8.9717093551260962E-01,  -3.1231739662675601E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [   8.9717093551260962E-01,   3.1231739662675601E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -8.9717093551260962E-01,  -3.1231739662675601E-01,   3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -8.9717093551260962E-01,   3.1231739662675601E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [   8.9717093551260962E-01,  -3.1231739662675601E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [  -8.9717093551260962E-01,  -3.1231739662675601E-01,  -3.1231739662675601E-01,   2.2103001841639160E-03],
            [   3.4198470369537892E-01,   3.4198470369537892E-01,   8.7526734480201407E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,   3.4198470369537892E-01,   8.7526734480201407E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,  -3.4198470369537892E-01,   8.7526734480201407E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,   3.4198470369537892E-01,  -8.7526734480201407E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,  -3.4198470369537892E-01,   8.7526734480201407E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,   3.4198470369537892E-01,  -8.7526734480201407E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,  -3.4198470369537892E-01,  -8.7526734480201407E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,  -3.4198470369537892E-01,  -8.7526734480201407E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,   8.7526734480201407E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,  -8.7526734480201407E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,   8.7526734480201407E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,  -8.7526734480201407E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,   8.7526734480201407E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,  -8.7526734480201407E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -3.4198470369537892E-01,  -8.7526734480201407E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [   3.4198470369537892E-01,   8.7526734480201407E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [   8.7526734480201407E-01,   3.4198470369537892E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -8.7526734480201407E-01,   3.4198470369537892E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [   8.7526734480201407E-01,  -3.4198470369537892E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [   8.7526734480201407E-01,   3.4198470369537892E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -8.7526734480201407E-01,  -3.4198470369537892E-01,   3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -8.7526734480201407E-01,   3.4198470369537892E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [   8.7526734480201407E-01,  -3.4198470369537892E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [  -8.7526734480201407E-01,  -3.4198470369537892E-01,  -3.4198470369537892E-01,   2.2548875333651026E-03],
            [   3.7123864569997578E-01,   3.7123864569997578E-01,   8.5109560912843141E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,   3.7123864569997578E-01,   8.5109560912843141E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,  -3.7123864569997578E-01,   8.5109560912843141E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,   3.7123864569997578E-01,  -8.5109560912843141E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,  -3.7123864569997578E-01,   8.5109560912843141E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,   3.7123864569997578E-01,  -8.5109560912843141E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,  -3.7123864569997578E-01,  -8.5109560912843141E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,  -3.7123864569997578E-01,  -8.5109560912843141E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,   8.5109560912843141E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,  -8.5109560912843141E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,   8.5109560912843141E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,  -8.5109560912843141E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,   8.5109560912843141E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,  -8.5109560912843141E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -3.7123864569997578E-01,  -8.5109560912843141E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [   3.7123864569997578E-01,   8.5109560912843141E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [   8.5109560912843141E-01,   3.7123864569997578E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -8.5109560912843141E-01,   3.7123864569997578E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [   8.5109560912843141E-01,  -3.7123864569997578E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [   8.5109560912843141E-01,   3.7123864569997578E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -8.5109560912843141E-01,  -3.7123864569997578E-01,   3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -8.5109560912843141E-01,   3.7123864569997578E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [   8.5109560912843141E-01,  -3.7123864569997578E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [  -8.5109560912843141E-01,  -3.7123864569997578E-01,  -3.7123864569997578E-01,   2.2911485767736130E-03],
            [   3.9996276498768280E-01,   3.9996276498768280E-01,   8.2465724591906386E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,   3.9996276498768280E-01,   8.2465724591906386E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,  -3.9996276498768280E-01,   8.2465724591906386E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,   3.9996276498768280E-01,  -8.2465724591906386E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,  -3.9996276498768280E-01,   8.2465724591906386E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,   3.9996276498768280E-01,  -8.2465724591906386E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,  -3.9996276498768280E-01,  -8.2465724591906386E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,  -3.9996276498768280E-01,  -8.2465724591906386E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,   8.2465724591906386E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,  -8.2465724591906386E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,   8.2465724591906386E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,  -8.2465724591906386E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,   8.2465724591906386E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,  -8.2465724591906386E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -3.9996276498768280E-01,  -8.2465724591906386E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [   3.9996276498768280E-01,   8.2465724591906386E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [   8.2465724591906386E-01,   3.9996276498768280E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -8.2465724591906386E-01,   3.9996276498768280E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [   8.2465724591906386E-01,  -3.9996276498768280E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [   8.2465724591906386E-01,   3.9996276498768280E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -8.2465724591906386E-01,  -3.9996276498768280E-01,   3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -8.2465724591906386E-01,   3.9996276498768280E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [   8.2465724591906386E-01,  -3.9996276498768280E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [  -8.2465724591906386E-01,  -3.9996276498768280E-01,  -3.9996276498768280E-01,   2.3201205279485848E-03],
            [   4.2804664586480928E-01,   4.2804664586480928E-01,   7.9595988462219192E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,   4.2804664586480928E-01,   7.9595988462219192E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,  -4.2804664586480928E-01,   7.9595988462219192E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,   4.2804664586480928E-01,  -7.9595988462219192E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,  -4.2804664586480928E-01,   7.9595988462219192E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,   4.2804664586480928E-01,  -7.9595988462219192E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,  -4.2804664586480928E-01,  -7.9595988462219192E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,  -4.2804664586480928E-01,  -7.9595988462219192E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,   7.9595988462219192E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,  -7.9595988462219192E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,   7.9595988462219192E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,  -7.9595988462219192E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,   7.9595988462219192E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,  -7.9595988462219192E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -4.2804664586480928E-01,  -7.9595988462219192E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [   4.2804664586480928E-01,   7.9595988462219192E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [   7.9595988462219192E-01,   4.2804664586480928E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -7.9595988462219192E-01,   4.2804664586480928E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [   7.9595988462219192E-01,  -4.2804664586480928E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [   7.9595988462219192E-01,   4.2804664586480928E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -7.9595988462219192E-01,  -4.2804664586480928E-01,   4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -7.9595988462219192E-01,   4.2804664586480928E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [   7.9595988462219192E-01,  -4.2804664586480928E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [  -7.9595988462219192E-01,  -4.2804664586480928E-01,  -4.2804664586480928E-01,   2.3427284671223422E-03],
            [   4.5538443601857109E-01,   4.5538443601857109E-01,   7.6501635986696115E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,   4.5538443601857109E-01,   7.6501635986696115E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,  -4.5538443601857109E-01,   7.6501635986696115E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,   4.5538443601857109E-01,  -7.6501635986696115E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,  -4.5538443601857109E-01,   7.6501635986696115E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,   4.5538443601857109E-01,  -7.6501635986696115E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,  -4.5538443601857109E-01,  -7.6501635986696115E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,  -4.5538443601857109E-01,  -7.6501635986696115E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,   7.6501635986696115E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,  -7.6501635986696115E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,   7.6501635986696115E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,  -7.6501635986696115E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,   7.6501635986696115E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,  -7.6501635986696115E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -4.5538443601857109E-01,  -7.6501635986696115E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [   4.5538443601857109E-01,   7.6501635986696115E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [   7.6501635986696115E-01,   4.5538443601857109E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -7.6501635986696115E-01,   4.5538443601857109E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [   7.6501635986696115E-01,  -4.5538443601857109E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [   7.6501635986696115E-01,   4.5538443601857109E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -7.6501635986696115E-01,  -4.5538443601857109E-01,   4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -7.6501635986696115E-01,   4.5538443601857109E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [   7.6501635986696115E-01,  -4.5538443601857109E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [  -7.6501635986696115E-01,  -4.5538443601857109E-01,  -4.5538443601857109E-01,   2.3598169910973273E-03],
            [   4.8187360944378338E-01,   4.8187360944378338E-01,   7.3184400594883625E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,   4.8187360944378338E-01,   7.3184400594883625E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,  -4.8187360944378338E-01,   7.3184400594883625E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,   4.8187360944378338E-01,  -7.3184400594883625E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,  -4.8187360944378338E-01,   7.3184400594883625E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,   4.8187360944378338E-01,  -7.3184400594883625E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,  -4.8187360944378338E-01,  -7.3184400594883625E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,  -4.8187360944378338E-01,  -7.3184400594883625E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,   7.3184400594883625E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,  -7.3184400594883625E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,   7.3184400594883625E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,  -7.3184400594883625E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,   7.3184400594883625E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,  -7.3184400594883625E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -4.8187360944378338E-01,  -7.3184400594883625E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [   4.8187360944378338E-01,   7.3184400594883625E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [   7.3184400594883625E-01,   4.8187360944378338E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -7.3184400594883625E-01,   4.8187360944378338E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [   7.3184400594883625E-01,  -4.8187360944378338E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [   7.3184400594883625E-01,   4.8187360944378338E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -7.3184400594883625E-01,  -4.8187360944378338E-01,   4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -7.3184400594883625E-01,   4.8187360944378338E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [   7.3184400594883625E-01,  -4.8187360944378338E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [  -7.3184400594883625E-01,  -4.8187360944378338E-01,  -4.8187360944378338E-01,   2.3721742915167468E-03],
            [   5.0741387092606294E-01,   5.0741387092606294E-01,   6.9646416073166140E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,   5.0741387092606294E-01,   6.9646416073166140E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,  -5.0741387092606294E-01,   6.9646416073166140E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,   5.0741387092606294E-01,  -6.9646416073166140E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,  -5.0741387092606294E-01,   6.9646416073166140E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,   5.0741387092606294E-01,  -6.9646416073166140E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,  -5.0741387092606294E-01,  -6.9646416073166140E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,  -5.0741387092606294E-01,  -6.9646416073166140E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,   6.9646416073166140E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,  -6.9646416073166140E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,   6.9646416073166140E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,  -6.9646416073166140E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,   6.9646416073166140E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,  -6.9646416073166140E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -5.0741387092606294E-01,  -6.9646416073166140E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [   5.0741387092606294E-01,   6.9646416073166140E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [   6.9646416073166140E-01,   5.0741387092606294E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -6.9646416073166140E-01,   5.0741387092606294E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [   6.9646416073166140E-01,  -5.0741387092606294E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [   6.9646416073166140E-01,   5.0741387092606294E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -6.9646416073166140E-01,  -5.0741387092606294E-01,   5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -6.9646416073166140E-01,   5.0741387092606294E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [   6.9646416073166140E-01,  -5.0741387092606294E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [  -6.9646416073166140E-01,  -5.0741387092606294E-01,  -5.0741387092606294E-01,   2.3805501750352367E-03],
            [   5.3190613045707069E-01,   5.3190613045707069E-01,   6.5890191740832815E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,   5.3190613045707069E-01,   6.5890191740832815E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,  -5.3190613045707069E-01,   6.5890191740832815E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,   5.3190613045707069E-01,  -6.5890191740832815E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,  -5.3190613045707069E-01,   6.5890191740832815E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,   5.3190613045707069E-01,  -6.5890191740832815E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,  -5.3190613045707069E-01,  -6.5890191740832815E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,  -5.3190613045707069E-01,  -6.5890191740832815E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,   6.5890191740832815E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,  -6.5890191740832815E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,   6.5890191740832815E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,  -6.5890191740832815E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,   6.5890191740832815E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,  -6.5890191740832815E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -5.3190613045707069E-01,  -6.5890191740832815E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [   5.3190613045707069E-01,   6.5890191740832815E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [   6.5890191740832815E-01,   5.3190613045707069E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -6.5890191740832815E-01,   5.3190613045707069E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [   6.5890191740832815E-01,  -5.3190613045707069E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [   6.5890191740832815E-01,   5.3190613045707069E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -6.5890191740832815E-01,  -5.3190613045707069E-01,   5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -6.5890191740832815E-01,   5.3190613045707069E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [   6.5890191740832815E-01,  -5.3190613045707069E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [  -6.5890191740832815E-01,  -5.3190613045707069E-01,  -5.3190613045707069E-01,   2.3856687862185591E-03],
            [   5.5525149786772865E-01,   5.5525149786772865E-01,   6.1918619835336075E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,   5.5525149786772865E-01,   6.1918619835336075E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,  -5.5525149786772865E-01,   6.1918619835336075E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,   5.5525149786772865E-01,  -6.1918619835336075E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,  -5.5525149786772865E-01,   6.1918619835336075E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,   5.5525149786772865E-01,  -6.1918619835336075E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,  -5.5525149786772865E-01,  -6.1918619835336075E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,  -5.5525149786772865E-01,  -6.1918619835336075E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,   6.1918619835336075E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,  -6.1918619835336075E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,   6.1918619835336075E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,  -6.1918619835336075E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,   6.1918619835336075E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,  -6.1918619835336075E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -5.5525149786772865E-01,  -6.1918619835336075E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [   5.5525149786772865E-01,   6.1918619835336075E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [   6.1918619835336075E-01,   5.5525149786772865E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -6.1918619835336075E-01,   5.5525149786772865E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [   6.1918619835336075E-01,  -5.5525149786772865E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [   6.1918619835336075E-01,   5.5525149786772865E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -6.1918619835336075E-01,  -5.5525149786772865E-01,   5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -6.1918619835336075E-01,   5.5525149786772865E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [   6.1918619835336075E-01,  -5.5525149786772865E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [  -6.1918619835336075E-01,  -5.5525149786772865E-01,  -5.5525149786772865E-01,   2.3882361334897099E-03],
            [   5.9810090252461834E-01,   5.9810090252461834E-01,   5.3343286437795889E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,   5.9810090252461834E-01,   5.3343286437795889E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,  -5.9810090252461834E-01,   5.3343286437795889E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,   5.9810090252461834E-01,  -5.3343286437795889E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,  -5.9810090252461834E-01,   5.3343286437795889E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,   5.9810090252461834E-01,  -5.3343286437795889E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,  -5.9810090252461834E-01,  -5.3343286437795889E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,  -5.9810090252461834E-01,  -5.3343286437795889E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,   5.3343286437795889E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,  -5.3343286437795889E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,   5.3343286437795889E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,  -5.3343286437795889E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,   5.3343286437795889E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,  -5.3343286437795889E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.9810090252461834E-01,  -5.3343286437795889E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.9810090252461834E-01,   5.3343286437795889E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.3343286437795889E-01,   5.9810090252461834E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.3343286437795889E-01,   5.9810090252461834E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.3343286437795889E-01,  -5.9810090252461834E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.3343286437795889E-01,   5.9810090252461834E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.3343286437795889E-01,  -5.9810090252461834E-01,   5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.3343286437795889E-01,   5.9810090252461834E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [   5.3343286437795889E-01,  -5.9810090252461834E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [  -5.3343286437795889E-01,  -5.9810090252461834E-01,  -5.9810090252461834E-01,   2.3884542509328820E-03],
            [   6.1739901922281160E-01,   6.1739901922281160E-01,   4.8748015562217573E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,   6.1739901922281160E-01,   4.8748015562217573E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,  -6.1739901922281160E-01,   4.8748015562217573E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,   6.1739901922281160E-01,  -4.8748015562217573E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,  -6.1739901922281160E-01,   4.8748015562217573E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,   6.1739901922281160E-01,  -4.8748015562217573E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,  -6.1739901922281160E-01,  -4.8748015562217573E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,  -6.1739901922281160E-01,  -4.8748015562217573E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,   4.8748015562217573E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,  -4.8748015562217573E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,   4.8748015562217573E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,  -4.8748015562217573E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,   4.8748015562217573E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,  -4.8748015562217573E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -6.1739901922281160E-01,  -4.8748015562217573E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [   6.1739901922281160E-01,   4.8748015562217573E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [   4.8748015562217573E-01,   6.1739901922281160E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -4.8748015562217573E-01,   6.1739901922281160E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [   4.8748015562217573E-01,  -6.1739901922281160E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [   4.8748015562217573E-01,   6.1739901922281160E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -4.8748015562217573E-01,  -6.1739901922281160E-01,   6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -4.8748015562217573E-01,   6.1739901922281160E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [   4.8748015562217573E-01,  -6.1739901922281160E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [  -4.8748015562217573E-01,  -6.1739901922281160E-01,  -6.1739901922281160E-01,   2.3874062829912263E-03],
            [   6.3513652394111308E-01,   6.3513652394111308E-01,   4.3954885042734415E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,   6.3513652394111308E-01,   4.3954885042734415E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,  -6.3513652394111308E-01,   4.3954885042734415E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,   6.3513652394111308E-01,  -4.3954885042734415E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,  -6.3513652394111308E-01,   4.3954885042734415E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,   6.3513652394111308E-01,  -4.3954885042734415E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,  -6.3513652394111308E-01,  -4.3954885042734415E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,  -6.3513652394111308E-01,  -4.3954885042734415E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,   4.3954885042734415E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,  -4.3954885042734415E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,   4.3954885042734415E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,  -4.3954885042734415E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,   4.3954885042734415E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,  -4.3954885042734415E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -6.3513652394111308E-01,  -4.3954885042734415E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [   6.3513652394111308E-01,   4.3954885042734415E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [   4.3954885042734415E-01,   6.3513652394111308E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -4.3954885042734415E-01,   6.3513652394111308E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [   4.3954885042734415E-01,  -6.3513652394111308E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [   4.3954885042734415E-01,   6.3513652394111308E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -4.3954885042734415E-01,  -6.3513652394111308E-01,   6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -4.3954885042734415E-01,   6.3513652394111308E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [   4.3954885042734415E-01,  -6.3513652394111308E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [  -4.3954885042734415E-01,  -6.3513652394111308E-01,  -6.3513652394111308E-01,   2.3863715147819779E-03],
            [   6.5120102282271997E-01,   6.5120102282271997E-01,   3.8971073342838108E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,   6.5120102282271997E-01,   3.8971073342838108E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,  -6.5120102282271997E-01,   3.8971073342838108E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,   6.5120102282271997E-01,  -3.8971073342838108E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,  -6.5120102282271997E-01,   3.8971073342838108E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,   6.5120102282271997E-01,  -3.8971073342838108E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,  -6.5120102282271997E-01,  -3.8971073342838108E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,  -6.5120102282271997E-01,  -3.8971073342838108E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,   3.8971073342838108E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,  -3.8971073342838108E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,   3.8971073342838108E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,  -3.8971073342838108E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,   3.8971073342838108E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,  -3.8971073342838108E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -6.5120102282271997E-01,  -3.8971073342838108E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [   6.5120102282271997E-01,   3.8971073342838108E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [   3.8971073342838108E-01,   6.5120102282271997E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -3.8971073342838108E-01,   6.5120102282271997E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [   3.8971073342838108E-01,  -6.5120102282271997E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [   3.8971073342838108E-01,   6.5120102282271997E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -3.8971073342838108E-01,  -6.5120102282271997E-01,   6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -3.8971073342838108E-01,   6.5120102282271997E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [   3.8971073342838108E-01,  -6.5120102282271997E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [  -3.8971073342838108E-01,  -6.5120102282271997E-01,  -6.5120102282271997E-01,   2.3858275725798521E-03],
            [   6.6547583639481200E-01,   6.6547583639481200E-01,   3.3805890366806024E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,   6.6547583639481200E-01,   3.3805890366806024E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,  -6.6547583639481200E-01,   3.3805890366806024E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,   6.6547583639481200E-01,  -3.3805890366806024E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,  -6.6547583639481200E-01,   3.3805890366806024E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,   6.6547583639481200E-01,  -3.3805890366806024E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,  -6.6547583639481200E-01,  -3.3805890366806024E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,  -6.6547583639481200E-01,  -3.3805890366806024E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,   3.3805890366806024E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,  -3.3805890366806024E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,   3.3805890366806024E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,  -3.3805890366806024E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,   3.3805890366806024E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,  -3.3805890366806024E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -6.6547583639481200E-01,  -3.3805890366806024E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [   6.6547583639481200E-01,   3.3805890366806024E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [   3.3805890366806024E-01,   6.6547583639481200E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -3.3805890366806024E-01,   6.6547583639481200E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [   3.3805890366806024E-01,  -6.6547583639481200E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [   3.3805890366806024E-01,   6.6547583639481200E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -3.3805890366806024E-01,  -6.6547583639481200E-01,   6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -3.3805890366806024E-01,   6.6547583639481200E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [   3.3805890366806024E-01,  -6.6547583639481200E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [  -3.3805890366806024E-01,  -6.6547583639481200E-01,  -6.6547583639481200E-01,   2.3861084289407103E-03],
            [   6.7784104148533697E-01,   6.7784104148533697E-01,   2.8471572656976180E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,   6.7784104148533697E-01,   2.8471572656976180E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,  -6.7784104148533697E-01,   2.8471572656976180E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,   6.7784104148533697E-01,  -2.8471572656976180E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,  -6.7784104148533697E-01,   2.8471572656976180E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,   6.7784104148533697E-01,  -2.8471572656976180E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,  -6.7784104148533697E-01,  -2.8471572656976180E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,  -6.7784104148533697E-01,  -2.8471572656976180E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,   2.8471572656976180E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,  -2.8471572656976180E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,   2.8471572656976180E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,  -2.8471572656976180E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,   2.8471572656976180E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,  -2.8471572656976180E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -6.7784104148533697E-01,  -2.8471572656976180E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [   6.7784104148533697E-01,   2.8471572656976180E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [   2.8471572656976180E-01,   6.7784104148533697E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -2.8471572656976180E-01,   6.7784104148533697E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [   2.8471572656976180E-01,  -6.7784104148533697E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [   2.8471572656976180E-01,   6.7784104148533697E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -2.8471572656976180E-01,  -6.7784104148533697E-01,   6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -2.8471572656976180E-01,   6.7784104148533697E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [   2.8471572656976180E-01,  -6.7784104148533697E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [  -2.8471572656976180E-01,  -6.7784104148533697E-01,  -6.7784104148533697E-01,   2.3873510599409656E-03],
            [   6.8817608874841096E-01,   6.8817608874841096E-01,   2.2984199300797570E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,   6.8817608874841096E-01,   2.2984199300797570E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,  -6.8817608874841096E-01,   2.2984199300797570E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,   6.8817608874841096E-01,  -2.2984199300797570E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,  -6.8817608874841096E-01,   2.2984199300797570E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,   6.8817608874841096E-01,  -2.2984199300797570E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,  -6.8817608874841096E-01,  -2.2984199300797570E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,  -6.8817608874841096E-01,  -2.2984199300797570E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,   2.2984199300797570E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,  -2.2984199300797570E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,   2.2984199300797570E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,  -2.2984199300797570E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,   2.2984199300797570E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,  -2.2984199300797570E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -6.8817608874841096E-01,  -2.2984199300797570E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [   6.8817608874841096E-01,   2.2984199300797570E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [   2.2984199300797570E-01,   6.8817608874841096E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -2.2984199300797570E-01,   6.8817608874841096E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [   2.2984199300797570E-01,  -6.8817608874841096E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [   2.2984199300797570E-01,   6.8817608874841096E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -2.2984199300797570E-01,  -6.8817608874841096E-01,   6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -2.2984199300797570E-01,   6.8817608874841096E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [   2.2984199300797570E-01,  -6.8817608874841096E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [  -2.2984199300797570E-01,  -6.8817608874841096E-01,  -6.8817608874841096E-01,   2.3894508306238657E-03],
            [   6.9636452670945981E-01,   6.9636452670945981E-01,   1.7364588069234502E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,   6.9636452670945981E-01,   1.7364588069234502E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,  -6.9636452670945981E-01,   1.7364588069234502E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,   6.9636452670945981E-01,  -1.7364588069234502E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,  -6.9636452670945981E-01,   1.7364588069234502E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,   6.9636452670945981E-01,  -1.7364588069234502E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,  -6.9636452670945981E-01,  -1.7364588069234502E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,  -6.9636452670945981E-01,  -1.7364588069234502E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,   1.7364588069234502E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,  -1.7364588069234502E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,   1.7364588069234502E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,  -1.7364588069234502E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,   1.7364588069234502E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,  -1.7364588069234502E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -6.9636452670945981E-01,  -1.7364588069234502E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [   6.9636452670945981E-01,   1.7364588069234502E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [   1.7364588069234502E-01,   6.9636452670945981E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -1.7364588069234502E-01,   6.9636452670945981E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [   1.7364588069234502E-01,  -6.9636452670945981E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [   1.7364588069234502E-01,   6.9636452670945981E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -1.7364588069234502E-01,  -6.9636452670945981E-01,   6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -1.7364588069234502E-01,   6.9636452670945981E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [   1.7364588069234502E-01,  -6.9636452670945981E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [  -1.7364588069234502E-01,  -6.9636452670945981E-01,  -6.9636452670945981E-01,   2.3920504249251629E-03],
            [   7.0230106171535789E-01,   7.0230106171535789E-01,   1.1638916370075933E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,   7.0230106171535789E-01,   1.1638916370075933E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,  -7.0230106171535789E-01,   1.1638916370075933E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,   7.0230106171535789E-01,  -1.1638916370075933E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,  -7.0230106171535789E-01,   1.1638916370075933E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,   7.0230106171535789E-01,  -1.1638916370075933E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,  -7.0230106171535789E-01,  -1.1638916370075933E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,  -7.0230106171535789E-01,  -1.1638916370075933E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,   1.1638916370075933E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,  -1.1638916370075933E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,   1.1638916370075933E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,  -1.1638916370075933E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,   1.1638916370075933E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,  -1.1638916370075933E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -7.0230106171535789E-01,  -1.1638916370075933E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [   7.0230106171535789E-01,   1.1638916370075933E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [   1.1638916370075933E-01,   7.0230106171535789E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -1.1638916370075933E-01,   7.0230106171535789E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [   1.1638916370075933E-01,  -7.0230106171535789E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [   1.1638916370075933E-01,   7.0230106171535789E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -1.1638916370075933E-01,  -7.0230106171535789E-01,   7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -1.1638916370075933E-01,   7.0230106171535789E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [   1.1638916370075933E-01,  -7.0230106171535789E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [  -1.1638916370075933E-01,  -7.0230106171535789E-01,  -7.0230106171535789E-01,   2.3945924913723457E-03],
            [   7.0590046366287529E-01,   7.0590046366287529E-01,   5.8387248617102441E-02,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,   7.0590046366287529E-01,   5.8387248617102441E-02,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,  -7.0590046366287529E-01,   5.8387248617102441E-02,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,   7.0590046366287529E-01,  -5.8387248617102441E-02,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,  -7.0590046366287529E-01,   5.8387248617102441E-02,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,   7.0590046366287529E-01,  -5.8387248617102441E-02,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,  -7.0590046366287529E-01,  -5.8387248617102441E-02,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,  -7.0590046366287529E-01,  -5.8387248617102441E-02,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,   5.8387248617102441E-02,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,  -5.8387248617102441E-02,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,   5.8387248617102441E-02,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,  -5.8387248617102441E-02,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,   5.8387248617102441E-02,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,  -5.8387248617102441E-02,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -7.0590046366287529E-01,  -5.8387248617102441E-02,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [   7.0590046366287529E-01,   5.8387248617102441E-02,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [   5.8387248617102441E-02,   7.0590046366287529E-01,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -5.8387248617102441E-02,   7.0590046366287529E-01,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [   5.8387248617102441E-02,  -7.0590046366287529E-01,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [   5.8387248617102441E-02,   7.0590046366287529E-01,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -5.8387248617102441E-02,  -7.0590046366287529E-01,   7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -5.8387248617102441E-02,   7.0590046366287529E-01,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [   5.8387248617102441E-02,  -7.0590046366287529E-01,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [  -5.8387248617102441E-02,  -7.0590046366287529E-01,  -7.0590046366287529E-01,   2.3964535673421257E-03],
            [   3.5524703124725748E-02,   9.9936879852629990E-01,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [  -3.5524703124725748E-02,   9.9936879852629990E-01,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [   3.5524703124725748E-02,  -9.9936879852629990E-01,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [  -3.5524703124725748E-02,  -9.9936879852629990E-01,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [   9.9936879852629990E-01,   3.5524703124725748E-02,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [  -9.9936879852629990E-01,   3.5524703124725748E-02,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [   9.9936879852629990E-01,  -3.5524703124725748E-02,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [  -9.9936879852629990E-01,  -3.5524703124725748E-02,   0.0000000000000000E+00,   7.5310232001900659E-04],
            [   3.5524703124725748E-02,   0.0000000000000000E+00,   9.9936879852629990E-01,   7.5310232001900659E-04],
            [  -3.5524703124725748E-02,   0.0000000000000000E+00,   9.9936879852629990E-01,   7.5310232001900659E-04],
            [   3.5524703124725748E-02,   0.0000000000000000E+00,  -9.9936879852629990E-01,   7.5310232001900659E-04],
            [  -3.5524703124725748E-02,   0.0000000000000000E+00,  -9.9936879852629990E-01,   7.5310232001900659E-04],
            [   9.9936879852629990E-01,   0.0000000000000000E+00,   3.5524703124725748E-02,   7.5310232001900659E-04],
            [  -9.9936879852629990E-01,   0.0000000000000000E+00,   3.5524703124725748E-02,   7.5310232001900659E-04],
            [   9.9936879852629990E-01,   0.0000000000000000E+00,  -3.5524703124725748E-02,   7.5310232001900659E-04],
            [  -9.9936879852629990E-01,   0.0000000000000000E+00,  -3.5524703124725748E-02,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,   3.5524703124725748E-02,   9.9936879852629990E-01,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,  -3.5524703124725748E-02,   9.9936879852629990E-01,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,   3.5524703124725748E-02,  -9.9936879852629990E-01,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,  -3.5524703124725748E-02,  -9.9936879852629990E-01,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,   9.9936879852629990E-01,   3.5524703124725748E-02,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,  -9.9936879852629990E-01,   3.5524703124725748E-02,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,   9.9936879852629990E-01,  -3.5524703124725748E-02,   7.5310232001900659E-04],
            [   0.0000000000000000E+00,  -9.9936879852629990E-01,  -3.5524703124725748E-02,   7.5310232001900659E-04],
            [   9.1511766208412837E-02,   9.9580399509412332E-01,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [  -9.1511766208412837E-02,   9.9580399509412332E-01,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [   9.1511766208412837E-02,  -9.9580399509412332E-01,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [  -9.1511766208412837E-02,  -9.9580399509412332E-01,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [   9.9580399509412332E-01,   9.1511766208412837E-02,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [  -9.9580399509412332E-01,   9.1511766208412837E-02,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [   9.9580399509412332E-01,  -9.1511766208412837E-02,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [  -9.9580399509412332E-01,  -9.1511766208412837E-02,   0.0000000000000000E+00,   1.2251029334134993E-03],
            [   9.1511766208412837E-02,   0.0000000000000000E+00,   9.9580399509412332E-01,   1.2251029334134993E-03],
            [  -9.1511766208412837E-02,   0.0000000000000000E+00,   9.9580399509412332E-01,   1.2251029334134993E-03],
            [   9.1511766208412837E-02,   0.0000000000000000E+00,  -9.9580399509412332E-01,   1.2251029334134993E-03],
            [  -9.1511766208412837E-02,   0.0000000000000000E+00,  -9.9580399509412332E-01,   1.2251029334134993E-03],
            [   9.9580399509412332E-01,   0.0000000000000000E+00,   9.1511766208412837E-02,   1.2251029334134993E-03],
            [  -9.9580399509412332E-01,   0.0000000000000000E+00,   9.1511766208412837E-02,   1.2251029334134993E-03],
            [   9.9580399509412332E-01,   0.0000000000000000E+00,  -9.1511766208412837E-02,   1.2251029334134993E-03],
            [  -9.9580399509412332E-01,   0.0000000000000000E+00,  -9.1511766208412837E-02,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,   9.1511766208412837E-02,   9.9580399509412332E-01,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,  -9.1511766208412837E-02,   9.9580399509412332E-01,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,   9.1511766208412837E-02,  -9.9580399509412332E-01,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,  -9.1511766208412837E-02,  -9.9580399509412332E-01,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,   9.9580399509412332E-01,   9.1511766208412837E-02,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,  -9.9580399509412332E-01,   9.1511766208412837E-02,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,   9.9580399509412332E-01,  -9.1511766208412837E-02,   1.2251029334134993E-03],
            [   0.0000000000000000E+00,  -9.9580399509412332E-01,  -9.1511766208412837E-02,   1.2251029334134993E-03],
            [   1.5661979300689799E-01,   9.8765896970486544E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [  -1.5661979300689799E-01,   9.8765896970486544E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [   1.5661979300689799E-01,  -9.8765896970486544E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [  -1.5661979300689799E-01,  -9.8765896970486544E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [   9.8765896970486544E-01,   1.5661979300689799E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [  -9.8765896970486544E-01,   1.5661979300689799E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [   9.8765896970486544E-01,  -1.5661979300689799E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [  -9.8765896970486544E-01,  -1.5661979300689799E-01,   0.0000000000000000E+00,   1.5603421175328712E-03],
            [   1.5661979300689799E-01,   0.0000000000000000E+00,   9.8765896970486544E-01,   1.5603421175328712E-03],
            [  -1.5661979300689799E-01,   0.0000000000000000E+00,   9.8765896970486544E-01,   1.5603421175328712E-03],
            [   1.5661979300689799E-01,   0.0000000000000000E+00,  -9.8765896970486544E-01,   1.5603421175328712E-03],
            [  -1.5661979300689799E-01,   0.0000000000000000E+00,  -9.8765896970486544E-01,   1.5603421175328712E-03],
            [   9.8765896970486544E-01,   0.0000000000000000E+00,   1.5661979300689799E-01,   1.5603421175328712E-03],
            [  -9.8765896970486544E-01,   0.0000000000000000E+00,   1.5661979300689799E-01,   1.5603421175328712E-03],
            [   9.8765896970486544E-01,   0.0000000000000000E+00,  -1.5661979300689799E-01,   1.5603421175328712E-03],
            [  -9.8765896970486544E-01,   0.0000000000000000E+00,  -1.5661979300689799E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,   1.5661979300689799E-01,   9.8765896970486544E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,  -1.5661979300689799E-01,   9.8765896970486544E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,   1.5661979300689799E-01,  -9.8765896970486544E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,  -1.5661979300689799E-01,  -9.8765896970486544E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,   9.8765896970486544E-01,   1.5661979300689799E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,  -9.8765896970486544E-01,   1.5661979300689799E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,   9.8765896970486544E-01,  -1.5661979300689799E-01,   1.5603421175328712E-03],
            [   0.0000000000000000E+00,  -9.8765896970486544E-01,  -1.5661979300689799E-01,   1.5603421175328712E-03],
            [   2.2654675992719070E-01,   9.7400029033183133E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [  -2.2654675992719070E-01,   9.7400029033183133E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [   2.2654675992719070E-01,  -9.7400029033183133E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [  -2.2654675992719070E-01,  -9.7400029033183133E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [   9.7400029033183133E-01,   2.2654675992719070E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [  -9.7400029033183133E-01,   2.2654675992719070E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [   9.7400029033183133E-01,  -2.2654675992719070E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [  -9.7400029033183133E-01,  -2.2654675992719070E-01,   0.0000000000000000E+00,   1.8065743059821665E-03],
            [   2.2654675992719070E-01,   0.0000000000000000E+00,   9.7400029033183133E-01,   1.8065743059821665E-03],
            [  -2.2654675992719070E-01,   0.0000000000000000E+00,   9.7400029033183133E-01,   1.8065743059821665E-03],
            [   2.2654675992719070E-01,   0.0000000000000000E+00,  -9.7400029033183133E-01,   1.8065743059821665E-03],
            [  -2.2654675992719070E-01,   0.0000000000000000E+00,  -9.7400029033183133E-01,   1.8065743059821665E-03],
            [   9.7400029033183133E-01,   0.0000000000000000E+00,   2.2654675992719070E-01,   1.8065743059821665E-03],
            [  -9.7400029033183133E-01,   0.0000000000000000E+00,   2.2654675992719070E-01,   1.8065743059821665E-03],
            [   9.7400029033183133E-01,   0.0000000000000000E+00,  -2.2654675992719070E-01,   1.8065743059821665E-03],
            [  -9.7400029033183133E-01,   0.0000000000000000E+00,  -2.2654675992719070E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,   2.2654675992719070E-01,   9.7400029033183133E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,  -2.2654675992719070E-01,   9.7400029033183133E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,   2.2654675992719070E-01,  -9.7400029033183133E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,  -2.2654675992719070E-01,  -9.7400029033183133E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,   9.7400029033183133E-01,   2.2654675992719070E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,  -9.7400029033183133E-01,   2.2654675992719070E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,   9.7400029033183133E-01,  -2.2654675992719070E-01,   1.8065743059821665E-03],
            [   0.0000000000000000E+00,  -9.7400029033183133E-01,  -2.2654675992719070E-01,   1.8065743059821665E-03],
            [   2.9882423185813611E-01,   9.5430816744613212E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [  -2.9882423185813611E-01,   9.5430816744613212E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [   2.9882423185813611E-01,  -9.5430816744613212E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [  -2.9882423185813611E-01,  -9.5430816744613212E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [   9.5430816744613212E-01,   2.9882423185813611E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [  -9.5430816744613212E-01,   2.9882423185813611E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [   9.5430816744613212E-01,  -2.9882423185813611E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [  -9.5430816744613212E-01,  -2.9882423185813611E-01,   0.0000000000000000E+00,   1.9907645015828281E-03],
            [   2.9882423185813611E-01,   0.0000000000000000E+00,   9.5430816744613212E-01,   1.9907645015828281E-03],
            [  -2.9882423185813611E-01,   0.0000000000000000E+00,   9.5430816744613212E-01,   1.9907645015828281E-03],
            [   2.9882423185813611E-01,   0.0000000000000000E+00,  -9.5430816744613212E-01,   1.9907645015828281E-03],
            [  -2.9882423185813611E-01,   0.0000000000000000E+00,  -9.5430816744613212E-01,   1.9907645015828281E-03],
            [   9.5430816744613212E-01,   0.0000000000000000E+00,   2.9882423185813611E-01,   1.9907645015828281E-03],
            [  -9.5430816744613212E-01,   0.0000000000000000E+00,   2.9882423185813611E-01,   1.9907645015828281E-03],
            [   9.5430816744613212E-01,   0.0000000000000000E+00,  -2.9882423185813611E-01,   1.9907645015828281E-03],
            [  -9.5430816744613212E-01,   0.0000000000000000E+00,  -2.9882423185813611E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,   2.9882423185813611E-01,   9.5430816744613212E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,  -2.9882423185813611E-01,   9.5430816744613212E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,   2.9882423185813611E-01,  -9.5430816744613212E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,  -2.9882423185813611E-01,  -9.5430816744613212E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,   9.5430816744613212E-01,   2.9882423185813611E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,  -9.5430816744613212E-01,   2.9882423185813611E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,   9.5430816744613212E-01,  -2.9882423185813611E-01,   1.9907645015828281E-03],
            [   0.0000000000000000E+00,  -9.5430816744613212E-01,  -2.9882423185813611E-01,   1.9907645015828281E-03],
            [   3.7174824197038858E-01,   9.2833358475923167E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [  -3.7174824197038858E-01,   9.2833358475923167E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [   3.7174824197038858E-01,  -9.2833358475923167E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [  -3.7174824197038858E-01,  -9.2833358475923167E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [   9.2833358475923167E-01,   3.7174824197038858E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [  -9.2833358475923167E-01,   3.7174824197038858E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [   9.2833358475923167E-01,  -3.7174824197038858E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [  -9.2833358475923167E-01,  -3.7174824197038858E-01,   0.0000000000000000E+00,   2.1292917682165661E-03],
            [   3.7174824197038858E-01,   0.0000000000000000E+00,   9.2833358475923167E-01,   2.1292917682165661E-03],
            [  -3.7174824197038858E-01,   0.0000000000000000E+00,   9.2833358475923167E-01,   2.1292917682165661E-03],
            [   3.7174824197038858E-01,   0.0000000000000000E+00,  -9.2833358475923167E-01,   2.1292917682165661E-03],
            [  -3.7174824197038858E-01,   0.0000000000000000E+00,  -9.2833358475923167E-01,   2.1292917682165661E-03],
            [   9.2833358475923167E-01,   0.0000000000000000E+00,   3.7174824197038858E-01,   2.1292917682165661E-03],
            [  -9.2833358475923167E-01,   0.0000000000000000E+00,   3.7174824197038858E-01,   2.1292917682165661E-03],
            [   9.2833358475923167E-01,   0.0000000000000000E+00,  -3.7174824197038858E-01,   2.1292917682165661E-03],
            [  -9.2833358475923167E-01,   0.0000000000000000E+00,  -3.7174824197038858E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,   3.7174824197038858E-01,   9.2833358475923167E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,  -3.7174824197038858E-01,   9.2833358475923167E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,   3.7174824197038858E-01,  -9.2833358475923167E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,  -3.7174824197038858E-01,  -9.2833358475923167E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,   9.2833358475923167E-01,   3.7174824197038858E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,  -9.2833358475923167E-01,   3.7174824197038858E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,   9.2833358475923167E-01,  -3.7174824197038858E-01,   2.1292917682165661E-03],
            [   0.0000000000000000E+00,  -9.2833358475923167E-01,  -3.7174824197038858E-01,   2.1292917682165661E-03],
            [   4.4400944917588892E-01,   8.9602210298771301E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [  -4.4400944917588892E-01,   8.9602210298771301E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [   4.4400944917588892E-01,  -8.9602210298771301E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [  -4.4400944917588892E-01,  -8.9602210298771301E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [   8.9602210298771301E-01,   4.4400944917588892E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [  -8.9602210298771301E-01,   4.4400944917588892E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [   8.9602210298771301E-01,  -4.4400944917588892E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [  -8.9602210298771301E-01,  -4.4400944917588892E-01,   0.0000000000000000E+00,   2.2325627837927690E-03],
            [   4.4400944917588892E-01,   0.0000000000000000E+00,   8.9602210298771301E-01,   2.2325627837927690E-03],
            [  -4.4400944917588892E-01,   0.0000000000000000E+00,   8.9602210298771301E-01,   2.2325627837927690E-03],
            [   4.4400944917588892E-01,   0.0000000000000000E+00,  -8.9602210298771301E-01,   2.2325627837927690E-03],
            [  -4.4400944917588892E-01,   0.0000000000000000E+00,  -8.9602210298771301E-01,   2.2325627837927690E-03],
            [   8.9602210298771301E-01,   0.0000000000000000E+00,   4.4400944917588892E-01,   2.2325627837927690E-03],
            [  -8.9602210298771301E-01,   0.0000000000000000E+00,   4.4400944917588892E-01,   2.2325627837927690E-03],
            [   8.9602210298771301E-01,   0.0000000000000000E+00,  -4.4400944917588892E-01,   2.2325627837927690E-03],
            [  -8.9602210298771301E-01,   0.0000000000000000E+00,  -4.4400944917588892E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,   4.4400944917588892E-01,   8.9602210298771301E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,  -4.4400944917588892E-01,   8.9602210298771301E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,   4.4400944917588892E-01,  -8.9602210298771301E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,  -4.4400944917588892E-01,  -8.9602210298771301E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,   8.9602210298771301E-01,   4.4400944917588892E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,  -8.9602210298771301E-01,   4.4400944917588892E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,   8.9602210298771301E-01,  -4.4400944917588892E-01,   2.2325627837927690E-03],
            [   0.0000000000000000E+00,  -8.9602210298771301E-01,  -4.4400944917588892E-01,   2.2325627837927690E-03],
            [   5.1453370967566425E-01,   8.5747015202128130E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [  -5.1453370967566425E-01,   8.5747015202128130E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [   5.1453370967566425E-01,  -8.5747015202128130E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [  -5.1453370967566425E-01,  -8.5747015202128130E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [   8.5747015202128130E-01,   5.1453370967566425E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [  -8.5747015202128130E-01,   5.1453370967566425E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [   8.5747015202128130E-01,  -5.1453370967566425E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [  -8.5747015202128130E-01,  -5.1453370967566425E-01,   0.0000000000000000E+00,   2.3073520668219550E-03],
            [   5.1453370967566425E-01,   0.0000000000000000E+00,   8.5747015202128130E-01,   2.3073520668219550E-03],
            [  -5.1453370967566425E-01,   0.0000000000000000E+00,   8.5747015202128130E-01,   2.3073520668219550E-03],
            [   5.1453370967566425E-01,   0.0000000000000000E+00,  -8.5747015202128130E-01,   2.3073520668219550E-03],
            [  -5.1453370967566425E-01,   0.0000000000000000E+00,  -8.5747015202128130E-01,   2.3073520668219550E-03],
            [   8.5747015202128130E-01,   0.0000000000000000E+00,   5.1453370967566425E-01,   2.3073520668219550E-03],
            [  -8.5747015202128130E-01,   0.0000000000000000E+00,   5.1453370967566425E-01,   2.3073520668219550E-03],
            [   8.5747015202128130E-01,   0.0000000000000000E+00,  -5.1453370967566425E-01,   2.3073520668219550E-03],
            [  -8.5747015202128130E-01,   0.0000000000000000E+00,  -5.1453370967566425E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,   5.1453370967566425E-01,   8.5747015202128130E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,  -5.1453370967566425E-01,   8.5747015202128130E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,   5.1453370967566425E-01,  -8.5747015202128130E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,  -5.1453370967566425E-01,  -8.5747015202128130E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,   8.5747015202128130E-01,   5.1453370967566425E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,  -8.5747015202128130E-01,   5.1453370967566425E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,   8.5747015202128130E-01,  -5.1453370967566425E-01,   2.3073520668219550E-03],
            [   0.0000000000000000E+00,  -8.5747015202128130E-01,  -5.1453370967566425E-01,   2.3073520668219550E-03],
            [   5.8240536728602299E-01,   8.1289851036672023E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [  -5.8240536728602299E-01,   8.1289851036672023E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [   5.8240536728602299E-01,  -8.1289851036672023E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [  -5.8240536728602299E-01,  -8.1289851036672023E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [   8.1289851036672023E-01,   5.8240536728602299E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [  -8.1289851036672023E-01,   5.8240536728602299E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [   8.1289851036672023E-01,  -5.8240536728602299E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [  -8.1289851036672023E-01,  -5.8240536728602299E-01,   0.0000000000000000E+00,   2.3580728196327568E-03],
            [   5.8240536728602299E-01,   0.0000000000000000E+00,   8.1289851036672023E-01,   2.3580728196327568E-03],
            [  -5.8240536728602299E-01,   0.0000000000000000E+00,   8.1289851036672023E-01,   2.3580728196327568E-03],
            [   5.8240536728602299E-01,   0.0000000000000000E+00,  -8.1289851036672023E-01,   2.3580728196327568E-03],
            [  -5.8240536728602299E-01,   0.0000000000000000E+00,  -8.1289851036672023E-01,   2.3580728196327568E-03],
            [   8.1289851036672023E-01,   0.0000000000000000E+00,   5.8240536728602299E-01,   2.3580728196327568E-03],
            [  -8.1289851036672023E-01,   0.0000000000000000E+00,   5.8240536728602299E-01,   2.3580728196327568E-03],
            [   8.1289851036672023E-01,   0.0000000000000000E+00,  -5.8240536728602299E-01,   2.3580728196327568E-03],
            [  -8.1289851036672023E-01,   0.0000000000000000E+00,  -5.8240536728602299E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,   5.8240536728602299E-01,   8.1289851036672023E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,  -5.8240536728602299E-01,   8.1289851036672023E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,   5.8240536728602299E-01,  -8.1289851036672023E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,  -5.8240536728602299E-01,  -8.1289851036672023E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,   8.1289851036672023E-01,   5.8240536728602299E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,  -8.1289851036672023E-01,   5.8240536728602299E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,   8.1289851036672023E-01,  -5.8240536728602299E-01,   2.3580728196327568E-03],
            [   0.0000000000000000E+00,  -8.1289851036672023E-01,  -5.8240536728602299E-01,   2.3580728196327568E-03],
            [   6.4682839610433696E-01,   7.6263557876163302E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [  -6.4682839610433696E-01,   7.6263557876163302E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [   6.4682839610433696E-01,  -7.6263557876163302E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [  -6.4682839610433696E-01,  -7.6263557876163302E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [   7.6263557876163302E-01,   6.4682839610433696E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [  -7.6263557876163302E-01,   6.4682839610433696E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [   7.6263557876163302E-01,  -6.4682839610433696E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [  -7.6263557876163302E-01,  -6.4682839610433696E-01,   0.0000000000000000E+00,   2.3874929655681313E-03],
            [   6.4682839610433696E-01,   0.0000000000000000E+00,   7.6263557876163302E-01,   2.3874929655681313E-03],
            [  -6.4682839610433696E-01,   0.0000000000000000E+00,   7.6263557876163302E-01,   2.3874929655681313E-03],
            [   6.4682839610433696E-01,   0.0000000000000000E+00,  -7.6263557876163302E-01,   2.3874929655681313E-03],
            [  -6.4682839610433696E-01,   0.0000000000000000E+00,  -7.6263557876163302E-01,   2.3874929655681313E-03],
            [   7.6263557876163302E-01,   0.0000000000000000E+00,   6.4682839610433696E-01,   2.3874929655681313E-03],
            [  -7.6263557876163302E-01,   0.0000000000000000E+00,   6.4682839610433696E-01,   2.3874929655681313E-03],
            [   7.6263557876163302E-01,   0.0000000000000000E+00,  -6.4682839610433696E-01,   2.3874929655681313E-03],
            [  -7.6263557876163302E-01,   0.0000000000000000E+00,  -6.4682839610433696E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,   6.4682839610433696E-01,   7.6263557876163302E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,  -6.4682839610433696E-01,   7.6263557876163302E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,   6.4682839610433696E-01,  -7.6263557876163302E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,  -6.4682839610433696E-01,  -7.6263557876163302E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,   7.6263557876163302E-01,   6.4682839610433696E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,  -7.6263557876163302E-01,   6.4682839610433696E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,   7.6263557876163302E-01,  -6.4682839610433696E-01,   2.3874929655681313E-03],
            [   0.0000000000000000E+00,  -7.6263557876163302E-01,  -6.4682839610433696E-01,   2.3874929655681313E-03],
            [   6.0959642591043729E-02,   1.7878282753429311E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,   1.7878282753429311E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,  -1.7878282753429311E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,   1.7878282753429311E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,  -1.7878282753429311E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,  -1.7878282753429311E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,   1.7878282753429311E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,  -1.7878282753429311E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,   6.0959642591043729E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,   6.0959642591043729E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,  -6.0959642591043729E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,   6.0959642591043729E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,  -6.0959642591043729E-02,   9.9798010450156804E-01,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,  -6.0959642591043729E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,   6.0959642591043729E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,  -6.0959642591043729E-02,  -9.9798010450156804E-01,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,   6.0959642591043729E-02,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,   6.0959642591043729E-02,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,  -6.0959642591043729E-02,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,   6.0959642591043729E-02,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,  -6.0959642591043729E-02,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,  -6.0959642591043729E-02,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,   6.0959642591043729E-02,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,  -6.0959642591043729E-02,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,   1.7878282753429311E-02,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,   1.7878282753429311E-02,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,  -1.7878282753429311E-02,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,   1.7878282753429311E-02,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,  -1.7878282753429311E-02,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   9.9798010450156804E-01,  -1.7878282753429311E-02,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,   1.7878282753429311E-02,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -9.9798010450156804E-01,  -1.7878282753429311E-02,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,   9.9798010450156804E-01,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,   9.9798010450156804E-01,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,  -9.9798010450156804E-01,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,   9.9798010450156804E-01,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,  -9.9798010450156804E-01,   1.7878282753429311E-02,   1.0233113295218827E-03],
            [   6.0959642591043729E-02,  -9.9798010450156804E-01,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,   9.9798010450156804E-01,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [  -6.0959642591043729E-02,  -9.9798010450156804E-01,  -1.7878282753429311E-02,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,   9.9798010450156804E-01,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,   9.9798010450156804E-01,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,  -9.9798010450156804E-01,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,   9.9798010450156804E-01,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,  -9.9798010450156804E-01,   6.0959642591043729E-02,   1.0233113295218827E-03],
            [   1.7878282753429311E-02,  -9.9798010450156804E-01,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,   9.9798010450156804E-01,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [  -1.7878282753429311E-02,  -9.9798010450156804E-01,  -6.0959642591043729E-02,   1.0233113295218827E-03],
            [   8.8119622709593878E-02,   3.9538887407920963E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,   3.9538887407920963E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,  -3.9538887407920963E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,   3.9538887407920963E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,  -3.9538887407920963E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,  -3.9538887407920963E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,   3.9538887407920963E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,  -3.9538887407920963E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,   8.8119622709593878E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,   8.8119622709593878E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,  -8.8119622709593878E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,   8.8119622709593878E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,  -8.8119622709593878E-02,   9.9532487584509943E-01,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,  -8.8119622709593878E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,   8.8119622709593878E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,  -8.8119622709593878E-02,  -9.9532487584509943E-01,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,   8.8119622709593878E-02,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,   8.8119622709593878E-02,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,  -8.8119622709593878E-02,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,   8.8119622709593878E-02,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,  -8.8119622709593878E-02,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,  -8.8119622709593878E-02,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,   8.8119622709593878E-02,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,  -8.8119622709593878E-02,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,   3.9538887407920963E-02,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,   3.9538887407920963E-02,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,  -3.9538887407920963E-02,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,   3.9538887407920963E-02,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,  -3.9538887407920963E-02,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   9.9532487584509943E-01,  -3.9538887407920963E-02,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,   3.9538887407920963E-02,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -9.9532487584509943E-01,  -3.9538887407920963E-02,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,   9.9532487584509943E-01,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,   9.9532487584509943E-01,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,  -9.9532487584509943E-01,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,   9.9532487584509943E-01,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,  -9.9532487584509943E-01,   3.9538887407920963E-02,   1.2564937910994611E-03],
            [   8.8119622709593878E-02,  -9.9532487584509943E-01,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,   9.9532487584509943E-01,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [  -8.8119622709593878E-02,  -9.9532487584509943E-01,  -3.9538887407920963E-02,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,   9.9532487584509943E-01,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,   9.9532487584509943E-01,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,  -9.9532487584509943E-01,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,   9.9532487584509943E-01,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,  -9.9532487584509943E-01,   8.8119622709593878E-02,   1.2564937910994611E-03],
            [   3.9538887407920963E-02,  -9.9532487584509943E-01,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,   9.9532487584509943E-01,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [  -3.9538887407920963E-02,  -9.9532487584509943E-01,  -8.8119622709593878E-02,   1.2564937910994611E-03],
            [   1.1659367224288310E-01,   6.3781217977229895E-02,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,   6.3781217977229895E-02,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,  -6.3781217977229895E-02,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,   6.3781217977229895E-02,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,  -6.3781217977229895E-02,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,  -6.3781217977229895E-02,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,   6.3781217977229895E-02,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,  -6.3781217977229895E-02,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,   1.1659367224288310E-01,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,   1.1659367224288310E-01,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,  -1.1659367224288310E-01,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,   1.1659367224288310E-01,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,  -1.1659367224288310E-01,   9.9112959386059107E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,  -1.1659367224288310E-01,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,   1.1659367224288310E-01,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,  -1.1659367224288310E-01,  -9.9112959386059107E-01,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,   1.1659367224288310E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,   1.1659367224288310E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,  -1.1659367224288310E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,   1.1659367224288310E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,  -1.1659367224288310E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,  -1.1659367224288310E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,   1.1659367224288310E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,  -1.1659367224288310E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,   6.3781217977229895E-02,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,   6.3781217977229895E-02,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,  -6.3781217977229895E-02,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,   6.3781217977229895E-02,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,  -6.3781217977229895E-02,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   9.9112959386059107E-01,  -6.3781217977229895E-02,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,   6.3781217977229895E-02,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -9.9112959386059107E-01,  -6.3781217977229895E-02,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,   9.9112959386059107E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,   9.9112959386059107E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,  -9.9112959386059107E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,   9.9112959386059107E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,  -9.9112959386059107E-01,   6.3781217977229895E-02,   1.4529230203057842E-03],
            [   1.1659367224288310E-01,  -9.9112959386059107E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,   9.9112959386059107E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [  -1.1659367224288310E-01,  -9.9112959386059107E-01,  -6.3781217977229895E-02,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,   9.9112959386059107E-01,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,   9.9112959386059107E-01,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,  -9.9112959386059107E-01,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,   9.9112959386059107E-01,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,  -9.9112959386059107E-01,   1.1659367224288310E-01,   1.4529230203057842E-03],
            [   6.3781217977229895E-02,  -9.9112959386059107E-01,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,   9.9112959386059107E-01,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [  -6.3781217977229895E-02,  -9.9112959386059107E-01,  -1.1659367224288310E-01,   1.4529230203057842E-03],
            [   1.4602328570317849E-01,   8.9858908137450372E-02,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,   8.9858908137450372E-02,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,  -8.9858908137450372E-02,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,   8.9858908137450372E-02,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,  -8.9858908137450372E-02,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,  -8.9858908137450372E-02,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,   8.9858908137450372E-02,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,  -8.9858908137450372E-02,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,   1.4602328570317849E-01,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,   1.4602328570317849E-01,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,  -1.4602328570317849E-01,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,   1.4602328570317849E-01,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,  -1.4602328570317849E-01,   9.8519164463610487E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,  -1.4602328570317849E-01,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,   1.4602328570317849E-01,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,  -1.4602328570317849E-01,  -9.8519164463610487E-01,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,   1.4602328570317849E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,   1.4602328570317849E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,  -1.4602328570317849E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,   1.4602328570317849E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,  -1.4602328570317849E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,  -1.4602328570317849E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,   1.4602328570317849E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,  -1.4602328570317849E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,   8.9858908137450372E-02,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,   8.9858908137450372E-02,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,  -8.9858908137450372E-02,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,   8.9858908137450372E-02,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,  -8.9858908137450372E-02,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   9.8519164463610487E-01,  -8.9858908137450372E-02,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,   8.9858908137450372E-02,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -9.8519164463610487E-01,  -8.9858908137450372E-02,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,   9.8519164463610487E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,   9.8519164463610487E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,  -9.8519164463610487E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,   9.8519164463610487E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,  -9.8519164463610487E-01,   8.9858908137450372E-02,   1.6180862091000720E-03],
            [   1.4602328570317849E-01,  -9.8519164463610487E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,   9.8519164463610487E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [  -1.4602328570317849E-01,  -9.8519164463610487E-01,  -8.9858908137450372E-02,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,   9.8519164463610487E-01,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,   9.8519164463610487E-01,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,  -9.8519164463610487E-01,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,   9.8519164463610487E-01,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,  -9.8519164463610487E-01,   1.4602328570317849E-01,   1.6180862091000720E-03],
            [   8.9858908137450372E-02,  -9.8519164463610487E-01,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,   9.8519164463610487E-01,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [  -8.9858908137450372E-02,  -9.8519164463610487E-01,  -1.4602328570317849E-01,   1.6180862091000720E-03],
            [   1.7611971101817550E-01,   1.1726065105761620E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,   1.1726065105761620E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,  -1.1726065105761620E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,   1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,  -1.1726065105761620E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,  -1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,   1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,  -1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,   1.7611971101817550E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,   1.7611971101817550E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,  -1.7611971101817550E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,   1.7611971101817550E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,  -1.7611971101817550E-01,   9.7735959968909003E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,  -1.7611971101817550E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,   1.7611971101817550E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,  -1.7611971101817550E-01,  -9.7735959968909003E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,   1.7611971101817550E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,   1.7611971101817550E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,  -1.7611971101817550E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,   1.7611971101817550E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,  -1.7611971101817550E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,  -1.7611971101817550E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,   1.7611971101817550E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,  -1.7611971101817550E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,   1.1726065105761620E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,   1.1726065105761620E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,   1.1726065105761620E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   9.7735959968909003E-01,  -1.1726065105761620E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,   1.1726065105761620E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -9.7735959968909003E-01,  -1.1726065105761620E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,   9.7735959968909003E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,   9.7735959968909003E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,  -9.7735959968909003E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,   9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,  -9.7735959968909003E-01,   1.1726065105761620E-01,   1.7572544291731128E-03],
            [   1.7611971101817550E-01,  -9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,   9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [  -1.7611971101817550E-01,  -9.7735959968909003E-01,  -1.1726065105761620E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,   9.7735959968909003E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,   9.7735959968909003E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,   9.7735959968909003E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,  -9.7735959968909003E-01,   1.7611971101817550E-01,   1.7572544291731128E-03],
            [   1.1726065105761620E-01,  -9.7735959968909003E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,   9.7735959968909003E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [  -1.1726065105761620E-01,  -9.7735959968909003E-01,  -1.7611971101817550E-01,   1.7572544291731128E-03],
            [   2.0664711904637181E-01,   1.4561028769709949E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,   1.4561028769709949E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,  -1.4561028769709949E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,   1.4561028769709949E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,  -1.4561028769709949E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,  -1.4561028769709949E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,   1.4561028769709949E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,  -1.4561028769709949E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,   2.0664711904637181E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,   2.0664711904637181E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,  -2.0664711904637181E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,   2.0664711904637181E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,  -2.0664711904637181E-01,   9.6751982527832603E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,  -2.0664711904637181E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,   2.0664711904637181E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,  -2.0664711904637181E-01,  -9.6751982527832603E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,   2.0664711904637181E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,   2.0664711904637181E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,  -2.0664711904637181E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,   2.0664711904637181E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,  -2.0664711904637181E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,  -2.0664711904637181E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,   2.0664711904637181E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,  -2.0664711904637181E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,   1.4561028769709949E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,   1.4561028769709949E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,  -1.4561028769709949E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,   1.4561028769709949E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,  -1.4561028769709949E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   9.6751982527832603E-01,  -1.4561028769709949E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,   1.4561028769709949E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -9.6751982527832603E-01,  -1.4561028769709949E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,   9.6751982527832603E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,   9.6751982527832603E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,  -9.6751982527832603E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,   9.6751982527832603E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,  -9.6751982527832603E-01,   1.4561028769709949E-01,   1.8747472612974240E-03],
            [   2.0664711904637181E-01,  -9.6751982527832603E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,   9.6751982527832603E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [  -2.0664711904637181E-01,  -9.6751982527832603E-01,  -1.4561028769709949E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,   9.6751982527832603E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,   9.6751982527832603E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,  -9.6751982527832603E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,   9.6751982527832603E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,  -9.6751982527832603E-01,   2.0664711904637181E-01,   1.8747472612974240E-03],
            [   1.4561028769709949E-01,  -9.6751982527832603E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,   9.6751982527832603E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [  -1.4561028769709949E-01,  -9.6751982527832603E-01,  -2.0664711904637181E-01,   1.8747472612974240E-03],
            [   2.3740760263281521E-01,   1.7461538230117751E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,   1.7461538230117751E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,  -1.7461538230117751E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,   1.7461538230117751E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,  -1.7461538230117751E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,  -1.7461538230117751E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,   1.7461538230117751E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,  -1.7461538230117751E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,   2.3740760263281521E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,   2.3740760263281521E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,  -2.3740760263281521E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,   2.3740760263281521E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,  -2.3740760263281521E-01,   9.5558730552260518E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,  -2.3740760263281521E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,   2.3740760263281521E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,  -2.3740760263281521E-01,  -9.5558730552260518E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,   2.3740760263281521E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,   2.3740760263281521E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,  -2.3740760263281521E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,   2.3740760263281521E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,  -2.3740760263281521E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,  -2.3740760263281521E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,   2.3740760263281521E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,  -2.3740760263281521E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,   1.7461538230117751E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,   1.7461538230117751E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,  -1.7461538230117751E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,   1.7461538230117751E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,  -1.7461538230117751E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   9.5558730552260518E-01,  -1.7461538230117751E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,   1.7461538230117751E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -9.5558730552260518E-01,  -1.7461538230117751E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,   9.5558730552260518E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,   9.5558730552260518E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,  -9.5558730552260518E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,   9.5558730552260518E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,  -9.5558730552260518E-01,   1.7461538230117751E-01,   1.9739954646189671E-03],
            [   2.3740760263281521E-01,  -9.5558730552260518E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,   9.5558730552260518E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [  -2.3740760263281521E-01,  -9.5558730552260518E-01,  -1.7461538230117751E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,   9.5558730552260518E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,   9.5558730552260518E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,  -9.5558730552260518E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,   9.5558730552260518E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,  -9.5558730552260518E-01,   2.3740760263281521E-01,   1.9739954646189671E-03],
            [   1.7461538230117751E-01,  -9.5558730552260518E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,   9.5558730552260518E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [  -1.7461538230117751E-01,  -9.5558730552260518E-01,  -2.3740760263281521E-01,   1.9739954646189671E-03],
            [   2.6823054743370511E-01,   2.0403830702955841E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,   2.0403830702955841E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,  -2.0403830702955841E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,   2.0403830702955841E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,  -2.0403830702955841E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,  -2.0403830702955841E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,   2.0403830702955841E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,  -2.0403830702955841E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,   2.6823054743370511E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,   2.6823054743370511E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,  -2.6823054743370511E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,   2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,  -2.6823054743370511E-01,   9.4149919951528716E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,  -2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,   2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,  -2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,   2.6823054743370511E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,   2.6823054743370511E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,   2.6823054743370511E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,  -2.6823054743370511E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,   2.6823054743370511E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,  -2.6823054743370511E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,   2.0403830702955841E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,   2.0403830702955841E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,  -2.0403830702955841E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,   2.0403830702955841E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,  -2.0403830702955841E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   9.4149919951528716E-01,  -2.0403830702955841E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,   2.0403830702955841E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -9.4149919951528716E-01,  -2.0403830702955841E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,   9.4149919951528716E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,   9.4149919951528716E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,   9.4149919951528716E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,  -9.4149919951528716E-01,   2.0403830702955841E-01,   2.0577230166936118E-03],
            [   2.6823054743370511E-01,  -9.4149919951528716E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,   9.4149919951528716E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [  -2.6823054743370511E-01,  -9.4149919951528716E-01,  -2.0403830702955841E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,   9.4149919951528716E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,   9.4149919951528716E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,  -9.4149919951528716E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,   9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,  -9.4149919951528716E-01,   2.6823054743370511E-01,   2.0577230166936118E-03],
            [   2.0403830702955841E-01,  -9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,   9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [  -2.0403830702955841E-01,  -9.4149919951528716E-01,  -2.6823054743370511E-01,   2.0577230166936118E-03],
            [   2.9896533121423691E-01,   2.3367886340036981E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,   2.3367886340036981E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,  -2.3367886340036981E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,   2.3367886340036981E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,  -2.3367886340036981E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,  -2.3367886340036981E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,   2.3367886340036981E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,  -2.3367886340036981E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,   2.9896533121423691E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,   2.9896533121423691E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,  -2.9896533121423691E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,   2.9896533121423691E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,  -2.9896533121423691E-01,   9.2521020289006384E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,  -2.9896533121423691E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,   2.9896533121423691E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,  -2.9896533121423691E-01,  -9.2521020289006384E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,   2.9896533121423691E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,   2.9896533121423691E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,  -2.9896533121423691E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,   2.9896533121423691E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,  -2.9896533121423691E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,  -2.9896533121423691E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,   2.9896533121423691E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,  -2.9896533121423691E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,   2.3367886340036981E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,   2.3367886340036981E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,  -2.3367886340036981E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,   2.3367886340036981E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,  -2.3367886340036981E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   9.2521020289006384E-01,  -2.3367886340036981E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,   2.3367886340036981E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -9.2521020289006384E-01,  -2.3367886340036981E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,   9.2521020289006384E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,   9.2521020289006384E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,  -9.2521020289006384E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,   9.2521020289006384E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,  -9.2521020289006384E-01,   2.3367886340036981E-01,   2.1281155755935566E-03],
            [   2.9896533121423691E-01,  -9.2521020289006384E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,   9.2521020289006384E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [  -2.9896533121423691E-01,  -9.2521020289006384E-01,  -2.3367886340036981E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,   9.2521020289006384E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,   9.2521020289006384E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,  -9.2521020289006384E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,   9.2521020289006384E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,  -9.2521020289006384E-01,   2.9896533121423691E-01,   2.1281155755935566E-03],
            [   2.3367886340036981E-01,  -9.2521020289006384E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,   9.2521020289006384E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [  -2.3367886340036981E-01,  -9.2521020289006384E-01,  -2.9896533121423691E-01,   2.1281155755935566E-03],
            [   3.2947627527722090E-01,   2.6336327526542191E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,   2.6336327526542191E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,  -2.6336327526542191E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,   2.6336327526542191E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,  -2.6336327526542191E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,  -2.6336327526542191E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,   2.6336327526542191E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,  -2.6336327526542191E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,   3.2947627527722090E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,   3.2947627527722090E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,  -3.2947627527722090E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,   3.2947627527722090E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,  -3.2947627527722090E-01,   9.0668912493253084E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,  -3.2947627527722090E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,   3.2947627527722090E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,  -3.2947627527722090E-01,  -9.0668912493253084E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,   3.2947627527722090E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,   3.2947627527722090E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,  -3.2947627527722090E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,   3.2947627527722090E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,  -3.2947627527722090E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,  -3.2947627527722090E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,   3.2947627527722090E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,  -3.2947627527722090E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,   2.6336327526542191E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,   2.6336327526542191E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,  -2.6336327526542191E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,   2.6336327526542191E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,  -2.6336327526542191E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   9.0668912493253084E-01,  -2.6336327526542191E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,   2.6336327526542191E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -9.0668912493253084E-01,  -2.6336327526542191E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,   9.0668912493253084E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,   9.0668912493253084E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,  -9.0668912493253084E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,   9.0668912493253084E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,  -9.0668912493253084E-01,   2.6336327526542191E-01,   2.1869540908808324E-03],
            [   3.2947627527722090E-01,  -9.0668912493253084E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,   9.0668912493253084E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [  -3.2947627527722090E-01,  -9.0668912493253084E-01,  -2.6336327526542191E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,   9.0668912493253084E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,   9.0668912493253084E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,  -9.0668912493253084E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,   9.0668912493253084E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,  -9.0668912493253084E-01,   3.2947627527722090E-01,   2.1869540908808324E-03],
            [   2.6336327526542191E-01,  -9.0668912493253084E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,   9.0668912493253084E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [  -2.6336327526542191E-01,  -9.0668912493253084E-01,  -3.2947627527722090E-01,   2.1869540908808324E-03],
            [   3.5963908872760858E-01,   2.9293690980516007E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,   2.9293690980516007E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,  -2.9293690980516007E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,   2.9293690980516007E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,  -2.9293690980516007E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,  -2.9293690980516007E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,   2.9293690980516007E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,  -2.9293690980516007E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,   3.5963908872760858E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,   3.5963908872760858E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,  -3.5963908872760858E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,   3.5963908872760858E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,  -3.5963908872760858E-01,   8.8591630120061504E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,  -3.5963908872760858E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,   3.5963908872760858E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,  -3.5963908872760858E-01,  -8.8591630120061504E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,   3.5963908872760858E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,   3.5963908872760858E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,  -3.5963908872760858E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,   3.5963908872760858E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,  -3.5963908872760858E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,  -3.5963908872760858E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,   3.5963908872760858E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,  -3.5963908872760858E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,   2.9293690980516007E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,   2.9293690980516007E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,  -2.9293690980516007E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,   2.9293690980516007E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,  -2.9293690980516007E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   8.8591630120061504E-01,  -2.9293690980516007E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,   2.9293690980516007E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -8.8591630120061504E-01,  -2.9293690980516007E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,   8.8591630120061504E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,   8.8591630120061504E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,  -8.8591630120061504E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,   8.8591630120061504E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,  -8.8591630120061504E-01,   2.9293690980516007E-01,   2.2357164693917629E-03],
            [   3.5963908872760858E-01,  -8.8591630120061504E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,   8.8591630120061504E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [  -3.5963908872760858E-01,  -8.8591630120061504E-01,  -2.9293690980516007E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,   8.8591630120061504E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,   8.8591630120061504E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,  -8.8591630120061504E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,   8.8591630120061504E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,  -8.8591630120061504E-01,   3.5963908872760858E-01,   2.2357164693917629E-03],
            [   2.9293690980516007E-01,  -8.8591630120061504E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,   8.8591630120061504E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [  -2.9293690980516007E-01,  -8.8591630120061504E-01,  -3.5963908872760858E-01,   2.2357164693917629E-03],
            [   3.8933830463988123E-01,   3.2225927852755121E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,   3.2225927852755121E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,  -3.2225927852755121E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,   3.2225927852755121E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,  -3.2225927852755121E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,  -3.2225927852755121E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,   3.2225927852755121E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,  -3.2225927852755121E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,   3.8933830463988123E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,   3.8933830463988123E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,  -3.8933830463988123E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,   3.8933830463988123E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,  -3.8933830463988123E-01,   8.6288159207567128E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,  -3.8933830463988123E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,   3.8933830463988123E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,  -3.8933830463988123E-01,  -8.6288159207567128E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,   3.8933830463988123E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,   3.8933830463988123E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,  -3.8933830463988123E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,   3.8933830463988123E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,  -3.8933830463988123E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,  -3.8933830463988123E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,   3.8933830463988123E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,  -3.8933830463988123E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,   3.2225927852755121E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,   3.2225927852755121E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,  -3.2225927852755121E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,   3.2225927852755121E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,  -3.2225927852755121E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   8.6288159207567128E-01,  -3.2225927852755121E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,   3.2225927852755121E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -8.6288159207567128E-01,  -3.2225927852755121E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,   8.6288159207567128E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,   8.6288159207567128E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,  -8.6288159207567128E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,   8.6288159207567128E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,  -8.6288159207567128E-01,   3.2225927852755121E-01,   2.2756542444174067E-03],
            [   3.8933830463988123E-01,  -8.6288159207567128E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,   8.6288159207567128E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [  -3.8933830463988123E-01,  -8.6288159207567128E-01,  -3.2225927852755121E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,   8.6288159207567128E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,   8.6288159207567128E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,  -8.6288159207567128E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,   8.6288159207567128E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,  -8.6288159207567128E-01,   3.8933830463988123E-01,   2.2756542444174067E-03],
            [   3.2225927852755121E-01,  -8.6288159207567128E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,   8.6288159207567128E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [  -3.2225927852755121E-01,  -8.6288159207567128E-01,  -3.8933830463988123E-01,   2.2756542444174067E-03],
            [   4.1846537893583469E-01,   3.5120047911957430E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,   3.5120047911957430E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,  -3.5120047911957430E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,   3.5120047911957430E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,  -3.5120047911957430E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,  -3.5120047911957430E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,   3.5120047911957430E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,  -3.5120047911957430E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,   4.1846537893583469E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,   4.1846537893583469E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,  -4.1846537893583469E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,   4.1846537893583469E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,  -4.1846537893583469E-01,   8.3758280193558765E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,  -4.1846537893583469E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,   4.1846537893583469E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,  -4.1846537893583469E-01,  -8.3758280193558765E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,   4.1846537893583469E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,   4.1846537893583469E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,  -4.1846537893583469E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,   4.1846537893583469E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,  -4.1846537893583469E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,  -4.1846537893583469E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,   4.1846537893583469E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,  -4.1846537893583469E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,   3.5120047911957430E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,   3.5120047911957430E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,  -3.5120047911957430E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,   3.5120047911957430E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,  -3.5120047911957430E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   8.3758280193558765E-01,  -3.5120047911957430E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,   3.5120047911957430E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -8.3758280193558765E-01,  -3.5120047911957430E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,   8.3758280193558765E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,   8.3758280193558765E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,  -8.3758280193558765E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,   8.3758280193558765E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,  -8.3758280193558765E-01,   3.5120047911957430E-01,   2.3078505724321570E-03],
            [   4.1846537893583469E-01,  -8.3758280193558765E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,   8.3758280193558765E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [  -4.1846537893583469E-01,  -8.3758280193558765E-01,  -3.5120047911957430E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,   8.3758280193558765E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,   8.3758280193558765E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,  -8.3758280193558765E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,   8.3758280193558765E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,  -8.3758280193558765E-01,   4.1846537893583469E-01,   2.3078505724321570E-03],
            [   3.5120047911957430E-01,  -8.3758280193558765E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,   8.3758280193558765E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [  -3.5120047911957430E-01,  -8.3758280193558765E-01,  -4.1846537893583469E-01,   2.3078505724321570E-03],
            [   4.4691723190761662E-01,   3.7963856776845373E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,   3.7963856776845373E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,  -3.7963856776845373E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,   3.7963856776845373E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,  -3.7963856776845373E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,  -3.7963856776845373E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,   3.7963856776845373E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,  -3.7963856776845373E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,   4.4691723190761662E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,   4.4691723190761662E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,  -4.4691723190761662E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,   4.4691723190761662E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,  -4.4691723190761662E-01,   8.1002441054992336E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,  -4.4691723190761662E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,   4.4691723190761662E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,  -4.4691723190761662E-01,  -8.1002441054992336E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,   4.4691723190761662E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,   4.4691723190761662E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,  -4.4691723190761662E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,   4.4691723190761662E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,  -4.4691723190761662E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,  -4.4691723190761662E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,   4.4691723190761662E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,  -4.4691723190761662E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,   3.7963856776845373E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,   3.7963856776845373E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,  -3.7963856776845373E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,   3.7963856776845373E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,  -3.7963856776845373E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   8.1002441054992336E-01,  -3.7963856776845373E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,   3.7963856776845373E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -8.1002441054992336E-01,  -3.7963856776845373E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,   8.1002441054992336E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,   8.1002441054992336E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,  -8.1002441054992336E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,   8.1002441054992336E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,  -8.1002441054992336E-01,   3.7963856776845373E-01,   2.3332644349039144E-03],
            [   4.4691723190761662E-01,  -8.1002441054992336E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,   8.1002441054992336E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [  -4.4691723190761662E-01,  -8.1002441054992336E-01,  -3.7963856776845373E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,   8.1002441054992336E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,   8.1002441054992336E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,  -8.1002441054992336E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,   8.1002441054992336E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,  -8.1002441054992336E-01,   4.4691723190761662E-01,   2.3332644349039144E-03],
            [   3.7963856776845373E-01,  -8.1002441054992336E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,   8.1002441054992336E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [  -3.7963856776845373E-01,  -8.1002441054992336E-01,  -4.4691723190761662E-01,   2.3332644349039144E-03],
            [   4.7459508132769762E-01,   4.0745753782638788E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,   4.0745753782638788E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,  -4.0745753782638788E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,   4.0745753782638788E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,  -4.0745753782638788E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,  -4.0745753782638788E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,   4.0745753782638788E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,  -4.0745753782638788E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,   4.7459508132769762E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,   4.7459508132769762E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,  -4.7459508132769762E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,   4.7459508132769762E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,  -4.7459508132769762E-01,   7.8021654920157502E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,  -4.7459508132769762E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,   4.7459508132769762E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,  -4.7459508132769762E-01,  -7.8021654920157502E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,   4.7459508132769762E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,   4.7459508132769762E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,  -4.7459508132769762E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,   4.7459508132769762E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,  -4.7459508132769762E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,  -4.7459508132769762E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,   4.7459508132769762E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,  -4.7459508132769762E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,   4.0745753782638788E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,   4.0745753782638788E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,  -4.0745753782638788E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,   4.0745753782638788E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,  -4.0745753782638788E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   7.8021654920157502E-01,  -4.0745753782638788E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,   4.0745753782638788E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -7.8021654920157502E-01,  -4.0745753782638788E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,   7.8021654920157502E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,   7.8021654920157502E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,  -7.8021654920157502E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,   7.8021654920157502E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,  -7.8021654920157502E-01,   4.0745753782638788E-01,   2.3527645830337695E-03],
            [   4.7459508132769762E-01,  -7.8021654920157502E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,   7.8021654920157502E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [  -4.7459508132769762E-01,  -7.8021654920157502E-01,  -4.0745753782638788E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,   7.8021654920157502E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,   7.8021654920157502E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,  -7.8021654920157502E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,   7.8021654920157502E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,  -7.8021654920157502E-01,   4.7459508132769762E-01,   2.3527645830337695E-03],
            [   4.0745753782638788E-01,  -7.8021654920157502E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,   7.8021654920157502E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [  -4.0745753782638788E-01,  -7.8021654920157502E-01,  -4.7459508132769762E-01,   2.3527645830337695E-03],
            [   5.0140346014102621E-01,   4.3454569060278281E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,   4.3454569060278281E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,  -4.3454569060278281E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,   4.3454569060278281E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,  -4.3454569060278281E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,  -4.3454569060278281E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,   4.3454569060278281E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,  -4.3454569060278281E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,   5.0140346014102621E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,   5.0140346014102621E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,  -5.0140346014102621E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,   5.0140346014102621E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,  -5.0140346014102621E-01,   7.4817418622748333E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,  -5.0140346014102621E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,   5.0140346014102621E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,  -5.0140346014102621E-01,  -7.4817418622748333E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,   5.0140346014102621E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,   5.0140346014102621E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,  -5.0140346014102621E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,   5.0140346014102621E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,  -5.0140346014102621E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,  -5.0140346014102621E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,   5.0140346014102621E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,  -5.0140346014102621E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,   4.3454569060278281E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,   4.3454569060278281E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,  -4.3454569060278281E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,   4.3454569060278281E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,  -4.3454569060278281E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   7.4817418622748333E-01,  -4.3454569060278281E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,   4.3454569060278281E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -7.4817418622748333E-01,  -4.3454569060278281E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,   7.4817418622748333E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,   7.4817418622748333E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,  -7.4817418622748333E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,   7.4817418622748333E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,  -7.4817418622748333E-01,   4.3454569060278281E-01,   2.3671556899161517E-03],
            [   5.0140346014102621E-01,  -7.4817418622748333E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,   7.4817418622748333E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [  -5.0140346014102621E-01,  -7.4817418622748333E-01,  -4.3454569060278281E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,   7.4817418622748333E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,   7.4817418622748333E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,  -7.4817418622748333E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,   7.4817418622748333E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,  -7.4817418622748333E-01,   5.0140346014102621E-01,   2.3671556899161517E-03],
            [   4.3454569060278281E-01,  -7.4817418622748333E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,   7.4817418622748333E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [  -4.3454569060278281E-01,  -7.4817418622748333E-01,  -5.0140346014102621E-01,   2.3671556899161517E-03],
            [   5.2724934045512395E-01,   4.6079425152051340E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,   4.6079425152051340E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,  -4.6079425152051340E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,   4.6079425152051340E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,  -4.6079425152051340E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,  -4.6079425152051340E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,   4.6079425152051340E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,  -4.6079425152051340E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,   5.2724934045512395E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,   5.2724934045512395E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,  -5.2724934045512395E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,   5.2724934045512395E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,  -5.2724934045512395E-01,   7.1391651525601141E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,  -5.2724934045512395E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,   5.2724934045512395E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,  -5.2724934045512395E-01,  -7.1391651525601141E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,   5.2724934045512395E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,   5.2724934045512395E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,  -5.2724934045512395E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,   5.2724934045512395E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,  -5.2724934045512395E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,  -5.2724934045512395E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,   5.2724934045512395E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,  -5.2724934045512395E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,   4.6079425152051340E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,   4.6079425152051340E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,  -4.6079425152051340E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,   4.6079425152051340E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,  -4.6079425152051340E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   7.1391651525601141E-01,  -4.6079425152051340E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,   4.6079425152051340E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -7.1391651525601141E-01,  -4.6079425152051340E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,   7.1391651525601141E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,   7.1391651525601141E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,  -7.1391651525601141E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,   7.1391651525601141E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,  -7.1391651525601141E-01,   4.6079425152051340E-01,   2.3771983298477004E-03],
            [   5.2724934045512395E-01,  -7.1391651525601141E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,   7.1391651525601141E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [  -5.2724934045512395E-01,  -7.1391651525601141E-01,  -4.6079425152051340E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,   7.1391651525601141E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,   7.1391651525601141E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,  -7.1391651525601141E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,   7.1391651525601141E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,  -7.1391651525601141E-01,   5.2724934045512395E-01,   2.3771983298477004E-03],
            [   4.6079425152051340E-01,  -7.1391651525601141E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,   7.1391651525601141E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [  -4.6079425152051340E-01,  -7.1391651525601141E-01,  -5.2724934045512395E-01,   2.3771983298477004E-03],
            [   5.5204130518463657E-01,   4.8609612841817201E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,   4.8609612841817201E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,  -4.8609612841817201E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,   4.8609612841817201E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,  -4.8609612841817201E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,  -4.8609612841817201E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,   4.8609612841817201E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,  -4.8609612841817201E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,   5.5204130518463657E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,   5.5204130518463657E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,  -5.5204130518463657E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,   5.5204130518463657E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,  -5.5204130518463657E-01,   6.7746656840533992E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,  -5.5204130518463657E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,   5.5204130518463657E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,  -5.5204130518463657E-01,  -6.7746656840533992E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,   5.5204130518463657E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,   5.5204130518463657E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,  -5.5204130518463657E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,   5.5204130518463657E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,  -5.5204130518463657E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,  -5.5204130518463657E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,   5.5204130518463657E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,  -5.5204130518463657E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,   4.8609612841817201E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,   4.8609612841817201E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,  -4.8609612841817201E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,   4.8609612841817201E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,  -4.8609612841817201E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   6.7746656840533992E-01,  -4.8609612841817201E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,   4.8609612841817201E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -6.7746656840533992E-01,  -4.8609612841817201E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,   6.7746656840533992E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,   6.7746656840533992E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,  -6.7746656840533992E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,   6.7746656840533992E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,  -6.7746656840533992E-01,   4.8609612841817201E-01,   2.3836237110837662E-03],
            [   5.5204130518463657E-01,  -6.7746656840533992E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,   6.7746656840533992E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [  -5.5204130518463657E-01,  -6.7746656840533992E-01,  -4.8609612841817201E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,   6.7746656840533992E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,   6.7746656840533992E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,  -6.7746656840533992E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,   6.7746656840533992E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,  -6.7746656840533992E-01,   5.5204130518463657E-01,   2.3836237110837662E-03],
            [   4.8609612841817201E-01,  -6.7746656840533992E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,   6.7746656840533992E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [  -4.8609612841817201E-01,  -6.7746656840533992E-01,  -5.5204130518463657E-01,   2.3836237110837662E-03],
            [   5.7568872375030766E-01,   5.1034473953427895E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,   5.1034473953427895E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,  -5.1034473953427895E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,   5.1034473953427895E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,  -5.1034473953427895E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,  -5.1034473953427895E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,   5.1034473953427895E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,  -5.1034473953427895E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,   5.7568872375030766E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,   5.7568872375030766E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,  -5.7568872375030766E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,   5.7568872375030766E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,  -5.7568872375030766E-01,   6.3885110955247693E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,  -5.7568872375030766E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,   5.7568872375030766E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,  -5.7568872375030766E-01,  -6.3885110955247693E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,   5.7568872375030766E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,   5.7568872375030766E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,  -5.7568872375030766E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,   5.7568872375030766E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,  -5.7568872375030766E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,  -5.7568872375030766E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,   5.7568872375030766E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,  -5.7568872375030766E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,   5.1034473953427895E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,   5.1034473953427895E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,  -5.1034473953427895E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,   5.1034473953427895E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,  -5.1034473953427895E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   6.3885110955247693E-01,  -5.1034473953427895E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,   5.1034473953427895E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -6.3885110955247693E-01,  -5.1034473953427895E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,   6.3885110955247693E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,   6.3885110955247693E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,  -6.3885110955247693E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,   6.3885110955247693E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,  -6.3885110955247693E-01,   5.1034473953427895E-01,   2.3871434718338485E-03],
            [   5.7568872375030766E-01,  -6.3885110955247693E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,   6.3885110955247693E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [  -5.7568872375030766E-01,  -6.3885110955247693E-01,  -5.1034473953427895E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,   6.3885110955247693E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,   6.3885110955247693E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,  -6.3885110955247693E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,   6.3885110955247693E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,  -6.3885110955247693E-01,   5.7568872375030766E-01,   2.3871434718338485E-03],
            [   5.1034473953427895E-01,  -6.3885110955247693E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,   6.3885110955247693E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [  -5.1034473953427895E-01,  -6.3885110955247693E-01,  -5.7568872375030766E-01,   2.3871434718338485E-03],
            [   1.2250394305883520E-01,   2.1364559226557930E-02,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,   2.1364559226557930E-02,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,  -2.1364559226557930E-02,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,   2.1364559226557930E-02,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,  -2.1364559226557930E-02,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,  -2.1364559226557930E-02,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,   2.1364559226557930E-02,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,  -2.1364559226557930E-02,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,   1.2250394305883520E-01,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,   1.2250394305883520E-01,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,  -1.2250394305883520E-01,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,   1.2250394305883520E-01,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,  -1.2250394305883520E-01,   9.9223804580558816E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,  -1.2250394305883520E-01,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,   1.2250394305883520E-01,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,  -1.2250394305883520E-01,  -9.9223804580558816E-01,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,   1.2250394305883520E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,   1.2250394305883520E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,  -1.2250394305883520E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,   1.2250394305883520E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,  -1.2250394305883520E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,  -1.2250394305883520E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,   1.2250394305883520E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,  -1.2250394305883520E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,   2.1364559226557930E-02,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,   2.1364559226557930E-02,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,  -2.1364559226557930E-02,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,   2.1364559226557930E-02,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,  -2.1364559226557930E-02,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   9.9223804580558816E-01,  -2.1364559226557930E-02,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,   2.1364559226557930E-02,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -9.9223804580558816E-01,  -2.1364559226557930E-02,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,   9.9223804580558816E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,   9.9223804580558816E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,  -9.9223804580558816E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,   9.9223804580558816E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,  -9.9223804580558816E-01,   2.1364559226557930E-02,   1.4115827095022486E-03],
            [   1.2250394305883520E-01,  -9.9223804580558816E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,   9.9223804580558816E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [  -1.2250394305883520E-01,  -9.9223804580558816E-01,  -2.1364559226557930E-02,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,   9.9223804580558816E-01,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,   9.9223804580558816E-01,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,  -9.9223804580558816E-01,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,   9.9223804580558816E-01,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,  -9.9223804580558816E-01,   1.2250394305883520E-01,   1.4115827095022486E-03],
            [   2.1364559226557930E-02,  -9.9223804580558816E-01,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,   9.9223804580558816E-01,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [  -2.1364559226557930E-02,  -9.9223804580558816E-01,  -1.2250394305883520E-01,   1.4115827095022486E-03],
            [   1.5391132173213720E-01,   4.5209261661371881E-02,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,   4.5209261661371881E-02,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,  -4.5209261661371881E-02,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,   4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,  -4.5209261661371881E-02,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,  -4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,   4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,  -4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,   1.5391132173213720E-01,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,   1.5391132173213720E-01,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,  -1.5391132173213720E-01,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,   1.5391132173213720E-01,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,  -1.5391132173213720E-01,   9.8704986079868329E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,  -1.5391132173213720E-01,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,   1.5391132173213720E-01,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,  -1.5391132173213720E-01,  -9.8704986079868329E-01,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,   1.5391132173213720E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,   1.5391132173213720E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,  -1.5391132173213720E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,   1.5391132173213720E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,  -1.5391132173213720E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,  -1.5391132173213720E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,   1.5391132173213720E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,  -1.5391132173213720E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,   4.5209261661371881E-02,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,   4.5209261661371881E-02,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,   4.5209261661371881E-02,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   9.8704986079868329E-01,  -4.5209261661371881E-02,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,   4.5209261661371881E-02,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -9.8704986079868329E-01,  -4.5209261661371881E-02,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,   9.8704986079868329E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,   9.8704986079868329E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,  -9.8704986079868329E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,   9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,  -9.8704986079868329E-01,   4.5209261661371881E-02,   1.5754444095241163E-03],
            [   1.5391132173213720E-01,  -9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,   9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [  -1.5391132173213720E-01,  -9.8704986079868329E-01,  -4.5209261661371881E-02,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,   9.8704986079868329E-01,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,   9.8704986079868329E-01,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,   9.8704986079868329E-01,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,  -9.8704986079868329E-01,   1.5391132173213720E-01,   1.5754444095241163E-03],
            [   4.5209261661371881E-02,  -9.8704986079868329E-01,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,   9.8704986079868329E-01,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [  -4.5209261661371881E-02,  -9.8704986079868329E-01,  -1.5391132173213720E-01,   1.5754444095241163E-03],
            [   1.8562130986377121E-01,   7.0864681778648186E-02,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,   7.0864681778648186E-02,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,  -7.0864681778648186E-02,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,   7.0864681778648186E-02,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,  -7.0864681778648186E-02,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,  -7.0864681778648186E-02,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,   7.0864681778648186E-02,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,  -7.0864681778648186E-02,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,   1.8562130986377121E-01,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,   1.8562130986377121E-01,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,  -1.8562130986377121E-01,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,   1.8562130986377121E-01,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,  -1.8562130986377121E-01,   9.8006271544267454E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,  -1.8562130986377121E-01,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,   1.8562130986377121E-01,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,  -1.8562130986377121E-01,  -9.8006271544267454E-01,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,   1.8562130986377121E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,   1.8562130986377121E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,  -1.8562130986377121E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,   1.8562130986377121E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,  -1.8562130986377121E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,  -1.8562130986377121E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,   1.8562130986377121E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,  -1.8562130986377121E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,   7.0864681778648186E-02,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,   7.0864681778648186E-02,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,  -7.0864681778648186E-02,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,   7.0864681778648186E-02,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,  -7.0864681778648186E-02,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   9.8006271544267454E-01,  -7.0864681778648186E-02,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,   7.0864681778648186E-02,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -9.8006271544267454E-01,  -7.0864681778648186E-02,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,   9.8006271544267454E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,   9.8006271544267454E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,  -9.8006271544267454E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,   9.8006271544267454E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,  -9.8006271544267454E-01,   7.0864681778648186E-02,   1.7169006392590083E-03],
            [   1.8562130986377121E-01,  -9.8006271544267454E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,   9.8006271544267454E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [  -1.8562130986377121E-01,  -9.8006271544267454E-01,  -7.0864681778648186E-02,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,   9.8006271544267454E-01,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,   9.8006271544267454E-01,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,  -9.8006271544267454E-01,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,   9.8006271544267454E-01,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,  -9.8006271544267454E-01,   1.8562130986377121E-01,   1.7169006392590083E-03],
            [   7.0864681778648186E-02,  -9.8006271544267454E-01,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,   9.8006271544267454E-01,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [  -7.0864681778648186E-02,  -9.8006271544267454E-01,  -1.8562130986377121E-01,   1.7169006392590083E-03],
            [   2.1749987280351310E-01,   9.7852394887729177E-02,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,   9.7852394887729177E-02,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,  -9.7852394887729177E-02,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,   9.7852394887729177E-02,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,  -9.7852394887729177E-02,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,  -9.7852394887729177E-02,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,   9.7852394887729177E-02,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,  -9.7852394887729177E-02,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,   2.1749987280351310E-01,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,   2.1749987280351310E-01,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,  -2.1749987280351310E-01,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,   2.1749987280351310E-01,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,  -2.1749987280351310E-01,   9.7114299366529522E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,  -2.1749987280351310E-01,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,   2.1749987280351310E-01,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,  -2.1749987280351310E-01,  -9.7114299366529522E-01,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,   2.1749987280351310E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,   2.1749987280351310E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,  -2.1749987280351310E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,   2.1749987280351310E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,  -2.1749987280351310E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,  -2.1749987280351310E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,   2.1749987280351310E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,  -2.1749987280351310E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,   9.7852394887729177E-02,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,   9.7852394887729177E-02,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,  -9.7852394887729177E-02,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,   9.7852394887729177E-02,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,  -9.7852394887729177E-02,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7114299366529522E-01,  -9.7852394887729177E-02,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,   9.7852394887729177E-02,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7114299366529522E-01,  -9.7852394887729177E-02,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,   9.7114299366529522E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,   9.7114299366529522E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,  -9.7114299366529522E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,   9.7114299366529522E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,  -9.7114299366529522E-01,   9.7852394887729177E-02,   1.8381293445122095E-03],
            [   2.1749987280351310E-01,  -9.7114299366529522E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,   9.7114299366529522E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [  -2.1749987280351310E-01,  -9.7114299366529522E-01,  -9.7852394887729177E-02,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,   9.7114299366529522E-01,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,   9.7114299366529522E-01,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,  -9.7114299366529522E-01,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,   9.7114299366529522E-01,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,  -9.7114299366529522E-01,   2.1749987280351310E-01,   1.8381293445122095E-03],
            [   9.7852394887729177E-02,  -9.7114299366529522E-01,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,   9.7114299366529522E-01,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [  -9.7852394887729177E-02,  -9.7114299366529522E-01,  -2.1749987280351310E-01,   1.8381293445122095E-03],
            [   2.4941283369383299E-01,   1.2581063962672101E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,   1.2581063962672101E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,  -1.2581063962672101E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,   1.2581063962672101E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,  -1.2581063962672101E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,  -1.2581063962672101E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,   1.2581063962672101E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,  -1.2581063962672101E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,   2.4941283369383299E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,   2.4941283369383299E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,  -2.4941283369383299E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,   2.4941283369383299E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,  -2.4941283369383299E-01,   9.6019004438992583E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,  -2.4941283369383299E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,   2.4941283369383299E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,  -2.4941283369383299E-01,  -9.6019004438992583E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,   2.4941283369383299E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,   2.4941283369383299E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,  -2.4941283369383299E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,   2.4941283369383299E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,  -2.4941283369383299E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,  -2.4941283369383299E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,   2.4941283369383299E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,  -2.4941283369383299E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,   1.2581063962672101E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,   1.2581063962672101E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,  -1.2581063962672101E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,   1.2581063962672101E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,  -1.2581063962672101E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   9.6019004438992583E-01,  -1.2581063962672101E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,   1.2581063962672101E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -9.6019004438992583E-01,  -1.2581063962672101E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,   9.6019004438992583E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,   9.6019004438992583E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,  -9.6019004438992583E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,   9.6019004438992583E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,  -9.6019004438992583E-01,   1.2581063962672101E-01,   1.9416003507893458E-03],
            [   2.4941283369383299E-01,  -9.6019004438992583E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,   9.6019004438992583E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [  -2.4941283369383299E-01,  -9.6019004438992583E-01,  -1.2581063962672101E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,   9.6019004438992583E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,   9.6019004438992583E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,  -9.6019004438992583E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,   9.6019004438992583E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,  -9.6019004438992583E-01,   2.4941283369383299E-01,   1.9416003507893458E-03],
            [   1.2581063962672101E-01,  -9.6019004438992583E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,   9.6019004438992583E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [  -1.2581063962672101E-01,  -9.6019004438992583E-01,  -2.4941283369383299E-01,   1.9416003507893458E-03],
            [   2.8123215621434799E-01,   1.5445291250470011E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,   1.5445291250470011E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,  -1.5445291250470011E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,   1.5445291250470011E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,  -1.5445291250470011E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,  -1.5445291250470011E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,   1.5445291250470011E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,  -1.5445291250470011E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,   2.8123215621434799E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,   2.8123215621434799E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,  -2.8123215621434799E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,   2.8123215621434799E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,  -2.8123215621434799E-01,   9.4712869882072726E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,  -2.8123215621434799E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,   2.8123215621434799E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,  -2.8123215621434799E-01,  -9.4712869882072726E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,   2.8123215621434799E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,   2.8123215621434799E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,  -2.8123215621434799E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,   2.8123215621434799E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,  -2.8123215621434799E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,  -2.8123215621434799E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,   2.8123215621434799E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,  -2.8123215621434799E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,   1.5445291250470011E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,   1.5445291250470011E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,  -1.5445291250470011E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,   1.5445291250470011E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,  -1.5445291250470011E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   9.4712869882072726E-01,  -1.5445291250470011E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,   1.5445291250470011E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -9.4712869882072726E-01,  -1.5445291250470011E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,   9.4712869882072726E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,   9.4712869882072726E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,  -9.4712869882072726E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,   9.4712869882072726E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,  -9.4712869882072726E-01,   1.5445291250470011E-01,   2.0295898442581925E-03],
            [   2.8123215621434799E-01,  -9.4712869882072726E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,   9.4712869882072726E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [  -2.8123215621434799E-01,  -9.4712869882072726E-01,  -1.5445291250470011E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,   9.4712869882072726E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,   9.4712869882072726E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,  -9.4712869882072726E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,   9.4712869882072726E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,  -9.4712869882072726E-01,   2.8123215621434799E-01,   2.0295898442581925E-03],
            [   1.5445291250470011E-01,  -9.4712869882072726E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,   9.4712869882072726E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [  -1.5445291250470011E-01,  -9.4712869882072726E-01,  -2.8123215621434799E-01,   2.0295898442581925E-03],
            [   3.1283722764561112E-01,   1.8354335122027529E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,   1.8354335122027529E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,  -1.8354335122027529E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,   1.8354335122027529E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,  -1.8354335122027529E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,  -1.8354335122027529E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,   1.8354335122027529E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,  -1.8354335122027529E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,   3.1283722764561112E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,   3.1283722764561112E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,  -3.1283722764561112E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,   3.1283722764561112E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,  -3.1283722764561112E-01,   9.3190380792324201E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,  -3.1283722764561112E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,   3.1283722764561112E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,  -3.1283722764561112E-01,  -9.3190380792324201E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,   3.1283722764561112E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,   3.1283722764561112E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,  -3.1283722764561112E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,   3.1283722764561112E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,  -3.1283722764561112E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,  -3.1283722764561112E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,   3.1283722764561112E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,  -3.1283722764561112E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,   1.8354335122027529E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,   1.8354335122027529E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,  -1.8354335122027529E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,   1.8354335122027529E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,  -1.8354335122027529E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   9.3190380792324201E-01,  -1.8354335122027529E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,   1.8354335122027529E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -9.3190380792324201E-01,  -1.8354335122027529E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,   9.3190380792324201E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,   9.3190380792324201E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,  -9.3190380792324201E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,   9.3190380792324201E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,  -9.3190380792324201E-01,   1.8354335122027529E-01,   2.1040711739314152E-03],
            [   3.1283722764561112E-01,  -9.3190380792324201E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,   9.3190380792324201E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [  -3.1283722764561112E-01,  -9.3190380792324201E-01,  -1.8354335122027529E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,   9.3190380792324201E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,   9.3190380792324201E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,  -9.3190380792324201E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,   9.3190380792324201E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,  -9.3190380792324201E-01,   3.1283722764561112E-01,   2.1040711739314152E-03],
            [   1.8354335122027529E-01,  -9.3190380792324201E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,   9.3190380792324201E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [  -1.8354335122027529E-01,  -9.3190380792324201E-01,  -3.1283722764561112E-01,   2.1040711739314152E-03],
            [   3.4411451601779730E-01,   2.1288132586195849E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,   2.1288132586195849E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,  -2.1288132586195849E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,   2.1288132586195849E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,  -2.1288132586195849E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,  -2.1288132586195849E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,   2.1288132586195849E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,  -2.1288132586195849E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,   3.4411451601779730E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,   3.4411451601779730E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,  -3.4411451601779730E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,   3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,  -3.4411451601779730E-01,   9.1447621126254119E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,  -3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,   3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,  -3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,   3.4411451601779730E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,   3.4411451601779730E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,   3.4411451601779730E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,  -3.4411451601779730E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,   3.4411451601779730E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,  -3.4411451601779730E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,   2.1288132586195849E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,   2.1288132586195849E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,  -2.1288132586195849E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,   2.1288132586195849E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,  -2.1288132586195849E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   9.1447621126254119E-01,  -2.1288132586195849E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,   2.1288132586195849E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -9.1447621126254119E-01,  -2.1288132586195849E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,   9.1447621126254119E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,   9.1447621126254119E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,   9.1447621126254119E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,  -9.1447621126254119E-01,   2.1288132586195849E-01,   2.1667250403179000E-03],
            [   3.4411451601779730E-01,  -9.1447621126254119E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,   9.1447621126254119E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [  -3.4411451601779730E-01,  -9.1447621126254119E-01,  -2.1288132586195849E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,   9.1447621126254119E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,   9.1447621126254119E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,  -9.1447621126254119E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,   9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,  -9.1447621126254119E-01,   3.4411451601779730E-01,   2.1667250403179000E-03],
            [   2.1288132586195849E-01,  -9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,   9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [  -2.1288132586195849E-01,  -9.1447621126254119E-01,  -3.4411451601779730E-01,   2.1667250403179000E-03],
            [   3.7495677148535100E-01,   2.4229137348808291E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,   2.4229137348808291E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,  -2.4229137348808291E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,   2.4229137348808291E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,  -2.4229137348808291E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,  -2.4229137348808291E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,   2.4229137348808291E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,  -2.4229137348808291E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,   3.7495677148535100E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,   3.7495677148535100E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,  -3.7495677148535100E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,   3.7495677148535100E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,  -3.7495677148535100E-01,   8.9481970801415667E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,  -3.7495677148535100E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,   3.7495677148535100E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,  -3.7495677148535100E-01,  -8.9481970801415667E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,   3.7495677148535100E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,   3.7495677148535100E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,  -3.7495677148535100E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,   3.7495677148535100E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,  -3.7495677148535100E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,  -3.7495677148535100E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,   3.7495677148535100E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,  -3.7495677148535100E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,   2.4229137348808291E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,   2.4229137348808291E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,  -2.4229137348808291E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,   2.4229137348808291E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,  -2.4229137348808291E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   8.9481970801415667E-01,  -2.4229137348808291E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,   2.4229137348808291E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -8.9481970801415667E-01,  -2.4229137348808291E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,   8.9481970801415667E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,   8.9481970801415667E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,  -8.9481970801415667E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,   8.9481970801415667E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,  -8.9481970801415667E-01,   2.4229137348808291E-01,   2.2189833236504843E-03],
            [   3.7495677148535100E-01,  -8.9481970801415667E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,   8.9481970801415667E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [  -3.7495677148535100E-01,  -8.9481970801415667E-01,  -2.4229137348808291E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,   8.9481970801415667E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,   8.9481970801415667E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,  -8.9481970801415667E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,   8.9481970801415667E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,  -8.9481970801415667E-01,   3.7495677148535100E-01,   2.2189833236504843E-03],
            [   2.4229137348808291E-01,  -8.9481970801415667E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,   8.9481970801415667E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [  -2.4229137348808291E-01,  -8.9481970801415667E-01,  -3.7495677148535100E-01,   2.2189833236504843E-03],
            [   4.0526217320156099E-01,   2.7161637483914530E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,   2.7161637483914530E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,  -2.7161637483914530E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,   2.7161637483914530E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,  -2.7161637483914530E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,  -2.7161637483914530E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,   2.7161637483914530E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,  -2.7161637483914530E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,   4.0526217320156099E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,   4.0526217320156099E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,  -4.0526217320156099E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,   4.0526217320156099E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,  -4.0526217320156099E-01,   8.7291873384135188E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,  -4.0526217320156099E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,   4.0526217320156099E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,  -4.0526217320156099E-01,  -8.7291873384135188E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,   4.0526217320156099E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,   4.0526217320156099E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,  -4.0526217320156099E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,   4.0526217320156099E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,  -4.0526217320156099E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,  -4.0526217320156099E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,   4.0526217320156099E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,  -4.0526217320156099E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,   2.7161637483914530E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,   2.7161637483914530E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,  -2.7161637483914530E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,   2.7161637483914530E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,  -2.7161637483914530E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   8.7291873384135188E-01,  -2.7161637483914530E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,   2.7161637483914530E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -8.7291873384135188E-01,  -2.7161637483914530E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,   8.7291873384135188E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,   8.7291873384135188E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,  -8.7291873384135188E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,   8.7291873384135188E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,  -8.7291873384135188E-01,   2.7161637483914530E-01,   2.2620775591888202E-03],
            [   4.0526217320156099E-01,  -8.7291873384135188E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,   8.7291873384135188E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [  -4.0526217320156099E-01,  -8.7291873384135188E-01,  -2.7161637483914530E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,   8.7291873384135188E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,   8.7291873384135188E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,  -8.7291873384135188E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,   8.7291873384135188E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,  -8.7291873384135188E-01,   4.0526217320156099E-01,   2.2620775591888202E-03],
            [   2.7161637483914530E-01,  -8.7291873384135188E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,   8.7291873384135188E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [  -2.7161637483914530E-01,  -8.7291873384135188E-01,  -4.0526217320156099E-01,   2.2620775591888202E-03],
            [   4.3493354535223849E-01,   3.0071276712402800E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,   3.0071276712402800E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,  -3.0071276712402800E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,   3.0071276712402800E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,  -3.0071276712402800E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,  -3.0071276712402800E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,   3.0071276712402800E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,  -3.0071276712402800E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,   4.3493354535223849E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,   4.3493354535223849E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,  -4.3493354535223849E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,   4.3493354535223849E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,  -4.3493354535223849E-01,   8.4876654199841217E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,  -4.3493354535223849E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,   4.3493354535223849E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,  -4.3493354535223849E-01,  -8.4876654199841217E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,   4.3493354535223849E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,   4.3493354535223849E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,  -4.3493354535223849E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,   4.3493354535223849E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,  -4.3493354535223849E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,  -4.3493354535223849E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,   4.3493354535223849E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,  -4.3493354535223849E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,   3.0071276712402800E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,   3.0071276712402800E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,  -3.0071276712402800E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,   3.0071276712402800E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,  -3.0071276712402800E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   8.4876654199841217E-01,  -3.0071276712402800E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,   3.0071276712402800E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -8.4876654199841217E-01,  -3.0071276712402800E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,   8.4876654199841217E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,   8.4876654199841217E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,  -8.4876654199841217E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,   8.4876654199841217E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,  -8.4876654199841217E-01,   3.0071276712402800E-01,   2.2970828323890988E-03],
            [   4.3493354535223849E-01,  -8.4876654199841217E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,   8.4876654199841217E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [  -4.3493354535223849E-01,  -8.4876654199841217E-01,  -3.0071276712402800E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,   8.4876654199841217E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,   8.4876654199841217E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,  -8.4876654199841217E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,   8.4876654199841217E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,  -8.4876654199841217E-01,   4.3493354535223849E-01,   2.2970828323890988E-03],
            [   3.0071276712402800E-01,  -8.4876654199841217E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,   8.4876654199841217E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [  -3.0071276712402800E-01,  -8.4876654199841217E-01,  -4.3493354535223849E-01,   2.2970828323890988E-03],
            [   4.6387766415249648E-01,   3.2944706772164789E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,   3.2944706772164789E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,  -3.2944706772164789E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,   3.2944706772164789E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,  -3.2944706772164789E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,  -3.2944706772164789E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,   3.2944706772164789E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,  -3.2944706772164789E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,   4.6387766415249648E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,   4.6387766415249648E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,  -4.6387766415249648E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,   4.6387766415249648E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,  -4.6387766415249648E-01,   8.2236375301324627E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,  -4.6387766415249648E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,   4.6387766415249648E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,  -4.6387766415249648E-01,  -8.2236375301324627E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,   4.6387766415249648E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,   4.6387766415249648E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,  -4.6387766415249648E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,   4.6387766415249648E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,  -4.6387766415249648E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,  -4.6387766415249648E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,   4.6387766415249648E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,  -4.6387766415249648E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,   3.2944706772164789E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,   3.2944706772164789E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,  -3.2944706772164789E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,   3.2944706772164789E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,  -3.2944706772164789E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   8.2236375301324627E-01,  -3.2944706772164789E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,   3.2944706772164789E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -8.2236375301324627E-01,  -3.2944706772164789E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,   8.2236375301324627E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,   8.2236375301324627E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,  -8.2236375301324627E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,   8.2236375301324627E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,  -8.2236375301324627E-01,   3.2944706772164789E-01,   2.3249548707363053E-03],
            [   4.6387766415249648E-01,  -8.2236375301324627E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,   8.2236375301324627E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [  -4.6387766415249648E-01,  -8.2236375301324627E-01,  -3.2944706772164789E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,   8.2236375301324627E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,   8.2236375301324627E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,  -8.2236375301324627E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,   8.2236375301324627E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,  -8.2236375301324627E-01,   4.6387766415249648E-01,   2.3249548707363053E-03],
            [   3.2944706772164789E-01,  -8.2236375301324627E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,   8.2236375301324627E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [  -3.2944706772164789E-01,  -8.2236375301324627E-01,  -4.6387766415249648E-01,   2.3249548707363053E-03],
            [   4.9200464104626868E-01,   3.5769325436991550E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,   3.5769325436991550E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,  -3.5769325436991550E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,   3.5769325436991550E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,  -3.5769325436991550E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,  -3.5769325436991550E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,   3.5769325436991550E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,  -3.5769325436991550E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,   4.9200464104626868E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,   4.9200464104626868E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,  -4.9200464104626868E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,   4.9200464104626868E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,  -4.9200464104626868E-01,   7.9371718449784823E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,  -4.9200464104626868E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,   4.9200464104626868E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,  -4.9200464104626868E-01,  -7.9371718449784823E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,   4.9200464104626868E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,   4.9200464104626868E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,  -4.9200464104626868E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,   4.9200464104626868E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,  -4.9200464104626868E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,  -4.9200464104626868E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,   4.9200464104626868E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,  -4.9200464104626868E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,   3.5769325436991550E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,   3.5769325436991550E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,  -3.5769325436991550E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,   3.5769325436991550E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,  -3.5769325436991550E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   7.9371718449784823E-01,  -3.5769325436991550E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,   3.5769325436991550E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -7.9371718449784823E-01,  -3.5769325436991550E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,   7.9371718449784823E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,   7.9371718449784823E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,  -7.9371718449784823E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,   7.9371718449784823E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,  -7.9371718449784823E-01,   3.5769325436991550E-01,   2.3465604914535997E-03],
            [   4.9200464104626868E-01,  -7.9371718449784823E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,   7.9371718449784823E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [  -4.9200464104626868E-01,  -7.9371718449784823E-01,  -3.5769325436991550E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,   7.9371718449784823E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,   7.9371718449784823E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,  -7.9371718449784823E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,   7.9371718449784823E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,  -7.9371718449784823E-01,   4.9200464104626868E-01,   2.3465604914535997E-03],
            [   3.5769325436991550E-01,  -7.9371718449784823E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,   7.9371718449784823E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [  -3.5769325436991550E-01,  -7.9371718449784823E-01,  -4.9200464104626868E-01,   2.3465604914535997E-03],
            [   5.1922735548617038E-01,   3.8533070597577640E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,   3.8533070597577640E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,  -3.8533070597577640E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,   3.8533070597577640E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,  -3.8533070597577640E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,  -3.8533070597577640E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,   3.8533070597577640E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,  -3.8533070597577640E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,   5.1922735548617038E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,   5.1922735548617038E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,  -5.1922735548617038E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,   5.1922735548617038E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,  -5.1922735548617038E-01,   7.6283890851676395E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,  -5.1922735548617038E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,   5.1922735548617038E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,  -5.1922735548617038E-01,  -7.6283890851676395E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,   5.1922735548617038E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,   5.1922735548617038E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,  -5.1922735548617038E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,   5.1922735548617038E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,  -5.1922735548617038E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,  -5.1922735548617038E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,   5.1922735548617038E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,  -5.1922735548617038E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,   3.8533070597577640E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,   3.8533070597577640E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,  -3.8533070597577640E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,   3.8533070597577640E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,  -3.8533070597577640E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   7.6283890851676395E-01,  -3.8533070597577640E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,   3.8533070597577640E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -7.6283890851676395E-01,  -3.8533070597577640E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,   7.6283890851676395E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,   7.6283890851676395E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,  -7.6283890851676395E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,   7.6283890851676395E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,  -7.6283890851676395E-01,   3.8533070597577640E-01,   2.3627022222648558E-03],
            [   5.1922735548617038E-01,  -7.6283890851676395E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,   7.6283890851676395E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [  -5.1922735548617038E-01,  -7.6283890851676395E-01,  -3.8533070597577640E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,   7.6283890851676395E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,   7.6283890851676395E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,  -7.6283890851676395E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,   7.6283890851676395E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,  -7.6283890851676395E-01,   5.1922735548617038E-01,   2.3627022222648558E-03],
            [   3.8533070597577640E-01,  -7.6283890851676395E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,   7.6283890851676395E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [  -3.8533070597577640E-01,  -7.6283890851676395E-01,  -5.1922735548617038E-01,   2.3627022222648558E-03],
            [   5.4546090811365222E-01,   4.1224250444526939E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,   4.1224250444526939E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,  -4.1224250444526939E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,   4.1224250444526939E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,  -4.1224250444526939E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,  -4.1224250444526939E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,   4.1224250444526939E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,  -4.1224250444526939E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,   5.4546090811365222E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,   5.4546090811365222E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,  -5.4546090811365222E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,   5.4546090811365222E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,  -5.4546090811365222E-01,   7.2974551403110510E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,  -5.4546090811365222E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,   5.4546090811365222E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,  -5.4546090811365222E-01,  -7.2974551403110510E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,   5.4546090811365222E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,   5.4546090811365222E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,  -5.4546090811365222E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,   5.4546090811365222E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,  -5.4546090811365222E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,  -5.4546090811365222E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,   5.4546090811365222E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,  -5.4546090811365222E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,   4.1224250444526939E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,   4.1224250444526939E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,  -4.1224250444526939E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,   4.1224250444526939E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,  -4.1224250444526939E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   7.2974551403110510E-01,  -4.1224250444526939E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,   4.1224250444526939E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -7.2974551403110510E-01,  -4.1224250444526939E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,   7.2974551403110510E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,   7.2974551403110510E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,  -7.2974551403110510E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,   7.2974551403110510E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,  -7.2974551403110510E-01,   4.1224250444526939E-01,   2.3741379173676017E-03],
            [   5.4546090811365222E-01,  -7.2974551403110510E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,   7.2974551403110510E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [  -5.4546090811365222E-01,  -7.2974551403110510E-01,  -4.1224250444526939E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,   7.2974551403110510E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,   7.2974551403110510E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,  -7.2974551403110510E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,   7.2974551403110510E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,  -7.2974551403110510E-01,   5.4546090811365222E-01,   2.3741379173676017E-03],
            [   4.1224250444526939E-01,  -7.2974551403110510E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,   7.2974551403110510E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [  -4.1224250444526939E-01,  -7.2974551403110510E-01,  -5.4546090811365222E-01,   2.3741379173676017E-03],
            [   5.7062206614241395E-01,   4.3831395877810270E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,   4.3831395877810270E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,  -4.3831395877810270E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,   4.3831395877810270E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,  -4.3831395877810270E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,  -4.3831395877810270E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,   4.3831395877810270E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,  -4.3831395877810270E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,   5.7062206614241395E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,   5.7062206614241395E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,  -5.7062206614241395E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,   5.7062206614241395E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,  -5.7062206614241395E-01,   6.9445758054155504E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,  -5.7062206614241395E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,   5.7062206614241395E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,  -5.7062206614241395E-01,  -6.9445758054155504E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,   5.7062206614241395E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,   5.7062206614241395E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,  -5.7062206614241395E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,   5.7062206614241395E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,  -5.7062206614241395E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,  -5.7062206614241395E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,   5.7062206614241395E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,  -5.7062206614241395E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,   4.3831395877810270E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,   4.3831395877810270E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,  -4.3831395877810270E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,   4.3831395877810270E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,  -4.3831395877810270E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   6.9445758054155504E-01,  -4.3831395877810270E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,   4.3831395877810270E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -6.9445758054155504E-01,  -4.3831395877810270E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,   6.9445758054155504E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,   6.9445758054155504E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,  -6.9445758054155504E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,   6.9445758054155504E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,  -6.9445758054155504E-01,   4.3831395877810270E-01,   2.3815959412747337E-03],
            [   5.7062206614241395E-01,  -6.9445758054155504E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,   6.9445758054155504E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [  -5.7062206614241395E-01,  -6.9445758054155504E-01,  -4.3831395877810270E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,   6.9445758054155504E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,   6.9445758054155504E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,  -6.9445758054155504E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,   6.9445758054155504E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,  -6.9445758054155504E-01,   5.7062206614241395E-01,   2.3815959412747337E-03],
            [   4.3831395877810270E-01,  -6.9445758054155504E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,   6.9445758054155504E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [  -4.3831395877810270E-01,  -6.9445758054155504E-01,  -5.7062206614241395E-01,   2.3815959412747337E-03],
            [   5.9462867551815179E-01,   4.6343125363005527E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,   4.6343125363005527E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,  -4.6343125363005527E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,   4.6343125363005527E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,  -4.6343125363005527E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,  -4.6343125363005527E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,   4.6343125363005527E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,  -4.6343125363005527E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,   5.9462867551815179E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,   5.9462867551815179E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,  -5.9462867551815179E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,   5.9462867551815179E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,  -5.9462867551815179E-01,   6.5699939985543665E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,  -5.9462867551815179E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,   5.9462867551815179E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,  -5.9462867551815179E-01,  -6.5699939985543665E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,   5.9462867551815179E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,   5.9462867551815179E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,  -5.9462867551815179E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,   5.9462867551815179E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,  -5.9462867551815179E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,  -5.9462867551815179E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,   5.9462867551815179E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,  -5.9462867551815179E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,   4.6343125363005527E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,   4.6343125363005527E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,  -4.6343125363005527E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,   4.6343125363005527E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,  -4.6343125363005527E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   6.5699939985543665E-01,  -4.6343125363005527E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,   4.6343125363005527E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -6.5699939985543665E-01,  -4.6343125363005527E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,   6.5699939985543665E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,   6.5699939985543665E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,  -6.5699939985543665E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,   6.5699939985543665E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,  -6.5699939985543665E-01,   4.6343125363005527E-01,   2.3857861283029165E-03],
            [   5.9462867551815179E-01,  -6.5699939985543665E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,   6.5699939985543665E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [  -5.9462867551815179E-01,  -6.5699939985543665E-01,  -4.6343125363005527E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,   6.5699939985543665E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,   6.5699939985543665E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,  -6.5699939985543665E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,   6.5699939985543665E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,  -6.5699939985543665E-01,   5.9462867551815179E-01,   2.3857861283029165E-03],
            [   4.6343125363005527E-01,  -6.5699939985543665E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,   6.5699939985543665E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [  -4.6343125363005527E-01,  -6.5699939985543665E-01,  -5.9462867551815179E-01,   2.3857861283029165E-03],
            [   1.9053707909242951E-01,   2.3713115377819789E-02,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,   2.3713115377819789E-02,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,  -2.3713115377819789E-02,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,   2.3713115377819789E-02,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,  -2.3713115377819789E-02,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,  -2.3713115377819789E-02,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,   2.3713115377819789E-02,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,  -2.3713115377819789E-02,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,   1.9053707909242951E-01,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,   1.9053707909242951E-01,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,  -1.9053707909242951E-01,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,   1.9053707909242951E-01,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,  -1.9053707909242951E-01,   9.8139355492585312E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,  -1.9053707909242951E-01,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,   1.9053707909242951E-01,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,  -1.9053707909242951E-01,  -9.8139355492585312E-01,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,   1.9053707909242951E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,   1.9053707909242951E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,  -1.9053707909242951E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,   1.9053707909242951E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,  -1.9053707909242951E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,  -1.9053707909242951E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,   1.9053707909242951E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,  -1.9053707909242951E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,   2.3713115377819789E-02,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,   2.3713115377819789E-02,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,  -2.3713115377819789E-02,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,   2.3713115377819789E-02,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,  -2.3713115377819789E-02,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   9.8139355492585312E-01,  -2.3713115377819789E-02,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,   2.3713115377819789E-02,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -9.8139355492585312E-01,  -2.3713115377819789E-02,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,   9.8139355492585312E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,   9.8139355492585312E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,  -9.8139355492585312E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,   9.8139355492585312E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,  -9.8139355492585312E-01,   2.3713115377819789E-02,   1.6953365189020532E-03],
            [   1.9053707909242951E-01,  -9.8139355492585312E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,   9.8139355492585312E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [  -1.9053707909242951E-01,  -9.8139355492585312E-01,  -2.3713115377819789E-02,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,   9.8139355492585312E-01,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,   9.8139355492585312E-01,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,  -9.8139355492585312E-01,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,   9.8139355492585312E-01,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,  -9.8139355492585312E-01,   1.9053707909242951E-01,   1.6953365189020532E-03],
            [   2.3713115377819789E-02,  -9.8139355492585312E-01,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,   9.8139355492585312E-01,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [  -2.3713115377819789E-02,  -9.8139355492585312E-01,  -1.9053707909242951E-01,   1.6953365189020532E-03],
            [   2.2425187177480091E-01,   4.9178780592548058E-02,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,   4.9178780592548058E-02,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,  -4.9178780592548058E-02,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,   4.9178780592548058E-02,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,  -4.9178780592548058E-02,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,  -4.9178780592548058E-02,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,   4.9178780592548058E-02,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,  -4.9178780592548058E-02,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,   2.2425187177480091E-01,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,   2.2425187177480091E-01,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,  -2.2425187177480091E-01,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,   2.2425187177480091E-01,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,  -2.2425187177480091E-01,   9.7328954866726491E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,  -2.2425187177480091E-01,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,   2.2425187177480091E-01,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,  -2.2425187177480091E-01,  -9.7328954866726491E-01,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,   2.2425187177480091E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,   2.2425187177480091E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,  -2.2425187177480091E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,   2.2425187177480091E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,  -2.2425187177480091E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,  -2.2425187177480091E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,   2.2425187177480091E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,  -2.2425187177480091E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,   4.9178780592548058E-02,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,   4.9178780592548058E-02,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,  -4.9178780592548058E-02,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,   4.9178780592548058E-02,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,  -4.9178780592548058E-02,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   9.7328954866726491E-01,  -4.9178780592548058E-02,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,   4.9178780592548058E-02,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -9.7328954866726491E-01,  -4.9178780592548058E-02,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,   9.7328954866726491E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,   9.7328954866726491E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,  -9.7328954866726491E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,   9.7328954866726491E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,  -9.7328954866726491E-01,   4.9178780592548058E-02,   1.8146594008525796E-03],
            [   2.2425187177480091E-01,  -9.7328954866726491E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,   9.7328954866726491E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [  -2.2425187177480091E-01,  -9.7328954866726491E-01,  -4.9178780592548058E-02,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,   9.7328954866726491E-01,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,   9.7328954866726491E-01,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,  -9.7328954866726491E-01,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,   9.7328954866726491E-01,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,  -9.7328954866726491E-01,   2.2425187177480091E-01,   1.8146594008525796E-03],
            [   4.9178780592548058E-02,  -9.7328954866726491E-01,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,   9.7328954866726491E-01,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [  -4.9178780592548058E-02,  -9.7328954866726491E-01,  -2.2425187177480091E-01,   1.8146594008525796E-03],
            [   2.5771908080259359E-01,   7.5954989604951423E-02,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,   7.5954989604951423E-02,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,  -7.5954989604951423E-02,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,   7.5954989604951423E-02,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,  -7.5954989604951423E-02,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,  -7.5954989604951423E-02,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,   7.5954989604951423E-02,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,  -7.5954989604951423E-02,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,   2.5771908080259359E-01,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,   2.5771908080259359E-01,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,  -2.5771908080259359E-01,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,   2.5771908080259359E-01,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,  -2.5771908080259359E-01,   9.6322983495341230E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,  -2.5771908080259359E-01,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,   2.5771908080259359E-01,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,  -2.5771908080259359E-01,  -9.6322983495341230E-01,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,   2.5771908080259359E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,   2.5771908080259359E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,  -2.5771908080259359E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,   2.5771908080259359E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,  -2.5771908080259359E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,  -2.5771908080259359E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,   2.5771908080259359E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,  -2.5771908080259359E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,   7.5954989604951423E-02,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,   7.5954989604951423E-02,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,  -7.5954989604951423E-02,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,   7.5954989604951423E-02,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,  -7.5954989604951423E-02,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   9.6322983495341230E-01,  -7.5954989604951423E-02,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,   7.5954989604951423E-02,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -9.6322983495341230E-01,  -7.5954989604951423E-02,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,   9.6322983495341230E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,   9.6322983495341230E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,  -9.6322983495341230E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,   9.6322983495341230E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,  -9.6322983495341230E-01,   7.5954989604951423E-02,   1.9186301867463106E-03],
            [   2.5771908080259359E-01,  -9.6322983495341230E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,   9.6322983495341230E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [  -2.5771908080259359E-01,  -9.6322983495341230E-01,  -7.5954989604951423E-02,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,   9.6322983495341230E-01,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,   9.6322983495341230E-01,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,  -9.6322983495341230E-01,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,   9.6322983495341230E-01,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,  -9.6322983495341230E-01,   2.5771908080259359E-01,   1.9186301867463106E-03],
            [   7.5954989604951423E-02,  -9.6322983495341230E-01,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,   9.6322983495341230E-01,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [  -7.5954989604951423E-02,  -9.6322983495341230E-01,  -2.5771908080259359E-01,   1.9186301867463106E-03],
            [   2.9087245349271867E-01,   1.0369910831911000E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,   1.0369910831911000E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,  -1.0369910831911000E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,   1.0369910831911000E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,  -1.0369910831911000E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,  -1.0369910831911000E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,   1.0369910831911000E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,  -1.0369910831911000E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,   2.9087245349271867E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,   2.9087245349271867E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,  -2.9087245349271867E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,   2.9087245349271867E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,  -2.9087245349271867E-01,   9.5112549683674641E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,  -2.9087245349271867E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,   2.9087245349271867E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,  -2.9087245349271867E-01,  -9.5112549683674641E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,   2.9087245349271867E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,   2.9087245349271867E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,  -2.9087245349271867E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,   2.9087245349271867E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,  -2.9087245349271867E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,  -2.9087245349271867E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,   2.9087245349271867E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,  -2.9087245349271867E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,   1.0369910831911000E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,   1.0369910831911000E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,  -1.0369910831911000E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,   1.0369910831911000E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,  -1.0369910831911000E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   9.5112549683674641E-01,  -1.0369910831911000E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,   1.0369910831911000E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -9.5112549683674641E-01,  -1.0369910831911000E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,   9.5112549683674641E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,   9.5112549683674641E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,  -9.5112549683674641E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,   9.5112549683674641E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,  -9.5112549683674641E-01,   1.0369910831911000E-01,   2.0083683740613392E-03],
            [   2.9087245349271867E-01,  -9.5112549683674641E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,   9.5112549683674641E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [  -2.9087245349271867E-01,  -9.5112549683674641E-01,  -1.0369910831911000E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,   9.5112549683674641E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,   9.5112549683674641E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,  -9.5112549683674641E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,   9.5112549683674641E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,  -9.5112549683674641E-01,   2.9087245349271867E-01,   2.0083683740613392E-03],
            [   1.0369910831911000E-01,  -9.5112549683674641E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,   9.5112549683674641E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [  -1.0369910831911000E-01,  -9.5112549683674641E-01,  -2.9087245349271867E-01,   2.0083683740613392E-03],
            [   3.2363540200562191E-01,   1.3213485844502340E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,   1.3213485844502340E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,  -1.3213485844502340E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,   1.3213485844502340E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,  -1.3213485844502340E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,  -1.3213485844502340E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,   1.3213485844502340E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,  -1.3213485844502340E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,   3.2363540200562191E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,   3.2363540200562191E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,  -3.2363540200562191E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,   3.2363540200562191E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,  -3.2363540200562191E-01,   9.3691008413421040E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,  -3.2363540200562191E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,   3.2363540200562191E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,  -3.2363540200562191E-01,  -9.3691008413421040E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,   3.2363540200562191E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,   3.2363540200562191E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,  -3.2363540200562191E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,   3.2363540200562191E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,  -3.2363540200562191E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,  -3.2363540200562191E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,   3.2363540200562191E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,  -3.2363540200562191E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,   1.3213485844502340E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,   1.3213485844502340E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,  -1.3213485844502340E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,   1.3213485844502340E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,  -1.3213485844502340E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   9.3691008413421040E-01,  -1.3213485844502340E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,   1.3213485844502340E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -9.3691008413421040E-01,  -1.3213485844502340E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,   9.3691008413421040E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,   9.3691008413421040E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,  -9.3691008413421040E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,   9.3691008413421040E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,  -9.3691008413421040E-01,   1.3213485844502340E-01,   2.0852061976576212E-03],
            [   3.2363540200562191E-01,  -9.3691008413421040E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,   9.3691008413421040E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [  -3.2363540200562191E-01,  -9.3691008413421040E-01,  -1.3213485844502340E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,   9.3691008413421040E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,   9.3691008413421040E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,  -9.3691008413421040E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,   9.3691008413421040E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,  -9.3691008413421040E-01,   3.2363540200562191E-01,   2.0852061976576212E-03],
            [   1.3213485844502340E-01,  -9.3691008413421040E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,   9.3691008413421040E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [  -1.3213485844502340E-01,  -9.3691008413421040E-01,  -3.2363540200562191E-01,   2.0852061976576212E-03],
            [   3.5592673593045432E-01,   1.6103165713147891E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,   1.6103165713147891E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,  -1.6103165713147891E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,   1.6103165713147891E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,  -1.6103165713147891E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,  -1.6103165713147891E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,   1.6103165713147891E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,  -1.6103165713147891E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,   3.5592673593045432E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,   3.5592673593045432E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,  -3.5592673593045432E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,   3.5592673593045432E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,  -3.5592673593045432E-01,   9.2053515090483229E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,  -3.5592673593045432E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,   3.5592673593045432E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,  -3.5592673593045432E-01,  -9.2053515090483229E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,   3.5592673593045432E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,   3.5592673593045432E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,  -3.5592673593045432E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,   3.5592673593045432E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,  -3.5592673593045432E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,  -3.5592673593045432E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,   3.5592673593045432E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,  -3.5592673593045432E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,   1.6103165713147891E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,   1.6103165713147891E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,  -1.6103165713147891E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,   1.6103165713147891E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,  -1.6103165713147891E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   9.2053515090483229E-01,  -1.6103165713147891E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,   1.6103165713147891E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -9.2053515090483229E-01,  -1.6103165713147891E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,   9.2053515090483229E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,   9.2053515090483229E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,  -9.2053515090483229E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,   9.2053515090483229E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,  -9.2053515090483229E-01,   1.6103165713147891E-01,   2.1504577585860526E-03],
            [   3.5592673593045432E-01,  -9.2053515090483229E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,   9.2053515090483229E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [  -3.5592673593045432E-01,  -9.2053515090483229E-01,  -1.6103165713147891E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,   9.2053515090483229E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,   9.2053515090483229E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,  -9.2053515090483229E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,   9.2053515090483229E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,  -9.2053515090483229E-01,   3.5592673593045432E-01,   2.1504577585860526E-03],
            [   1.6103165713147891E-01,  -9.2053515090483229E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,   9.2053515090483229E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [  -1.6103165713147891E-01,  -9.2053515090483229E-01,  -3.5592673593045432E-01,   2.1504577585860526E-03],
            [   3.8766371236769559E-01,   1.9019120803957071E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,   1.9019120803957071E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,  -1.9019120803957071E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,   1.9019120803957071E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,  -1.9019120803957071E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,  -1.9019120803957071E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,   1.9019120803957071E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,  -1.9019120803957071E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,   3.8766371236769559E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,   3.8766371236769559E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,  -3.8766371236769559E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,   3.8766371236769559E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,  -3.8766371236769559E-01,   9.0196682339083034E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,  -3.8766371236769559E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,   3.8766371236769559E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,  -3.8766371236769559E-01,  -9.0196682339083034E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,   3.8766371236769559E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,   3.8766371236769559E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,  -3.8766371236769559E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,   3.8766371236769559E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,  -3.8766371236769559E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,  -3.8766371236769559E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,   3.8766371236769559E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,  -3.8766371236769559E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,   1.9019120803957071E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,   1.9019120803957071E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,  -1.9019120803957071E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,   1.9019120803957071E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,  -1.9019120803957071E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   9.0196682339083034E-01,  -1.9019120803957071E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,   1.9019120803957071E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -9.0196682339083034E-01,  -1.9019120803957071E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,   9.0196682339083034E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,   9.0196682339083034E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,  -9.0196682339083034E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,   9.0196682339083034E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,  -9.0196682339083034E-01,   1.9019120803957071E-01,   2.2053386360587472E-03],
            [   3.8766371236769559E-01,  -9.0196682339083034E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,   9.0196682339083034E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [  -3.8766371236769559E-01,  -9.0196682339083034E-01,  -1.9019120803957071E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,   9.0196682339083034E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,   9.0196682339083034E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,  -9.0196682339083034E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,   9.0196682339083034E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,  -9.0196682339083034E-01,   3.8766371236769559E-01,   2.2053386360587472E-03],
            [   1.9019120803957071E-01,  -9.0196682339083034E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,   9.0196682339083034E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [  -1.9019120803957071E-01,  -9.0196682339083034E-01,  -3.8766371236769559E-01,   2.2053386360587472E-03],
            [   4.1876367052188418E-01,   2.1943849501379500E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,   2.1943849501379500E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,  -2.1943849501379500E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,   2.1943849501379500E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,  -2.1943849501379500E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,  -2.1943849501379500E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,   2.1943849501379500E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,  -2.1943849501379500E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,   4.1876367052188418E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,   4.1876367052188418E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,  -4.1876367052188418E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,   4.1876367052188418E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,  -4.1876367052188418E-01,   8.8118314507094353E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,  -4.1876367052188418E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,   4.1876367052188418E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,  -4.1876367052188418E-01,  -8.8118314507094353E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,   4.1876367052188418E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,   4.1876367052188418E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,  -4.1876367052188418E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,   4.1876367052188418E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,  -4.1876367052188418E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,  -4.1876367052188418E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,   4.1876367052188418E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,  -4.1876367052188418E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,   2.1943849501379500E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,   2.1943849501379500E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,  -2.1943849501379500E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,   2.1943849501379500E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,  -2.1943849501379500E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   8.8118314507094353E-01,  -2.1943849501379500E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,   2.1943849501379500E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -8.8118314507094353E-01,  -2.1943849501379500E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,   8.8118314507094353E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,   8.8118314507094353E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,  -8.8118314507094353E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,   8.8118314507094353E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,  -8.8118314507094353E-01,   2.1943849501379500E-01,   2.2509484355358925E-03],
            [   4.1876367052188418E-01,  -8.8118314507094353E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,   8.8118314507094353E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [  -4.1876367052188418E-01,  -8.8118314507094353E-01,  -2.1943849501379500E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,   8.8118314507094353E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,   8.8118314507094353E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,  -8.8118314507094353E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,   8.8118314507094353E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,  -8.8118314507094353E-01,   4.1876367052188418E-01,   2.2509484355358925E-03],
            [   2.1943849501379500E-01,  -8.8118314507094353E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,   8.8118314507094353E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [  -2.1943849501379500E-01,  -8.8118314507094353E-01,  -4.1876367052188418E-01,   2.2509484355358925E-03],
            [   4.4914490198831070E-01,   2.4861553347638579E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,   2.4861553347638579E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,  -2.4861553347638579E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,   2.4861553347638579E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,  -2.4861553347638579E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,  -2.4861553347638579E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,   2.4861553347638579E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,  -2.4861553347638579E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,   4.4914490198831070E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,   4.4914490198831070E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,  -4.4914490198831070E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,   4.4914490198831070E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,  -4.4914490198831070E-01,   8.5817199530872768E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,  -4.4914490198831070E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,   4.4914490198831070E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,  -4.4914490198831070E-01,  -8.5817199530872768E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,   4.4914490198831070E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,   4.4914490198831070E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,  -4.4914490198831070E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,   4.4914490198831070E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,  -4.4914490198831070E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,  -4.4914490198831070E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,   4.4914490198831070E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,  -4.4914490198831070E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,   2.4861553347638579E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,   2.4861553347638579E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,  -2.4861553347638579E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,   2.4861553347638579E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,  -2.4861553347638579E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   8.5817199530872768E-01,  -2.4861553347638579E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,   2.4861553347638579E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -8.5817199530872768E-01,  -2.4861553347638579E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,   8.5817199530872768E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,   8.5817199530872768E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,  -8.5817199530872768E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,   8.5817199530872768E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,  -8.5817199530872768E-01,   2.4861553347638579E-01,   2.2882786616640681E-03],
            [   4.4914490198831070E-01,  -8.5817199530872768E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,   8.5817199530872768E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [  -4.4914490198831070E-01,  -8.5817199530872768E-01,  -2.4861553347638579E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,   8.5817199530872768E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,   8.5817199530872768E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,  -8.5817199530872768E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,   8.5817199530872768E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,  -8.5817199530872768E-01,   4.4914490198831070E-01,   2.2882786616640681E-03],
            [   2.4861553347638579E-01,  -8.5817199530872768E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,   8.5817199530872768E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [  -2.4861553347638579E-01,  -8.5817199530872768E-01,  -4.4914490198831070E-01,   2.2882786616640681E-03],
            [   4.7872709324254448E-01,   2.7757689318123352E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,   2.7757689318123352E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,  -2.7757689318123352E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,   2.7757689318123352E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,  -2.7757689318123352E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,  -2.7757689318123352E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,   2.7757689318123352E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,  -2.7757689318123352E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,   4.7872709324254448E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,   4.7872709324254448E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,  -4.7872709324254448E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,   4.7872709324254448E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,  -4.7872709324254448E-01,   8.3292943192529711E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,  -4.7872709324254448E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,   4.7872709324254448E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,  -4.7872709324254448E-01,  -8.3292943192529711E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,   4.7872709324254448E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,   4.7872709324254448E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,  -4.7872709324254448E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,   4.7872709324254448E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,  -4.7872709324254448E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,  -4.7872709324254448E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,   4.7872709324254448E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,  -4.7872709324254448E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,   2.7757689318123352E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,   2.7757689318123352E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,  -2.7757689318123352E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,   2.7757689318123352E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,  -2.7757689318123352E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   8.3292943192529711E-01,  -2.7757689318123352E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,   2.7757689318123352E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -8.3292943192529711E-01,  -2.7757689318123352E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,   8.3292943192529711E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,   8.3292943192529711E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,  -8.3292943192529711E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,   8.3292943192529711E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,  -8.3292943192529711E-01,   2.7757689318123352E-01,   2.3182296304592644E-03],
            [   4.7872709324254448E-01,  -8.3292943192529711E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,   8.3292943192529711E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [  -4.7872709324254448E-01,  -8.3292943192529711E-01,  -2.7757689318123352E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,   8.3292943192529711E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,   8.3292943192529711E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,  -8.3292943192529711E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,   8.3292943192529711E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,  -8.3292943192529711E-01,   4.7872709324254448E-01,   2.3182296304592644E-03],
            [   2.7757689318123352E-01,  -8.3292943192529711E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,   8.3292943192529711E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [  -2.7757689318123352E-01,  -8.3292943192529711E-01,  -4.7872709324254448E-01,   2.3182296304592644E-03],
            [   5.0743151530555741E-01,   3.0618637865911202E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,   3.0618637865911202E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,  -3.0618637865911202E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,   3.0618637865911202E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,  -3.0618637865911202E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,  -3.0618637865911202E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,   3.0618637865911202E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,  -3.0618637865911202E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,   5.0743151530555741E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,   5.0743151530555741E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,  -5.0743151530555741E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,   5.0743151530555741E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,  -5.0743151530555741E-01,   8.0545835323641946E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,  -5.0743151530555741E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,   5.0743151530555741E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,  -5.0743151530555741E-01,  -8.0545835323641946E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,   5.0743151530555741E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,   5.0743151530555741E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,  -5.0743151530555741E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,   5.0743151530555741E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,  -5.0743151530555741E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,  -5.0743151530555741E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,   5.0743151530555741E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,  -5.0743151530555741E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,   3.0618637865911202E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,   3.0618637865911202E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,  -3.0618637865911202E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,   3.0618637865911202E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,  -3.0618637865911202E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   8.0545835323641946E-01,  -3.0618637865911202E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,   3.0618637865911202E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -8.0545835323641946E-01,  -3.0618637865911202E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,   8.0545835323641946E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,   8.0545835323641946E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,  -8.0545835323641946E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,   8.0545835323641946E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,  -8.0545835323641946E-01,   3.0618637865911202E-01,   2.3416294153431297E-03],
            [   5.0743151530555741E-01,  -8.0545835323641946E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,   8.0545835323641946E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [  -5.0743151530555741E-01,  -8.0545835323641946E-01,  -3.0618637865911202E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,   8.0545835323641946E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,   8.0545835323641946E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,  -8.0545835323641946E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,   8.0545835323641946E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,  -8.0545835323641946E-01,   5.0743151530555741E-01,   2.3416294153431297E-03],
            [   3.0618637865911202E-01,  -8.0545835323641946E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,   8.0545835323641946E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [  -3.0618637865911202E-01,  -8.0545835323641946E-01,  -5.0743151530555741E-01,   2.3416294153431297E-03],
            [   5.3518105077383360E-01,   3.3431447181525559E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,   3.3431447181525559E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,  -3.3431447181525559E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,   3.3431447181525559E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,  -3.3431447181525559E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,  -3.3431447181525559E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,   3.3431447181525559E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,  -3.3431447181525559E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,   5.3518105077383360E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,   5.3518105077383360E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,  -5.3518105077383360E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,   5.3518105077383360E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,  -5.3518105077383360E-01,   7.7576741155290996E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,  -5.3518105077383360E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,   5.3518105077383360E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,  -5.3518105077383360E-01,  -7.7576741155290996E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,   5.3518105077383360E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,   5.3518105077383360E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,  -5.3518105077383360E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,   5.3518105077383360E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,  -5.3518105077383360E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,  -5.3518105077383360E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,   5.3518105077383360E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,  -5.3518105077383360E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,   3.3431447181525559E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,   3.3431447181525559E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,  -3.3431447181525559E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,   3.3431447181525559E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,  -3.3431447181525559E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   7.7576741155290996E-01,  -3.3431447181525559E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,   3.3431447181525559E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -7.7576741155290996E-01,  -3.3431447181525559E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,   7.7576741155290996E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,   7.7576741155290996E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,  -7.7576741155290996E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,   7.7576741155290996E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,  -7.7576741155290996E-01,   3.3431447181525559E-01,   2.3592518992150268E-03],
            [   5.3518105077383360E-01,  -7.7576741155290996E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,   7.7576741155290996E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [  -5.3518105077383360E-01,  -7.7576741155290996E-01,  -3.3431447181525559E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,   7.7576741155290996E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,   7.7576741155290996E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,  -7.7576741155290996E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,   7.7576741155290996E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,  -7.7576741155290996E-01,   5.3518105077383360E-01,   2.3592518992150268E-03],
            [   3.3431447181525559E-01,  -7.7576741155290996E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,   7.7576741155290996E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [  -3.3431447181525559E-01,  -7.7576741155290996E-01,  -5.3518105077383360E-01,   2.3592518992150268E-03],
            [   5.6190010259753809E-01,   3.6183627290284270E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,   3.6183627290284270E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,  -3.6183627290284270E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,   3.6183627290284270E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,  -3.6183627290284270E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,  -3.6183627290284270E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,   3.6183627290284270E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,  -3.6183627290284270E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,   5.6190010259753809E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,   5.6190010259753809E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,  -5.6190010259753809E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,   5.6190010259753809E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,  -5.6190010259753809E-01,   7.4387014075889324E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,  -5.6190010259753809E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,   5.6190010259753809E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,  -5.6190010259753809E-01,  -7.4387014075889324E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,   5.6190010259753809E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,   5.6190010259753809E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,  -5.6190010259753809E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,   5.6190010259753809E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,  -5.6190010259753809E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,  -5.6190010259753809E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,   5.6190010259753809E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,  -5.6190010259753809E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,   3.6183627290284270E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,   3.6183627290284270E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,  -3.6183627290284270E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,   3.6183627290284270E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,  -3.6183627290284270E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   7.4387014075889324E-01,  -3.6183627290284270E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,   3.6183627290284270E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -7.4387014075889324E-01,  -3.6183627290284270E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,   7.4387014075889324E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,   7.4387014075889324E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,  -7.4387014075889324E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,   7.4387014075889324E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,  -7.4387014075889324E-01,   3.6183627290284270E-01,   2.3718327650249981E-03],
            [   5.6190010259753809E-01,  -7.4387014075889324E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,   7.4387014075889324E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [  -5.6190010259753809E-01,  -7.4387014075889324E-01,  -3.6183627290284270E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,   7.4387014075889324E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,   7.4387014075889324E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,  -7.4387014075889324E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,   7.4387014075889324E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,  -7.4387014075889324E-01,   5.6190010259753809E-01,   2.3718327650249981E-03],
            [   3.6183627290284270E-01,  -7.4387014075889324E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,   7.4387014075889324E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [  -3.6183627290284270E-01,  -7.4387014075889324E-01,  -5.6190010259753809E-01,   2.3718327650249981E-03],
            [   5.8751440352680462E-01,   3.8862975836204078E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,   3.8862975836204078E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,  -3.8862975836204078E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,   3.8862975836204078E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,  -3.8862975836204078E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,  -3.8862975836204078E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,   3.8862975836204078E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,  -3.8862975836204078E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,   5.8751440352680462E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,   5.8751440352680462E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,  -5.8751440352680462E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,   5.8751440352680462E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,  -5.8751440352680462E-01,   7.0978428875539701E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,  -5.8751440352680462E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,   5.8751440352680462E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,  -5.8751440352680462E-01,  -7.0978428875539701E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,   5.8751440352680462E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,   5.8751440352680462E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,  -5.8751440352680462E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,   5.8751440352680462E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,  -5.8751440352680462E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,  -5.8751440352680462E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,   5.8751440352680462E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,  -5.8751440352680462E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,   3.8862975836204078E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,   3.8862975836204078E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,  -3.8862975836204078E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,   3.8862975836204078E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,  -3.8862975836204078E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   7.0978428875539701E-01,  -3.8862975836204078E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,   3.8862975836204078E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -7.0978428875539701E-01,  -3.8862975836204078E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,   7.0978428875539701E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,   7.0978428875539701E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,  -7.0978428875539701E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,   7.0978428875539701E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,  -7.0978428875539701E-01,   3.8862975836204078E-01,   2.3800829463165507E-03],
            [   5.8751440352680462E-01,  -7.0978428875539701E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,   7.0978428875539701E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [  -5.8751440352680462E-01,  -7.0978428875539701E-01,  -3.8862975836204078E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,   7.0978428875539701E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,   7.0978428875539701E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,  -7.0978428875539701E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,   7.0978428875539701E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,  -7.0978428875539701E-01,   5.8751440352680462E-01,   2.3800829463165507E-03],
            [   3.8862975836204078E-01,  -7.0978428875539701E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,   7.0978428875539701E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [  -3.8862975836204078E-01,  -7.0978428875539701E-01,  -5.8751440352680462E-01,   2.3800829463165507E-03],
            [   6.1195073087344953E-01,   4.1457422777920311E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,   4.1457422777920311E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,  -4.1457422777920311E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,   4.1457422777920311E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,  -4.1457422777920311E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,  -4.1457422777920311E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,   4.1457422777920311E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,  -4.1457422777920311E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,   6.1195073087344953E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,   6.1195073087344953E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,  -6.1195073087344953E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,   6.1195073087344953E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,  -6.1195073087344953E-01,   6.7353137465505519E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,  -6.1195073087344953E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,   6.1195073087344953E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,  -6.1195073087344953E-01,  -6.7353137465505519E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,   6.1195073087344953E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,   6.1195073087344953E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,  -6.1195073087344953E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,   6.1195073087344953E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,  -6.1195073087344953E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,  -6.1195073087344953E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,   6.1195073087344953E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,  -6.1195073087344953E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,   4.1457422777920311E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,   4.1457422777920311E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,  -4.1457422777920311E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,   4.1457422777920311E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,  -4.1457422777920311E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   6.7353137465505519E-01,  -4.1457422777920311E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,   4.1457422777920311E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -6.7353137465505519E-01,  -4.1457422777920311E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,   6.7353137465505519E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,   6.7353137465505519E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,  -6.7353137465505519E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,   6.7353137465505519E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,  -6.7353137465505519E-01,   4.1457422777920311E-01,   2.3846992222409128E-03],
            [   6.1195073087344953E-01,  -6.7353137465505519E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,   6.7353137465505519E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [  -6.1195073087344953E-01,  -6.7353137465505519E-01,  -4.1457422777920311E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,   6.7353137465505519E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,   6.7353137465505519E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,  -6.7353137465505519E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,   6.7353137465505519E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,  -6.7353137465505519E-01,   6.1195073087344953E-01,   2.3846992222409128E-03],
            [   4.1457422777920311E-01,  -6.7353137465505519E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,   6.7353137465505519E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [  -4.1457422777920311E-01,  -6.7353137465505519E-01,  -6.1195073087344953E-01,   2.3846992222409128E-03],
            [   2.6197338701194628E-01,   2.5400471863893530E-02,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,   2.5400471863893530E-02,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,  -2.5400471863893530E-02,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,   2.5400471863893530E-02,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,  -2.5400471863893530E-02,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,  -2.5400471863893530E-02,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,   2.5400471863893530E-02,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,  -2.5400471863893530E-02,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,   2.6197338701194628E-01,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,   2.6197338701194628E-01,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,  -2.6197338701194628E-01,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,   2.6197338701194628E-01,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,  -2.6197338701194628E-01,   9.6474077374524847E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,  -2.6197338701194628E-01,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,   2.6197338701194628E-01,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,  -2.6197338701194628E-01,  -9.6474077374524847E-01,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,   2.6197338701194628E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,   2.6197338701194628E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,  -2.6197338701194628E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,   2.6197338701194628E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,  -2.6197338701194628E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,  -2.6197338701194628E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,   2.6197338701194628E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,  -2.6197338701194628E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,   2.5400471863893530E-02,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,   2.5400471863893530E-02,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,  -2.5400471863893530E-02,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,   2.5400471863893530E-02,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,  -2.5400471863893530E-02,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   9.6474077374524847E-01,  -2.5400471863893530E-02,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,   2.5400471863893530E-02,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -9.6474077374524847E-01,  -2.5400471863893530E-02,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,   9.6474077374524847E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,   9.6474077374524847E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,  -9.6474077374524847E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,   9.6474077374524847E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,  -9.6474077374524847E-01,   2.5400471863893530E-02,   1.9067293896006174E-03],
            [   2.6197338701194628E-01,  -9.6474077374524847E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,   9.6474077374524847E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [  -2.6197338701194628E-01,  -9.6474077374524847E-01,  -2.5400471863893530E-02,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,   9.6474077374524847E-01,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,   9.6474077374524847E-01,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,  -9.6474077374524847E-01,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,   9.6474077374524847E-01,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,  -9.6474077374524847E-01,   2.6197338701194628E-01,   1.9067293896006174E-03],
            [   2.5400471863893530E-02,  -9.6474077374524847E-01,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,   9.6474077374524847E-01,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [  -2.5400471863893530E-02,  -9.6474077374524847E-01,  -2.6197338701194628E-01,   1.9067293896006174E-03],
            [   2.9681497432379489E-01,   5.2081070185439893E-02,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,   5.2081070185439893E-02,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,  -5.2081070185439893E-02,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,   5.2081070185439893E-02,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,  -5.2081070185439893E-02,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,  -5.2081070185439893E-02,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,   5.2081070185439893E-02,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,  -5.2081070185439893E-02,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,   2.9681497432379489E-01,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,   2.9681497432379489E-01,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,  -2.9681497432379489E-01,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,   2.9681497432379489E-01,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,  -2.9681497432379489E-01,   9.5351372991976591E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,  -2.9681497432379489E-01,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,   2.9681497432379489E-01,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,  -2.9681497432379489E-01,  -9.5351372991976591E-01,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,   2.9681497432379489E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,   2.9681497432379489E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,  -2.9681497432379489E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,   2.9681497432379489E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,  -2.9681497432379489E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,  -2.9681497432379489E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,   2.9681497432379489E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,  -2.9681497432379489E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,   5.2081070185439893E-02,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,   5.2081070185439893E-02,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,  -5.2081070185439893E-02,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,   5.2081070185439893E-02,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,  -5.2081070185439893E-02,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   9.5351372991976591E-01,  -5.2081070185439893E-02,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,   5.2081070185439893E-02,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -9.5351372991976591E-01,  -5.2081070185439893E-02,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,   9.5351372991976591E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,   9.5351372991976591E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,  -9.5351372991976591E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,   9.5351372991976591E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,  -9.5351372991976591E-01,   5.2081070185439893E-02,   1.9952136284787443E-03],
            [   2.9681497432379489E-01,  -9.5351372991976591E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,   9.5351372991976591E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [  -2.9681497432379489E-01,  -9.5351372991976591E-01,  -5.2081070185439893E-02,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,   9.5351372991976591E-01,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,   9.5351372991976591E-01,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,  -9.5351372991976591E-01,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,   9.5351372991976591E-01,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,  -9.5351372991976591E-01,   2.9681497432379489E-01,   1.9952136284787443E-03],
            [   5.2081070185439893E-02,  -9.5351372991976591E-01,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,   9.5351372991976591E-01,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [  -5.2081070185439893E-02,  -9.5351372991976591E-01,  -2.9681497432379489E-01,   1.9952136284787443E-03],
            [   3.3104515048604882E-01,   7.9718284708855988E-02,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,   7.9718284708855988E-02,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,  -7.9718284708855988E-02,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,   7.9718284708855988E-02,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,  -7.9718284708855988E-02,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,  -7.9718284708855988E-02,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,   7.9718284708855988E-02,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,  -7.9718284708855988E-02,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,   3.3104515048604882E-01,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,   3.3104515048604882E-01,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,  -3.3104515048604882E-01,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,   3.3104515048604882E-01,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,  -3.3104515048604882E-01,   9.4024151334789885E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,  -3.3104515048604882E-01,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,   3.3104515048604882E-01,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,  -3.3104515048604882E-01,  -9.4024151334789885E-01,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,   3.3104515048604882E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,   3.3104515048604882E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,  -3.3104515048604882E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,   3.3104515048604882E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,  -3.3104515048604882E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,  -3.3104515048604882E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,   3.3104515048604882E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,  -3.3104515048604882E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,   7.9718284708855988E-02,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,   7.9718284708855988E-02,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,  -7.9718284708855988E-02,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,   7.9718284708855988E-02,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,  -7.9718284708855988E-02,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   9.4024151334789885E-01,  -7.9718284708855988E-02,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,   7.9718284708855988E-02,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -9.4024151334789885E-01,  -7.9718284708855988E-02,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,   9.4024151334789885E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,   9.4024151334789885E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,  -9.4024151334789885E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,   9.4024151334789885E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,  -9.4024151334789885E-01,   7.9718284708855988E-02,   2.0723118619343389E-03],
            [   3.3104515048604882E-01,  -9.4024151334789885E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,   9.4024151334789885E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [  -3.3104515048604882E-01,  -9.4024151334789885E-01,  -7.9718284708855988E-02,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,   9.4024151334789885E-01,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,   9.4024151334789885E-01,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,  -9.4024151334789885E-01,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,   9.4024151334789885E-01,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,  -9.4024151334789885E-01,   3.3104515048604882E-01,   2.0723118619343389E-03],
            [   7.9718284708855988E-02,  -9.4024151334789885E-01,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,   9.4024151334789885E-01,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [  -7.9718284708855988E-02,  -9.4024151334789885E-01,  -3.3104515048604882E-01,   2.0723118619343389E-03],
            [   3.6462155673766761E-01,   1.0804659991779270E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,   1.0804659991779270E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,  -1.0804659991779270E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,   1.0804659991779270E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,  -1.0804659991779270E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,  -1.0804659991779270E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,   1.0804659991779270E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,  -1.0804659991779270E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,   3.6462155673766761E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,   3.6462155673766761E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,  -3.6462155673766761E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,   3.6462155673766761E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,  -3.6462155673766761E-01,   9.2486596467185678E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,  -3.6462155673766761E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,   3.6462155673766761E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,  -3.6462155673766761E-01,  -9.2486596467185678E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,   3.6462155673766761E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,   3.6462155673766761E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,  -3.6462155673766761E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,   3.6462155673766761E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,  -3.6462155673766761E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,  -3.6462155673766761E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,   3.6462155673766761E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,  -3.6462155673766761E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,   1.0804659991779270E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,   1.0804659991779270E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,  -1.0804659991779270E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,   1.0804659991779270E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,  -1.0804659991779270E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   9.2486596467185678E-01,  -1.0804659991779270E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,   1.0804659991779270E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -9.2486596467185678E-01,  -1.0804659991779270E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,   9.2486596467185678E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,   9.2486596467185678E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,  -9.2486596467185678E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,   9.2486596467185678E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,  -9.2486596467185678E-01,   1.0804659991779270E-01,   2.1386897360901784E-03],
            [   3.6462155673766761E-01,  -9.2486596467185678E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,   9.2486596467185678E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [  -3.6462155673766761E-01,  -9.2486596467185678E-01,  -1.0804659991779270E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,   9.2486596467185678E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,   9.2486596467185678E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,  -9.2486596467185678E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,   9.2486596467185678E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,  -9.2486596467185678E-01,   3.6462155673766761E-01,   2.1386897360901784E-03],
            [   1.0804659991779270E-01,  -9.2486596467185678E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,   9.2486596467185678E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [  -1.0804659991779270E-01,  -9.2486596467185678E-01,  -3.6462155673766761E-01,   2.1386897360901784E-03],
            [   3.9749167852793599E-01,   1.3684138493666290E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,   1.3684138493666290E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,  -1.3684138493666290E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,   1.3684138493666290E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,  -1.3684138493666290E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,  -1.3684138493666290E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,   1.3684138493666290E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,  -1.3684138493666290E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,   3.9749167852793599E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,   3.9749167852793599E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,  -3.9749167852793599E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,   3.9749167852793599E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,  -3.9749167852793599E-01,   9.0734491835776543E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,  -3.9749167852793599E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,   3.9749167852793599E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,  -3.9749167852793599E-01,  -9.0734491835776543E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,   3.9749167852793599E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,   3.9749167852793599E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,  -3.9749167852793599E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,   3.9749167852793599E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,  -3.9749167852793599E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,  -3.9749167852793599E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,   3.9749167852793599E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,  -3.9749167852793599E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,   1.3684138493666290E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,   1.3684138493666290E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,  -1.3684138493666290E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,   1.3684138493666290E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,  -1.3684138493666290E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   9.0734491835776543E-01,  -1.3684138493666290E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,   1.3684138493666290E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -9.0734491835776543E-01,  -1.3684138493666290E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,   9.0734491835776543E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,   9.0734491835776543E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,  -9.0734491835776543E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,   9.0734491835776543E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,  -9.0734491835776543E-01,   1.3684138493666290E-01,   2.1951536272868922E-03],
            [   3.9749167852793599E-01,  -9.0734491835776543E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,   9.0734491835776543E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [  -3.9749167852793599E-01,  -9.0734491835776543E-01,  -1.3684138493666290E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,   9.0734491835776543E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,   9.0734491835776543E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,  -9.0734491835776543E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,   9.0734491835776543E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,  -9.0734491835776543E-01,   3.9749167852793599E-01,   2.1951536272868922E-03],
            [   1.3684138493666290E-01,  -9.0734491835776543E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,   9.0734491835776543E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [  -1.3684138493666290E-01,  -9.0734491835776543E-01,  -3.9749167852793599E-01,   2.1951536272868922E-03],
            [   4.2959674037720291E-01,   1.6590731847635590E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,   1.6590731847635590E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,  -1.6590731847635590E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,   1.6590731847635590E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,  -1.6590731847635590E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,  -1.6590731847635590E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,   1.6590731847635590E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,  -1.6590731847635590E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,   4.2959674037720291E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,   4.2959674037720291E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,  -4.2959674037720291E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,   4.2959674037720291E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,  -4.2959674037720291E-01,   8.8764936902656955E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,  -4.2959674037720291E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,   4.2959674037720291E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,  -4.2959674037720291E-01,  -8.8764936902656955E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,   4.2959674037720291E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,   4.2959674037720291E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,  -4.2959674037720291E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,   4.2959674037720291E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,  -4.2959674037720291E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,  -4.2959674037720291E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,   4.2959674037720291E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,  -4.2959674037720291E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,   1.6590731847635590E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,   1.6590731847635590E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,  -1.6590731847635590E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,   1.6590731847635590E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,  -1.6590731847635590E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   8.8764936902656955E-01,  -1.6590731847635590E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,   1.6590731847635590E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -8.8764936902656955E-01,  -1.6590731847635590E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,   8.8764936902656955E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,   8.8764936902656955E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,  -8.8764936902656955E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,   8.8764936902656955E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,  -8.8764936902656955E-01,   1.6590731847635590E-01,   2.2425385945784612E-03],
            [   4.2959674037720291E-01,  -8.8764936902656955E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,   8.8764936902656955E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [  -4.2959674037720291E-01,  -8.8764936902656955E-01,  -1.6590731847635590E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,   8.8764936902656955E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,   8.8764936902656955E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,  -8.8764936902656955E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,   8.8764936902656955E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,  -8.8764936902656955E-01,   4.2959674037720291E-01,   2.2425385945784612E-03],
            [   1.6590731847635590E-01,  -8.8764936902656955E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,   8.8764936902656955E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [  -1.6590731847635590E-01,  -8.8764936902656955E-01,  -4.2959674037720291E-01,   2.2425385945784612E-03],
            [   4.6087428544734471E-01,   1.9507037304546140E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,   1.9507037304546140E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,  -1.9507037304546140E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,   1.9507037304546140E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,  -1.9507037304546140E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,  -1.9507037304546140E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,   1.9507037304546140E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,  -1.9507037304546140E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,   4.6087428544734471E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,   4.6087428544734471E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,  -4.6087428544734471E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,   4.6087428544734471E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,  -4.6087428544734471E-01,   8.6576119257755135E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,  -4.6087428544734471E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,   4.6087428544734471E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,  -4.6087428544734471E-01,  -8.6576119257755135E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,   4.6087428544734471E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,   4.6087428544734471E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,  -4.6087428544734471E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,   4.6087428544734471E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,  -4.6087428544734471E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,  -4.6087428544734471E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,   4.6087428544734471E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,  -4.6087428544734471E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,   1.9507037304546140E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,   1.9507037304546140E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,  -1.9507037304546140E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,   1.9507037304546140E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,  -1.9507037304546140E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   8.6576119257755135E-01,  -1.9507037304546140E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,   1.9507037304546140E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -8.6576119257755135E-01,  -1.9507037304546140E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,   8.6576119257755135E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,   8.6576119257755135E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,  -8.6576119257755135E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,   8.6576119257755135E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,  -8.6576119257755135E-01,   1.9507037304546140E-01,   2.2816602825383868E-03],
            [   4.6087428544734471E-01,  -8.6576119257755135E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,   8.6576119257755135E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [  -4.6087428544734471E-01,  -8.6576119257755135E-01,  -1.9507037304546140E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,   8.6576119257755135E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,   8.6576119257755135E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,  -8.6576119257755135E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,   8.6576119257755135E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,  -8.6576119257755135E-01,   4.6087428544734471E-01,   2.2816602825383868E-03],
            [   1.9507037304546140E-01,  -8.6576119257755135E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,   8.6576119257755135E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [  -1.9507037304546140E-01,  -8.6576119257755135E-01,  -4.6087428544734471E-01,   2.2816602825383868E-03],
            [   4.9125988589499031E-01,   2.2417211443767240E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,   2.2417211443767240E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,  -2.2417211443767240E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,   2.2417211443767240E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,  -2.2417211443767240E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,  -2.2417211443767240E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,   2.2417211443767240E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,  -2.2417211443767240E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,   4.9125988589499031E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,   4.9125988589499031E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,  -4.9125988589499031E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,   4.9125988589499031E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,  -4.9125988589499031E-01,   8.4167130616350716E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,  -4.9125988589499031E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,   4.9125988589499031E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,  -4.9125988589499031E-01,  -8.4167130616350716E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,   4.9125988589499031E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,   4.9125988589499031E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,  -4.9125988589499031E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,   4.9125988589499031E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,  -4.9125988589499031E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,  -4.9125988589499031E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,   4.9125988589499031E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,  -4.9125988589499031E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,   2.2417211443767240E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,   2.2417211443767240E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,  -2.2417211443767240E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,   2.2417211443767240E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,  -2.2417211443767240E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   8.4167130616350716E-01,  -2.2417211443767240E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,   2.2417211443767240E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -8.4167130616350716E-01,  -2.2417211443767240E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,   8.4167130616350716E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,   8.4167130616350716E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,  -8.4167130616350716E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,   8.4167130616350716E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,  -8.4167130616350716E-01,   2.2417211443767240E-01,   2.3132983932524112E-03],
            [   4.9125988589499031E-01,  -8.4167130616350716E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,   8.4167130616350716E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [  -4.9125988589499031E-01,  -8.4167130616350716E-01,  -2.2417211443767240E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,   8.4167130616350716E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,   8.4167130616350716E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,  -8.4167130616350716E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,   8.4167130616350716E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,  -8.4167130616350716E-01,   4.9125988589499031E-01,   2.3132983932524112E-03],
            [   2.2417211443767240E-01,  -8.4167130616350716E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,   8.4167130616350716E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [  -2.2417211443767240E-01,  -8.4167130616350716E-01,  -4.9125988589499031E-01,   2.3132983932524112E-03],
            [   5.2068827589455580E-01,   2.5306552554064887E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,   2.5306552554064887E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,  -2.5306552554064887E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,   2.5306552554064887E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,  -2.5306552554064887E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,  -2.5306552554064887E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,   2.5306552554064887E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,  -2.5306552554064887E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,   5.2068827589455580E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,   5.2068827589455580E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,  -5.2068827589455580E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,   5.2068827589455580E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,  -5.2068827589455580E-01,   8.1537816939674690E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,  -5.2068827589455580E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,   5.2068827589455580E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,  -5.2068827589455580E-01,  -8.1537816939674690E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,   5.2068827589455580E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,   5.2068827589455580E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,  -5.2068827589455580E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,   5.2068827589455580E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,  -5.2068827589455580E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,  -5.2068827589455580E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,   5.2068827589455580E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,  -5.2068827589455580E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,   2.5306552554064887E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,   2.5306552554064887E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,  -2.5306552554064887E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,   2.5306552554064887E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,  -2.5306552554064887E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   8.1537816939674690E-01,  -2.5306552554064887E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,   2.5306552554064887E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -8.1537816939674690E-01,  -2.5306552554064887E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,   8.1537816939674690E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,   8.1537816939674690E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,  -8.1537816939674690E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,   8.1537816939674690E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,  -8.1537816939674690E-01,   2.5306552554064887E-01,   2.3381954078745258E-03],
            [   5.2068827589455580E-01,  -8.1537816939674690E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,   8.1537816939674690E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [  -5.2068827589455580E-01,  -8.1537816939674690E-01,  -2.5306552554064887E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,   8.1537816939674690E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,   8.1537816939674690E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,  -8.1537816939674690E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,   8.1537816939674690E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,  -8.1537816939674690E-01,   5.2068827589455580E-01,   2.3381954078745258E-03],
            [   2.5306552554064887E-01,  -8.1537816939674690E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,   8.1537816939674690E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [  -2.5306552554064887E-01,  -8.1537816939674690E-01,  -5.2068827589455580E-01,   2.3381954078745258E-03],
            [   5.4909409140198195E-01,   2.8161184097310660E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,   2.8161184097310660E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,  -2.8161184097310660E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,   2.8161184097310660E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,  -2.8161184097310660E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,  -2.8161184097310660E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,   2.8161184097310660E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,  -2.8161184097310660E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,   5.4909409140198195E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,   5.4909409140198195E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,  -5.4909409140198195E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,   5.4909409140198195E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,  -5.4909409140198195E-01,   7.8688655460057877E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,  -5.4909409140198195E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,   5.4909409140198195E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,  -5.4909409140198195E-01,  -7.8688655460057877E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,   5.4909409140198195E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,   5.4909409140198195E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,  -5.4909409140198195E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,   5.4909409140198195E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,  -5.4909409140198195E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,  -5.4909409140198195E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,   5.4909409140198195E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,  -5.4909409140198195E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,   2.8161184097310660E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,   2.8161184097310660E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,  -2.8161184097310660E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,   2.8161184097310660E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,  -2.8161184097310660E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   7.8688655460057877E-01,  -2.8161184097310660E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,   2.8161184097310660E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -7.8688655460057877E-01,  -2.8161184097310660E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,   7.8688655460057877E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,   7.8688655460057877E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,  -7.8688655460057877E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,   7.8688655460057877E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,  -7.8688655460057877E-01,   2.8161184097310660E-01,   2.3570623033187074E-03],
            [   5.4909409140198195E-01,  -7.8688655460057877E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,   7.8688655460057877E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [  -5.4909409140198195E-01,  -7.8688655460057877E-01,  -2.8161184097310660E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,   7.8688655460057877E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,   7.8688655460057877E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,  -7.8688655460057877E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,   7.8688655460057877E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,  -7.8688655460057877E-01,   5.4909409140198195E-01,   2.3570623033187074E-03],
            [   2.8161184097310660E-01,  -7.8688655460057877E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,   7.8688655460057877E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [  -2.8161184097310660E-01,  -7.8688655460057877E-01,  -5.4909409140198195E-01,   2.3570623033187074E-03],
            [   5.7641233020255422E-01,   3.0967805045932378E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,   3.0967805045932378E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,  -3.0967805045932378E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,   3.0967805045932378E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,  -3.0967805045932378E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,  -3.0967805045932378E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,   3.0967805045932378E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,  -3.0967805045932378E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,   5.7641233020255422E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,   5.7641233020255422E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,  -5.7641233020255422E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,   5.7641233020255422E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,  -5.7641233020255422E-01,   7.5620653967958651E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,  -5.7641233020255422E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,   5.7641233020255422E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,  -5.7641233020255422E-01,  -7.5620653967958651E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,   5.7641233020255422E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,   5.7641233020255422E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,  -5.7641233020255422E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,   5.7641233020255422E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,  -5.7641233020255422E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,  -5.7641233020255422E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,   5.7641233020255422E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,  -5.7641233020255422E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,   3.0967805045932378E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,   3.0967805045932378E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,  -3.0967805045932378E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,   3.0967805045932378E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,  -3.0967805045932378E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   7.5620653967958651E-01,  -3.0967805045932378E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,   3.0967805045932378E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -7.5620653967958651E-01,  -3.0967805045932378E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,   7.5620653967958651E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,   7.5620653967958651E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,  -7.5620653967958651E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,   7.5620653967958651E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,  -7.5620653967958651E-01,   3.0967805045932378E-01,   2.3705870514596525E-03],
            [   5.7641233020255422E-01,  -7.5620653967958651E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,   7.5620653967958651E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [  -5.7641233020255422E-01,  -7.5620653967958651E-01,  -3.0967805045932378E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,   7.5620653967958651E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,   7.5620653967958651E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,  -7.5620653967958651E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,   7.5620653967958651E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,  -7.5620653967958651E-01,   5.7641233020255422E-01,   2.3705870514596525E-03],
            [   3.0967805045932378E-01,  -7.5620653967958651E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,   7.5620653967958651E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [  -3.0967805045932378E-01,  -7.5620653967958651E-01,  -5.7641233020255422E-01,   2.3705870514596525E-03],
            [   6.0257860042135059E-01,   3.3713483663949873E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,   3.3713483663949873E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,  -3.3713483663949873E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,   3.3713483663949873E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,  -3.3713483663949873E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,  -3.3713483663949873E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,   3.3713483663949873E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,  -3.3713483663949873E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,   6.0257860042135059E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,   6.0257860042135059E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,  -6.0257860042135059E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,   6.0257860042135059E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,  -6.0257860042135059E-01,   7.2335270251676320E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,  -6.0257860042135059E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,   6.0257860042135059E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,  -6.0257860042135059E-01,  -7.2335270251676320E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,   6.0257860042135059E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,   6.0257860042135059E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,  -6.0257860042135059E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,   6.0257860042135059E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,  -6.0257860042135059E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,  -6.0257860042135059E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,   6.0257860042135059E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,  -6.0257860042135059E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,   3.3713483663949873E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,   3.3713483663949873E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,  -3.3713483663949873E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,   3.3713483663949873E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,  -3.3713483663949873E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   7.2335270251676320E-01,  -3.3713483663949873E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,   3.3713483663949873E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -7.2335270251676320E-01,  -3.3713483663949873E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,   7.2335270251676320E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,   7.2335270251676320E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,  -7.2335270251676320E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,   7.2335270251676320E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,  -7.2335270251676320E-01,   3.3713483663949873E-01,   2.3794436874465734E-03],
            [   6.0257860042135059E-01,  -7.2335270251676320E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,   7.2335270251676320E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [  -6.0257860042135059E-01,  -7.2335270251676320E-01,  -3.3713483663949873E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,   7.2335270251676320E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,   7.2335270251676320E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,  -7.2335270251676320E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,   7.2335270251676320E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,  -7.2335270251676320E-01,   6.0257860042135059E-01,   2.3794436874465734E-03],
            [   3.3713483663949873E-01,  -7.2335270251676320E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,   7.2335270251676320E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [  -3.3713483663949873E-01,  -7.2335270251676320E-01,  -6.0257860042135059E-01,   2.3794436874465734E-03],
            [   6.2752919647949557E-01,   3.6385478276943961E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,   3.6385478276943961E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,  -3.6385478276943961E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,   3.6385478276943961E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,  -3.6385478276943961E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,  -3.6385478276943961E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,   3.6385478276943961E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,  -3.6385478276943961E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,   6.2752919647949557E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,   6.2752919647949557E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,  -6.2752919647949557E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,   6.2752919647949557E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,  -6.2752919647949557E-01,   6.8834352224859541E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,  -6.2752919647949557E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,   6.2752919647949557E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,  -6.2752919647949557E-01,  -6.8834352224859541E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,   6.2752919647949557E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,   6.2752919647949557E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,  -6.2752919647949557E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,   6.2752919647949557E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,  -6.2752919647949557E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,  -6.2752919647949557E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,   6.2752919647949557E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,  -6.2752919647949557E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,   3.6385478276943961E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,   3.6385478276943961E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,  -3.6385478276943961E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,   3.6385478276943961E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,  -3.6385478276943961E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   6.8834352224859541E-01,  -3.6385478276943961E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,   3.6385478276943961E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -6.8834352224859541E-01,  -3.6385478276943961E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,   6.8834352224859541E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,   6.8834352224859541E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,  -6.8834352224859541E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,   6.8834352224859541E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,  -6.8834352224859541E-01,   3.6385478276943961E-01,   2.3843006665829254E-03],
            [   6.2752919647949557E-01,  -6.8834352224859541E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,   6.8834352224859541E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [  -6.2752919647949557E-01,  -6.8834352224859541E-01,  -3.6385478276943961E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,   6.8834352224859541E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,   6.8834352224859541E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,  -6.8834352224859541E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,   6.8834352224859541E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,  -6.8834352224859541E-01,   6.2752919647949557E-01,   2.3843006665829254E-03],
            [   3.6385478276943961E-01,  -6.8834352224859541E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,   6.8834352224859541E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [  -3.6385478276943961E-01,  -6.8834352224859541E-01,  -6.2752919647949557E-01,   2.3843006665829254E-03],
            [   3.3481894798617712E-01,   2.6648419355374431E-02,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,   2.6648419355374431E-02,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,  -2.6648419355374431E-02,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,   2.6648419355374431E-02,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,  -2.6648419355374431E-02,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,  -2.6648419355374431E-02,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,   2.6648419355374431E-02,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,  -2.6648419355374431E-02,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,   3.3481894798617712E-01,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,   3.3481894798617712E-01,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,  -3.3481894798617712E-01,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,   3.3481894798617712E-01,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,  -3.3481894798617712E-01,   9.4190558646569766E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,  -3.3481894798617712E-01,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,   3.3481894798617712E-01,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,  -3.3481894798617712E-01,  -9.4190558646569766E-01,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,   3.3481894798617712E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,   3.3481894798617712E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,  -3.3481894798617712E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,   3.3481894798617712E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,  -3.3481894798617712E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,  -3.3481894798617712E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,   3.3481894798617712E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,  -3.3481894798617712E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,   2.6648419355374431E-02,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,   2.6648419355374431E-02,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,  -2.6648419355374431E-02,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,   2.6648419355374431E-02,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,  -2.6648419355374431E-02,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   9.4190558646569766E-01,  -2.6648419355374431E-02,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,   2.6648419355374431E-02,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -9.4190558646569766E-01,  -2.6648419355374431E-02,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,   9.4190558646569766E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,   9.4190558646569766E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,  -9.4190558646569766E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,   9.4190558646569766E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,  -9.4190558646569766E-01,   2.6648419355374431E-02,   2.0657967427421347E-03],
            [   3.3481894798617712E-01,  -9.4190558646569766E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,   9.4190558646569766E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [  -3.3481894798617712E-01,  -9.4190558646569766E-01,  -2.6648419355374431E-02,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,   9.4190558646569766E-01,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,   9.4190558646569766E-01,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,  -9.4190558646569766E-01,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,   9.4190558646569766E-01,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,  -9.4190558646569766E-01,   3.3481894798617712E-01,   2.0657967427421347E-03],
            [   2.6648419355374431E-02,  -9.4190558646569766E-01,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,   9.4190558646569766E-01,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [  -2.6648419355374431E-02,  -9.4190558646569766E-01,  -3.3481894798617712E-01,   2.0657967427421347E-03],
            [   3.6995155458552947E-01,   5.4240000668434950E-02,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,   5.4240000668434950E-02,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,  -5.4240000668434950E-02,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,   5.4240000668434950E-02,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,  -5.4240000668434950E-02,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,  -5.4240000668434950E-02,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,   5.4240000668434950E-02,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,  -5.4240000668434950E-02,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,   3.6995155458552947E-01,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,   3.6995155458552947E-01,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,  -3.6995155458552947E-01,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,   3.6995155458552947E-01,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,  -3.6995155458552947E-01,   9.2746637113549202E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,  -3.6995155458552947E-01,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,   3.6995155458552947E-01,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,  -3.6995155458552947E-01,  -9.2746637113549202E-01,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,   3.6995155458552947E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,   3.6995155458552947E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,  -3.6995155458552947E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,   3.6995155458552947E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,  -3.6995155458552947E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,  -3.6995155458552947E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,   3.6995155458552947E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,  -3.6995155458552947E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,   5.4240000668434950E-02,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,   5.4240000668434950E-02,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,  -5.4240000668434950E-02,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,   5.4240000668434950E-02,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,  -5.4240000668434950E-02,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   9.2746637113549202E-01,  -5.4240000668434950E-02,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,   5.4240000668434950E-02,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -9.2746637113549202E-01,  -5.4240000668434950E-02,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,   9.2746637113549202E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,   9.2746637113549202E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,  -9.2746637113549202E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,   9.2746637113549202E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,  -9.2746637113549202E-01,   5.4240000668434950E-02,   2.1316338882774529E-03],
            [   3.6995155458552947E-01,  -9.2746637113549202E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,   9.2746637113549202E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [  -3.6995155458552947E-01,  -9.2746637113549202E-01,  -5.4240000668434950E-02,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,   9.2746637113549202E-01,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,   9.2746637113549202E-01,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,  -9.2746637113549202E-01,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,   9.2746637113549202E-01,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,  -9.2746637113549202E-01,   3.6995155458552947E-01,   2.1316338882774529E-03],
            [   5.4240000668434950E-02,  -9.2746637113549202E-01,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,   9.2746637113549202E-01,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [  -5.4240000668434950E-02,  -9.2746637113549202E-01,  -3.6995155458552947E-01,   2.1316338882774529E-03],
            [   4.0420030714746691E-01,   8.2519927154308545E-02,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,   8.2519927154308545E-02,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,  -8.2519927154308545E-02,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,   8.2519927154308545E-02,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,  -8.2519927154308545E-02,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,  -8.2519927154308545E-02,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,   8.2519927154308545E-02,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,  -8.2519927154308545E-02,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,   4.0420030714746691E-01,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,   4.0420030714746691E-01,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,  -4.0420030714746691E-01,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,   4.0420030714746691E-01,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,  -4.0420030714746691E-01,   9.1094048835494246E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,  -4.0420030714746691E-01,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,   4.0420030714746691E-01,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,  -4.0420030714746691E-01,  -9.1094048835494246E-01,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,   4.0420030714746691E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,   4.0420030714746691E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,  -4.0420030714746691E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,   4.0420030714746691E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,  -4.0420030714746691E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,  -4.0420030714746691E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,   4.0420030714746691E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,  -4.0420030714746691E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,   8.2519927154308545E-02,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,   8.2519927154308545E-02,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,  -8.2519927154308545E-02,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,   8.2519927154308545E-02,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,  -8.2519927154308545E-02,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   9.1094048835494246E-01,  -8.2519927154308545E-02,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,   8.2519927154308545E-02,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -9.1094048835494246E-01,  -8.2519927154308545E-02,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,   9.1094048835494246E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,   9.1094048835494246E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,  -9.1094048835494246E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,   9.1094048835494246E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,  -9.1094048835494246E-01,   8.2519927154308545E-02,   2.1885001747497320E-03],
            [   4.0420030714746691E-01,  -9.1094048835494246E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,   9.1094048835494246E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [  -4.0420030714746691E-01,  -9.1094048835494246E-01,  -8.2519927154308545E-02,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,   9.1094048835494246E-01,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,   9.1094048835494246E-01,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,  -9.1094048835494246E-01,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,   9.1094048835494246E-01,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,  -9.1094048835494246E-01,   4.0420030714746691E-01,   2.1885001747497320E-03],
            [   8.2519927154308545E-02,  -9.1094048835494246E-01,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,   9.1094048835494246E-01,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [  -8.2519927154308545E-02,  -9.1094048835494246E-01,  -4.0420030714746691E-01,   2.1885001747497320E-03],
            [   4.3753201001826242E-01,   1.1126951824837100E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,   1.1126951824837100E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,  -1.1126951824837100E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,   1.1126951824837100E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,  -1.1126951824837100E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,  -1.1126951824837100E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,   1.1126951824837100E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,  -1.1126951824837100E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,   4.3753201001826242E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,   4.3753201001826242E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,  -4.3753201001826242E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,   4.3753201001826242E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,  -4.3753201001826242E-01,   8.9229189983892299E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,  -4.3753201001826242E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,   4.3753201001826242E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,  -4.3753201001826242E-01,  -8.9229189983892299E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,   4.3753201001826242E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,   4.3753201001826242E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,  -4.3753201001826242E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,   4.3753201001826242E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,  -4.3753201001826242E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,  -4.3753201001826242E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,   4.3753201001826242E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,  -4.3753201001826242E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,   1.1126951824837100E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,   1.1126951824837100E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,  -1.1126951824837100E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,   1.1126951824837100E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,  -1.1126951824837100E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   8.9229189983892299E-01,  -1.1126951824837100E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,   1.1126951824837100E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -8.9229189983892299E-01,  -1.1126951824837100E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,   8.9229189983892299E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,   8.9229189983892299E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,  -8.9229189983892299E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,   8.9229189983892299E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,  -8.9229189983892299E-01,   1.1126951824837100E-01,   2.2368331737686832E-03],
            [   4.3753201001826242E-01,  -8.9229189983892299E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,   8.9229189983892299E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [  -4.3753201001826242E-01,  -8.9229189983892299E-01,  -1.1126951824837100E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,   8.9229189983892299E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,   8.9229189983892299E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,  -8.9229189983892299E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,   8.9229189983892299E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,  -8.9229189983892299E-01,   4.3753201001826242E-01,   2.2368331737686832E-03],
            [   1.1126951824837100E-01,  -8.9229189983892299E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,   8.9229189983892299E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [  -1.1126951824837100E-01,  -8.9229189983892299E-01,  -4.3753201001826242E-01,   2.2368331737686832E-03],
            [   4.6990544903359471E-01,   1.4029641164678161E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,   1.4029641164678161E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,  -1.4029641164678161E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,   1.4029641164678161E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,  -1.4029641164678161E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,  -1.4029641164678161E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,   1.4029641164678161E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,  -1.4029641164678161E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,   4.6990544903359471E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,   4.6990544903359471E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,  -4.6990544903359471E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,   4.6990544903359471E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,  -4.6990544903359471E-01,   8.7149629135617812E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,  -4.6990544903359471E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,   4.6990544903359471E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,  -4.6990544903359471E-01,  -8.7149629135617812E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,   4.6990544903359471E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,   4.6990544903359471E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,  -4.6990544903359471E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,   4.6990544903359471E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,  -4.6990544903359471E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,  -4.6990544903359471E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,   4.6990544903359471E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,  -4.6990544903359471E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,   1.4029641164678161E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,   1.4029641164678161E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,  -1.4029641164678161E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,   1.4029641164678161E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,  -1.4029641164678161E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   8.7149629135617812E-01,  -1.4029641164678161E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,   1.4029641164678161E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -8.7149629135617812E-01,  -1.4029641164678161E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,   8.7149629135617812E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,   8.7149629135617812E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,  -8.7149629135617812E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,   8.7149629135617812E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,  -8.7149629135617812E-01,   1.4029641164678161E-01,   2.2771731142912943E-03],
            [   4.6990544903359471E-01,  -8.7149629135617812E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,   8.7149629135617812E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [  -4.6990544903359471E-01,  -8.7149629135617812E-01,  -1.4029641164678161E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,   8.7149629135617812E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,   8.7149629135617812E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,  -8.7149629135617812E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,   8.7149629135617812E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,  -8.7149629135617812E-01,   4.6990544903359471E-01,   2.2771731142912943E-03],
            [   1.4029641164678161E-01,  -8.7149629135617812E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,   8.7149629135617812E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [  -1.4029641164678161E-01,  -8.7149629135617812E-01,  -4.6990544903359471E-01,   2.2771731142912943E-03],
            [   5.0127398794319522E-01,   1.6942751175842910E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,   1.6942751175842910E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,  -1.6942751175842910E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,   1.6942751175842910E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,  -1.6942751175842910E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,  -1.6942751175842910E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,   1.6942751175842910E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,  -1.6942751175842910E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,   5.0127398794319522E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,   5.0127398794319522E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,  -5.0127398794319522E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,   5.0127398794319522E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,  -5.0127398794319522E-01,   8.4853916071733115E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,  -5.0127398794319522E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,   5.0127398794319522E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,  -5.0127398794319522E-01,  -8.4853916071733115E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,   5.0127398794319522E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,   5.0127398794319522E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,  -5.0127398794319522E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,   5.0127398794319522E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,  -5.0127398794319522E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,  -5.0127398794319522E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,   5.0127398794319522E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,  -5.0127398794319522E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,   1.6942751175842910E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,   1.6942751175842910E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,  -1.6942751175842910E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,   1.6942751175842910E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,  -1.6942751175842910E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   8.4853916071733115E-01,  -1.6942751175842910E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,   1.6942751175842910E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -8.4853916071733115E-01,  -1.6942751175842910E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,   8.4853916071733115E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,   8.4853916071733115E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,  -8.4853916071733115E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,   8.4853916071733115E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,  -8.4853916071733115E-01,   1.6942751175842910E-01,   2.3101050113460584E-03],
            [   5.0127398794319522E-01,  -8.4853916071733115E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,   8.4853916071733115E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [  -5.0127398794319522E-01,  -8.4853916071733115E-01,  -1.6942751175842910E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,   8.4853916071733115E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,   8.4853916071733115E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,  -8.4853916071733115E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,   8.4853916071733115E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,  -8.4853916071733115E-01,   5.0127398794319522E-01,   2.3101050113460584E-03],
            [   1.6942751175842910E-01,  -8.4853916071733115E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,   8.4853916071733115E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [  -1.6942751175842910E-01,  -8.4853916071733115E-01,  -5.0127398794319522E-01,   2.3101050113460584E-03],
            [   5.3158748837549663E-01,   1.9850382353126891E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,   1.9850382353126891E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,  -1.9850382353126891E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,   1.9850382353126891E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,  -1.9850382353126891E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,  -1.9850382353126891E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,   1.9850382353126891E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,  -1.9850382353126891E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,   5.3158748837549663E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,   5.3158748837549663E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,  -5.3158748837549663E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,   5.3158748837549663E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,  -5.3158748837549663E-01,   8.2341421790378266E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,  -5.3158748837549663E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,   5.3158748837549663E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,  -5.3158748837549663E-01,  -8.2341421790378266E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,   5.3158748837549663E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,   5.3158748837549663E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,  -5.3158748837549663E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,   5.3158748837549663E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,  -5.3158748837549663E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,  -5.3158748837549663E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,   5.3158748837549663E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,  -5.3158748837549663E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,   1.9850382353126891E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,   1.9850382353126891E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,  -1.9850382353126891E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,   1.9850382353126891E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,  -1.9850382353126891E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   8.2341421790378266E-01,  -1.9850382353126891E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,   1.9850382353126891E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -8.2341421790378266E-01,  -1.9850382353126891E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,   8.2341421790378266E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,   8.2341421790378266E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,  -8.2341421790378266E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,   8.2341421790378266E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,  -8.2341421790378266E-01,   1.9850382353126891E-01,   2.3362304477898541E-03],
            [   5.3158748837549663E-01,  -8.2341421790378266E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,   8.2341421790378266E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [  -5.3158748837549663E-01,  -8.2341421790378266E-01,  -1.9850382353126891E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,   8.2341421790378266E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,   8.2341421790378266E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,  -8.2341421790378266E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,   8.2341421790378266E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,  -8.2341421790378266E-01,   5.3158748837549663E-01,   2.3362304477898541E-03],
            [   1.9850382353126891E-01,  -8.2341421790378266E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,   8.2341421790378266E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [  -1.9850382353126891E-01,  -8.2341421790378266E-01,  -5.3158748837549663E-01,   2.3362304477898541E-03],
            [   5.6079371096221164E-01,   2.2737656600208930E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,   2.2737656600208930E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,  -2.2737656600208930E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,   2.2737656600208930E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,  -2.2737656600208930E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,  -2.2737656600208930E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,   2.2737656600208930E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,  -2.2737656600208930E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,   5.6079371096221164E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,   5.6079371096221164E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,  -5.6079371096221164E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,   5.6079371096221164E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,  -5.6079371096221164E-01,   7.9612204527844155E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,  -5.6079371096221164E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,   5.6079371096221164E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,  -5.6079371096221164E-01,  -7.9612204527844155E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,   5.6079371096221164E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,   5.6079371096221164E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,  -5.6079371096221164E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,   5.6079371096221164E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,  -5.6079371096221164E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,  -5.6079371096221164E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,   5.6079371096221164E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,  -5.6079371096221164E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,   2.2737656600208930E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,   2.2737656600208930E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,  -2.2737656600208930E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,   2.2737656600208930E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,  -2.2737656600208930E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   7.9612204527844155E-01,  -2.2737656600208930E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,   2.2737656600208930E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -7.9612204527844155E-01,  -2.2737656600208930E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,   7.9612204527844155E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,   7.9612204527844155E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,  -7.9612204527844155E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,   7.9612204527844155E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,  -7.9612204527844155E-01,   2.2737656600208930E-01,   2.3561558111821878E-03],
            [   5.6079371096221164E-01,  -7.9612204527844155E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,   7.9612204527844155E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [  -5.6079371096221164E-01,  -7.9612204527844155E-01,  -2.2737656600208930E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,   7.9612204527844155E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,   7.9612204527844155E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,  -7.9612204527844155E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,   7.9612204527844155E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,  -7.9612204527844155E-01,   5.6079371096221164E-01,   2.3561558111821878E-03],
            [   2.2737656600208930E-01,  -7.9612204527844155E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,   7.9612204527844155E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [  -2.2737656600208930E-01,  -7.9612204527844155E-01,  -5.6079371096221164E-01,   2.3561558111821878E-03],
            [   5.8883932234955205E-01,   2.5590414928497640E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,   2.5590414928497640E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,  -2.5590414928497640E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,   2.5590414928497640E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,  -2.5590414928497640E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,  -2.5590414928497640E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,   2.5590414928497640E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,  -2.5590414928497640E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,   5.8883932234955205E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,   5.8883932234955205E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,  -5.8883932234955205E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,   5.8883932234955205E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,  -5.8883932234955205E-01,   7.6666897604745476E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,  -5.8883932234955205E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,   5.8883932234955205E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,  -5.8883932234955205E-01,  -7.6666897604745476E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,   5.8883932234955205E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,   5.8883932234955205E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,  -5.8883932234955205E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,   5.8883932234955205E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,  -5.8883932234955205E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,  -5.8883932234955205E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,   5.8883932234955205E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,  -5.8883932234955205E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,   2.5590414928497640E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,   2.5590414928497640E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,  -2.5590414928497640E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,   2.5590414928497640E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,  -2.5590414928497640E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   7.6666897604745476E-01,  -2.5590414928497640E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,   2.5590414928497640E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -7.6666897604745476E-01,  -2.5590414928497640E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,   7.6666897604745476E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,   7.6666897604745476E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,  -7.6666897604745476E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,   7.6666897604745476E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,  -7.6666897604745476E-01,   2.5590414928497640E-01,   2.3704895066839256E-03],
            [   5.8883932234955205E-01,  -7.6666897604745476E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,   7.6666897604745476E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [  -5.8883932234955205E-01,  -7.6666897604745476E-01,  -2.5590414928497640E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,   7.6666897604745476E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,   7.6666897604745476E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,  -7.6666897604745476E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,   7.6666897604745476E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,  -7.6666897604745476E-01,   5.8883932234955205E-01,   2.3704895066839256E-03],
            [   2.5590414928497640E-01,  -7.6666897604745476E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,   7.6666897604745476E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [  -2.5590414928497640E-01,  -7.6666897604745476E-01,  -5.8883932234955205E-01,   2.3704895066839256E-03],
            [   6.1567059791601630E-01,   2.8394972519768991E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,   2.8394972519768991E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,  -2.8394972519768991E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,   2.8394972519768991E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,  -2.8394972519768991E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,  -2.8394972519768991E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,   2.8394972519768991E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,  -2.8394972519768991E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,   6.1567059791601630E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,   6.1567059791601630E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,  -6.1567059791601630E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,   6.1567059791601630E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,  -6.1567059791601630E-01,   7.3506616601629227E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,  -6.1567059791601630E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,   6.1567059791601630E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,  -6.1567059791601630E-01,  -7.3506616601629227E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,   6.1567059791601630E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,   6.1567059791601630E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,  -6.1567059791601630E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,   6.1567059791601630E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,  -6.1567059791601630E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,  -6.1567059791601630E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,   6.1567059791601630E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,  -6.1567059791601630E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,   2.8394972519768991E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,   2.8394972519768991E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,  -2.8394972519768991E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,   2.8394972519768991E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,  -2.8394972519768991E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   7.3506616601629227E-01,  -2.8394972519768991E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,   2.8394972519768991E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -7.3506616601629227E-01,  -2.8394972519768991E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,   7.3506616601629227E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,   7.3506616601629227E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,  -7.3506616601629227E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,   7.3506616601629227E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,  -7.3506616601629227E-01,   2.8394972519768991E-01,   2.3798438666347839E-03],
            [   6.1567059791601630E-01,  -7.3506616601629227E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,   7.3506616601629227E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [  -6.1567059791601630E-01,  -7.3506616601629227E-01,  -2.8394972519768991E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,   7.3506616601629227E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,   7.3506616601629227E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,  -7.3506616601629227E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,   7.3506616601629227E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,  -7.3506616601629227E-01,   6.1567059791601630E-01,   2.3798438666347839E-03],
            [   2.8394972519768991E-01,  -7.3506616601629227E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,   7.3506616601629227E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [  -2.8394972519768991E-01,  -7.3506616601629227E-01,  -6.1567059791601630E-01,   2.3798438666347839E-03],
            [   6.4123388090781230E-01,   3.1137910605006902E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,   3.1137910605006902E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,  -3.1137910605006902E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,   3.1137910605006902E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,  -3.1137910605006902E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,  -3.1137910605006902E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,   3.1137910605006902E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,  -3.1137910605006902E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,   6.4123388090781230E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,   6.4123388090781230E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,  -6.4123388090781230E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,   6.4123388090781230E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,  -6.4123388090781230E-01,   7.0132885459773109E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,  -6.4123388090781230E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,   6.4123388090781230E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,  -6.4123388090781230E-01,  -7.0132885459773109E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,   6.4123388090781230E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,   6.4123388090781230E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,  -6.4123388090781230E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,   6.4123388090781230E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,  -6.4123388090781230E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,  -6.4123388090781230E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,   6.4123388090781230E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,  -6.4123388090781230E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,   3.1137910605006902E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,   3.1137910605006902E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,  -3.1137910605006902E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,   3.1137910605006902E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,  -3.1137910605006902E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   7.0132885459773109E-01,  -3.1137910605006902E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,   3.1137910605006902E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -7.0132885459773109E-01,  -3.1137910605006902E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,   7.0132885459773109E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,   7.0132885459773109E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,  -7.0132885459773109E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,   7.0132885459773109E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,  -7.0132885459773109E-01,   3.1137910605006902E-01,   2.3848392156578997E-03],
            [   6.4123388090781230E-01,  -7.0132885459773109E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,   7.0132885459773109E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [  -6.4123388090781230E-01,  -7.0132885459773109E-01,  -3.1137910605006902E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,   7.0132885459773109E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,   7.0132885459773109E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,  -7.0132885459773109E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,   7.0132885459773109E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,  -7.0132885459773109E-01,   6.4123388090781230E-01,   2.3848392156578997E-03],
            [   3.1137910605006902E-01,  -7.0132885459773109E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,   7.0132885459773109E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [  -3.1137910605006902E-01,  -7.0132885459773109E-01,  -6.4123388090781230E-01,   2.3848392156578997E-03],
            [   4.0760512592571668E-01,   2.7577922908584629E-02,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,   2.7577922908584629E-02,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,  -2.7577922908584629E-02,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,   2.7577922908584629E-02,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,  -2.7577922908584629E-02,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,  -2.7577922908584629E-02,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,   2.7577922908584629E-02,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,  -2.7577922908584629E-02,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,   4.0760512592571668E-01,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,   4.0760512592571668E-01,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,  -4.0760512592571668E-01,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,   4.0760512592571668E-01,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,  -4.0760512592571668E-01,   9.1274175947369085E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,  -4.0760512592571668E-01,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,   4.0760512592571668E-01,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,  -4.0760512592571668E-01,  -9.1274175947369085E-01,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,   4.0760512592571668E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,   4.0760512592571668E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,  -4.0760512592571668E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,   4.0760512592571668E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,  -4.0760512592571668E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,  -4.0760512592571668E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,   4.0760512592571668E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,  -4.0760512592571668E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,   2.7577922908584629E-02,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,   2.7577922908584629E-02,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,  -2.7577922908584629E-02,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,   2.7577922908584629E-02,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,  -2.7577922908584629E-02,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   9.1274175947369085E-01,  -2.7577922908584629E-02,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,   2.7577922908584629E-02,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -9.1274175947369085E-01,  -2.7577922908584629E-02,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,   9.1274175947369085E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,   9.1274175947369085E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,  -9.1274175947369085E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,   9.1274175947369085E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,  -9.1274175947369085E-01,   2.7577922908584629E-02,   2.1852465186466452E-03],
            [   4.0760512592571668E-01,  -9.1274175947369085E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,   9.1274175947369085E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [  -4.0760512592571668E-01,  -9.1274175947369085E-01,  -2.7577922908584629E-02,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,   9.1274175947369085E-01,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,   9.1274175947369085E-01,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,  -9.1274175947369085E-01,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,   9.1274175947369085E-01,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,  -9.1274175947369085E-01,   4.0760512592571668E-01,   2.1852465186466452E-03],
            [   2.7577922908584629E-02,  -9.1274175947369085E-01,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,   9.1274175947369085E-01,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [  -2.7577922908584629E-02,  -9.1274175947369085E-01,  -4.0760512592571668E-01,   2.1852465186466452E-03],
            [   4.4237881257915201E-01,   5.5841368349842928E-02,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,   5.5841368349842928E-02,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,  -5.5841368349842928E-02,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,   5.5841368349842928E-02,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,  -5.5841368349842928E-02,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,  -5.5841368349842928E-02,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,   5.5841368349842928E-02,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,  -5.5841368349842928E-02,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,   4.4237881257915201E-01,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,   4.4237881257915201E-01,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,  -4.4237881257915201E-01,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,   4.4237881257915201E-01,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,  -4.4237881257915201E-01,   8.9508811173083780E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,  -4.4237881257915201E-01,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,   4.4237881257915201E-01,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,  -4.4237881257915201E-01,  -8.9508811173083780E-01,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,   4.4237881257915201E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,   4.4237881257915201E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,  -4.4237881257915201E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,   4.4237881257915201E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,  -4.4237881257915201E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,  -4.4237881257915201E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,   4.4237881257915201E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,  -4.4237881257915201E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,   5.5841368349842928E-02,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,   5.5841368349842928E-02,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,  -5.5841368349842928E-02,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,   5.5841368349842928E-02,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,  -5.5841368349842928E-02,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   8.9508811173083780E-01,  -5.5841368349842928E-02,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,   5.5841368349842928E-02,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -8.9508811173083780E-01,  -5.5841368349842928E-02,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,   8.9508811173083780E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,   8.9508811173083780E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,  -8.9508811173083780E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,   8.9508811173083780E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,  -8.9508811173083780E-01,   5.5841368349842928E-02,   2.2335999439831145E-03],
            [   4.4237881257915201E-01,  -8.9508811173083780E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,   8.9508811173083780E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [  -4.4237881257915201E-01,  -8.9508811173083780E-01,  -5.5841368349842928E-02,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,   8.9508811173083780E-01,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,   8.9508811173083780E-01,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,  -8.9508811173083780E-01,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,   8.9508811173083780E-01,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,  -8.9508811173083780E-01,   4.4237881257915201E-01,   2.2335999439831145E-03],
            [   5.5841368349842928E-02,  -8.9508811173083780E-01,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,   8.9508811173083780E-01,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [  -5.5841368349842928E-02,  -8.9508811173083780E-01,  -4.4237881257915201E-01,   2.2335999439831145E-03],
            [   4.7604809173282581E-01,   8.4577720877271431E-02,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,   8.4577720877271431E-02,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,  -8.4577720877271431E-02,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,   8.4577720877271431E-02,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,  -8.4577720877271431E-02,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,  -8.4577720877271431E-02,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,   8.4577720877271431E-02,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,  -8.4577720877271431E-02,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,   4.7604809173282581E-01,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,   4.7604809173282581E-01,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,  -4.7604809173282581E-01,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,   4.7604809173282581E-01,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,  -4.7604809173282581E-01,   8.7534268917306979E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,  -4.7604809173282581E-01,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,   4.7604809173282581E-01,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,  -4.7604809173282581E-01,  -8.7534268917306979E-01,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,   4.7604809173282581E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,   4.7604809173282581E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,  -4.7604809173282581E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,   4.7604809173282581E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,  -4.7604809173282581E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,  -4.7604809173282581E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,   4.7604809173282581E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,  -4.7604809173282581E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,   8.4577720877271431E-02,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,   8.4577720877271431E-02,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,  -8.4577720877271431E-02,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,   8.4577720877271431E-02,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,  -8.4577720877271431E-02,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.7534268917306979E-01,  -8.4577720877271431E-02,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,   8.4577720877271431E-02,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.7534268917306979E-01,  -8.4577720877271431E-02,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,   8.7534268917306979E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,   8.7534268917306979E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,  -8.7534268917306979E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,   8.7534268917306979E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,  -8.7534268917306979E-01,   8.4577720877271431E-02,   2.2745266718151845E-03],
            [   4.7604809173282581E-01,  -8.7534268917306979E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,   8.7534268917306979E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [  -4.7604809173282581E-01,  -8.7534268917306979E-01,  -8.4577720877271431E-02,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,   8.7534268917306979E-01,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,   8.7534268917306979E-01,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,  -8.7534268917306979E-01,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,   8.7534268917306979E-01,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,  -8.7534268917306979E-01,   4.7604809173282581E-01,   2.2745266718151845E-03],
            [   8.4577720877271431E-02,  -8.7534268917306979E-01,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,   8.7534268917306979E-01,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [  -8.4577720877271431E-02,  -8.7534268917306979E-01,  -4.7604809173282581E-01,   2.2745266718151845E-03],
            [   5.0858387259462967E-01,   1.1359758463592480E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,   1.1359758463592480E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,  -1.1359758463592480E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,   1.1359758463592480E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,  -1.1359758463592480E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,  -1.1359758463592480E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,   1.1359758463592480E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,  -1.1359758463592480E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,   5.0858387259462967E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,   5.0858387259462967E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,  -5.0858387259462967E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,   5.0858387259462967E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,  -5.0858387259462967E-01,   8.5348581318117600E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,  -5.0858387259462967E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,   5.0858387259462967E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,  -5.0858387259462967E-01,  -8.5348581318117600E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,   5.0858387259462967E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,   5.0858387259462967E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,  -5.0858387259462967E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,   5.0858387259462967E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,  -5.0858387259462967E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,  -5.0858387259462967E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,   5.0858387259462967E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,  -5.0858387259462967E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,   1.1359758463592480E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,   1.1359758463592480E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,  -1.1359758463592480E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,   1.1359758463592480E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,  -1.1359758463592480E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   8.5348581318117600E-01,  -1.1359758463592480E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,   1.1359758463592480E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -8.5348581318117600E-01,  -1.1359758463592480E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,   8.5348581318117600E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,   8.5348581318117600E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,  -8.5348581318117600E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,   8.5348581318117600E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,  -8.5348581318117600E-01,   1.1359758463592480E-01,   2.3083421508152584E-03],
            [   5.0858387259462967E-01,  -8.5348581318117600E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,   8.5348581318117600E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [  -5.0858387259462967E-01,  -8.5348581318117600E-01,  -1.1359758463592480E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,   8.5348581318117600E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,   8.5348581318117600E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,  -8.5348581318117600E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,   8.5348581318117600E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,  -8.5348581318117600E-01,   5.0858387259462967E-01,   2.3083421508152584E-03],
            [   1.1359758463592480E-01,  -8.5348581318117600E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,   8.5348581318117600E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [  -1.1359758463592480E-01,  -8.5348581318117600E-01,  -5.0858387259462967E-01,   2.3083421508152584E-03],
            [   5.3995136373912178E-01,   1.4272869047650530E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,   1.4272869047650530E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,  -1.4272869047650530E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,   1.4272869047650530E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,  -1.4272869047650530E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,  -1.4272869047650530E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,   1.4272869047650530E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,  -1.4272869047650530E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,   5.3995136373912178E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,   5.3995136373912178E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,  -5.3995136373912178E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,   5.3995136373912178E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,  -5.3995136373912178E-01,   8.2950650733500852E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,  -5.3995136373912178E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,   5.3995136373912178E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,  -5.3995136373912178E-01,  -8.2950650733500852E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,   5.3995136373912178E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,   5.3995136373912178E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,  -5.3995136373912178E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,   5.3995136373912178E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,  -5.3995136373912178E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,  -5.3995136373912178E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,   5.3995136373912178E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,  -5.3995136373912178E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,   1.4272869047650530E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,   1.4272869047650530E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,  -1.4272869047650530E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,   1.4272869047650530E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,  -1.4272869047650530E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   8.2950650733500852E-01,  -1.4272869047650530E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,   1.4272869047650530E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -8.2950650733500852E-01,  -1.4272869047650530E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,   8.2950650733500852E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,   8.2950650733500852E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,  -8.2950650733500852E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,   8.2950650733500852E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,  -8.2950650733500852E-01,   1.4272869047650530E-01,   2.3354467503296388E-03],
            [   5.3995136373912178E-01,  -8.2950650733500852E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,   8.2950650733500852E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [  -5.3995136373912178E-01,  -8.2950650733500852E-01,  -1.4272869047650530E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,   8.2950650733500852E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,   8.2950650733500852E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,  -8.2950650733500852E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,   8.2950650733500852E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,  -8.2950650733500852E-01,   5.3995136373912178E-01,   2.3354467503296388E-03],
            [   1.4272869047650530E-01,  -8.2950650733500852E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,   8.2950650733500852E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [  -1.4272869047650530E-01,  -8.2950650733500852E-01,  -5.3995136373912178E-01,   2.3354467503296388E-03],
            [   5.7011184336363796E-01,   1.7181127400576349E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,   1.7181127400576349E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,  -1.7181127400576349E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,   1.7181127400576349E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,  -1.7181127400576349E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,  -1.7181127400576349E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,   1.7181127400576349E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,  -1.7181127400576349E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,   5.7011184336363796E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,   5.7011184336363796E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,  -5.7011184336363796E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,   5.7011184336363796E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,  -5.7011184336363796E-01,   8.0340112781911821E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,  -5.7011184336363796E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,   5.7011184336363796E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,  -5.7011184336363796E-01,  -8.0340112781911821E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,   5.7011184336363796E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,   5.7011184336363796E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,  -5.7011184336363796E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,   5.7011184336363796E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,  -5.7011184336363796E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,  -5.7011184336363796E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,   5.7011184336363796E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,  -5.7011184336363796E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,   1.7181127400576349E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,   1.7181127400576349E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,  -1.7181127400576349E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,   1.7181127400576349E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,  -1.7181127400576349E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   8.0340112781911821E-01,  -1.7181127400576349E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,   1.7181127400576349E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -8.0340112781911821E-01,  -1.7181127400576349E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,   8.0340112781911821E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,   8.0340112781911821E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,  -8.0340112781911821E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,   8.0340112781911821E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,  -8.0340112781911821E-01,   1.7181127400576349E-01,   2.3562941949141093E-03],
            [   5.7011184336363796E-01,  -8.0340112781911821E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,   8.0340112781911821E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [  -5.7011184336363796E-01,  -8.0340112781911821E-01,  -1.7181127400576349E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,   8.0340112781911821E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,   8.0340112781911821E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,  -8.0340112781911821E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,   8.0340112781911821E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,  -8.0340112781911821E-01,   5.7011184336363796E-01,   2.3562941949141093E-03],
            [   1.7181127400576349E-01,  -8.0340112781911821E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,   8.0340112781911821E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [  -1.7181127400576349E-01,  -8.0340112781911821E-01,  -5.7011184336363796E-01,   2.3562941949141093E-03],
            [   5.9902405306060214E-01,   2.0069448559853509E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,   2.0069448559853509E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,  -2.0069448559853509E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,   2.0069448559853509E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,  -2.0069448559853509E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,  -2.0069448559853509E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,   2.0069448559853509E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,  -2.0069448559853509E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,   5.9902405306060214E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,   5.9902405306060214E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,  -5.9902405306060214E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,   5.9902405306060214E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,  -5.9902405306060214E-01,   7.7517217913518299E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,  -5.9902405306060214E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,   5.9902405306060214E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,  -5.9902405306060214E-01,  -7.7517217913518299E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,   5.9902405306060214E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,   5.9902405306060214E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,  -5.9902405306060214E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,   5.9902405306060214E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,  -5.9902405306060214E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,  -5.9902405306060214E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,   5.9902405306060214E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,  -5.9902405306060214E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,   2.0069448559853509E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,   2.0069448559853509E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,  -2.0069448559853509E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,   2.0069448559853509E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,  -2.0069448559853509E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   7.7517217913518299E-01,  -2.0069448559853509E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,   2.0069448559853509E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -7.7517217913518299E-01,  -2.0069448559853509E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,   7.7517217913518299E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,   7.7517217913518299E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,  -7.7517217913518299E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,   7.7517217913518299E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,  -7.7517217913518299E-01,   2.0069448559853509E-01,   2.3713749663593149E-03],
            [   5.9902405306060214E-01,  -7.7517217913518299E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,   7.7517217913518299E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [  -5.9902405306060214E-01,  -7.7517217913518299E-01,  -2.0069448559853509E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,   7.7517217913518299E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,   7.7517217913518299E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,  -7.7517217913518299E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,   7.7517217913518299E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,  -7.7517217913518299E-01,   5.9902405306060214E-01,   2.3713749663593149E-03],
            [   2.0069448559853509E-01,  -7.7517217913518299E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,   7.7517217913518299E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [  -2.0069448559853509E-01,  -7.7517217913518299E-01,  -5.9902405306060214E-01,   2.3713749663593149E-03],
            [   6.2664526851396951E-01,   2.2923350905989071E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,   2.2923350905989071E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,  -2.2923350905989071E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,   2.2923350905989071E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,  -2.2923350905989071E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,  -2.2923350905989071E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,   2.2923350905989071E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,  -2.2923350905989071E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,   6.2664526851396951E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,   6.2664526851396951E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,  -6.2664526851396951E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,   6.2664526851396951E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,  -6.2664526851396951E-01,   7.4482729929369806E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,  -6.2664526851396951E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,   6.2664526851396951E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,  -6.2664526851396951E-01,  -7.4482729929369806E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,   6.2664526851396951E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,   6.2664526851396951E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,  -6.2664526851396951E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,   6.2664526851396951E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,  -6.2664526851396951E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,  -6.2664526851396951E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,   6.2664526851396951E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,  -6.2664526851396951E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,   2.2923350905989071E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,   2.2923350905989071E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,  -2.2923350905989071E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,   2.2923350905989071E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,  -2.2923350905989071E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   7.4482729929369806E-01,  -2.2923350905989071E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,   2.2923350905989071E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -7.4482729929369806E-01,  -2.2923350905989071E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,   7.4482729929369806E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,   7.4482729929369806E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,  -7.4482729929369806E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,   7.4482729929369806E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,  -7.4482729929369806E-01,   2.2923350905989071E-01,   2.3812087961134982E-03],
            [   6.2664526851396951E-01,  -7.4482729929369806E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,   7.4482729929369806E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [  -6.2664526851396951E-01,  -7.4482729929369806E-01,  -2.2923350905989071E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,   7.4482729929369806E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,   7.4482729929369806E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,  -7.4482729929369806E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,   7.4482729929369806E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,  -7.4482729929369806E-01,   6.2664526851396951E-01,   2.3812087961134982E-03],
            [   2.2923350905989071E-01,  -7.4482729929369806E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,   7.4482729929369806E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [  -2.2923350905989071E-01,  -7.4482729929369806E-01,  -6.2664526851396951E-01,   2.3812087961134982E-03],
            [   6.5293209714159417E-01,   2.5728715123537138E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,   2.5728715123537138E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,  -2.5728715123537138E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,   2.5728715123537138E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,  -2.5728715123537138E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,  -2.5728715123537138E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,   2.5728715123537138E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,  -2.5728715123537138E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,   6.5293209714159417E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,   6.5293209714159417E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,  -6.5293209714159417E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,   6.5293209714159417E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,  -6.5293209714159417E-01,   7.1237840950682030E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,  -6.5293209714159417E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,   6.5293209714159417E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,  -6.5293209714159417E-01,  -7.1237840950682030E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,   6.5293209714159417E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,   6.5293209714159417E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,  -6.5293209714159417E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,   6.5293209714159417E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,  -6.5293209714159417E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,  -6.5293209714159417E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,   6.5293209714159417E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,  -6.5293209714159417E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,   2.5728715123537138E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,   2.5728715123537138E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,  -2.5728715123537138E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,   2.5728715123537138E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,  -2.5728715123537138E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   7.1237840950682030E-01,  -2.5728715123537138E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,   2.5728715123537138E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -7.1237840950682030E-01,  -2.5728715123537138E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,   7.1237840950682030E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,   7.1237840950682030E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,  -7.1237840950682030E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,   7.1237840950682030E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,  -7.1237840950682030E-01,   2.5728715123537138E-01,   2.3863425468403157E-03],
            [   6.5293209714159417E-01,  -7.1237840950682030E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,   7.1237840950682030E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [  -6.5293209714159417E-01,  -7.1237840950682030E-01,  -2.5728715123537138E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,   7.1237840950682030E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,   7.1237840950682030E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,  -7.1237840950682030E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,   7.1237840950682030E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,  -7.1237840950682030E-01,   6.5293209714159417E-01,   2.3863425468403157E-03],
            [   2.5728715123537138E-01,  -7.1237840950682030E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,   7.1237840950682030E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [  -2.5728715123537138E-01,  -7.1237840950682030E-01,  -6.5293209714159417E-01,   2.3863425468403157E-03],
            [   4.7915838346101258E-01,   2.8260941977359320E-02,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,   2.8260941977359320E-02,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,  -2.8260941977359320E-02,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,   2.8260941977359320E-02,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,  -2.8260941977359320E-02,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,  -2.8260941977359320E-02,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,   2.8260941977359320E-02,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,  -2.8260941977359320E-02,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,   4.7915838346101258E-01,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,   4.7915838346101258E-01,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,  -4.7915838346101258E-01,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,   4.7915838346101258E-01,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,  -4.7915838346101258E-01,   8.7727336829381841E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,  -4.7915838346101258E-01,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,   4.7915838346101258E-01,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,  -4.7915838346101258E-01,  -8.7727336829381841E-01,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,   4.7915838346101258E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,   4.7915838346101258E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,  -4.7915838346101258E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,   4.7915838346101258E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,  -4.7915838346101258E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,  -4.7915838346101258E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,   4.7915838346101258E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,  -4.7915838346101258E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,   2.8260941977359320E-02,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,   2.8260941977359320E-02,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,  -2.8260941977359320E-02,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,   2.8260941977359320E-02,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,  -2.8260941977359320E-02,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   8.7727336829381841E-01,  -2.8260941977359320E-02,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,   2.8260941977359320E-02,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -8.7727336829381841E-01,  -2.8260941977359320E-02,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,   8.7727336829381841E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,   8.7727336829381841E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,  -8.7727336829381841E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,   8.7727336829381841E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,  -8.7727336829381841E-01,   2.8260941977359320E-02,   2.2733381462292945E-03],
            [   4.7915838346101258E-01,  -8.7727336829381841E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,   8.7727336829381841E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [  -4.7915838346101258E-01,  -8.7727336829381841E-01,  -2.8260941977359320E-02,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,   8.7727336829381841E-01,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,   8.7727336829381841E-01,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,  -8.7727336829381841E-01,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,   8.7727336829381841E-01,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,  -8.7727336829381841E-01,   4.7915838346101258E-01,   2.2733381462292945E-03],
            [   2.8260941977359320E-02,  -8.7727336829381841E-01,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,   8.7727336829381841E-01,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [  -2.8260941977359320E-02,  -8.7727336829381841E-01,  -4.7915838346101258E-01,   2.2733381462292945E-03],
            [   5.1303739527969405E-01,   5.6998713596836489E-02,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,   5.6998713596836489E-02,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,  -5.6998713596836489E-02,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,   5.6998713596836489E-02,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,  -5.6998713596836489E-02,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,  -5.6998713596836489E-02,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,   5.6998713596836489E-02,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,  -5.6998713596836489E-02,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,   5.1303739527969405E-01,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,   5.1303739527969405E-01,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,  -5.1303739527969405E-01,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,   5.1303739527969405E-01,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,  -5.1303739527969405E-01,   8.5647170279754870E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,  -5.1303739527969405E-01,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,   5.1303739527969405E-01,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,  -5.1303739527969405E-01,  -8.5647170279754870E-01,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,   5.1303739527969405E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,   5.1303739527969405E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,  -5.1303739527969405E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,   5.1303739527969405E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,  -5.1303739527969405E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,  -5.1303739527969405E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,   5.1303739527969405E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,  -5.1303739527969405E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,   5.6998713596836489E-02,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,   5.6998713596836489E-02,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,  -5.6998713596836489E-02,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,   5.6998713596836489E-02,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,  -5.6998713596836489E-02,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   8.5647170279754870E-01,  -5.6998713596836489E-02,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,   5.6998713596836489E-02,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -8.5647170279754870E-01,  -5.6998713596836489E-02,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,   8.5647170279754870E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,   8.5647170279754870E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,  -8.5647170279754870E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,   8.5647170279754870E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,  -8.5647170279754870E-01,   5.6998713596836489E-02,   2.3075590188066349E-03],
            [   5.1303739527969405E-01,  -8.5647170279754870E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,   8.5647170279754870E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [  -5.1303739527969405E-01,  -8.5647170279754870E-01,  -5.6998713596836489E-02,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,   8.5647170279754870E-01,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,   8.5647170279754870E-01,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,  -8.5647170279754870E-01,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,   8.5647170279754870E-01,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,  -8.5647170279754870E-01,   5.1303739527969405E-01,   2.3075590188066349E-03],
            [   5.6998713596836489E-02,  -8.5647170279754870E-01,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,   8.5647170279754870E-01,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [  -5.6998713596836489E-02,  -8.5647170279754870E-01,  -5.1303739527969405E-01,   2.3075590188066349E-03],
            [   5.4562524296284765E-01,   8.6027125285543946E-02,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,   8.6027125285543946E-02,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,  -8.6027125285543946E-02,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,   8.6027125285543946E-02,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,  -8.6027125285543946E-02,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,  -8.6027125285543946E-02,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,   8.6027125285543946E-02,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,  -8.6027125285543946E-02,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,   5.4562524296284765E-01,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,   5.4562524296284765E-01,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,  -5.4562524296284765E-01,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,   5.4562524296284765E-01,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,  -5.4562524296284765E-01,   8.3360208010587333E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,  -5.4562524296284765E-01,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,   5.4562524296284765E-01,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,  -5.4562524296284765E-01,  -8.3360208010587333E-01,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,   5.4562524296284765E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,   5.4562524296284765E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,  -5.4562524296284765E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,   5.4562524296284765E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,  -5.4562524296284765E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,  -5.4562524296284765E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,   5.4562524296284765E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,  -5.4562524296284765E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,   8.6027125285543946E-02,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,   8.6027125285543946E-02,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,  -8.6027125285543946E-02,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,   8.6027125285543946E-02,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,  -8.6027125285543946E-02,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.3360208010587333E-01,  -8.6027125285543946E-02,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,   8.6027125285543946E-02,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.3360208010587333E-01,  -8.6027125285543946E-02,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,   8.3360208010587333E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,   8.3360208010587333E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,  -8.3360208010587333E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,   8.3360208010587333E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,  -8.3360208010587333E-01,   8.6027125285543946E-02,   2.3353681389195959E-03],
            [   5.4562524296284765E-01,  -8.3360208010587333E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,   8.3360208010587333E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [  -5.4562524296284765E-01,  -8.3360208010587333E-01,  -8.6027125285543946E-02,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,   8.3360208010587333E-01,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,   8.3360208010587333E-01,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,  -8.3360208010587333E-01,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,   8.3360208010587333E-01,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,  -8.3360208010587333E-01,   5.4562524296284765E-01,   2.3353681389195959E-03],
            [   8.6027125285543946E-02,  -8.3360208010587333E-01,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,   8.3360208010587333E-01,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [  -8.6027125285543946E-02,  -8.3360208010587333E-01,  -5.4562524296284765E-01,   2.3353681389195959E-03],
            [   5.7689563296823854E-01,   1.1517481372212809E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,   1.1517481372212809E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,  -1.1517481372212809E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,   1.1517481372212809E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,  -1.1517481372212809E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,  -1.1517481372212809E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,   1.1517481372212809E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,  -1.1517481372212809E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,   5.7689563296823854E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,   5.7689563296823854E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,  -5.7689563296823854E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,   5.7689563296823854E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,  -5.7689563296823854E-01,   8.0865702924431970E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,  -5.7689563296823854E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,   5.7689563296823854E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,  -5.7689563296823854E-01,  -8.0865702924431970E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,   5.7689563296823854E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,   5.7689563296823854E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,  -5.7689563296823854E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,   5.7689563296823854E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,  -5.7689563296823854E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,  -5.7689563296823854E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,   5.7689563296823854E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,  -5.7689563296823854E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,   1.1517481372212809E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,   1.1517481372212809E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,  -1.1517481372212809E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,   1.1517481372212809E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,  -1.1517481372212809E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   8.0865702924431970E-01,  -1.1517481372212809E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,   1.1517481372212809E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -8.0865702924431970E-01,  -1.1517481372212809E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,   8.0865702924431970E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,   8.0865702924431970E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,  -8.0865702924431970E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,   8.0865702924431970E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,  -8.0865702924431970E-01,   1.1517481372212809E-01,   2.3570164579200621E-03],
            [   5.7689563296823854E-01,  -8.0865702924431970E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,   8.0865702924431970E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [  -5.7689563296823854E-01,  -8.0865702924431970E-01,  -1.1517481372212809E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,   8.0865702924431970E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,   8.0865702924431970E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,  -8.0865702924431970E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,   8.0865702924431970E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,  -8.0865702924431970E-01,   5.7689563296823854E-01,   2.3570164579200621E-03],
            [   1.1517481372212809E-01,  -8.0865702924431970E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,   8.0865702924431970E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [  -1.1517481372212809E-01,  -8.0865702924431970E-01,  -5.7689563296823854E-01,   2.3570164579200621E-03],
            [   6.0681869446990455E-01,   1.4428116541363620E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,   1.4428116541363620E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,  -1.4428116541363620E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,   1.4428116541363620E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,  -1.4428116541363620E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,  -1.4428116541363620E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,   1.4428116541363620E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,  -1.4428116541363620E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,   6.0681869446990455E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,   6.0681869446990455E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,  -6.0681869446990455E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,   6.0681869446990455E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,  -6.0681869446990455E-01,   7.8163547600446304E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,  -6.0681869446990455E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,   6.0681869446990455E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,  -6.0681869446990455E-01,  -7.8163547600446304E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,   6.0681869446990455E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,   6.0681869446990455E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,  -6.0681869446990455E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,   6.0681869446990455E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,  -6.0681869446990455E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,  -6.0681869446990455E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,   6.0681869446990455E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,  -6.0681869446990455E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,   1.4428116541363620E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,   1.4428116541363620E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,  -1.4428116541363620E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,   1.4428116541363620E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,  -1.4428116541363620E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   7.8163547600446304E-01,  -1.4428116541363620E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,   1.4428116541363620E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -7.8163547600446304E-01,  -1.4428116541363620E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,   7.8163547600446304E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,   7.8163547600446304E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,  -7.8163547600446304E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,   7.8163547600446304E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,  -7.8163547600446304E-01,   1.4428116541363620E-01,   2.3728333096676001E-03],
            [   6.0681869446990455E-01,  -7.8163547600446304E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,   7.8163547600446304E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [  -6.0681869446990455E-01,  -7.8163547600446304E-01,  -1.4428116541363620E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,   7.8163547600446304E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,   7.8163547600446304E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,  -7.8163547600446304E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,   7.8163547600446304E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,  -7.8163547600446304E-01,   6.0681869446990455E-01,   2.3728333096676001E-03],
            [   1.4428116541363620E-01,  -7.8163547600446304E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,   7.8163547600446304E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [  -1.4428116541363620E-01,  -7.8163547600446304E-01,  -6.0681869446990455E-01,   2.3728333096676001E-03],
            [   6.3536222480249072E-01,   1.7319303216576801E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,   1.7319303216576801E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,  -1.7319303216576801E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,   1.7319303216576801E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,  -1.7319303216576801E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,  -1.7319303216576801E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,   1.7319303216576801E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,  -1.7319303216576801E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,   6.3536222480249072E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,   6.3536222480249072E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,  -6.3536222480249072E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,   6.3536222480249072E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,  -6.3536222480249072E-01,   7.5254170442790513E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,  -6.3536222480249072E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,   6.3536222480249072E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,  -6.3536222480249072E-01,  -7.5254170442790513E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,   6.3536222480249072E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,   6.3536222480249072E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,  -6.3536222480249072E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,   6.3536222480249072E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,  -6.3536222480249072E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,  -6.3536222480249072E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,   6.3536222480249072E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,  -6.3536222480249072E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,   1.7319303216576801E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,   1.7319303216576801E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,  -1.7319303216576801E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,   1.7319303216576801E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,  -1.7319303216576801E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   7.5254170442790513E-01,  -1.7319303216576801E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,   1.7319303216576801E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -7.5254170442790513E-01,  -1.7319303216576801E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,   7.5254170442790513E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,   7.5254170442790513E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,  -7.5254170442790513E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,   7.5254170442790513E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,  -7.5254170442790513E-01,   1.7319303216576801E-01,   2.3832088994835054E-03],
            [   6.3536222480249072E-01,  -7.5254170442790513E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,   7.5254170442790513E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [  -6.3536222480249072E-01,  -7.5254170442790513E-01,  -1.7319303216576801E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,   7.5254170442790513E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,   7.5254170442790513E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,  -7.5254170442790513E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,   7.5254170442790513E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,  -7.5254170442790513E-01,   6.3536222480249072E-01,   2.3832088994835054E-03],
            [   1.7319303216576801E-01,  -7.5254170442790513E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,   7.5254170442790513E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [  -1.7319303216576801E-01,  -7.5254170442790513E-01,  -6.3536222480249072E-01,   2.3832088994835054E-03],
            [   6.6249270357317969E-01,   2.0176199587560609E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,   2.0176199587560609E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,  -2.0176199587560609E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,   2.0176199587560609E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,  -2.0176199587560609E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,  -2.0176199587560609E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,   2.0176199587560609E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,  -2.0176199587560609E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,   6.6249270357317969E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,   6.6249270357317969E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,  -6.6249270357317969E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,   6.6249270357317969E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,  -6.6249270357317969E-01,   7.2138444309022287E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,  -6.6249270357317969E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,   6.6249270357317969E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,  -6.6249270357317969E-01,  -7.2138444309022287E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,   6.6249270357317969E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,   6.6249270357317969E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,  -6.6249270357317969E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,   6.6249270357317969E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,  -6.6249270357317969E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,  -6.6249270357317969E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,   6.6249270357317969E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,  -6.6249270357317969E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,   2.0176199587560609E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,   2.0176199587560609E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,  -2.0176199587560609E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,   2.0176199587560609E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,  -2.0176199587560609E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   7.2138444309022287E-01,  -2.0176199587560609E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,   2.0176199587560609E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -7.2138444309022287E-01,  -2.0176199587560609E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,   7.2138444309022287E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,   7.2138444309022287E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,  -7.2138444309022287E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,   7.2138444309022287E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,  -7.2138444309022287E-01,   2.0176199587560609E-01,   2.3885849767438538E-03],
            [   6.6249270357317969E-01,  -7.2138444309022287E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,   7.2138444309022287E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [  -6.6249270357317969E-01,  -7.2138444309022287E-01,  -2.0176199587560609E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,   7.2138444309022287E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,   7.2138444309022287E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,  -7.2138444309022287E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,   7.2138444309022287E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,  -7.2138444309022287E-01,   6.6249270357317969E-01,   2.3885849767438538E-03],
            [   2.0176199587560609E-01,  -7.2138444309022287E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,   7.2138444309022287E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [  -2.0176199587560609E-01,  -7.2138444309022287E-01,  -6.6249270357317969E-01,   2.3885849767438538E-03],
            [   5.4849335080284878E-01,   2.8742197559073909E-02,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,   2.8742197559073909E-02,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,  -2.8742197559073909E-02,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,   2.8742197559073909E-02,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,  -2.8742197559073909E-02,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,  -2.8742197559073909E-02,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,   2.8742197559073909E-02,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,  -2.8742197559073909E-02,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,   5.4849335080284878E-01,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,   5.4849335080284878E-01,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,  -5.4849335080284878E-01,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,   5.4849335080284878E-01,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,  -5.4849335080284878E-01,   8.3566077459968069E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,  -5.4849335080284878E-01,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,   5.4849335080284878E-01,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,  -5.4849335080284878E-01,  -8.3566077459968069E-01,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,   5.4849335080284878E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,   5.4849335080284878E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,  -5.4849335080284878E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,   5.4849335080284878E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,  -5.4849335080284878E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,  -5.4849335080284878E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,   5.4849335080284878E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,  -5.4849335080284878E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,   2.8742197559073909E-02,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,   2.8742197559073909E-02,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,  -2.8742197559073909E-02,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,   2.8742197559073909E-02,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,  -2.8742197559073909E-02,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   8.3566077459968069E-01,  -2.8742197559073909E-02,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,   2.8742197559073909E-02,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -8.3566077459968069E-01,  -2.8742197559073909E-02,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,   8.3566077459968069E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,   8.3566077459968069E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,  -8.3566077459968069E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,   8.3566077459968069E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,  -8.3566077459968069E-01,   2.8742197559073909E-02,   2.3354914467290031E-03],
            [   5.4849335080284878E-01,  -8.3566077459968069E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,   8.3566077459968069E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [  -5.4849335080284878E-01,  -8.3566077459968069E-01,  -2.8742197559073909E-02,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,   8.3566077459968069E-01,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,   8.3566077459968069E-01,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,  -8.3566077459968069E-01,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,   8.3566077459968069E-01,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,  -8.3566077459968069E-01,   5.4849335080284878E-01,   2.3354914467290031E-03],
            [   2.8742197559073909E-02,  -8.3566077459968069E-01,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,   8.3566077459968069E-01,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [  -2.8742197559073909E-02,  -8.3566077459968069E-01,  -5.4849335080284878E-01,   2.3354914467290031E-03],
            [   5.8102076821421056E-01,   5.7783121237136949E-02,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,   5.7783121237136949E-02,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,  -5.7783121237136949E-02,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,   5.7783121237136949E-02,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,  -5.7783121237136949E-02,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,  -5.7783121237136949E-02,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,   5.7783121237136949E-02,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,  -5.7783121237136949E-02,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,   5.8102076821421056E-01,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,   5.8102076821421056E-01,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,  -5.8102076821421056E-01,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,   5.8102076821421056E-01,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,  -5.8102076821421056E-01,   8.1183494492653063E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,  -5.8102076821421056E-01,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,   5.8102076821421056E-01,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,  -5.8102076821421056E-01,  -8.1183494492653063E-01,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,   5.8102076821421056E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,   5.8102076821421056E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,  -5.8102076821421056E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,   5.8102076821421056E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,  -5.8102076821421056E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,  -5.8102076821421056E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,   5.8102076821421056E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,  -5.8102076821421056E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,   5.7783121237136949E-02,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,   5.7783121237136949E-02,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,  -5.7783121237136949E-02,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,   5.7783121237136949E-02,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,  -5.7783121237136949E-02,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   8.1183494492653063E-01,  -5.7783121237136949E-02,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,   5.7783121237136949E-02,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -8.1183494492653063E-01,  -5.7783121237136949E-02,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,   8.1183494492653063E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,   8.1183494492653063E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,  -8.1183494492653063E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,   8.1183494492653063E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,  -8.1183494492653063E-01,   5.7783121237136949E-02,   2.3577636404225407E-03],
            [   5.8102076821421056E-01,  -8.1183494492653063E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,   8.1183494492653063E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [  -5.8102076821421056E-01,  -8.1183494492653063E-01,  -5.7783121237136949E-02,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,   8.1183494492653063E-01,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,   8.1183494492653063E-01,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,  -8.1183494492653063E-01,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,   8.1183494492653063E-01,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,  -8.1183494492653063E-01,   5.8102076821421056E-01,   2.3577636404225407E-03],
            [   5.7783121237136949E-02,  -8.1183494492653063E-01,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,   8.1183494492653063E-01,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [  -5.7783121237136949E-02,  -8.1183494492653063E-01,  -5.8102076821421056E-01,   2.3577636404225407E-03],
            [   6.1209551971813525E-01,   8.6952623714395258E-02,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,   8.6952623714395258E-02,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,  -8.6952623714395258E-02,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,   8.6952623714395258E-02,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,  -8.6952623714395258E-02,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,  -8.6952623714395258E-02,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,   8.6952623714395258E-02,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,  -8.6952623714395258E-02,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,   6.1209551971813525E-01,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,   6.1209551971813525E-01,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,  -6.1209551971813525E-01,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,   6.1209551971813525E-01,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,  -6.1209551971813525E-01,   7.8598875053665285E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,  -6.1209551971813525E-01,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,   6.1209551971813525E-01,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,  -6.1209551971813525E-01,  -7.8598875053665285E-01,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,   6.1209551971813525E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,   6.1209551971813525E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,  -6.1209551971813525E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,   6.1209551971813525E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,  -6.1209551971813525E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,  -6.1209551971813525E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,   6.1209551971813525E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,  -6.1209551971813525E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,   8.6952623714395258E-02,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,   8.6952623714395258E-02,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,  -8.6952623714395258E-02,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,   8.6952623714395258E-02,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,  -8.6952623714395258E-02,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   7.8598875053665285E-01,  -8.6952623714395258E-02,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,   8.6952623714395258E-02,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -7.8598875053665285E-01,  -8.6952623714395258E-02,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,   7.8598875053665285E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,   7.8598875053665285E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,  -7.8598875053665285E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,   7.8598875053665285E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,  -7.8598875053665285E-01,   8.6952623714395258E-02,   2.3742956421701255E-03],
            [   6.1209551971813525E-01,  -7.8598875053665285E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,   7.8598875053665285E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [  -6.1209551971813525E-01,  -7.8598875053665285E-01,  -8.6952623714395258E-02,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,   7.8598875053665285E-01,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,   7.8598875053665285E-01,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,  -7.8598875053665285E-01,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,   7.8598875053665285E-01,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,  -7.8598875053665285E-01,   6.1209551971813525E-01,   2.3742956421701255E-03],
            [   8.6952623714395258E-02,  -7.8598875053665285E-01,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,   7.8598875053665285E-01,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [  -8.6952623714395258E-02,  -7.8598875053665285E-01,  -6.1209551971813525E-01,   2.3742956421701255E-03],
            [   6.4169442842943192E-01,   1.1608937670571660E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,   1.1608937670571660E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,  -1.1608937670571660E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,   1.1608937670571660E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,  -1.1608937670571660E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,  -1.1608937670571660E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,   1.1608937670571660E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,  -1.1608937670571660E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,   6.4169442842943192E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,   6.4169442842943192E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,  -6.4169442842943192E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,   6.4169442842943192E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,  -6.4169442842943192E-01,   7.5812368195348101E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,  -6.4169442842943192E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,   6.4169442842943192E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,  -6.4169442842943192E-01,  -7.5812368195348101E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,   6.4169442842943192E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,   6.4169442842943192E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,  -6.4169442842943192E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,   6.4169442842943192E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,  -6.4169442842943192E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,  -6.4169442842943192E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,   6.4169442842943192E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,  -6.4169442842943192E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,   1.1608937670571660E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,   1.1608937670571660E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,  -1.1608937670571660E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,   1.1608937670571660E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,  -1.1608937670571660E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   7.5812368195348101E-01,  -1.1608937670571660E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,   1.1608937670571660E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -7.5812368195348101E-01,  -1.1608937670571660E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,   7.5812368195348101E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,   7.5812368195348101E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,  -7.5812368195348101E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,   7.5812368195348101E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,  -7.5812368195348101E-01,   1.1608937670571660E-01,   2.3853089352924416E-03],
            [   6.4169442842943192E-01,  -7.5812368195348101E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,   7.5812368195348101E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [  -6.4169442842943192E-01,  -7.5812368195348101E-01,  -1.1608937670571660E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,   7.5812368195348101E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,   7.5812368195348101E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,  -7.5812368195348101E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,   7.5812368195348101E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,  -7.5812368195348101E-01,   6.4169442842943192E-01,   2.3853089352924416E-03],
            [   1.1608937670571660E-01,  -7.5812368195348101E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,   7.5812368195348101E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [  -1.1608937670571660E-01,  -7.5812368195348101E-01,  -6.4169442842943192E-01,   2.3853089352924416E-03],
            [   6.6979263917312604E-01,   1.4503788267432510E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,   1.4503788267432510E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,  -1.4503788267432510E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,   1.4503788267432510E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,  -1.4503788267432510E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,  -1.4503788267432510E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,   1.4503788267432510E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,  -1.4503788267432510E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,   6.6979263917312604E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,   6.6979263917312604E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,  -6.6979263917312604E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,   6.6979263917312604E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,  -6.6979263917312604E-01,   7.2824572302132151E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,  -6.6979263917312604E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,   6.6979263917312604E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,  -6.6979263917312604E-01,  -7.2824572302132151E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,   6.6979263917312604E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,   6.6979263917312604E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,  -6.6979263917312604E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,   6.6979263917312604E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,  -6.6979263917312604E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,  -6.6979263917312604E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,   6.6979263917312604E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,  -6.6979263917312604E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,   1.4503788267432510E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,   1.4503788267432510E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,  -1.4503788267432510E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,   1.4503788267432510E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,  -1.4503788267432510E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   7.2824572302132151E-01,  -1.4503788267432510E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,   1.4503788267432510E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -7.2824572302132151E-01,  -1.4503788267432510E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,   7.2824572302132151E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,   7.2824572302132151E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,  -7.2824572302132151E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,   7.2824572302132151E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,  -7.2824572302132151E-01,   1.4503788267432510E-01,   2.3911037931924183E-03],
            [   6.6979263917312604E-01,  -7.2824572302132151E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,   7.2824572302132151E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [  -6.6979263917312604E-01,  -7.2824572302132151E-01,  -1.4503788267432510E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,   7.2824572302132151E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,   7.2824572302132151E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,  -7.2824572302132151E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,   7.2824572302132151E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,  -7.2824572302132151E-01,   6.6979263917312604E-01,   2.3911037931924183E-03],
            [   1.4503788267432510E-01,  -7.2824572302132151E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,   7.2824572302132151E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [  -1.4503788267432510E-01,  -7.2824572302132151E-01,  -6.6979263917312604E-01,   2.3911037931924183E-03],
            [   6.1475943905854880E-01,   2.9049576223414562E-02,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,   2.9049576223414562E-02,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,  -2.9049576223414562E-02,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,   2.9049576223414562E-02,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,  -2.9049576223414562E-02,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,  -2.9049576223414562E-02,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,   2.9049576223414562E-02,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,  -2.9049576223414562E-02,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,   6.1475943905854880E-01,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,   6.1475943905854880E-01,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,  -6.1475943905854880E-01,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,   6.1475943905854880E-01,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,  -6.1475943905854880E-01,   7.8817951902447869E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,  -6.1475943905854880E-01,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,   6.1475943905854880E-01,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,  -6.1475943905854880E-01,  -7.8817951902447869E-01,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,   6.1475943905854880E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,   6.1475943905854880E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,  -6.1475943905854880E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,   6.1475943905854880E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,  -6.1475943905854880E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,  -6.1475943905854880E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,   6.1475943905854880E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,  -6.1475943905854880E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,   2.9049576223414562E-02,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,   2.9049576223414562E-02,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,  -2.9049576223414562E-02,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,   2.9049576223414562E-02,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,  -2.9049576223414562E-02,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   7.8817951902447869E-01,  -2.9049576223414562E-02,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,   2.9049576223414562E-02,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -7.8817951902447869E-01,  -2.9049576223414562E-02,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,   7.8817951902447869E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,   7.8817951902447869E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,  -7.8817951902447869E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,   7.8817951902447869E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,  -7.8817951902447869E-01,   2.9049576223414562E-02,   2.3752019321705451E-03],
            [   6.1475943905854880E-01,  -7.8817951902447869E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,   7.8817951902447869E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [  -6.1475943905854880E-01,  -7.8817951902447869E-01,  -2.9049576223414562E-02,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,   7.8817951902447869E-01,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,   7.8817951902447869E-01,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,  -7.8817951902447869E-01,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,   7.8817951902447869E-01,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,  -7.8817951902447869E-01,   6.1475943905854880E-01,   2.3752019321705451E-03],
            [   2.9049576223414562E-02,  -7.8817951902447869E-01,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,   7.8817951902447869E-01,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [  -2.9049576223414562E-02,  -7.8817951902447869E-01,  -6.1475943905854880E-01,   2.3752019321705451E-03],
            [   6.4553900263567832E-01,   5.8238091526171973E-02,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,   5.8238091526171973E-02,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,  -5.8238091526171973E-02,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,   5.8238091526171973E-02,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,  -5.8238091526171973E-02,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,  -5.8238091526171973E-02,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,   5.8238091526171973E-02,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,  -5.8238091526171973E-02,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,   6.4553900263567832E-01,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,   6.4553900263567832E-01,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,  -6.4553900263567832E-01,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,   6.4553900263567832E-01,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,  -6.4553900263567832E-01,   7.6150359209364404E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,  -6.4553900263567832E-01,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,   6.4553900263567832E-01,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,  -6.4553900263567832E-01,  -7.6150359209364404E-01,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,   6.4553900263567832E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,   6.4553900263567832E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,  -6.4553900263567832E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,   6.4553900263567832E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,  -6.4553900263567832E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,  -6.4553900263567832E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,   6.4553900263567832E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,  -6.4553900263567832E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,   5.8238091526171973E-02,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,   5.8238091526171973E-02,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,  -5.8238091526171973E-02,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,   5.8238091526171973E-02,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,  -5.8238091526171973E-02,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   7.6150359209364404E-01,  -5.8238091526171973E-02,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,   5.8238091526171973E-02,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -7.6150359209364404E-01,  -5.8238091526171973E-02,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,   7.6150359209364404E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,   7.6150359209364404E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,  -7.6150359209364404E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,   7.6150359209364404E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,  -7.6150359209364404E-01,   5.8238091526171973E-02,   2.3868999616292485E-03],
            [   6.4553900263567832E-01,  -7.6150359209364404E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,   7.6150359209364404E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [  -6.4553900263567832E-01,  -7.6150359209364404E-01,  -5.8238091526171973E-02,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,   7.6150359209364404E-01,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,   7.6150359209364404E-01,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,  -7.6150359209364404E-01,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,   7.6150359209364404E-01,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,  -7.6150359209364404E-01,   6.4553900263567832E-01,   2.3868999616292485E-03],
            [   5.8238091526171973E-02,  -7.6150359209364404E-01,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,   7.6150359209364404E-01,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [  -5.8238091526171973E-02,  -7.6150359209364404E-01,  -6.4553900263567832E-01,   2.3868999616292485E-03],
            [   6.7472585883654768E-01,   8.7403848998847150E-02,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,   8.7403848998847150E-02,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,  -8.7403848998847150E-02,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,   8.7403848998847150E-02,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,  -8.7403848998847150E-02,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,  -8.7403848998847150E-02,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,   8.7403848998847150E-02,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,  -8.7403848998847150E-02,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,   6.7472585883654768E-01,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,   6.7472585883654768E-01,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,  -6.7472585883654768E-01,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,   6.7472585883654768E-01,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,  -6.7472585883654768E-01,   7.3287487513044813E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,  -6.7472585883654768E-01,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,   6.7472585883654768E-01,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,  -6.7472585883654768E-01,  -7.3287487513044813E-01,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,   6.7472585883654768E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,   6.7472585883654768E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,  -6.7472585883654768E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,   6.7472585883654768E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,  -6.7472585883654768E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,  -6.7472585883654768E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,   6.7472585883654768E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,  -6.7472585883654768E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,   8.7403848998847150E-02,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,   8.7403848998847150E-02,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,  -8.7403848998847150E-02,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,   8.7403848998847150E-02,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,  -8.7403848998847150E-02,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   7.3287487513044813E-01,  -8.7403848998847150E-02,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,   8.7403848998847150E-02,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -7.3287487513044813E-01,  -8.7403848998847150E-02,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,   7.3287487513044813E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,   7.3287487513044813E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,  -7.3287487513044813E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,   7.3287487513044813E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,  -7.3287487513044813E-01,   8.7403848998847150E-02,   2.3932914929724667E-03],
            [   6.7472585883654768E-01,  -7.3287487513044813E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,   7.3287487513044813E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [  -6.7472585883654768E-01,  -7.3287487513044813E-01,  -8.7403848998847150E-02,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,   7.3287487513044813E-01,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,   7.3287487513044813E-01,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,  -7.3287487513044813E-01,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,   7.3287487513044813E-01,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,  -7.3287487513044813E-01,   6.7472585883654768E-01,   2.3932914929724667E-03],
            [   8.7403848998847150E-02,  -7.3287487513044813E-01,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,   7.3287487513044813E-01,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [  -8.7403848998847150E-02,  -7.3287487513044813E-01,  -6.7472585883654768E-01,   2.3932914929724667E-03],
            [   6.7721357503953472E-01,   2.9199461358081050E-02,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,   2.9199461358081050E-02,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,  -2.9199461358081050E-02,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,   2.9199461358081050E-02,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,  -2.9199461358081050E-02,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,  -2.9199461358081050E-02,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,   2.9199461358081050E-02,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,  -2.9199461358081050E-02,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,   6.7721357503953472E-01,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,   6.7721357503953472E-01,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,  -6.7721357503953472E-01,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,   6.7721357503953472E-01,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,  -6.7721357503953472E-01,   7.3520688601139372E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,  -6.7721357503953472E-01,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,   6.7721357503953472E-01,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,  -6.7721357503953472E-01,  -7.3520688601139372E-01,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,   6.7721357503953472E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,   6.7721357503953472E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,  -6.7721357503953472E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,   6.7721357503953472E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,  -6.7721357503953472E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,  -6.7721357503953472E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,   6.7721357503953472E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,  -6.7721357503953472E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,   2.9199461358081050E-02,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,   2.9199461358081050E-02,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,  -2.9199461358081050E-02,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,   2.9199461358081050E-02,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,  -2.9199461358081050E-02,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   7.3520688601139372E-01,  -2.9199461358081050E-02,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,   2.9199461358081050E-02,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -7.3520688601139372E-01,  -2.9199461358081050E-02,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,   7.3520688601139372E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,   7.3520688601139372E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,  -7.3520688601139372E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,   7.3520688601139372E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,  -7.3520688601139372E-01,   2.9199461358081050E-02,   2.3945652729545647E-03],
            [   6.7721357503953472E-01,  -7.3520688601139372E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,   7.3520688601139372E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [  -6.7721357503953472E-01,  -7.3520688601139372E-01,  -2.9199461358081050E-02,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,   7.3520688601139372E-01,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,   7.3520688601139372E-01,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,  -7.3520688601139372E-01,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,   7.3520688601139372E-01,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,  -7.3520688601139372E-01,   6.7721357503953472E-01,   2.3945652729545647E-03],
            [   2.9199461358081050E-02,  -7.3520688601139372E-01,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,   7.3520688601139372E-01,  -6.7721357503953472E-01,   2.3945652729545647E-03],
            [  -2.9199461358081050E-02,  -7.3520688601139372E-01,  -6.7721357503953472E-01,   2.3945652729545647E-03],
        ])
  
        order = 131
  
        return Lebedev(order,xyzw)

